#include "tree_sitter/parser.h"

#if defined(__GNUC__) || defined(__clang__)
#pragma GCC diagnostic ignored "-Wmissing-field-initializers"
#endif

#define LANGUAGE_VERSION 14
#define STATE_COUNT 1404
#define LARGE_STATE_COUNT 28
#define SYMBOL_COUNT 212
#define ALIAS_COUNT 5
#define TOKEN_COUNT 94
#define EXTERNAL_TOKEN_COUNT 0
#define FIELD_COUNT 35
#define MAX_ALIAS_SEQUENCE_LENGTH 9
#define PRODUCTION_ID_COUNT 109

enum ts_symbol_identifiers {
  sym_identifier = 1,
  aux_sym_source_file_token1 = 2,
  anon_sym_SEMI = 3,
  anon_sym_NULL = 4,
  anon_sym_package = 5,
  anon_sym_import = 6,
  anon_sym_DOT = 7,
  sym_blank_identifier = 8,
  anon_sym_LPAREN = 9,
  anon_sym_RPAREN = 10,
  anon_sym_const = 11,
  anon_sym_COMMA = 12,
  anon_sym_EQ = 13,
  anon_sym_var = 14,
  anon_sym_func = 15,
  anon_sym_LBRACK = 16,
  anon_sym_RBRACK = 17,
  anon_sym_DOT_DOT_DOT = 18,
  anon_sym_type = 19,
  anon_sym_STAR = 20,
  anon_sym_struct = 21,
  anon_sym_TILDE = 22,
  anon_sym_LBRACE = 23,
  anon_sym_RBRACE = 24,
  anon_sym_interface = 25,
  anon_sym_PIPE = 26,
  anon_sym_map = 27,
  anon_sym_chan = 28,
  anon_sym_LT_DASH = 29,
  anon_sym_COLON_EQ = 30,
  anon_sym_PLUS_PLUS = 31,
  anon_sym_DASH_DASH = 32,
  anon_sym_STAR_EQ = 33,
  anon_sym_SLASH_EQ = 34,
  anon_sym_PERCENT_EQ = 35,
  anon_sym_LT_LT_EQ = 36,
  anon_sym_GT_GT_EQ = 37,
  anon_sym_AMP_EQ = 38,
  anon_sym_AMP_CARET_EQ = 39,
  anon_sym_PLUS_EQ = 40,
  anon_sym_DASH_EQ = 41,
  anon_sym_PIPE_EQ = 42,
  anon_sym_CARET_EQ = 43,
  anon_sym_COLON = 44,
  anon_sym_fallthrough = 45,
  anon_sym_break = 46,
  anon_sym_continue = 47,
  anon_sym_goto = 48,
  anon_sym_return = 49,
  anon_sym_go = 50,
  anon_sym_defer = 51,
  anon_sym_if = 52,
  anon_sym_else = 53,
  anon_sym_for = 54,
  anon_sym_range = 55,
  anon_sym_switch = 56,
  anon_sym_case = 57,
  anon_sym_default = 58,
  anon_sym_select = 59,
  anon_sym_new = 60,
  anon_sym_make = 61,
  anon_sym_PLUS = 62,
  anon_sym_DASH = 63,
  anon_sym_BANG = 64,
  anon_sym_CARET = 65,
  anon_sym_AMP = 66,
  anon_sym_SLASH = 67,
  anon_sym_PERCENT = 68,
  anon_sym_LT_LT = 69,
  anon_sym_GT_GT = 70,
  anon_sym_AMP_CARET = 71,
  anon_sym_EQ_EQ = 72,
  anon_sym_BANG_EQ = 73,
  anon_sym_LT = 74,
  anon_sym_LT_EQ = 75,
  anon_sym_GT = 76,
  anon_sym_GT_EQ = 77,
  anon_sym_AMP_AMP = 78,
  anon_sym_PIPE_PIPE = 79,
  sym_raw_string_literal = 80,
  anon_sym_DQUOTE = 81,
  anon_sym_DQUOTE2 = 82,
  sym__interpreted_string_literal_basic_content = 83,
  sym_escape_sequence = 84,
  sym_int_literal = 85,
  sym_float_literal = 86,
  sym_imaginary_literal = 87,
  sym_rune_literal = 88,
  sym_nil = 89,
  sym_true = 90,
  sym_false = 91,
  sym_iota = 92,
  sym_comment = 93,
  sym_source_file = 94,
  sym_package_clause = 95,
  sym_import_declaration = 96,
  sym_import_spec = 97,
  sym_dot = 98,
  sym_import_spec_list = 99,
  sym__declaration = 100,
  sym_const_declaration = 101,
  sym_const_spec = 102,
  sym_var_declaration = 103,
  sym_var_spec = 104,
  sym_var_spec_list = 105,
  sym_function_declaration = 106,
  sym_method_declaration = 107,
  sym_type_parameter_list = 108,
  sym_type_parameter_declaration = 109,
  sym_parameter_list = 110,
  sym_parameter_declaration = 111,
  sym_variadic_parameter_declaration = 112,
  sym_type_alias = 113,
  sym_type_declaration = 114,
  sym_type_spec = 115,
  sym_expression_list = 116,
  sym_parenthesized_type = 117,
  sym__simple_type = 118,
  sym_generic_type = 119,
  sym_type_arguments = 120,
  sym_pointer_type = 121,
  sym_array_type = 122,
  sym_implicit_length_array_type = 123,
  sym_slice_type = 124,
  sym_struct_type = 125,
  sym_negated_type = 126,
  sym_field_declaration_list = 127,
  sym_field_declaration = 128,
  sym_interface_type = 129,
  sym_method_elem = 130,
  sym_type_elem = 131,
  sym_map_type = 132,
  sym_channel_type = 133,
  sym_function_type = 134,
  sym_block = 135,
  sym__statement_list = 136,
  sym__statement = 137,
  sym_empty_statement = 138,
  sym__simple_statement = 139,
  sym_expression_statement = 140,
  sym_send_statement = 141,
  sym_receive_statement = 142,
  sym_inc_statement = 143,
  sym_dec_statement = 144,
  sym_assignment_statement = 145,
  sym_short_var_declaration = 146,
  sym_labeled_statement = 147,
  sym_empty_labeled_statement = 148,
  sym_fallthrough_statement = 149,
  sym_break_statement = 150,
  sym_continue_statement = 151,
  sym_goto_statement = 152,
  sym_return_statement = 153,
  sym_go_statement = 154,
  sym_defer_statement = 155,
  sym_if_statement = 156,
  sym_for_statement = 157,
  sym_for_clause = 158,
  sym_range_clause = 159,
  sym_expression_switch_statement = 160,
  sym_expression_case = 161,
  sym_default_case = 162,
  sym_type_switch_statement = 163,
  sym__type_switch_header = 164,
  sym_type_case = 165,
  sym_select_statement = 166,
  sym_communication_case = 167,
  sym__expression = 168,
  sym_parenthesized_expression = 169,
  sym_call_expression = 170,
  sym_variadic_argument = 171,
  sym_special_argument_list = 172,
  sym_argument_list = 173,
  sym_selector_expression = 174,
  sym_index_expression = 175,
  sym_slice_expression = 176,
  sym_type_assertion_expression = 177,
  sym_type_conversion_expression = 178,
  sym_type_instantiation_expression = 179,
  sym_composite_literal = 180,
  sym_literal_value = 181,
  sym_literal_element = 182,
  sym_keyed_element = 183,
  sym_func_literal = 184,
  sym_unary_expression = 185,
  sym_binary_expression = 186,
  sym_qualified_type = 187,
  sym_interpreted_string_literal = 188,
  aux_sym_source_file_repeat1 = 189,
  aux_sym_import_spec_list_repeat1 = 190,
  aux_sym_const_declaration_repeat1 = 191,
  aux_sym_const_spec_repeat1 = 192,
  aux_sym_var_spec_repeat1 = 193,
  aux_sym_var_spec_list_repeat1 = 194,
  aux_sym_type_parameter_list_repeat1 = 195,
  aux_sym_parameter_list_repeat1 = 196,
  aux_sym_type_declaration_repeat1 = 197,
  aux_sym_expression_list_repeat1 = 198,
  aux_sym_type_arguments_repeat1 = 199,
  aux_sym_field_declaration_list_repeat1 = 200,
  aux_sym_field_declaration_repeat1 = 201,
  aux_sym_interface_type_repeat1 = 202,
  aux_sym_type_elem_repeat1 = 203,
  aux_sym__statement_list_repeat1 = 204,
  aux_sym_expression_switch_statement_repeat1 = 205,
  aux_sym_type_switch_statement_repeat1 = 206,
  aux_sym_type_case_repeat1 = 207,
  aux_sym_select_statement_repeat1 = 208,
  aux_sym_argument_list_repeat1 = 209,
  aux_sym_literal_value_repeat1 = 210,
  aux_sym_interpreted_string_literal_repeat1 = 211,
  alias_sym_field_identifier = 212,
  alias_sym_label_name = 213,
  alias_sym_package_identifier = 214,
  alias_sym_type_constraint = 215,
  alias_sym_type_identifier = 216,
};

static const char * const ts_symbol_names[] = {
  [ts_builtin_sym_end] = "end",
  [sym_identifier] = "identifier",
  [aux_sym_source_file_token1] = "source_file_token1",
  [anon_sym_SEMI] = ";",
  [anon_sym_NULL] = "\0",
  [anon_sym_package] = "package",
  [anon_sym_import] = "import",
  [anon_sym_DOT] = ".",
  [sym_blank_identifier] = "blank_identifier",
  [anon_sym_LPAREN] = "(",
  [anon_sym_RPAREN] = ")",
  [anon_sym_const] = "const",
  [anon_sym_COMMA] = ",",
  [anon_sym_EQ] = "=",
  [anon_sym_var] = "var",
  [anon_sym_func] = "func",
  [anon_sym_LBRACK] = "[",
  [anon_sym_RBRACK] = "]",
  [anon_sym_DOT_DOT_DOT] = "...",
  [anon_sym_type] = "type",
  [anon_sym_STAR] = "*",
  [anon_sym_struct] = "struct",
  [anon_sym_TILDE] = "~",
  [anon_sym_LBRACE] = "{",
  [anon_sym_RBRACE] = "}",
  [anon_sym_interface] = "interface",
  [anon_sym_PIPE] = "|",
  [anon_sym_map] = "map",
  [anon_sym_chan] = "chan",
  [anon_sym_LT_DASH] = "<-",
  [anon_sym_COLON_EQ] = ":=",
  [anon_sym_PLUS_PLUS] = "++",
  [anon_sym_DASH_DASH] = "--",
  [anon_sym_STAR_EQ] = "*=",
  [anon_sym_SLASH_EQ] = "/=",
  [anon_sym_PERCENT_EQ] = "%=",
  [anon_sym_LT_LT_EQ] = "<<=",
  [anon_sym_GT_GT_EQ] = ">>=",
  [anon_sym_AMP_EQ] = "&=",
  [anon_sym_AMP_CARET_EQ] = "&^=",
  [anon_sym_PLUS_EQ] = "+=",
  [anon_sym_DASH_EQ] = "-=",
  [anon_sym_PIPE_EQ] = "|=",
  [anon_sym_CARET_EQ] = "^=",
  [anon_sym_COLON] = ":",
  [anon_sym_fallthrough] = "fallthrough",
  [anon_sym_break] = "break",
  [anon_sym_continue] = "continue",
  [anon_sym_goto] = "goto",
  [anon_sym_return] = "return",
  [anon_sym_go] = "go",
  [anon_sym_defer] = "defer",
  [anon_sym_if] = "if",
  [anon_sym_else] = "else",
  [anon_sym_for] = "for",
  [anon_sym_range] = "range",
  [anon_sym_switch] = "switch",
  [anon_sym_case] = "case",
  [anon_sym_default] = "default",
  [anon_sym_select] = "select",
  [anon_sym_new] = "identifier",
  [anon_sym_make] = "identifier",
  [anon_sym_PLUS] = "+",
  [anon_sym_DASH] = "-",
  [anon_sym_BANG] = "!",
  [anon_sym_CARET] = "^",
  [anon_sym_AMP] = "&",
  [anon_sym_SLASH] = "/",
  [anon_sym_PERCENT] = "%",
  [anon_sym_LT_LT] = "<<",
  [anon_sym_GT_GT] = ">>",
  [anon_sym_AMP_CARET] = "&^",
  [anon_sym_EQ_EQ] = "==",
  [anon_sym_BANG_EQ] = "!=",
  [anon_sym_LT] = "<",
  [anon_sym_LT_EQ] = "<=",
  [anon_sym_GT] = ">",
  [anon_sym_GT_EQ] = ">=",
  [anon_sym_AMP_AMP] = "&&",
  [anon_sym_PIPE_PIPE] = "||",
  [sym_raw_string_literal] = "raw_string_literal",
  [anon_sym_DQUOTE] = "\"",
  [anon_sym_DQUOTE2] = "\"",
  [sym__interpreted_string_literal_basic_content] = "_interpreted_string_literal_basic_content",
  [sym_escape_sequence] = "escape_sequence",
  [sym_int_literal] = "int_literal",
  [sym_float_literal] = "float_literal",
  [sym_imaginary_literal] = "imaginary_literal",
  [sym_rune_literal] = "rune_literal",
  [sym_nil] = "nil",
  [sym_true] = "true",
  [sym_false] = "false",
  [sym_iota] = "iota",
  [sym_comment] = "comment",
  [sym_source_file] = "source_file",
  [sym_package_clause] = "package_clause",
  [sym_import_declaration] = "import_declaration",
  [sym_import_spec] = "import_spec",
  [sym_dot] = "dot",
  [sym_import_spec_list] = "import_spec_list",
  [sym__declaration] = "_declaration",
  [sym_const_declaration] = "const_declaration",
  [sym_const_spec] = "const_spec",
  [sym_var_declaration] = "var_declaration",
  [sym_var_spec] = "var_spec",
  [sym_var_spec_list] = "var_spec_list",
  [sym_function_declaration] = "function_declaration",
  [sym_method_declaration] = "method_declaration",
  [sym_type_parameter_list] = "type_parameter_list",
  [sym_type_parameter_declaration] = "type_parameter_declaration",
  [sym_parameter_list] = "parameter_list",
  [sym_parameter_declaration] = "parameter_declaration",
  [sym_variadic_parameter_declaration] = "variadic_parameter_declaration",
  [sym_type_alias] = "type_alias",
  [sym_type_declaration] = "type_declaration",
  [sym_type_spec] = "type_spec",
  [sym_expression_list] = "expression_list",
  [sym_parenthesized_type] = "parenthesized_type",
  [sym__simple_type] = "_simple_type",
  [sym_generic_type] = "generic_type",
  [sym_type_arguments] = "type_arguments",
  [sym_pointer_type] = "pointer_type",
  [sym_array_type] = "array_type",
  [sym_implicit_length_array_type] = "implicit_length_array_type",
  [sym_slice_type] = "slice_type",
  [sym_struct_type] = "struct_type",
  [sym_negated_type] = "negated_type",
  [sym_field_declaration_list] = "field_declaration_list",
  [sym_field_declaration] = "field_declaration",
  [sym_interface_type] = "interface_type",
  [sym_method_elem] = "method_elem",
  [sym_type_elem] = "type_elem",
  [sym_map_type] = "map_type",
  [sym_channel_type] = "channel_type",
  [sym_function_type] = "function_type",
  [sym_block] = "block",
  [sym__statement_list] = "_statement_list",
  [sym__statement] = "_statement",
  [sym_empty_statement] = "empty_statement",
  [sym__simple_statement] = "_simple_statement",
  [sym_expression_statement] = "expression_statement",
  [sym_send_statement] = "send_statement",
  [sym_receive_statement] = "receive_statement",
  [sym_inc_statement] = "inc_statement",
  [sym_dec_statement] = "dec_statement",
  [sym_assignment_statement] = "assignment_statement",
  [sym_short_var_declaration] = "short_var_declaration",
  [sym_labeled_statement] = "labeled_statement",
  [sym_empty_labeled_statement] = "labeled_statement",
  [sym_fallthrough_statement] = "fallthrough_statement",
  [sym_break_statement] = "break_statement",
  [sym_continue_statement] = "continue_statement",
  [sym_goto_statement] = "goto_statement",
  [sym_return_statement] = "return_statement",
  [sym_go_statement] = "go_statement",
  [sym_defer_statement] = "defer_statement",
  [sym_if_statement] = "if_statement",
  [sym_for_statement] = "for_statement",
  [sym_for_clause] = "for_clause",
  [sym_range_clause] = "range_clause",
  [sym_expression_switch_statement] = "expression_switch_statement",
  [sym_expression_case] = "expression_case",
  [sym_default_case] = "default_case",
  [sym_type_switch_statement] = "type_switch_statement",
  [sym__type_switch_header] = "_type_switch_header",
  [sym_type_case] = "type_case",
  [sym_select_statement] = "select_statement",
  [sym_communication_case] = "communication_case",
  [sym__expression] = "_expression",
  [sym_parenthesized_expression] = "parenthesized_expression",
  [sym_call_expression] = "call_expression",
  [sym_variadic_argument] = "variadic_argument",
  [sym_special_argument_list] = "argument_list",
  [sym_argument_list] = "argument_list",
  [sym_selector_expression] = "selector_expression",
  [sym_index_expression] = "index_expression",
  [sym_slice_expression] = "slice_expression",
  [sym_type_assertion_expression] = "type_assertion_expression",
  [sym_type_conversion_expression] = "type_conversion_expression",
  [sym_type_instantiation_expression] = "type_instantiation_expression",
  [sym_composite_literal] = "composite_literal",
  [sym_literal_value] = "literal_value",
  [sym_literal_element] = "literal_element",
  [sym_keyed_element] = "keyed_element",
  [sym_func_literal] = "func_literal",
  [sym_unary_expression] = "unary_expression",
  [sym_binary_expression] = "binary_expression",
  [sym_qualified_type] = "qualified_type",
  [sym_interpreted_string_literal] = "interpreted_string_literal",
  [aux_sym_source_file_repeat1] = "source_file_repeat1",
  [aux_sym_import_spec_list_repeat1] = "import_spec_list_repeat1",
  [aux_sym_const_declaration_repeat1] = "const_declaration_repeat1",
  [aux_sym_const_spec_repeat1] = "const_spec_repeat1",
  [aux_sym_var_spec_repeat1] = "var_spec_repeat1",
  [aux_sym_var_spec_list_repeat1] = "var_spec_list_repeat1",
  [aux_sym_type_parameter_list_repeat1] = "type_parameter_list_repeat1",
  [aux_sym_parameter_list_repeat1] = "parameter_list_repeat1",
  [aux_sym_type_declaration_repeat1] = "type_declaration_repeat1",
  [aux_sym_expression_list_repeat1] = "expression_list_repeat1",
  [aux_sym_type_arguments_repeat1] = "type_arguments_repeat1",
  [aux_sym_field_declaration_list_repeat1] = "field_declaration_list_repeat1",
  [aux_sym_field_declaration_repeat1] = "field_declaration_repeat1",
  [aux_sym_interface_type_repeat1] = "interface_type_repeat1",
  [aux_sym_type_elem_repeat1] = "type_elem_repeat1",
  [aux_sym__statement_list_repeat1] = "_statement_list_repeat1",
  [aux_sym_expression_switch_statement_repeat1] = "expression_switch_statement_repeat1",
  [aux_sym_type_switch_statement_repeat1] = "type_switch_statement_repeat1",
  [aux_sym_type_case_repeat1] = "type_case_repeat1",
  [aux_sym_select_statement_repeat1] = "select_statement_repeat1",
  [aux_sym_argument_list_repeat1] = "argument_list_repeat1",
  [aux_sym_literal_value_repeat1] = "literal_value_repeat1",
  [aux_sym_interpreted_string_literal_repeat1] = "interpreted_string_literal_repeat1",
  [alias_sym_field_identifier] = "field_identifier",
  [alias_sym_label_name] = "label_name",
  [alias_sym_package_identifier] = "package_identifier",
  [alias_sym_type_constraint] = "type_constraint",
  [alias_sym_type_identifier] = "type_identifier",
};

static const TSSymbol ts_symbol_map[] = {
  [ts_builtin_sym_end] = ts_builtin_sym_end,
  [sym_identifier] = sym_identifier,
  [aux_sym_source_file_token1] = aux_sym_source_file_token1,
  [anon_sym_SEMI] = anon_sym_SEMI,
  [anon_sym_NULL] = anon_sym_NULL,
  [anon_sym_package] = anon_sym_package,
  [anon_sym_import] = anon_sym_import,
  [anon_sym_DOT] = anon_sym_DOT,
  [sym_blank_identifier] = sym_blank_identifier,
  [anon_sym_LPAREN] = anon_sym_LPAREN,
  [anon_sym_RPAREN] = anon_sym_RPAREN,
  [anon_sym_const] = anon_sym_const,
  [anon_sym_COMMA] = anon_sym_COMMA,
  [anon_sym_EQ] = anon_sym_EQ,
  [anon_sym_var] = anon_sym_var,
  [anon_sym_func] = anon_sym_func,
  [anon_sym_LBRACK] = anon_sym_LBRACK,
  [anon_sym_RBRACK] = anon_sym_RBRACK,
  [anon_sym_DOT_DOT_DOT] = anon_sym_DOT_DOT_DOT,
  [anon_sym_type] = anon_sym_type,
  [anon_sym_STAR] = anon_sym_STAR,
  [anon_sym_struct] = anon_sym_struct,
  [anon_sym_TILDE] = anon_sym_TILDE,
  [anon_sym_LBRACE] = anon_sym_LBRACE,
  [anon_sym_RBRACE] = anon_sym_RBRACE,
  [anon_sym_interface] = anon_sym_interface,
  [anon_sym_PIPE] = anon_sym_PIPE,
  [anon_sym_map] = anon_sym_map,
  [anon_sym_chan] = anon_sym_chan,
  [anon_sym_LT_DASH] = anon_sym_LT_DASH,
  [anon_sym_COLON_EQ] = anon_sym_COLON_EQ,
  [anon_sym_PLUS_PLUS] = anon_sym_PLUS_PLUS,
  [anon_sym_DASH_DASH] = anon_sym_DASH_DASH,
  [anon_sym_STAR_EQ] = anon_sym_STAR_EQ,
  [anon_sym_SLASH_EQ] = anon_sym_SLASH_EQ,
  [anon_sym_PERCENT_EQ] = anon_sym_PERCENT_EQ,
  [anon_sym_LT_LT_EQ] = anon_sym_LT_LT_EQ,
  [anon_sym_GT_GT_EQ] = anon_sym_GT_GT_EQ,
  [anon_sym_AMP_EQ] = anon_sym_AMP_EQ,
  [anon_sym_AMP_CARET_EQ] = anon_sym_AMP_CARET_EQ,
  [anon_sym_PLUS_EQ] = anon_sym_PLUS_EQ,
  [anon_sym_DASH_EQ] = anon_sym_DASH_EQ,
  [anon_sym_PIPE_EQ] = anon_sym_PIPE_EQ,
  [anon_sym_CARET_EQ] = anon_sym_CARET_EQ,
  [anon_sym_COLON] = anon_sym_COLON,
  [anon_sym_fallthrough] = anon_sym_fallthrough,
  [anon_sym_break] = anon_sym_break,
  [anon_sym_continue] = anon_sym_continue,
  [anon_sym_goto] = anon_sym_goto,
  [anon_sym_return] = anon_sym_return,
  [anon_sym_go] = anon_sym_go,
  [anon_sym_defer] = anon_sym_defer,
  [anon_sym_if] = anon_sym_if,
  [anon_sym_else] = anon_sym_else,
  [anon_sym_for] = anon_sym_for,
  [anon_sym_range] = anon_sym_range,
  [anon_sym_switch] = anon_sym_switch,
  [anon_sym_case] = anon_sym_case,
  [anon_sym_default] = anon_sym_default,
  [anon_sym_select] = anon_sym_select,
  [anon_sym_new] = sym_identifier,
  [anon_sym_make] = sym_identifier,
  [anon_sym_PLUS] = anon_sym_PLUS,
  [anon_sym_DASH] = anon_sym_DASH,
  [anon_sym_BANG] = anon_sym_BANG,
  [anon_sym_CARET] = anon_sym_CARET,
  [anon_sym_AMP] = anon_sym_AMP,
  [anon_sym_SLASH] = anon_sym_SLASH,
  [anon_sym_PERCENT] = anon_sym_PERCENT,
  [anon_sym_LT_LT] = anon_sym_LT_LT,
  [anon_sym_GT_GT] = anon_sym_GT_GT,
  [anon_sym_AMP_CARET] = anon_sym_AMP_CARET,
  [anon_sym_EQ_EQ] = anon_sym_EQ_EQ,
  [anon_sym_BANG_EQ] = anon_sym_BANG_EQ,
  [anon_sym_LT] = anon_sym_LT,
  [anon_sym_LT_EQ] = anon_sym_LT_EQ,
  [anon_sym_GT] = anon_sym_GT,
  [anon_sym_GT_EQ] = anon_sym_GT_EQ,
  [anon_sym_AMP_AMP] = anon_sym_AMP_AMP,
  [anon_sym_PIPE_PIPE] = anon_sym_PIPE_PIPE,
  [sym_raw_string_literal] = sym_raw_string_literal,
  [anon_sym_DQUOTE] = anon_sym_DQUOTE,
  [anon_sym_DQUOTE2] = anon_sym_DQUOTE,
  [sym__interpreted_string_literal_basic_content] = sym__interpreted_string_literal_basic_content,
  [sym_escape_sequence] = sym_escape_sequence,
  [sym_int_literal] = sym_int_literal,
  [sym_float_literal] = sym_float_literal,
  [sym_imaginary_literal] = sym_imaginary_literal,
  [sym_rune_literal] = sym_rune_literal,
  [sym_nil] = sym_nil,
  [sym_true] = sym_true,
  [sym_false] = sym_false,
  [sym_iota] = sym_iota,
  [sym_comment] = sym_comment,
  [sym_source_file] = sym_source_file,
  [sym_package_clause] = sym_package_clause,
  [sym_import_declaration] = sym_import_declaration,
  [sym_import_spec] = sym_import_spec,
  [sym_dot] = sym_dot,
  [sym_import_spec_list] = sym_import_spec_list,
  [sym__declaration] = sym__declaration,
  [sym_const_declaration] = sym_const_declaration,
  [sym_const_spec] = sym_const_spec,
  [sym_var_declaration] = sym_var_declaration,
  [sym_var_spec] = sym_var_spec,
  [sym_var_spec_list] = sym_var_spec_list,
  [sym_function_declaration] = sym_function_declaration,
  [sym_method_declaration] = sym_method_declaration,
  [sym_type_parameter_list] = sym_type_parameter_list,
  [sym_type_parameter_declaration] = sym_type_parameter_declaration,
  [sym_parameter_list] = sym_parameter_list,
  [sym_parameter_declaration] = sym_parameter_declaration,
  [sym_variadic_parameter_declaration] = sym_variadic_parameter_declaration,
  [sym_type_alias] = sym_type_alias,
  [sym_type_declaration] = sym_type_declaration,
  [sym_type_spec] = sym_type_spec,
  [sym_expression_list] = sym_expression_list,
  [sym_parenthesized_type] = sym_parenthesized_type,
  [sym__simple_type] = sym__simple_type,
  [sym_generic_type] = sym_generic_type,
  [sym_type_arguments] = sym_type_arguments,
  [sym_pointer_type] = sym_pointer_type,
  [sym_array_type] = sym_array_type,
  [sym_implicit_length_array_type] = sym_implicit_length_array_type,
  [sym_slice_type] = sym_slice_type,
  [sym_struct_type] = sym_struct_type,
  [sym_negated_type] = sym_negated_type,
  [sym_field_declaration_list] = sym_field_declaration_list,
  [sym_field_declaration] = sym_field_declaration,
  [sym_interface_type] = sym_interface_type,
  [sym_method_elem] = sym_method_elem,
  [sym_type_elem] = sym_type_elem,
  [sym_map_type] = sym_map_type,
  [sym_channel_type] = sym_channel_type,
  [sym_function_type] = sym_function_type,
  [sym_block] = sym_block,
  [sym__statement_list] = sym__statement_list,
  [sym__statement] = sym__statement,
  [sym_empty_statement] = sym_empty_statement,
  [sym__simple_statement] = sym__simple_statement,
  [sym_expression_statement] = sym_expression_statement,
  [sym_send_statement] = sym_send_statement,
  [sym_receive_statement] = sym_receive_statement,
  [sym_inc_statement] = sym_inc_statement,
  [sym_dec_statement] = sym_dec_statement,
  [sym_assignment_statement] = sym_assignment_statement,
  [sym_short_var_declaration] = sym_short_var_declaration,
  [sym_labeled_statement] = sym_labeled_statement,
  [sym_empty_labeled_statement] = sym_labeled_statement,
  [sym_fallthrough_statement] = sym_fallthrough_statement,
  [sym_break_statement] = sym_break_statement,
  [sym_continue_statement] = sym_continue_statement,
  [sym_goto_statement] = sym_goto_statement,
  [sym_return_statement] = sym_return_statement,
  [sym_go_statement] = sym_go_statement,
  [sym_defer_statement] = sym_defer_statement,
  [sym_if_statement] = sym_if_statement,
  [sym_for_statement] = sym_for_statement,
  [sym_for_clause] = sym_for_clause,
  [sym_range_clause] = sym_range_clause,
  [sym_expression_switch_statement] = sym_expression_switch_statement,
  [sym_expression_case] = sym_expression_case,
  [sym_default_case] = sym_default_case,
  [sym_type_switch_statement] = sym_type_switch_statement,
  [sym__type_switch_header] = sym__type_switch_header,
  [sym_type_case] = sym_type_case,
  [sym_select_statement] = sym_select_statement,
  [sym_communication_case] = sym_communication_case,
  [sym__expression] = sym__expression,
  [sym_parenthesized_expression] = sym_parenthesized_expression,
  [sym_call_expression] = sym_call_expression,
  [sym_variadic_argument] = sym_variadic_argument,
  [sym_special_argument_list] = sym_argument_list,
  [sym_argument_list] = sym_argument_list,
  [sym_selector_expression] = sym_selector_expression,
  [sym_index_expression] = sym_index_expression,
  [sym_slice_expression] = sym_slice_expression,
  [sym_type_assertion_expression] = sym_type_assertion_expression,
  [sym_type_conversion_expression] = sym_type_conversion_expression,
  [sym_type_instantiation_expression] = sym_type_instantiation_expression,
  [sym_composite_literal] = sym_composite_literal,
  [sym_literal_value] = sym_literal_value,
  [sym_literal_element] = sym_literal_element,
  [sym_keyed_element] = sym_keyed_element,
  [sym_func_literal] = sym_func_literal,
  [sym_unary_expression] = sym_unary_expression,
  [sym_binary_expression] = sym_binary_expression,
  [sym_qualified_type] = sym_qualified_type,
  [sym_interpreted_string_literal] = sym_interpreted_string_literal,
  [aux_sym_source_file_repeat1] = aux_sym_source_file_repeat1,
  [aux_sym_import_spec_list_repeat1] = aux_sym_import_spec_list_repeat1,
  [aux_sym_const_declaration_repeat1] = aux_sym_const_declaration_repeat1,
  [aux_sym_const_spec_repeat1] = aux_sym_const_spec_repeat1,
  [aux_sym_var_spec_repeat1] = aux_sym_var_spec_repeat1,
  [aux_sym_var_spec_list_repeat1] = aux_sym_var_spec_list_repeat1,
  [aux_sym_type_parameter_list_repeat1] = aux_sym_type_parameter_list_repeat1,
  [aux_sym_parameter_list_repeat1] = aux_sym_parameter_list_repeat1,
  [aux_sym_type_declaration_repeat1] = aux_sym_type_declaration_repeat1,
  [aux_sym_expression_list_repeat1] = aux_sym_expression_list_repeat1,
  [aux_sym_type_arguments_repeat1] = aux_sym_type_arguments_repeat1,
  [aux_sym_field_declaration_list_repeat1] = aux_sym_field_declaration_list_repeat1,
  [aux_sym_field_declaration_repeat1] = aux_sym_field_declaration_repeat1,
  [aux_sym_interface_type_repeat1] = aux_sym_interface_type_repeat1,
  [aux_sym_type_elem_repeat1] = aux_sym_type_elem_repeat1,
  [aux_sym__statement_list_repeat1] = aux_sym__statement_list_repeat1,
  [aux_sym_expression_switch_statement_repeat1] = aux_sym_expression_switch_statement_repeat1,
  [aux_sym_type_switch_statement_repeat1] = aux_sym_type_switch_statement_repeat1,
  [aux_sym_type_case_repeat1] = aux_sym_type_case_repeat1,
  [aux_sym_select_statement_repeat1] = aux_sym_select_statement_repeat1,
  [aux_sym_argument_list_repeat1] = aux_sym_argument_list_repeat1,
  [aux_sym_literal_value_repeat1] = aux_sym_literal_value_repeat1,
  [aux_sym_interpreted_string_literal_repeat1] = aux_sym_interpreted_string_literal_repeat1,
  [alias_sym_field_identifier] = alias_sym_field_identifier,
  [alias_sym_label_name] = alias_sym_label_name,
  [alias_sym_package_identifier] = alias_sym_package_identifier,
  [alias_sym_type_constraint] = alias_sym_type_constraint,
  [alias_sym_type_identifier] = alias_sym_type_identifier,
};

static const TSSymbolMetadata ts_symbol_metadata[] = {
  [ts_builtin_sym_end] = {
    .visible = false,
    .named = true,
  },
  [sym_identifier] = {
    .visible = true,
    .named = true,
  },
  [aux_sym_source_file_token1] = {
    .visible = false,
    .named = false,
  },
  [anon_sym_SEMI] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_NULL] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_package] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_import] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DOT] = {
    .visible = true,
    .named = false,
  },
  [sym_blank_identifier] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_LPAREN] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_RPAREN] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_const] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_COMMA] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_var] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_func] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LBRACK] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_RBRACK] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DOT_DOT_DOT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_type] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_STAR] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_struct] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_TILDE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LBRACE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_RBRACE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_interface] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PIPE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_map] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_chan] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LT_DASH] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_COLON_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PLUS_PLUS] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DASH_DASH] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_STAR_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_SLASH_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PERCENT_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LT_LT_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_GT_GT_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_AMP_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_AMP_CARET_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PLUS_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DASH_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PIPE_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_CARET_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_COLON] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_fallthrough] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_break] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_continue] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_goto] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_return] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_go] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_defer] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_if] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_else] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_for] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_range] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_switch] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_case] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_default] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_select] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_new] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_make] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_PLUS] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DASH] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_BANG] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_CARET] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_AMP] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_SLASH] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PERCENT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LT_LT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_GT_GT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_AMP_CARET] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_EQ_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_BANG_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LT_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_GT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_GT_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_AMP_AMP] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PIPE_PIPE] = {
    .visible = true,
    .named = false,
  },
  [sym_raw_string_literal] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_DQUOTE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DQUOTE2] = {
    .visible = true,
    .named = false,
  },
  [sym__interpreted_string_literal_basic_content] = {
    .visible = false,
    .named = true,
  },
  [sym_escape_sequence] = {
    .visible = true,
    .named = true,
  },
  [sym_int_literal] = {
    .visible = true,
    .named = true,
  },
  [sym_float_literal] = {
    .visible = true,
    .named = true,
  },
  [sym_imaginary_literal] = {
    .visible = true,
    .named = true,
  },
  [sym_rune_literal] = {
    .visible = true,
    .named = true,
  },
  [sym_nil] = {
    .visible = true,
    .named = true,
  },
  [sym_true] = {
    .visible = true,
    .named = true,
  },
  [sym_false] = {
    .visible = true,
    .named = true,
  },
  [sym_iota] = {
    .visible = true,
    .named = true,
  },
  [sym_comment] = {
    .visible = true,
    .named = true,
  },
  [sym_source_file] = {
    .visible = true,
    .named = true,
  },
  [sym_package_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_import_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_import_spec] = {
    .visible = true,
    .named = true,
  },
  [sym_dot] = {
    .visible = true,
    .named = true,
  },
  [sym_import_spec_list] = {
    .visible = true,
    .named = true,
  },
  [sym__declaration] = {
    .visible = false,
    .named = true,
  },
  [sym_const_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_const_spec] = {
    .visible = true,
    .named = true,
  },
  [sym_var_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_var_spec] = {
    .visible = true,
    .named = true,
  },
  [sym_var_spec_list] = {
    .visible = true,
    .named = true,
  },
  [sym_function_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_method_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_type_parameter_list] = {
    .visible = true,
    .named = true,
  },
  [sym_type_parameter_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_parameter_list] = {
    .visible = true,
    .named = true,
  },
  [sym_parameter_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_variadic_parameter_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_type_alias] = {
    .visible = true,
    .named = true,
  },
  [sym_type_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_type_spec] = {
    .visible = true,
    .named = true,
  },
  [sym_expression_list] = {
    .visible = true,
    .named = true,
  },
  [sym_parenthesized_type] = {
    .visible = true,
    .named = true,
  },
  [sym__simple_type] = {
    .visible = false,
    .named = true,
    .supertype = true,
  },
  [sym_generic_type] = {
    .visible = true,
    .named = true,
  },
  [sym_type_arguments] = {
    .visible = true,
    .named = true,
  },
  [sym_pointer_type] = {
    .visible = true,
    .named = true,
  },
  [sym_array_type] = {
    .visible = true,
    .named = true,
  },
  [sym_implicit_length_array_type] = {
    .visible = true,
    .named = true,
  },
  [sym_slice_type] = {
    .visible = true,
    .named = true,
  },
  [sym_struct_type] = {
    .visible = true,
    .named = true,
  },
  [sym_negated_type] = {
    .visible = true,
    .named = true,
  },
  [sym_field_declaration_list] = {
    .visible = true,
    .named = true,
  },
  [sym_field_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_interface_type] = {
    .visible = true,
    .named = true,
  },
  [sym_method_elem] = {
    .visible = true,
    .named = true,
  },
  [sym_type_elem] = {
    .visible = true,
    .named = true,
  },
  [sym_map_type] = {
    .visible = true,
    .named = true,
  },
  [sym_channel_type] = {
    .visible = true,
    .named = true,
  },
  [sym_function_type] = {
    .visible = true,
    .named = true,
  },
  [sym_block] = {
    .visible = true,
    .named = true,
  },
  [sym__statement_list] = {
    .visible = false,
    .named = true,
  },
  [sym__statement] = {
    .visible = false,
    .named = true,
    .supertype = true,
  },
  [sym_empty_statement] = {
    .visible = true,
    .named = true,
  },
  [sym__simple_statement] = {
    .visible = false,
    .named = true,
    .supertype = true,
  },
  [sym_expression_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_send_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_receive_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_inc_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_dec_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_assignment_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_short_var_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_labeled_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_empty_labeled_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_fallthrough_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_break_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_continue_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_goto_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_return_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_go_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_defer_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_if_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_for_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_for_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_range_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_expression_switch_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_expression_case] = {
    .visible = true,
    .named = true,
  },
  [sym_default_case] = {
    .visible = true,
    .named = true,
  },
  [sym_type_switch_statement] = {
    .visible = true,
    .named = true,
  },
  [sym__type_switch_header] = {
    .visible = false,
    .named = true,
  },
  [sym_type_case] = {
    .visible = true,
    .named = true,
  },
  [sym_select_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_communication_case] = {
    .visible = true,
    .named = true,
  },
  [sym__expression] = {
    .visible = false,
    .named = true,
    .supertype = true,
  },
  [sym_parenthesized_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_call_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_variadic_argument] = {
    .visible = true,
    .named = true,
  },
  [sym_special_argument_list] = {
    .visible = true,
    .named = true,
  },
  [sym_argument_list] = {
    .visible = true,
    .named = true,
  },
  [sym_selector_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_index_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_slice_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_type_assertion_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_type_conversion_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_type_instantiation_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_composite_literal] = {
    .visible = true,
    .named = true,
  },
  [sym_literal_value] = {
    .visible = true,
    .named = true,
  },
  [sym_literal_element] = {
    .visible = true,
    .named = true,
  },
  [sym_keyed_element] = {
    .visible = true,
    .named = true,
  },
  [sym_func_literal] = {
    .visible = true,
    .named = true,
  },
  [sym_unary_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_binary_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_qualified_type] = {
    .visible = true,
    .named = true,
  },
  [sym_interpreted_string_literal] = {
    .visible = true,
    .named = true,
  },
  [aux_sym_source_file_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_import_spec_list_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_const_declaration_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_const_spec_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_var_spec_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_var_spec_list_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_type_parameter_list_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_parameter_list_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_type_declaration_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_expression_list_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_type_arguments_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_field_declaration_list_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_field_declaration_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_interface_type_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_type_elem_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__statement_list_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_expression_switch_statement_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_type_switch_statement_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_type_case_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_select_statement_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_argument_list_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_literal_value_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_interpreted_string_literal_repeat1] = {
    .visible = false,
    .named = false,
  },
  [alias_sym_field_identifier] = {
    .visible = true,
    .named = true,
  },
  [alias_sym_label_name] = {
    .visible = true,
    .named = true,
  },
  [alias_sym_package_identifier] = {
    .visible = true,
    .named = true,
  },
  [alias_sym_type_constraint] = {
    .visible = true,
    .named = true,
  },
  [alias_sym_type_identifier] = {
    .visible = true,
    .named = true,
  },
};

enum ts_field_identifiers {
  field_alias = 1,
  field_alternative = 2,
  field_arguments = 3,
  field_body = 4,
  field_capacity = 5,
  field_channel = 6,
  field_communication = 7,
  field_condition = 8,
  field_consequence = 9,
  field_element = 10,
  field_end = 11,
  field_field = 12,
  field_function = 13,
  field_index = 14,
  field_initializer = 15,
  field_key = 16,
  field_label = 17,
  field_left = 18,
  field_length = 19,
  field_name = 20,
  field_operand = 21,
  field_operator = 22,
  field_package = 23,
  field_parameters = 24,
  field_path = 25,
  field_receiver = 26,
  field_result = 27,
  field_right = 28,
  field_start = 29,
  field_tag = 30,
  field_type = 31,
  field_type_arguments = 32,
  field_type_parameters = 33,
  field_update = 34,
  field_value = 35,
};

static const char * const ts_field_names[] = {
  [0] = NULL,
  [field_alias] = "alias",
  [field_alternative] = "alternative",
  [field_arguments] = "arguments",
  [field_body] = "body",
  [field_capacity] = "capacity",
  [field_channel] = "channel",
  [field_communication] = "communication",
  [field_condition] = "condition",
  [field_consequence] = "consequence",
  [field_element] = "element",
  [field_end] = "end",
  [field_field] = "field",
  [field_function] = "function",
  [field_index] = "index",
  [field_initializer] = "initializer",
  [field_key] = "key",
  [field_label] = "label",
  [field_left] = "left",
  [field_length] = "length",
  [field_name] = "name",
  [field_operand] = "operand",
  [field_operator] = "operator",
  [field_package] = "package",
  [field_parameters] = "parameters",
  [field_path] = "path",
  [field_receiver] = "receiver",
  [field_result] = "result",
  [field_right] = "right",
  [field_start] = "start",
  [field_tag] = "tag",
  [field_type] = "type",
  [field_type_arguments] = "type_arguments",
  [field_type_parameters] = "type_parameters",
  [field_update] = "update",
  [field_value] = "value",
};

static const TSFieldMapSlice ts_field_map_slices[PRODUCTION_ID_COUNT] = {
  [3] = {.index = 0, .length = 1},
  [4] = {.index = 1, .length = 1},
  [5] = {.index = 2, .length = 1},
  [6] = {.index = 3, .length = 2},
  [7] = {.index = 5, .length = 1},
  [9] = {.index = 6, .length = 1},
  [10] = {.index = 7, .length = 2},
  [11] = {.index = 9, .length = 2},
  [12] = {.index = 11, .length = 2},
  [13] = {.index = 11, .length = 2},
  [14] = {.index = 9, .length = 2},
  [15] = {.index = 13, .length = 2},
  [16] = {.index = 13, .length = 2},
  [17] = {.index = 15, .length = 2},
  [18] = {.index = 17, .length = 2},
  [19] = {.index = 19, .length = 1},
  [20] = {.index = 20, .length = 2},
  [21] = {.index = 22, .length = 2},
  [22] = {.index = 24, .length = 2},
  [23] = {.index = 26, .length = 1},
  [24] = {.index = 17, .length = 2},
  [25] = {.index = 19, .length = 1},
  [26] = {.index = 27, .length = 1},
  [27] = {.index = 28, .length = 1},
  [28] = {.index = 29, .length = 2},
  [29] = {.index = 31, .length = 1},
  [30] = {.index = 32, .length = 1},
  [31] = {.index = 33, .length = 2},
  [32] = {.index = 35, .length = 3},
  [33] = {.index = 38, .length = 2},
  [34] = {.index = 40, .length = 2},
  [35] = {.index = 42, .length = 2},
  [36] = {.index = 44, .length = 3},
  [37] = {.index = 47, .length = 2},
  [38] = {.index = 49, .length = 1},
  [39] = {.index = 50, .length = 3},
  [40] = {.index = 53, .length = 2},
  [41] = {.index = 55, .length = 1},
  [42] = {.index = 56, .length = 3},
  [43] = {.index = 59, .length = 3},
  [44] = {.index = 62, .length = 3},
  [45] = {.index = 65, .length = 3},
  [46] = {.index = 68, .length = 3},
  [47] = {.index = 71, .length = 1},
  [48] = {.index = 72, .length = 2},
  [49] = {.index = 74, .length = 2},
  [50] = {.index = 76, .length = 3},
  [51] = {.index = 55, .length = 1},
  [52] = {.index = 79, .length = 2},
  [53] = {.index = 17, .length = 2},
  [54] = {.index = 79, .length = 2},
  [55] = {.index = 81, .length = 2},
  [56] = {.index = 83, .length = 1},
  [57] = {.index = 84, .length = 1},
  [58] = {.index = 85, .length = 1},
  [59] = {.index = 86, .length = 3},
  [60] = {.index = 89, .length = 1},
  [61] = {.index = 90, .length = 2},
  [62] = {.index = 92, .length = 1},
  [63] = {.index = 93, .length = 2},
  [64] = {.index = 95, .length = 3},
  [65] = {.index = 98, .length = 3},
  [66] = {.index = 101, .length = 3},
  [67] = {.index = 74, .length = 2},
  [68] = {.index = 17, .length = 2},
  [69] = {.index = 104, .length = 4},
  [70] = {.index = 108, .length = 4},
  [71] = {.index = 112, .length = 4},
  [72] = {.index = 116, .length = 4},
  [73] = {.index = 120, .length = 4},
  [74] = {.index = 124, .length = 2},
  [75] = {.index = 124, .length = 2},
  [76] = {.index = 49, .length = 1},
  [77] = {.index = 126, .length = 3},
  [78] = {.index = 50, .length = 3},
  [79] = {.index = 129, .length = 3},
  [80] = {.index = 132, .length = 2},
  [81] = {.index = 134, .length = 3},
  [82] = {.index = 137, .length = 3},
  [83] = {.index = 140, .length = 2},
  [84] = {.index = 142, .length = 2},
  [85] = {.index = 144, .length = 2},
  [86] = {.index = 146, .length = 2},
  [87] = {.index = 148, .length = 1},
  [88] = {.index = 149, .length = 1},
  [89] = {.index = 150, .length = 2},
  [90] = {.index = 152, .length = 2},
  [91] = {.index = 154, .length = 2},
  [92] = {.index = 156, .length = 4},
  [93] = {.index = 160, .length = 4},
  [94] = {.index = 50, .length = 3},
  [95] = {.index = 164, .length = 5},
  [96] = {.index = 169, .length = 5},
  [97] = {.index = 174, .length = 4},
  [98] = {.index = 178, .length = 3},
  [99] = {.index = 181, .length = 2},
  [100] = {.index = 183, .length = 1},
  [101] = {.index = 184, .length = 3},
  [102] = {.index = 187, .length = 4},
  [103] = {.index = 191, .length = 2},
  [104] = {.index = 193, .length = 3},
  [105] = {.index = 196, .length = 2},
  [106] = {.index = 198, .length = 2},
  [107] = {.index = 200, .length = 4},
  [108] = {.index = 204, .length = 3},
};

static const TSFieldMapEntry ts_field_map_entries[] = {
  [0] =
    {field_path, 0},
  [1] =
    {field_name, 0},
  [2] =
    {field_parameters, 1},
  [3] =
    {field_operand, 1},
    {field_operator, 0},
  [5] =
    {field_value, 1},
  [6] =
    {field_body, 1},
  [7] =
    {field_arguments, 1},
    {field_function, 0},
  [9] =
    {field_type, 0},
    {field_type_arguments, 1},
  [11] =
    {field_body, 1},
    {field_type, 0},
  [13] =
    {field_name, 0},
    {field_path, 1},
  [15] =
    {field_name, 0},
    {field_name, 1},
  [17] =
    {field_name, 0},
    {field_type, 1},
  [19] =
    {field_type, 0},
  [20] =
    {field_name, 1},
    {field_parameters, 2},
  [22] =
    {field_parameters, 1},
    {field_result, 2},
  [24] =
    {field_body, 2},
    {field_parameters, 1},
  [26] =
    {field_element, 2},
  [27] =
    {field_label, 0},
  [28] =
    {field_value, 2},
  [29] =
    {field_condition, 1},
    {field_consequence, 2},
  [31] =
    {field_right, 1},
  [32] =
    {field_body, 2},
  [33] =
    {field_name, 2},
    {field_package, 0},
  [35] =
    {field_left, 0},
    {field_operator, 1},
    {field_right, 2},
  [38] =
    {field_left, 0},
    {field_right, 2},
  [40] =
    {field_field, 2},
    {field_operand, 0},
  [42] =
    {field_channel, 0},
    {field_value, 2},
  [44] =
    {field_arguments, 2},
    {field_function, 0},
    {field_type_arguments, 1},
  [47] =
    {field_name, 0},
    {field_value, 2},
  [49] =
    {field_name, 1},
  [50] =
    {field_name, 0},
    {field_name, 1, .inherited = true},
    {field_type, 2},
  [53] =
    {field_name, 0, .inherited = true},
    {field_name, 1, .inherited = true},
  [55] =
    {field_type, 1},
  [56] =
    {field_name, 1},
    {field_parameters, 3},
    {field_type_parameters, 2},
  [59] =
    {field_name, 1},
    {field_parameters, 2},
    {field_result, 3},
  [62] =
    {field_body, 3},
    {field_name, 1},
    {field_parameters, 2},
  [65] =
    {field_name, 2},
    {field_parameters, 3},
    {field_receiver, 1},
  [68] =
    {field_body, 3},
    {field_parameters, 1},
    {field_result, 2},
  [71] =
    {field_element, 3},
  [72] =
    {field_element, 3},
    {field_length, 1},
  [74] =
    {field_name, 0},
    {field_type, 2},
  [76] =
    {field_name, 0},
    {field_type, 2},
    {field_type_parameters, 1},
  [79] =
    {field_tag, 1},
    {field_type, 0},
  [81] =
    {field_name, 0},
    {field_parameters, 1},
  [83] =
    {field_update, 2},
  [84] =
    {field_condition, 1},
  [85] =
    {field_initializer, 0},
  [86] =
    {field_alias, 1, .inherited = true},
    {field_initializer, 1, .inherited = true},
    {field_value, 1, .inherited = true},
  [89] =
    {field_right, 0},
  [90] =
    {field_operand, 2},
    {field_type, 0},
  [92] =
    {field_operand, 0},
  [93] =
    {field_index, 2},
    {field_operand, 0},
  [95] =
    {field_name, 0},
    {field_type, 1},
    {field_value, 3},
  [98] =
    {field_name, 0},
    {field_name, 1},
    {field_value, 3},
  [101] =
    {field_name, 0},
    {field_name, 1, .inherited = true},
    {field_value, 3},
  [104] =
    {field_name, 1},
    {field_parameters, 3},
    {field_result, 4},
    {field_type_parameters, 2},
  [108] =
    {field_body, 4},
    {field_name, 1},
    {field_parameters, 3},
    {field_type_parameters, 2},
  [112] =
    {field_body, 4},
    {field_name, 1},
    {field_parameters, 2},
    {field_result, 3},
  [116] =
    {field_name, 2},
    {field_parameters, 3},
    {field_receiver, 1},
    {field_result, 4},
  [120] =
    {field_body, 4},
    {field_name, 2},
    {field_parameters, 3},
    {field_receiver, 1},
  [124] =
    {field_tag, 2},
    {field_type, 1},
  [126] =
    {field_name, 0},
    {field_tag, 2},
    {field_type, 1},
  [129] =
    {field_name, 0},
    {field_parameters, 1},
    {field_result, 2},
  [132] =
    {field_key, 2},
    {field_value, 4},
  [134] =
    {field_condition, 3},
    {field_consequence, 4},
    {field_initializer, 1},
  [137] =
    {field_alternative, 4},
    {field_condition, 1},
    {field_consequence, 2},
  [140] =
    {field_condition, 1},
    {field_update, 3},
  [142] =
    {field_left, 0},
    {field_right, 3},
  [144] =
    {field_initializer, 0},
    {field_update, 3},
  [146] =
    {field_condition, 2},
    {field_initializer, 0},
  [148] =
    {field_initializer, 1},
  [149] =
    {field_communication, 1},
  [150] =
    {field_operand, 0},
    {field_type, 3},
  [152] =
    {field_end, 3},
    {field_operand, 0},
  [154] =
    {field_operand, 0},
    {field_start, 2},
  [156] =
    {field_name, 0},
    {field_name, 1},
    {field_type, 2},
    {field_value, 4},
  [160] =
    {field_name, 0},
    {field_name, 1, .inherited = true},
    {field_type, 2},
    {field_value, 4},
  [164] =
    {field_body, 5},
    {field_name, 1},
    {field_parameters, 3},
    {field_result, 4},
    {field_type_parameters, 2},
  [169] =
    {field_body, 5},
    {field_name, 2},
    {field_parameters, 3},
    {field_receiver, 1},
    {field_result, 4},
  [174] =
    {field_name, 0},
    {field_name, 1, .inherited = true},
    {field_tag, 3},
    {field_type, 2},
  [178] =
    {field_condition, 2},
    {field_initializer, 0},
    {field_update, 4},
  [181] =
    {field_initializer, 1},
    {field_value, 3},
  [183] =
    {field_value, 0},
  [184] =
    {field_end, 4},
    {field_operand, 0},
    {field_start, 2},
  [187] =
    {field_alternative, 6},
    {field_condition, 3},
    {field_consequence, 4},
    {field_initializer, 1},
  [191] =
    {field_type, 1},
    {field_type, 2},
  [193] =
    {field_capacity, 5},
    {field_end, 3},
    {field_operand, 0},
  [196] =
    {field_alias, 0},
    {field_value, 2},
  [198] =
    {field_initializer, 0},
    {field_value, 2},
  [200] =
    {field_capacity, 6},
    {field_end, 4},
    {field_operand, 0},
    {field_start, 2},
  [204] =
    {field_alias, 2},
    {field_initializer, 0},
    {field_value, 4},
};

static const TSSymbol ts_alias_sequences[PRODUCTION_ID_COUNT][MAX_ALIAS_SEQUENCE_LENGTH] = {
  [0] = {0},
  [1] = {
    [0] = alias_sym_type_identifier,
  },
  [2] = {
    [1] = alias_sym_package_identifier,
  },
  [8] = {
    [1] = alias_sym_label_name,
  },
  [11] = {
    [0] = alias_sym_type_identifier,
  },
  [12] = {
    [0] = alias_sym_type_identifier,
  },
  [16] = {
    [0] = alias_sym_package_identifier,
  },
  [24] = {
    [0] = alias_sym_type_identifier,
  },
  [25] = {
    [0] = alias_sym_type_identifier,
  },
  [26] = {
    [0] = alias_sym_label_name,
  },
  [31] = {
    [0] = alias_sym_package_identifier,
    [2] = alias_sym_type_identifier,
  },
  [34] = {
    [2] = alias_sym_field_identifier,
  },
  [45] = {
    [2] = alias_sym_field_identifier,
  },
  [49] = {
    [0] = alias_sym_type_identifier,
  },
  [50] = {
    [0] = alias_sym_type_identifier,
  },
  [51] = {
    [1] = alias_sym_type_identifier,
  },
  [52] = {
    [0] = alias_sym_type_identifier,
  },
  [53] = {
    [0] = alias_sym_field_identifier,
  },
  [55] = {
    [0] = alias_sym_field_identifier,
  },
  [68] = {
    [1] = alias_sym_type_constraint,
  },
  [72] = {
    [2] = alias_sym_field_identifier,
  },
  [73] = {
    [2] = alias_sym_field_identifier,
  },
  [74] = {
    [1] = alias_sym_type_identifier,
  },
  [76] = {
    [1] = alias_sym_field_identifier,
  },
  [77] = {
    [0] = alias_sym_field_identifier,
  },
  [78] = {
    [0] = alias_sym_field_identifier,
  },
  [79] = {
    [0] = alias_sym_field_identifier,
  },
  [94] = {
    [2] = alias_sym_type_constraint,
  },
  [96] = {
    [2] = alias_sym_field_identifier,
  },
  [97] = {
    [0] = alias_sym_field_identifier,
  },
};

static const uint16_t ts_non_terminal_alias_map[] = {
  sym_type_elem, 2,
    sym_type_elem,
    alias_sym_type_constraint,
  0,
};

static const TSStateId ts_primary_state_ids[STATE_COUNT] = {
  [0] = 0,
  [1] = 1,
  [2] = 2,
  [3] = 3,
  [4] = 4,
  [5] = 5,
  [6] = 6,
  [7] = 7,
  [8] = 8,
  [9] = 9,
  [10] = 10,
  [11] = 11,
  [12] = 12,
  [13] = 12,
  [14] = 12,
  [15] = 12,
  [16] = 12,
  [17] = 12,
  [18] = 12,
  [19] = 19,
  [20] = 20,
  [21] = 21,
  [22] = 22,
  [23] = 23,
  [24] = 24,
  [25] = 25,
  [26] = 26,
  [27] = 27,
  [28] = 28,
  [29] = 29,
  [30] = 29,
  [31] = 29,
  [32] = 29,
  [33] = 29,
  [34] = 29,
  [35] = 35,
  [36] = 36,
  [37] = 36,
  [38] = 35,
  [39] = 36,
  [40] = 35,
  [41] = 35,
  [42] = 36,
  [43] = 36,
  [44] = 36,
  [45] = 35,
  [46] = 35,
  [47] = 47,
  [48] = 48,
  [49] = 49,
  [50] = 50,
  [51] = 51,
  [52] = 52,
  [53] = 53,
  [54] = 54,
  [55] = 54,
  [56] = 56,
  [57] = 57,
  [58] = 52,
  [59] = 54,
  [60] = 56,
  [61] = 57,
  [62] = 51,
  [63] = 52,
  [64] = 64,
  [65] = 57,
  [66] = 52,
  [67] = 67,
  [68] = 57,
  [69] = 54,
  [70] = 57,
  [71] = 52,
  [72] = 54,
  [73] = 57,
  [74] = 52,
  [75] = 75,
  [76] = 51,
  [77] = 51,
  [78] = 51,
  [79] = 51,
  [80] = 54,
  [81] = 81,
  [82] = 82,
  [83] = 83,
  [84] = 84,
  [85] = 81,
  [86] = 86,
  [87] = 87,
  [88] = 82,
  [89] = 89,
  [90] = 90,
  [91] = 81,
  [92] = 92,
  [93] = 93,
  [94] = 94,
  [95] = 83,
  [96] = 84,
  [97] = 92,
  [98] = 81,
  [99] = 99,
  [100] = 82,
  [101] = 82,
  [102] = 92,
  [103] = 103,
  [104] = 84,
  [105] = 105,
  [106] = 83,
  [107] = 107,
  [108] = 83,
  [109] = 84,
  [110] = 110,
  [111] = 83,
  [112] = 112,
  [113] = 82,
  [114] = 114,
  [115] = 84,
  [116] = 81,
  [117] = 92,
  [118] = 86,
  [119] = 119,
  [120] = 83,
  [121] = 84,
  [122] = 90,
  [123] = 86,
  [124] = 124,
  [125] = 82,
  [126] = 126,
  [127] = 90,
  [128] = 81,
  [129] = 92,
  [130] = 92,
  [131] = 131,
  [132] = 132,
  [133] = 133,
  [134] = 134,
  [135] = 135,
  [136] = 136,
  [137] = 137,
  [138] = 138,
  [139] = 132,
  [140] = 140,
  [141] = 133,
  [142] = 142,
  [143] = 140,
  [144] = 134,
  [145] = 131,
  [146] = 146,
  [147] = 137,
  [148] = 136,
  [149] = 149,
  [150] = 150,
  [151] = 138,
  [152] = 132,
  [153] = 133,
  [154] = 134,
  [155] = 131,
  [156] = 136,
  [157] = 157,
  [158] = 137,
  [159] = 159,
  [160] = 150,
  [161] = 142,
  [162] = 162,
  [163] = 163,
  [164] = 164,
  [165] = 165,
  [166] = 136,
  [167] = 137,
  [168] = 168,
  [169] = 142,
  [170] = 142,
  [171] = 171,
  [172] = 150,
  [173] = 142,
  [174] = 136,
  [175] = 138,
  [176] = 137,
  [177] = 132,
  [178] = 138,
  [179] = 133,
  [180] = 134,
  [181] = 131,
  [182] = 150,
  [183] = 138,
  [184] = 132,
  [185] = 133,
  [186] = 134,
  [187] = 131,
  [188] = 150,
  [189] = 136,
  [190] = 138,
  [191] = 137,
  [192] = 132,
  [193] = 133,
  [194] = 134,
  [195] = 131,
  [196] = 150,
  [197] = 138,
  [198] = 132,
  [199] = 133,
  [200] = 134,
  [201] = 131,
  [202] = 150,
  [203] = 136,
  [204] = 138,
  [205] = 137,
  [206] = 136,
  [207] = 137,
  [208] = 136,
  [209] = 136,
  [210] = 135,
  [211] = 164,
  [212] = 132,
  [213] = 168,
  [214] = 171,
  [215] = 135,
  [216] = 164,
  [217] = 133,
  [218] = 168,
  [219] = 171,
  [220] = 135,
  [221] = 164,
  [222] = 134,
  [223] = 168,
  [224] = 171,
  [225] = 135,
  [226] = 164,
  [227] = 131,
  [228] = 168,
  [229] = 171,
  [230] = 135,
  [231] = 164,
  [232] = 150,
  [233] = 168,
  [234] = 171,
  [235] = 140,
  [236] = 236,
  [237] = 237,
  [238] = 238,
  [239] = 239,
  [240] = 240,
  [241] = 241,
  [242] = 242,
  [243] = 243,
  [244] = 244,
  [245] = 245,
  [246] = 246,
  [247] = 247,
  [248] = 248,
  [249] = 249,
  [250] = 250,
  [251] = 251,
  [252] = 252,
  [253] = 253,
  [254] = 254,
  [255] = 255,
  [256] = 256,
  [257] = 257,
  [258] = 258,
  [259] = 259,
  [260] = 260,
  [261] = 261,
  [262] = 262,
  [263] = 263,
  [264] = 264,
  [265] = 265,
  [266] = 266,
  [267] = 267,
  [268] = 268,
  [269] = 269,
  [270] = 270,
  [271] = 271,
  [272] = 272,
  [273] = 273,
  [274] = 274,
  [275] = 275,
  [276] = 276,
  [277] = 277,
  [278] = 278,
  [279] = 279,
  [280] = 280,
  [281] = 281,
  [282] = 282,
  [283] = 283,
  [284] = 284,
  [285] = 285,
  [286] = 286,
  [287] = 287,
  [288] = 288,
  [289] = 289,
  [290] = 243,
  [291] = 239,
  [292] = 242,
  [293] = 247,
  [294] = 241,
  [295] = 244,
  [296] = 240,
  [297] = 246,
  [298] = 251,
  [299] = 264,
  [300] = 249,
  [301] = 285,
  [302] = 286,
  [303] = 265,
  [304] = 253,
  [305] = 254,
  [306] = 266,
  [307] = 252,
  [308] = 279,
  [309] = 268,
  [310] = 248,
  [311] = 267,
  [312] = 288,
  [313] = 269,
  [314] = 282,
  [315] = 283,
  [316] = 287,
  [317] = 257,
  [318] = 256,
  [319] = 258,
  [320] = 260,
  [321] = 261,
  [322] = 262,
  [323] = 263,
  [324] = 250,
  [325] = 271,
  [326] = 272,
  [327] = 273,
  [328] = 274,
  [329] = 275,
  [330] = 276,
  [331] = 277,
  [332] = 278,
  [333] = 284,
  [334] = 280,
  [335] = 281,
  [336] = 270,
  [337] = 240,
  [338] = 243,
  [339] = 246,
  [340] = 247,
  [341] = 241,
  [342] = 244,
  [343] = 242,
  [344] = 344,
  [345] = 251,
  [346] = 262,
  [347] = 277,
  [348] = 278,
  [349] = 280,
  [350] = 281,
  [351] = 282,
  [352] = 283,
  [353] = 284,
  [354] = 285,
  [355] = 286,
  [356] = 252,
  [357] = 250,
  [358] = 264,
  [359] = 271,
  [360] = 272,
  [361] = 273,
  [362] = 266,
  [363] = 274,
  [364] = 249,
  [365] = 265,
  [366] = 263,
  [367] = 254,
  [368] = 279,
  [369] = 275,
  [370] = 268,
  [371] = 248,
  [372] = 267,
  [373] = 288,
  [374] = 269,
  [375] = 270,
  [376] = 276,
  [377] = 287,
  [378] = 257,
  [379] = 256,
  [380] = 258,
  [381] = 260,
  [382] = 261,
  [383] = 253,
  [384] = 384,
  [385] = 385,
  [386] = 384,
  [387] = 242,
  [388] = 246,
  [389] = 251,
  [390] = 240,
  [391] = 391,
  [392] = 392,
  [393] = 256,
  [394] = 266,
  [395] = 395,
  [396] = 249,
  [397] = 265,
  [398] = 253,
  [399] = 254,
  [400] = 279,
  [401] = 268,
  [402] = 248,
  [403] = 267,
  [404] = 288,
  [405] = 269,
  [406] = 270,
  [407] = 287,
  [408] = 257,
  [409] = 250,
  [410] = 258,
  [411] = 260,
  [412] = 261,
  [413] = 262,
  [414] = 263,
  [415] = 264,
  [416] = 271,
  [417] = 272,
  [418] = 273,
  [419] = 274,
  [420] = 275,
  [421] = 276,
  [422] = 277,
  [423] = 278,
  [424] = 280,
  [425] = 281,
  [426] = 282,
  [427] = 283,
  [428] = 284,
  [429] = 285,
  [430] = 286,
  [431] = 240,
  [432] = 252,
  [433] = 242,
  [434] = 241,
  [435] = 384,
  [436] = 246,
  [437] = 247,
  [438] = 243,
  [439] = 344,
  [440] = 247,
  [441] = 244,
  [442] = 243,
  [443] = 244,
  [444] = 241,
  [445] = 384,
  [446] = 446,
  [447] = 447,
  [448] = 448,
  [449] = 449,
  [450] = 450,
  [451] = 451,
  [452] = 240,
  [453] = 251,
  [454] = 454,
  [455] = 455,
  [456] = 456,
  [457] = 271,
  [458] = 269,
  [459] = 248,
  [460] = 247,
  [461] = 243,
  [462] = 241,
  [463] = 244,
  [464] = 270,
  [465] = 287,
  [466] = 252,
  [467] = 467,
  [468] = 257,
  [469] = 256,
  [470] = 258,
  [471] = 260,
  [472] = 261,
  [473] = 262,
  [474] = 263,
  [475] = 264,
  [476] = 272,
  [477] = 273,
  [478] = 467,
  [479] = 250,
  [480] = 274,
  [481] = 268,
  [482] = 344,
  [483] = 276,
  [484] = 277,
  [485] = 278,
  [486] = 280,
  [487] = 242,
  [488] = 467,
  [489] = 281,
  [490] = 282,
  [491] = 384,
  [492] = 384,
  [493] = 455,
  [494] = 283,
  [495] = 246,
  [496] = 284,
  [497] = 285,
  [498] = 286,
  [499] = 456,
  [500] = 454,
  [501] = 279,
  [502] = 266,
  [503] = 267,
  [504] = 265,
  [505] = 253,
  [506] = 249,
  [507] = 254,
  [508] = 288,
  [509] = 275,
  [510] = 510,
  [511] = 511,
  [512] = 511,
  [513] = 513,
  [514] = 240,
  [515] = 251,
  [516] = 511,
  [517] = 517,
  [518] = 517,
  [519] = 517,
  [520] = 240,
  [521] = 511,
  [522] = 395,
  [523] = 510,
  [524] = 524,
  [525] = 511,
  [526] = 510,
  [527] = 511,
  [528] = 281,
  [529] = 250,
  [530] = 530,
  [531] = 530,
  [532] = 532,
  [533] = 533,
  [534] = 266,
  [535] = 240,
  [536] = 536,
  [537] = 249,
  [538] = 265,
  [539] = 253,
  [540] = 540,
  [541] = 541,
  [542] = 542,
  [543] = 254,
  [544] = 540,
  [545] = 279,
  [546] = 247,
  [547] = 547,
  [548] = 268,
  [549] = 243,
  [550] = 241,
  [551] = 244,
  [552] = 248,
  [553] = 267,
  [554] = 288,
  [555] = 269,
  [556] = 556,
  [557] = 557,
  [558] = 247,
  [559] = 243,
  [560] = 241,
  [561] = 244,
  [562] = 530,
  [563] = 556,
  [564] = 540,
  [565] = 565,
  [566] = 287,
  [567] = 257,
  [568] = 256,
  [569] = 258,
  [570] = 260,
  [571] = 261,
  [572] = 262,
  [573] = 263,
  [574] = 264,
  [575] = 271,
  [576] = 272,
  [577] = 273,
  [578] = 274,
  [579] = 275,
  [580] = 276,
  [581] = 277,
  [582] = 278,
  [583] = 280,
  [584] = 282,
  [585] = 283,
  [586] = 284,
  [587] = 285,
  [588] = 286,
  [589] = 556,
  [590] = 395,
  [591] = 252,
  [592] = 270,
  [593] = 593,
  [594] = 594,
  [595] = 595,
  [596] = 596,
  [597] = 344,
  [598] = 598,
  [599] = 598,
  [600] = 596,
  [601] = 448,
  [602] = 602,
  [603] = 603,
  [604] = 448,
  [605] = 602,
  [606] = 603,
  [607] = 602,
  [608] = 594,
  [609] = 594,
  [610] = 610,
  [611] = 344,
  [612] = 603,
  [613] = 448,
  [614] = 593,
  [615] = 610,
  [616] = 603,
  [617] = 598,
  [618] = 603,
  [619] = 610,
  [620] = 620,
  [621] = 594,
  [622] = 447,
  [623] = 594,
  [624] = 624,
  [625] = 596,
  [626] = 603,
  [627] = 448,
  [628] = 448,
  [629] = 602,
  [630] = 630,
  [631] = 598,
  [632] = 594,
  [633] = 602,
  [634] = 602,
  [635] = 635,
  [636] = 598,
  [637] = 598,
  [638] = 638,
  [639] = 447,
  [640] = 640,
  [641] = 641,
  [642] = 642,
  [643] = 643,
  [644] = 644,
  [645] = 645,
  [646] = 646,
  [647] = 646,
  [648] = 648,
  [649] = 638,
  [650] = 640,
  [651] = 644,
  [652] = 648,
  [653] = 653,
  [654] = 654,
  [655] = 655,
  [656] = 656,
  [657] = 646,
  [658] = 638,
  [659] = 640,
  [660] = 660,
  [661] = 661,
  [662] = 662,
  [663] = 644,
  [664] = 648,
  [665] = 653,
  [666] = 654,
  [667] = 654,
  [668] = 668,
  [669] = 646,
  [670] = 638,
  [671] = 640,
  [672] = 644,
  [673] = 648,
  [674] = 653,
  [675] = 654,
  [676] = 646,
  [677] = 640,
  [678] = 644,
  [679] = 648,
  [680] = 653,
  [681] = 654,
  [682] = 646,
  [683] = 638,
  [684] = 640,
  [685] = 644,
  [686] = 648,
  [687] = 653,
  [688] = 654,
  [689] = 638,
  [690] = 642,
  [691] = 642,
  [692] = 692,
  [693] = 653,
  [694] = 694,
  [695] = 695,
  [696] = 696,
  [697] = 697,
  [698] = 696,
  [699] = 699,
  [700] = 700,
  [701] = 701,
  [702] = 702,
  [703] = 703,
  [704] = 704,
  [705] = 705,
  [706] = 696,
  [707] = 699,
  [708] = 700,
  [709] = 702,
  [710] = 703,
  [711] = 696,
  [712] = 712,
  [713] = 704,
  [714] = 714,
  [715] = 715,
  [716] = 714,
  [717] = 694,
  [718] = 697,
  [719] = 696,
  [720] = 720,
  [721] = 712,
  [722] = 704,
  [723] = 723,
  [724] = 715,
  [725] = 699,
  [726] = 714,
  [727] = 694,
  [728] = 700,
  [729] = 729,
  [730] = 695,
  [731] = 702,
  [732] = 703,
  [733] = 733,
  [734] = 703,
  [735] = 699,
  [736] = 715,
  [737] = 700,
  [738] = 694,
  [739] = 702,
  [740] = 712,
  [741] = 741,
  [742] = 704,
  [743] = 702,
  [744] = 696,
  [745] = 715,
  [746] = 699,
  [747] = 694,
  [748] = 700,
  [749] = 749,
  [750] = 750,
  [751] = 704,
  [752] = 715,
  [753] = 694,
  [754] = 715,
  [755] = 702,
  [756] = 756,
  [757] = 703,
  [758] = 703,
  [759] = 733,
  [760] = 699,
  [761] = 705,
  [762] = 695,
  [763] = 733,
  [764] = 700,
  [765] = 705,
  [766] = 695,
  [767] = 733,
  [768] = 705,
  [769] = 695,
  [770] = 733,
  [771] = 705,
  [772] = 695,
  [773] = 733,
  [774] = 705,
  [775] = 704,
  [776] = 776,
  [777] = 777,
  [778] = 778,
  [779] = 779,
  [780] = 780,
  [781] = 781,
  [782] = 776,
  [783] = 779,
  [784] = 778,
  [785] = 777,
  [786] = 778,
  [787] = 779,
  [788] = 776,
  [789] = 777,
  [790] = 790,
  [791] = 791,
  [792] = 792,
  [793] = 792,
  [794] = 794,
  [795] = 795,
  [796] = 796,
  [797] = 797,
  [798] = 798,
  [799] = 796,
  [800] = 795,
  [801] = 801,
  [802] = 802,
  [803] = 795,
  [804] = 804,
  [805] = 805,
  [806] = 806,
  [807] = 807,
  [808] = 808,
  [809] = 809,
  [810] = 810,
  [811] = 811,
  [812] = 812,
  [813] = 813,
  [814] = 814,
  [815] = 815,
  [816] = 816,
  [817] = 817,
  [818] = 818,
  [819] = 819,
  [820] = 820,
  [821] = 821,
  [822] = 822,
  [823] = 823,
  [824] = 824,
  [825] = 825,
  [826] = 826,
  [827] = 827,
  [828] = 828,
  [829] = 829,
  [830] = 830,
  [831] = 831,
  [832] = 792,
  [833] = 833,
  [834] = 834,
  [835] = 835,
  [836] = 796,
  [837] = 837,
  [838] = 837,
  [839] = 839,
  [840] = 840,
  [841] = 792,
  [842] = 827,
  [843] = 816,
  [844] = 806,
  [845] = 845,
  [846] = 821,
  [847] = 804,
  [848] = 796,
  [849] = 849,
  [850] = 811,
  [851] = 818,
  [852] = 810,
  [853] = 830,
  [854] = 813,
  [855] = 855,
  [856] = 826,
  [857] = 815,
  [858] = 807,
  [859] = 812,
  [860] = 823,
  [861] = 845,
  [862] = 814,
  [863] = 849,
  [864] = 864,
  [865] = 824,
  [866] = 825,
  [867] = 817,
  [868] = 868,
  [869] = 869,
  [870] = 808,
  [871] = 828,
  [872] = 864,
  [873] = 809,
  [874] = 829,
  [875] = 822,
  [876] = 831,
  [877] = 820,
  [878] = 819,
  [879] = 879,
  [880] = 880,
  [881] = 790,
  [882] = 882,
  [883] = 879,
  [884] = 879,
  [885] = 885,
  [886] = 886,
  [887] = 792,
  [888] = 791,
  [889] = 885,
  [890] = 885,
  [891] = 792,
  [892] = 886,
  [893] = 886,
  [894] = 894,
  [895] = 796,
  [896] = 896,
  [897] = 897,
  [898] = 898,
  [899] = 899,
  [900] = 900,
  [901] = 901,
  [902] = 902,
  [903] = 903,
  [904] = 904,
  [905] = 905,
  [906] = 906,
  [907] = 907,
  [908] = 908,
  [909] = 909,
  [910] = 796,
  [911] = 911,
  [912] = 912,
  [913] = 913,
  [914] = 914,
  [915] = 915,
  [916] = 916,
  [917] = 828,
  [918] = 829,
  [919] = 830,
  [920] = 831,
  [921] = 827,
  [922] = 922,
  [923] = 923,
  [924] = 804,
  [925] = 925,
  [926] = 926,
  [927] = 927,
  [928] = 928,
  [929] = 929,
  [930] = 930,
  [931] = 931,
  [932] = 932,
  [933] = 933,
  [934] = 934,
  [935] = 935,
  [936] = 818,
  [937] = 806,
  [938] = 810,
  [939] = 812,
  [940] = 940,
  [941] = 941,
  [942] = 815,
  [943] = 943,
  [944] = 819,
  [945] = 945,
  [946] = 822,
  [947] = 947,
  [948] = 948,
  [949] = 949,
  [950] = 807,
  [951] = 951,
  [952] = 952,
  [953] = 808,
  [954] = 809,
  [955] = 955,
  [956] = 956,
  [957] = 957,
  [958] = 958,
  [959] = 959,
  [960] = 960,
  [961] = 811,
  [962] = 962,
  [963] = 963,
  [964] = 964,
  [965] = 965,
  [966] = 966,
  [967] = 967,
  [968] = 813,
  [969] = 969,
  [970] = 970,
  [971] = 971,
  [972] = 791,
  [973] = 814,
  [974] = 974,
  [975] = 975,
  [976] = 945,
  [977] = 977,
  [978] = 978,
  [979] = 790,
  [980] = 816,
  [981] = 981,
  [982] = 982,
  [983] = 817,
  [984] = 984,
  [985] = 985,
  [986] = 986,
  [987] = 987,
  [988] = 988,
  [989] = 820,
  [990] = 990,
  [991] = 991,
  [992] = 821,
  [993] = 993,
  [994] = 994,
  [995] = 995,
  [996] = 996,
  [997] = 997,
  [998] = 998,
  [999] = 823,
  [1000] = 824,
  [1001] = 825,
  [1002] = 826,
  [1003] = 1003,
  [1004] = 1004,
  [1005] = 1005,
  [1006] = 1006,
  [1007] = 1007,
  [1008] = 1008,
  [1009] = 1009,
  [1010] = 1010,
  [1011] = 1011,
  [1012] = 1012,
  [1013] = 1013,
  [1014] = 1014,
  [1015] = 1015,
  [1016] = 1016,
  [1017] = 1017,
  [1018] = 855,
  [1019] = 1019,
  [1020] = 1020,
  [1021] = 1021,
  [1022] = 855,
  [1023] = 1021,
  [1024] = 1024,
  [1025] = 1021,
  [1026] = 1024,
  [1027] = 1020,
  [1028] = 1028,
  [1029] = 1029,
  [1030] = 1030,
  [1031] = 855,
  [1032] = 855,
  [1033] = 1029,
  [1034] = 1034,
  [1035] = 1020,
  [1036] = 1036,
  [1037] = 1037,
  [1038] = 1024,
  [1039] = 1039,
  [1040] = 1030,
  [1041] = 855,
  [1042] = 1042,
  [1043] = 1039,
  [1044] = 959,
  [1045] = 1045,
  [1046] = 1046,
  [1047] = 1030,
  [1048] = 915,
  [1049] = 914,
  [1050] = 1050,
  [1051] = 1051,
  [1052] = 1052,
  [1053] = 1053,
  [1054] = 1054,
  [1055] = 1055,
  [1056] = 1056,
  [1057] = 1057,
  [1058] = 1058,
  [1059] = 1059,
  [1060] = 1060,
  [1061] = 1061,
  [1062] = 1062,
  [1063] = 249,
  [1064] = 1064,
  [1065] = 1065,
  [1066] = 1066,
  [1067] = 1051,
  [1068] = 894,
  [1069] = 1069,
  [1070] = 1070,
  [1071] = 1050,
  [1072] = 880,
  [1073] = 1052,
  [1074] = 1074,
  [1075] = 1075,
  [1076] = 1076,
  [1077] = 1077,
  [1078] = 1051,
  [1079] = 1079,
  [1080] = 1080,
  [1081] = 1081,
  [1082] = 1082,
  [1083] = 1051,
  [1084] = 894,
  [1085] = 1085,
  [1086] = 880,
  [1087] = 1052,
  [1088] = 1088,
  [1089] = 1089,
  [1090] = 880,
  [1091] = 1091,
  [1092] = 1092,
  [1093] = 1093,
  [1094] = 1094,
  [1095] = 1051,
  [1096] = 894,
  [1097] = 1050,
  [1098] = 1050,
  [1099] = 880,
  [1100] = 1052,
  [1101] = 1101,
  [1102] = 252,
  [1103] = 1088,
  [1104] = 894,
  [1105] = 1105,
  [1106] = 1106,
  [1107] = 1051,
  [1108] = 894,
  [1109] = 248,
  [1110] = 1060,
  [1111] = 1050,
  [1112] = 1069,
  [1113] = 880,
  [1114] = 1052,
  [1115] = 1115,
  [1116] = 1050,
  [1117] = 1007,
  [1118] = 1051,
  [1119] = 1050,
  [1120] = 1052,
  [1121] = 250,
  [1122] = 1122,
  [1123] = 1123,
  [1124] = 1124,
  [1125] = 1125,
  [1126] = 1126,
  [1127] = 923,
  [1128] = 1128,
  [1129] = 1091,
  [1130] = 1130,
  [1131] = 1131,
  [1132] = 977,
  [1133] = 1133,
  [1134] = 1134,
  [1135] = 1135,
  [1136] = 1136,
  [1137] = 1124,
  [1138] = 1136,
  [1139] = 1139,
  [1140] = 1140,
  [1141] = 1140,
  [1142] = 1142,
  [1143] = 1143,
  [1144] = 1144,
  [1145] = 1145,
  [1146] = 1145,
  [1147] = 1147,
  [1148] = 1148,
  [1149] = 1149,
  [1150] = 1150,
  [1151] = 1151,
  [1152] = 1152,
  [1153] = 1153,
  [1154] = 1154,
  [1155] = 1155,
  [1156] = 1156,
  [1157] = 1157,
  [1158] = 1158,
  [1159] = 1159,
  [1160] = 1160,
  [1161] = 1161,
  [1162] = 1152,
  [1163] = 1135,
  [1164] = 1164,
  [1165] = 1140,
  [1166] = 1144,
  [1167] = 1167,
  [1168] = 1145,
  [1169] = 1123,
  [1170] = 1170,
  [1171] = 1076,
  [1172] = 1142,
  [1173] = 1144,
  [1174] = 1135,
  [1175] = 1175,
  [1176] = 1176,
  [1177] = 1160,
  [1178] = 1161,
  [1179] = 1152,
  [1180] = 1135,
  [1181] = 1140,
  [1182] = 1144,
  [1183] = 1183,
  [1184] = 1167,
  [1185] = 1145,
  [1186] = 1186,
  [1187] = 1187,
  [1188] = 790,
  [1189] = 1143,
  [1190] = 1190,
  [1191] = 1064,
  [1192] = 1161,
  [1193] = 1160,
  [1194] = 1194,
  [1195] = 1161,
  [1196] = 1152,
  [1197] = 1197,
  [1198] = 1135,
  [1199] = 1140,
  [1200] = 1140,
  [1201] = 1144,
  [1202] = 1167,
  [1203] = 1126,
  [1204] = 1145,
  [1205] = 1142,
  [1206] = 1160,
  [1207] = 1207,
  [1208] = 1150,
  [1209] = 1144,
  [1210] = 1081,
  [1211] = 1053,
  [1212] = 1054,
  [1213] = 1143,
  [1214] = 1167,
  [1215] = 1215,
  [1216] = 1216,
  [1217] = 1161,
  [1218] = 1145,
  [1219] = 1219,
  [1220] = 791,
  [1221] = 1160,
  [1222] = 1150,
  [1223] = 1152,
  [1224] = 1160,
  [1225] = 1135,
  [1226] = 791,
  [1227] = 1149,
  [1228] = 1167,
  [1229] = 1216,
  [1230] = 1230,
  [1231] = 1151,
  [1232] = 1122,
  [1233] = 1161,
  [1234] = 1128,
  [1235] = 1066,
  [1236] = 1136,
  [1237] = 1237,
  [1238] = 1152,
  [1239] = 1239,
  [1240] = 1045,
  [1241] = 1065,
  [1242] = 1167,
  [1243] = 1243,
  [1244] = 1244,
  [1245] = 1245,
  [1246] = 1246,
  [1247] = 1244,
  [1248] = 1248,
  [1249] = 1243,
  [1250] = 1250,
  [1251] = 1248,
  [1252] = 1252,
  [1253] = 1015,
  [1254] = 1016,
  [1255] = 1255,
  [1256] = 1255,
  [1257] = 1257,
  [1258] = 1258,
  [1259] = 1255,
  [1260] = 1252,
  [1261] = 1261,
  [1262] = 1244,
  [1263] = 1263,
  [1264] = 1264,
  [1265] = 1248,
  [1266] = 1255,
  [1267] = 1248,
  [1268] = 1258,
  [1269] = 1269,
  [1270] = 1270,
  [1271] = 1243,
  [1272] = 1258,
  [1273] = 1273,
  [1274] = 1274,
  [1275] = 1255,
  [1276] = 1003,
  [1277] = 1277,
  [1278] = 1278,
  [1279] = 1279,
  [1280] = 1280,
  [1281] = 970,
  [1282] = 1282,
  [1283] = 1283,
  [1284] = 1017,
  [1285] = 1248,
  [1286] = 1286,
  [1287] = 1287,
  [1288] = 1288,
  [1289] = 1289,
  [1290] = 1280,
  [1291] = 1291,
  [1292] = 1258,
  [1293] = 1258,
  [1294] = 1280,
  [1295] = 1258,
  [1296] = 1296,
  [1297] = 1297,
  [1298] = 1298,
  [1299] = 1299,
  [1300] = 1280,
  [1301] = 1301,
  [1302] = 1244,
  [1303] = 1280,
  [1304] = 1304,
  [1305] = 1280,
  [1306] = 1283,
  [1307] = 1244,
  [1308] = 1308,
  [1309] = 1248,
  [1310] = 1310,
  [1311] = 1283,
  [1312] = 1283,
  [1313] = 1255,
  [1314] = 1283,
  [1315] = 1283,
  [1316] = 1244,
  [1317] = 1317,
  [1318] = 1318,
  [1319] = 1319,
  [1320] = 1320,
  [1321] = 1321,
  [1322] = 1322,
  [1323] = 1323,
  [1324] = 1324,
  [1325] = 1325,
  [1326] = 1318,
  [1327] = 1325,
  [1328] = 1324,
  [1329] = 1318,
  [1330] = 1330,
  [1331] = 1331,
  [1332] = 1332,
  [1333] = 1333,
  [1334] = 1319,
  [1335] = 1318,
  [1336] = 1333,
  [1337] = 1337,
  [1338] = 1318,
  [1339] = 1319,
  [1340] = 1333,
  [1341] = 1341,
  [1342] = 1342,
  [1343] = 1321,
  [1344] = 1344,
  [1345] = 1345,
  [1346] = 1319,
  [1347] = 1324,
  [1348] = 1324,
  [1349] = 1349,
  [1350] = 1331,
  [1351] = 1351,
  [1352] = 1352,
  [1353] = 1318,
  [1354] = 1354,
  [1355] = 1321,
  [1356] = 1342,
  [1357] = 1319,
  [1358] = 1358,
  [1359] = 1321,
  [1360] = 1360,
  [1361] = 1342,
  [1362] = 1325,
  [1363] = 1317,
  [1364] = 1352,
  [1365] = 1365,
  [1366] = 1322,
  [1367] = 1367,
  [1368] = 1368,
  [1369] = 1319,
  [1370] = 1370,
  [1371] = 1352,
  [1372] = 1372,
  [1373] = 1373,
  [1374] = 1374,
  [1375] = 1352,
  [1376] = 1376,
  [1377] = 1325,
  [1378] = 1325,
  [1379] = 1352,
  [1380] = 1365,
  [1381] = 1321,
  [1382] = 1319,
  [1383] = 1321,
  [1384] = 1384,
  [1385] = 1385,
  [1386] = 1386,
  [1387] = 1324,
  [1388] = 1352,
  [1389] = 1322,
  [1390] = 1390,
  [1391] = 1391,
  [1392] = 1392,
  [1393] = 1317,
  [1394] = 1394,
  [1395] = 1317,
  [1396] = 1396,
  [1397] = 1397,
  [1398] = 1324,
  [1399] = 1317,
  [1400] = 1325,
  [1401] = 1317,
  [1402] = 1402,
  [1403] = 1365,
};

static TSCharacterRange sym_identifier_character_set_1[] = {
  {'A', 'Z'}, {'_', '_'}, {'a', 'z'}, {0xaa, 0xaa}, {0xb5, 0xb5}, {0xba, 0xba}, {0xc0, 0xd6}, {0xd8, 0xf6},
  {0xf8, 0x2c1}, {0x2c6, 0x2d1}, {0x2e0, 0x2e4}, {0x2ec, 0x2ec}, {0x2ee, 0x2ee}, {0x370, 0x374}, {0x376, 0x377}, {0x37b, 0x37d},
  {0x37f, 0x37f}, {0x386, 0x386}, {0x388, 0x38a}, {0x38c, 0x38c}, {0x38e, 0x3a1}, {0x3a3, 0x3f5}, {0x3f7, 0x481}, {0x48a, 0x52f},
  {0x531, 0x556}, {0x559, 0x559}, {0x560, 0x588}, {0x5d0, 0x5ea}, {0x5ef, 0x5f2}, {0x620, 0x64a}, {0x66e, 0x66f}, {0x671, 0x6d3},
  {0x6d5, 0x6d5}, {0x6e5, 0x6e6}, {0x6ee, 0x6ef}, {0x6fa, 0x6fc}, {0x6ff, 0x6ff}, {0x710, 0x710}, {0x712, 0x72f}, {0x74d, 0x7a5},
  {0x7b1, 0x7b1}, {0x7ca, 0x7ea}, {0x7f4, 0x7f5}, {0x7fa, 0x7fa}, {0x800, 0x815}, {0x81a, 0x81a}, {0x824, 0x824}, {0x828, 0x828},
  {0x840, 0x858}, {0x860, 0x86a}, {0x870, 0x887}, {0x889, 0x88e}, {0x8a0, 0x8c9}, {0x904, 0x939}, {0x93d, 0x93d}, {0x950, 0x950},
  {0x958, 0x961}, {0x971, 0x980}, {0x985, 0x98c}, {0x98f, 0x990}, {0x993, 0x9a8}, {0x9aa, 0x9b0}, {0x9b2, 0x9b2}, {0x9b6, 0x9b9},
  {0x9bd, 0x9bd}, {0x9ce, 0x9ce}, {0x9dc, 0x9dd}, {0x9df, 0x9e1}, {0x9f0, 0x9f1}, {0x9fc, 0x9fc}, {0xa05, 0xa0a}, {0xa0f, 0xa10},
  {0xa13, 0xa28}, {0xa2a, 0xa30}, {0xa32, 0xa33}, {0xa35, 0xa36}, {0xa38, 0xa39}, {0xa59, 0xa5c}, {0xa5e, 0xa5e}, {0xa72, 0xa74},
  {0xa85, 0xa8d}, {0xa8f, 0xa91}, {0xa93, 0xaa8}, {0xaaa, 0xab0}, {0xab2, 0xab3}, {0xab5, 0xab9}, {0xabd, 0xabd}, {0xad0, 0xad0},
  {0xae0, 0xae1}, {0xaf9, 0xaf9}, {0xb05, 0xb0c}, {0xb0f, 0xb10}, {0xb13, 0xb28}, {0xb2a, 0xb30}, {0xb32, 0xb33}, {0xb35, 0xb39},
  {0xb3d, 0xb3d}, {0xb5c, 0xb5d}, {0xb5f, 0xb61}, {0xb71, 0xb71}, {0xb83, 0xb83}, {0xb85, 0xb8a}, {0xb8e, 0xb90}, {0xb92, 0xb95},
  {0xb99, 0xb9a}, {0xb9c, 0xb9c}, {0xb9e, 0xb9f}, {0xba3, 0xba4}, {0xba8, 0xbaa}, {0xbae, 0xbb9}, {0xbd0, 0xbd0}, {0xc05, 0xc0c},
  {0xc0e, 0xc10}, {0xc12, 0xc28}, {0xc2a, 0xc39}, {0xc3d, 0xc3d}, {0xc58, 0xc5a}, {0xc5d, 0xc5d}, {0xc60, 0xc61}, {0xc80, 0xc80},
  {0xc85, 0xc8c}, {0xc8e, 0xc90}, {0xc92, 0xca8}, {0xcaa, 0xcb3}, {0xcb5, 0xcb9}, {0xcbd, 0xcbd}, {0xcdd, 0xcde}, {0xce0, 0xce1},
  {0xcf1, 0xcf2}, {0xd04, 0xd0c}, {0xd0e, 0xd10}, {0xd12, 0xd3a}, {0xd3d, 0xd3d}, {0xd4e, 0xd4e}, {0xd54, 0xd56}, {0xd5f, 0xd61},
  {0xd7a, 0xd7f}, {0xd85, 0xd96}, {0xd9a, 0xdb1}, {0xdb3, 0xdbb}, {0xdbd, 0xdbd}, {0xdc0, 0xdc6}, {0xe01, 0xe30}, {0xe32, 0xe32},
  {0xe40, 0xe46}, {0xe81, 0xe82}, {0xe84, 0xe84}, {0xe86, 0xe8a}, {0xe8c, 0xea3}, {0xea5, 0xea5}, {0xea7, 0xeb0}, {0xeb2, 0xeb2},
  {0xebd, 0xebd}, {0xec0, 0xec4}, {0xec6, 0xec6}, {0xedc, 0xedf}, {0xf00, 0xf00}, {0xf40, 0xf47}, {0xf49, 0xf6c}, {0xf88, 0xf8c},
  {0x1000, 0x102a}, {0x103f, 0x103f}, {0x1050, 0x1055}, {0x105a, 0x105d}, {0x1061, 0x1061}, {0x1065, 0x1066}, {0x106e, 0x1070}, {0x1075, 0x1081},
  {0x108e, 0x108e}, {0x10a0, 0x10c5}, {0x10c7, 0x10c7}, {0x10cd, 0x10cd}, {0x10d0, 0x10fa}, {0x10fc, 0x1248}, {0x124a, 0x124d}, {0x1250, 0x1256},
  {0x1258, 0x1258}, {0x125a, 0x125d}, {0x1260, 0x1288}, {0x128a, 0x128d}, {0x1290, 0x12b0}, {0x12b2, 0x12b5}, {0x12b8, 0x12be}, {0x12c0, 0x12c0},
  {0x12c2, 0x12c5}, {0x12c8, 0x12d6}, {0x12d8, 0x1310}, {0x1312, 0x1315}, {0x1318, 0x135a}, {0x1380, 0x138f}, {0x13a0, 0x13f5}, {0x13f8, 0x13fd},
  {0x1401, 0x166c}, {0x166f, 0x167f}, {0x1681, 0x169a}, {0x16a0, 0x16ea}, {0x16ee, 0x16f8}, {0x1700, 0x1711}, {0x171f, 0x1731}, {0x1740, 0x1751},
  {0x1760, 0x176c}, {0x176e, 0x1770}, {0x1780, 0x17b3}, {0x17d7, 0x17d7}, {0x17dc, 0x17dc}, {0x1820, 0x1878}, {0x1880, 0x18a8}, {0x18aa, 0x18aa},
  {0x18b0, 0x18f5}, {0x1900, 0x191e}, {0x1950, 0x196d}, {0x1970, 0x1974}, {0x1980, 0x19ab}, {0x19b0, 0x19c9}, {0x1a00, 0x1a16}, {0x1a20, 0x1a54},
  {0x1aa7, 0x1aa7}, {0x1b05, 0x1b33}, {0x1b45, 0x1b4c}, {0x1b83, 0x1ba0}, {0x1bae, 0x1baf}, {0x1bba, 0x1be5}, {0x1c00, 0x1c23}, {0x1c4d, 0x1c4f},
  {0x1c5a, 0x1c7d}, {0x1c80, 0x1c88}, {0x1c90, 0x1cba}, {0x1cbd, 0x1cbf}, {0x1ce9, 0x1cec}, {0x1cee, 0x1cf3}, {0x1cf5, 0x1cf6}, {0x1cfa, 0x1cfa},
  {0x1d00, 0x1dbf}, {0x1e00, 0x1f15}, {0x1f18, 0x1f1d}, {0x1f20, 0x1f45}, {0x1f48, 0x1f4d}, {0x1f50, 0x1f57}, {0x1f59, 0x1f59}, {0x1f5b, 0x1f5b},
  {0x1f5d, 0x1f5d}, {0x1f5f, 0x1f7d}, {0x1f80, 0x1fb4}, {0x1fb6, 0x1fbc}, {0x1fbe, 0x1fbe}, {0x1fc2, 0x1fc4}, {0x1fc6, 0x1fcc}, {0x1fd0, 0x1fd3},
  {0x1fd6, 0x1fdb}, {0x1fe0, 0x1fec}, {0x1ff2, 0x1ff4}, {0x1ff6, 0x1ffc}, {0x2071, 0x2071}, {0x207f, 0x207f}, {0x2090, 0x209c}, {0x2102, 0x2102},
  {0x2107, 0x2107}, {0x210a, 0x2113}, {0x2115, 0x2115}, {0x2118, 0x211d}, {0x2124, 0x2124}, {0x2126, 0x2126}, {0x2128, 0x2128}, {0x212a, 0x2139},
  {0x213c, 0x213f}, {0x2145, 0x2149}, {0x214e, 0x214e}, {0x2160, 0x2188}, {0x2c00, 0x2ce4}, {0x2ceb, 0x2cee}, {0x2cf2, 0x2cf3}, {0x2d00, 0x2d25},
  {0x2d27, 0x2d27}, {0x2d2d, 0x2d2d}, {0x2d30, 0x2d67}, {0x2d6f, 0x2d6f}, {0x2d80, 0x2d96}, {0x2da0, 0x2da6}, {0x2da8, 0x2dae}, {0x2db0, 0x2db6},
  {0x2db8, 0x2dbe}, {0x2dc0, 0x2dc6}, {0x2dc8, 0x2dce}, {0x2dd0, 0x2dd6}, {0x2dd8, 0x2dde}, {0x3005, 0x3007}, {0x3021, 0x3029}, {0x3031, 0x3035},
  {0x3038, 0x303c}, {0x3041, 0x3096}, {0x309d, 0x309f}, {0x30a1, 0x30fa}, {0x30fc, 0x30ff}, {0x3105, 0x312f}, {0x3131, 0x318e}, {0x31a0, 0x31bf},
  {0x31f0, 0x31ff}, {0x3400, 0x4dbf}, {0x4e00, 0xa48c}, {0xa4d0, 0xa4fd}, {0xa500, 0xa60c}, {0xa610, 0xa61f}, {0xa62a, 0xa62b}, {0xa640, 0xa66e},
  {0xa67f, 0xa69d}, {0xa6a0, 0xa6ef}, {0xa717, 0xa71f}, {0xa722, 0xa788}, {0xa78b, 0xa7ca}, {0xa7d0, 0xa7d1}, {0xa7d3, 0xa7d3}, {0xa7d5, 0xa7d9},
  {0xa7f2, 0xa801}, {0xa803, 0xa805}, {0xa807, 0xa80a}, {0xa80c, 0xa822}, {0xa840, 0xa873}, {0xa882, 0xa8b3}, {0xa8f2, 0xa8f7}, {0xa8fb, 0xa8fb},
  {0xa8fd, 0xa8fe}, {0xa90a, 0xa925}, {0xa930, 0xa946}, {0xa960, 0xa97c}, {0xa984, 0xa9b2}, {0xa9cf, 0xa9cf}, {0xa9e0, 0xa9e4}, {0xa9e6, 0xa9ef},
  {0xa9fa, 0xa9fe}, {0xaa00, 0xaa28}, {0xaa40, 0xaa42}, {0xaa44, 0xaa4b}, {0xaa60, 0xaa76}, {0xaa7a, 0xaa7a}, {0xaa7e, 0xaaaf}, {0xaab1, 0xaab1},
  {0xaab5, 0xaab6}, {0xaab9, 0xaabd}, {0xaac0, 0xaac0}, {0xaac2, 0xaac2}, {0xaadb, 0xaadd}, {0xaae0, 0xaaea}, {0xaaf2, 0xaaf4}, {0xab01, 0xab06},
  {0xab09, 0xab0e}, {0xab11, 0xab16}, {0xab20, 0xab26}, {0xab28, 0xab2e}, {0xab30, 0xab5a}, {0xab5c, 0xab69}, {0xab70, 0xabe2}, {0xac00, 0xd7a3},
  {0xd7b0, 0xd7c6}, {0xd7cb, 0xd7fb}, {0xf900, 0xfa6d}, {0xfa70, 0xfad9}, {0xfb00, 0xfb06}, {0xfb13, 0xfb17}, {0xfb1d, 0xfb1d}, {0xfb1f, 0xfb28},
  {0xfb2a, 0xfb36}, {0xfb38, 0xfb3c}, {0xfb3e, 0xfb3e}, {0xfb40, 0xfb41}, {0xfb43, 0xfb44}, {0xfb46, 0xfbb1}, {0xfbd3, 0xfc5d}, {0xfc64, 0xfd3d},
  {0xfd50, 0xfd8f}, {0xfd92, 0xfdc7}, {0xfdf0, 0xfdf9}, {0xfe71, 0xfe71}, {0xfe73, 0xfe73}, {0xfe77, 0xfe77}, {0xfe79, 0xfe79}, {0xfe7b, 0xfe7b},
  {0xfe7d, 0xfe7d}, {0xfe7f, 0xfefc}, {0xff21, 0xff3a}, {0xff41, 0xff5a}, {0xff66, 0xff9d}, {0xffa0, 0xffbe}, {0xffc2, 0xffc7}, {0xffca, 0xffcf},
  {0xffd2, 0xffd7}, {0xffda, 0xffdc}, {0x10000, 0x1000b}, {0x1000d, 0x10026}, {0x10028, 0x1003a}, {0x1003c, 0x1003d}, {0x1003f, 0x1004d}, {0x10050, 0x1005d},
  {0x10080, 0x100fa}, {0x10140, 0x10174}, {0x10280, 0x1029c}, {0x102a0, 0x102d0}, {0x10300, 0x1031f}, {0x1032d, 0x1034a}, {0x10350, 0x10375}, {0x10380, 0x1039d},
  {0x103a0, 0x103c3}, {0x103c8, 0x103cf}, {0x103d1, 0x103d5}, {0x10400, 0x1049d}, {0x104b0, 0x104d3}, {0x104d8, 0x104fb}, {0x10500, 0x10527}, {0x10530, 0x10563},
  {0x10570, 0x1057a}, {0x1057c, 0x1058a}, {0x1058c, 0x10592}, {0x10594, 0x10595}, {0x10597, 0x105a1}, {0x105a3, 0x105b1}, {0x105b3, 0x105b9}, {0x105bb, 0x105bc},
  {0x10600, 0x10736}, {0x10740, 0x10755}, {0x10760, 0x10767}, {0x10780, 0x10785}, {0x10787, 0x107b0}, {0x107b2, 0x107ba}, {0x10800, 0x10805}, {0x10808, 0x10808},
  {0x1080a, 0x10835}, {0x10837, 0x10838}, {0x1083c, 0x1083c}, {0x1083f, 0x10855}, {0x10860, 0x10876}, {0x10880, 0x1089e}, {0x108e0, 0x108f2}, {0x108f4, 0x108f5},
  {0x10900, 0x10915}, {0x10920, 0x10939}, {0x10980, 0x109b7}, {0x109be, 0x109bf}, {0x10a00, 0x10a00}, {0x10a10, 0x10a13}, {0x10a15, 0x10a17}, {0x10a19, 0x10a35},
  {0x10a60, 0x10a7c}, {0x10a80, 0x10a9c}, {0x10ac0, 0x10ac7}, {0x10ac9, 0x10ae4}, {0x10b00, 0x10b35}, {0x10b40, 0x10b55}, {0x10b60, 0x10b72}, {0x10b80, 0x10b91},
  {0x10c00, 0x10c48}, {0x10c80, 0x10cb2}, {0x10cc0, 0x10cf2}, {0x10d00, 0x10d23}, {0x10e80, 0x10ea9}, {0x10eb0, 0x10eb1}, {0x10f00, 0x10f1c}, {0x10f27, 0x10f27},
  {0x10f30, 0x10f45}, {0x10f70, 0x10f81}, {0x10fb0, 0x10fc4}, {0x10fe0, 0x10ff6}, {0x11003, 0x11037}, {0x11071, 0x11072}, {0x11075, 0x11075}, {0x11083, 0x110af},
  {0x110d0, 0x110e8}, {0x11103, 0x11126}, {0x11144, 0x11144}, {0x11147, 0x11147}, {0x11150, 0x11172}, {0x11176, 0x11176}, {0x11183, 0x111b2}, {0x111c1, 0x111c4},
  {0x111da, 0x111da}, {0x111dc, 0x111dc}, {0x11200, 0x11211}, {0x11213, 0x1122b}, {0x1123f, 0x11240}, {0x11280, 0x11286}, {0x11288, 0x11288}, {0x1128a, 0x1128d},
  {0x1128f, 0x1129d}, {0x1129f, 0x112a8}, {0x112b0, 0x112de}, {0x11305, 0x1130c}, {0x1130f, 0x11310}, {0x11313, 0x11328}, {0x1132a, 0x11330}, {0x11332, 0x11333},
  {0x11335, 0x11339}, {0x1133d, 0x1133d}, {0x11350, 0x11350}, {0x1135d, 0x11361}, {0x11400, 0x11434}, {0x11447, 0x1144a}, {0x1145f, 0x11461}, {0x11480, 0x114af},
  {0x114c4, 0x114c5}, {0x114c7, 0x114c7}, {0x11580, 0x115ae}, {0x115d8, 0x115db}, {0x11600, 0x1162f}, {0x11644, 0x11644}, {0x11680, 0x116aa}, {0x116b8, 0x116b8},
  {0x11700, 0x1171a}, {0x11740, 0x11746}, {0x11800, 0x1182b}, {0x118a0, 0x118df}, {0x118ff, 0x11906}, {0x11909, 0x11909}, {0x1190c, 0x11913}, {0x11915, 0x11916},
  {0x11918, 0x1192f}, {0x1193f, 0x1193f}, {0x11941, 0x11941}, {0x119a0, 0x119a7}, {0x119aa, 0x119d0}, {0x119e1, 0x119e1}, {0x119e3, 0x119e3}, {0x11a00, 0x11a00},
  {0x11a0b, 0x11a32}, {0x11a3a, 0x11a3a}, {0x11a50, 0x11a50}, {0x11a5c, 0x11a89}, {0x11a9d, 0x11a9d}, {0x11ab0, 0x11af8}, {0x11c00, 0x11c08}, {0x11c0a, 0x11c2e},
  {0x11c40, 0x11c40}, {0x11c72, 0x11c8f}, {0x11d00, 0x11d06}, {0x11d08, 0x11d09}, {0x11d0b, 0x11d30}, {0x11d46, 0x11d46}, {0x11d60, 0x11d65}, {0x11d67, 0x11d68},
  {0x11d6a, 0x11d89}, {0x11d98, 0x11d98}, {0x11ee0, 0x11ef2}, {0x11f02, 0x11f02}, {0x11f04, 0x11f10}, {0x11f12, 0x11f33}, {0x11fb0, 0x11fb0}, {0x12000, 0x12399},
  {0x12400, 0x1246e}, {0x12480, 0x12543}, {0x12f90, 0x12ff0}, {0x13000, 0x1342f}, {0x13441, 0x13446}, {0x14400, 0x14646}, {0x16800, 0x16a38}, {0x16a40, 0x16a5e},
  {0x16a70, 0x16abe}, {0x16ad0, 0x16aed}, {0x16b00, 0x16b2f}, {0x16b40, 0x16b43}, {0x16b63, 0x16b77}, {0x16b7d, 0x16b8f}, {0x16e40, 0x16e7f}, {0x16f00, 0x16f4a},
  {0x16f50, 0x16f50}, {0x16f93, 0x16f9f}, {0x16fe0, 0x16fe1}, {0x16fe3, 0x16fe3}, {0x17000, 0x187f7}, {0x18800, 0x18cd5}, {0x18d00, 0x18d08}, {0x1aff0, 0x1aff3},
  {0x1aff5, 0x1affb}, {0x1affd, 0x1affe}, {0x1b000, 0x1b122}, {0x1b132, 0x1b132}, {0x1b150, 0x1b152}, {0x1b155, 0x1b155}, {0x1b164, 0x1b167}, {0x1b170, 0x1b2fb},
  {0x1bc00, 0x1bc6a}, {0x1bc70, 0x1bc7c}, {0x1bc80, 0x1bc88}, {0x1bc90, 0x1bc99}, {0x1d400, 0x1d454}, {0x1d456, 0x1d49c}, {0x1d49e, 0x1d49f}, {0x1d4a2, 0x1d4a2},
  {0x1d4a5, 0x1d4a6}, {0x1d4a9, 0x1d4ac}, {0x1d4ae, 0x1d4b9}, {0x1d4bb, 0x1d4bb}, {0x1d4bd, 0x1d4c3}, {0x1d4c5, 0x1d505}, {0x1d507, 0x1d50a}, {0x1d50d, 0x1d514},
  {0x1d516, 0x1d51c}, {0x1d51e, 0x1d539}, {0x1d53b, 0x1d53e}, {0x1d540, 0x1d544}, {0x1d546, 0x1d546}, {0x1d54a, 0x1d550}, {0x1d552, 0x1d6a5}, {0x1d6a8, 0x1d6c0},
  {0x1d6c2, 0x1d6da}, {0x1d6dc, 0x1d6fa}, {0x1d6fc, 0x1d714}, {0x1d716, 0x1d734}, {0x1d736, 0x1d74e}, {0x1d750, 0x1d76e}, {0x1d770, 0x1d788}, {0x1d78a, 0x1d7a8},
  {0x1d7aa, 0x1d7c2}, {0x1d7c4, 0x1d7cb}, {0x1df00, 0x1df1e}, {0x1df25, 0x1df2a}, {0x1e030, 0x1e06d}, {0x1e100, 0x1e12c}, {0x1e137, 0x1e13d}, {0x1e14e, 0x1e14e},
  {0x1e290, 0x1e2ad}, {0x1e2c0, 0x1e2eb}, {0x1e4d0, 0x1e4eb}, {0x1e7e0, 0x1e7e6}, {0x1e7e8, 0x1e7eb}, {0x1e7ed, 0x1e7ee}, {0x1e7f0, 0x1e7fe}, {0x1e800, 0x1e8c4},
  {0x1e900, 0x1e943}, {0x1e94b, 0x1e94b}, {0x1ee00, 0x1ee03}, {0x1ee05, 0x1ee1f}, {0x1ee21, 0x1ee22}, {0x1ee24, 0x1ee24}, {0x1ee27, 0x1ee27}, {0x1ee29, 0x1ee32},
  {0x1ee34, 0x1ee37}, {0x1ee39, 0x1ee39}, {0x1ee3b, 0x1ee3b}, {0x1ee42, 0x1ee42}, {0x1ee47, 0x1ee47}, {0x1ee49, 0x1ee49}, {0x1ee4b, 0x1ee4b}, {0x1ee4d, 0x1ee4f},
  {0x1ee51, 0x1ee52}, {0x1ee54, 0x1ee54}, {0x1ee57, 0x1ee57}, {0x1ee59, 0x1ee59}, {0x1ee5b, 0x1ee5b}, {0x1ee5d, 0x1ee5d}, {0x1ee5f, 0x1ee5f}, {0x1ee61, 0x1ee62},
  {0x1ee64, 0x1ee64}, {0x1ee67, 0x1ee6a}, {0x1ee6c, 0x1ee72}, {0x1ee74, 0x1ee77}, {0x1ee79, 0x1ee7c}, {0x1ee7e, 0x1ee7e}, {0x1ee80, 0x1ee89}, {0x1ee8b, 0x1ee9b},
  {0x1eea1, 0x1eea3}, {0x1eea5, 0x1eea9}, {0x1eeab, 0x1eebb}, {0x20000, 0x2a6df}, {0x2a700, 0x2b739}, {0x2b740, 0x2b81d}, {0x2b820, 0x2cea1}, {0x2ceb0, 0x2ebe0},
  {0x2ebf0, 0x2ee5d}, {0x2f800, 0x2fa1d}, {0x30000, 0x3134a}, {0x31350, 0x323af},
};

static TSCharacterRange sym_identifier_character_set_2[] = {
  {'0', '9'}, {'A', 'Z'}, {'_', '_'}, {'a', 'z'}, {0xaa, 0xaa}, {0xb5, 0xb5}, {0xb7, 0xb7}, {0xba, 0xba},
  {0xc0, 0xd6}, {0xd8, 0xf6}, {0xf8, 0x2c1}, {0x2c6, 0x2d1}, {0x2e0, 0x2e4}, {0x2ec, 0x2ec}, {0x2ee, 0x2ee}, {0x300, 0x374},
  {0x376, 0x377}, {0x37b, 0x37d}, {0x37f, 0x37f}, {0x386, 0x38a}, {0x38c, 0x38c}, {0x38e, 0x3a1}, {0x3a3, 0x3f5}, {0x3f7, 0x481},
  {0x483, 0x487}, {0x48a, 0x52f}, {0x531, 0x556}, {0x559, 0x559}, {0x560, 0x588}, {0x591, 0x5bd}, {0x5bf, 0x5bf}, {0x5c1, 0x5c2},
  {0x5c4, 0x5c5}, {0x5c7, 0x5c7}, {0x5d0, 0x5ea}, {0x5ef, 0x5f2}, {0x610, 0x61a}, {0x620, 0x669}, {0x66e, 0x6d3}, {0x6d5, 0x6dc},
  {0x6df, 0x6e8}, {0x6ea, 0x6fc}, {0x6ff, 0x6ff}, {0x710, 0x74a}, {0x74d, 0x7b1}, {0x7c0, 0x7f5}, {0x7fa, 0x7fa}, {0x7fd, 0x7fd},
  {0x800, 0x82d}, {0x840, 0x85b}, {0x860, 0x86a}, {0x870, 0x887}, {0x889, 0x88e}, {0x898, 0x8e1}, {0x8e3, 0x963}, {0x966, 0x96f},
  {0x971, 0x983}, {0x985, 0x98c}, {0x98f, 0x990}, {0x993, 0x9a8}, {0x9aa, 0x9b0}, {0x9b2, 0x9b2}, {0x9b6, 0x9b9}, {0x9bc, 0x9c4},
  {0x9c7, 0x9c8}, {0x9cb, 0x9ce}, {0x9d7, 0x9d7}, {0x9dc, 0x9dd}, {0x9df, 0x9e3}, {0x9e6, 0x9f1}, {0x9fc, 0x9fc}, {0x9fe, 0x9fe},
  {0xa01, 0xa03}, {0xa05, 0xa0a}, {0xa0f, 0xa10}, {0xa13, 0xa28}, {0xa2a, 0xa30}, {0xa32, 0xa33}, {0xa35, 0xa36}, {0xa38, 0xa39},
  {0xa3c, 0xa3c}, {0xa3e, 0xa42}, {0xa47, 0xa48}, {0xa4b, 0xa4d}, {0xa51, 0xa51}, {0xa59, 0xa5c}, {0xa5e, 0xa5e}, {0xa66, 0xa75},
  {0xa81, 0xa83}, {0xa85, 0xa8d}, {0xa8f, 0xa91}, {0xa93, 0xaa8}, {0xaaa, 0xab0}, {0xab2, 0xab3}, {0xab5, 0xab9}, {0xabc, 0xac5},
  {0xac7, 0xac9}, {0xacb, 0xacd}, {0xad0, 0xad0}, {0xae0, 0xae3}, {0xae6, 0xaef}, {0xaf9, 0xaff}, {0xb01, 0xb03}, {0xb05, 0xb0c},
  {0xb0f, 0xb10}, {0xb13, 0xb28}, {0xb2a, 0xb30}, {0xb32, 0xb33}, {0xb35, 0xb39}, {0xb3c, 0xb44}, {0xb47, 0xb48}, {0xb4b, 0xb4d},
  {0xb55, 0xb57}, {0xb5c, 0xb5d}, {0xb5f, 0xb63}, {0xb66, 0xb6f}, {0xb71, 0xb71}, {0xb82, 0xb83}, {0xb85, 0xb8a}, {0xb8e, 0xb90},
  {0xb92, 0xb95}, {0xb99, 0xb9a}, {0xb9c, 0xb9c}, {0xb9e, 0xb9f}, {0xba3, 0xba4}, {0xba8, 0xbaa}, {0xbae, 0xbb9}, {0xbbe, 0xbc2},
  {0xbc6, 0xbc8}, {0xbca, 0xbcd}, {0xbd0, 0xbd0}, {0xbd7, 0xbd7}, {0xbe6, 0xbef}, {0xc00, 0xc0c}, {0xc0e, 0xc10}, {0xc12, 0xc28},
  {0xc2a, 0xc39}, {0xc3c, 0xc44}, {0xc46, 0xc48}, {0xc4a, 0xc4d}, {0xc55, 0xc56}, {0xc58, 0xc5a}, {0xc5d, 0xc5d}, {0xc60, 0xc63},
  {0xc66, 0xc6f}, {0xc80, 0xc83}, {0xc85, 0xc8c}, {0xc8e, 0xc90}, {0xc92, 0xca8}, {0xcaa, 0xcb3}, {0xcb5, 0xcb9}, {0xcbc, 0xcc4},
  {0xcc6, 0xcc8}, {0xcca, 0xccd}, {0xcd5, 0xcd6}, {0xcdd, 0xcde}, {0xce0, 0xce3}, {0xce6, 0xcef}, {0xcf1, 0xcf3}, {0xd00, 0xd0c},
  {0xd0e, 0xd10}, {0xd12, 0xd44}, {0xd46, 0xd48}, {0xd4a, 0xd4e}, {0xd54, 0xd57}, {0xd5f, 0xd63}, {0xd66, 0xd6f}, {0xd7a, 0xd7f},
  {0xd81, 0xd83}, {0xd85, 0xd96}, {0xd9a, 0xdb1}, {0xdb3, 0xdbb}, {0xdbd, 0xdbd}, {0xdc0, 0xdc6}, {0xdca, 0xdca}, {0xdcf, 0xdd4},
  {0xdd6, 0xdd6}, {0xdd8, 0xddf}, {0xde6, 0xdef}, {0xdf2, 0xdf3}, {0xe01, 0xe3a}, {0xe40, 0xe4e}, {0xe50, 0xe59}, {0xe81, 0xe82},
  {0xe84, 0xe84}, {0xe86, 0xe8a}, {0xe8c, 0xea3}, {0xea5, 0xea5}, {0xea7, 0xebd}, {0xec0, 0xec4}, {0xec6, 0xec6}, {0xec8, 0xece},
  {0xed0, 0xed9}, {0xedc, 0xedf}, {0xf00, 0xf00}, {0xf18, 0xf19}, {0xf20, 0xf29}, {0xf35, 0xf35}, {0xf37, 0xf37}, {0xf39, 0xf39},
  {0xf3e, 0xf47}, {0xf49, 0xf6c}, {0xf71, 0xf84}, {0xf86, 0xf97}, {0xf99, 0xfbc}, {0xfc6, 0xfc6}, {0x1000, 0x1049}, {0x1050, 0x109d},
  {0x10a0, 0x10c5}, {0x10c7, 0x10c7}, {0x10cd, 0x10cd}, {0x10d0, 0x10fa}, {0x10fc, 0x1248}, {0x124a, 0x124d}, {0x1250, 0x1256}, {0x1258, 0x1258},
  {0x125a, 0x125d}, {0x1260, 0x1288}, {0x128a, 0x128d}, {0x1290, 0x12b0}, {0x12b2, 0x12b5}, {0x12b8, 0x12be}, {0x12c0, 0x12c0}, {0x12c2, 0x12c5},
  {0x12c8, 0x12d6}, {0x12d8, 0x1310}, {0x1312, 0x1315}, {0x1318, 0x135a}, {0x135d, 0x135f}, {0x1369, 0x1371}, {0x1380, 0x138f}, {0x13a0, 0x13f5},
  {0x13f8, 0x13fd}, {0x1401, 0x166c}, {0x166f, 0x167f}, {0x1681, 0x169a}, {0x16a0, 0x16ea}, {0x16ee, 0x16f8}, {0x1700, 0x1715}, {0x171f, 0x1734},
  {0x1740, 0x1753}, {0x1760, 0x176c}, {0x176e, 0x1770}, {0x1772, 0x1773}, {0x1780, 0x17d3}, {0x17d7, 0x17d7}, {0x17dc, 0x17dd}, {0x17e0, 0x17e9},
  {0x180b, 0x180d}, {0x180f, 0x1819}, {0x1820, 0x1878}, {0x1880, 0x18aa}, {0x18b0, 0x18f5}, {0x1900, 0x191e}, {0x1920, 0x192b}, {0x1930, 0x193b},
  {0x1946, 0x196d}, {0x1970, 0x1974}, {0x1980, 0x19ab}, {0x19b0, 0x19c9}, {0x19d0, 0x19da}, {0x1a00, 0x1a1b}, {0x1a20, 0x1a5e}, {0x1a60, 0x1a7c},
  {0x1a7f, 0x1a89}, {0x1a90, 0x1a99}, {0x1aa7, 0x1aa7}, {0x1ab0, 0x1abd}, {0x1abf, 0x1ace}, {0x1b00, 0x1b4c}, {0x1b50, 0x1b59}, {0x1b6b, 0x1b73},
  {0x1b80, 0x1bf3}, {0x1c00, 0x1c37}, {0x1c40, 0x1c49}, {0x1c4d, 0x1c7d}, {0x1c80, 0x1c88}, {0x1c90, 0x1cba}, {0x1cbd, 0x1cbf}, {0x1cd0, 0x1cd2},
  {0x1cd4, 0x1cfa}, {0x1d00, 0x1f15}, {0x1f18, 0x1f1d}, {0x1f20, 0x1f45}, {0x1f48, 0x1f4d}, {0x1f50, 0x1f57}, {0x1f59, 0x1f59}, {0x1f5b, 0x1f5b},
  {0x1f5d, 0x1f5d}, {0x1f5f, 0x1f7d}, {0x1f80, 0x1fb4}, {0x1fb6, 0x1fbc}, {0x1fbe, 0x1fbe}, {0x1fc2, 0x1fc4}, {0x1fc6, 0x1fcc}, {0x1fd0, 0x1fd3},
  {0x1fd6, 0x1fdb}, {0x1fe0, 0x1fec}, {0x1ff2, 0x1ff4}, {0x1ff6, 0x1ffc}, {0x200c, 0x200d}, {0x203f, 0x2040}, {0x2054, 0x2054}, {0x2071, 0x2071},
  {0x207f, 0x207f}, {0x2090, 0x209c}, {0x20d0, 0x20dc}, {0x20e1, 0x20e1}, {0x20e5, 0x20f0}, {0x2102, 0x2102}, {0x2107, 0x2107}, {0x210a, 0x2113},
  {0x2115, 0x2115}, {0x2118, 0x211d}, {0x2124, 0x2124}, {0x2126, 0x2126}, {0x2128, 0x2128}, {0x212a, 0x2139}, {0x213c, 0x213f}, {0x2145, 0x2149},
  {0x214e, 0x214e}, {0x2160, 0x2188}, {0x2c00, 0x2ce4}, {0x2ceb, 0x2cf3}, {0x2d00, 0x2d25}, {0x2d27, 0x2d27}, {0x2d2d, 0x2d2d}, {0x2d30, 0x2d67},
  {0x2d6f, 0x2d6f}, {0x2d7f, 0x2d96}, {0x2da0, 0x2da6}, {0x2da8, 0x2dae}, {0x2db0, 0x2db6}, {0x2db8, 0x2dbe}, {0x2dc0, 0x2dc6}, {0x2dc8, 0x2dce},
  {0x2dd0, 0x2dd6}, {0x2dd8, 0x2dde}, {0x2de0, 0x2dff}, {0x3005, 0x3007}, {0x3021, 0x302f}, {0x3031, 0x3035}, {0x3038, 0x303c}, {0x3041, 0x3096},
  {0x3099, 0x309a}, {0x309d, 0x309f}, {0x30a1, 0x30ff}, {0x3105, 0x312f}, {0x3131, 0x318e}, {0x31a0, 0x31bf}, {0x31f0, 0x31ff}, {0x3400, 0x4dbf},
  {0x4e00, 0xa48c}, {0xa4d0, 0xa4fd}, {0xa500, 0xa60c}, {0xa610, 0xa62b}, {0xa640, 0xa66f}, {0xa674, 0xa67d}, {0xa67f, 0xa6f1}, {0xa717, 0xa71f},
  {0xa722, 0xa788}, {0xa78b, 0xa7ca}, {0xa7d0, 0xa7d1}, {0xa7d3, 0xa7d3}, {0xa7d5, 0xa7d9}, {0xa7f2, 0xa827}, {0xa82c, 0xa82c}, {0xa840, 0xa873},
  {0xa880, 0xa8c5}, {0xa8d0, 0xa8d9}, {0xa8e0, 0xa8f7}, {0xa8fb, 0xa8fb}, {0xa8fd, 0xa92d}, {0xa930, 0xa953}, {0xa960, 0xa97c}, {0xa980, 0xa9c0},
  {0xa9cf, 0xa9d9}, {0xa9e0, 0xa9fe}, {0xaa00, 0xaa36}, {0xaa40, 0xaa4d}, {0xaa50, 0xaa59}, {0xaa60, 0xaa76}, {0xaa7a, 0xaac2}, {0xaadb, 0xaadd},
  {0xaae0, 0xaaef}, {0xaaf2, 0xaaf6}, {0xab01, 0xab06}, {0xab09, 0xab0e}, {0xab11, 0xab16}, {0xab20, 0xab26}, {0xab28, 0xab2e}, {0xab30, 0xab5a},
  {0xab5c, 0xab69}, {0xab70, 0xabea}, {0xabec, 0xabed}, {0xabf0, 0xabf9}, {0xac00, 0xd7a3}, {0xd7b0, 0xd7c6}, {0xd7cb, 0xd7fb}, {0xf900, 0xfa6d},
  {0xfa70, 0xfad9}, {0xfb00, 0xfb06}, {0xfb13, 0xfb17}, {0xfb1d, 0xfb28}, {0xfb2a, 0xfb36}, {0xfb38, 0xfb3c}, {0xfb3e, 0xfb3e}, {0xfb40, 0xfb41},
  {0xfb43, 0xfb44}, {0xfb46, 0xfbb1}, {0xfbd3, 0xfc5d}, {0xfc64, 0xfd3d}, {0xfd50, 0xfd8f}, {0xfd92, 0xfdc7}, {0xfdf0, 0xfdf9}, {0xfe00, 0xfe0f},
  {0xfe20, 0xfe2f}, {0xfe33, 0xfe34}, {0xfe4d, 0xfe4f}, {0xfe71, 0xfe71}, {0xfe73, 0xfe73}, {0xfe77, 0xfe77}, {0xfe79, 0xfe79}, {0xfe7b, 0xfe7b},
  {0xfe7d, 0xfe7d}, {0xfe7f, 0xfefc}, {0xff10, 0xff19}, {0xff21, 0xff3a}, {0xff3f, 0xff3f}, {0xff41, 0xff5a}, {0xff65, 0xffbe}, {0xffc2, 0xffc7},
  {0xffca, 0xffcf}, {0xffd2, 0xffd7}, {0xffda, 0xffdc}, {0x10000, 0x1000b}, {0x1000d, 0x10026}, {0x10028, 0x1003a}, {0x1003c, 0x1003d}, {0x1003f, 0x1004d},
  {0x10050, 0x1005d}, {0x10080, 0x100fa}, {0x10140, 0x10174}, {0x101fd, 0x101fd}, {0x10280, 0x1029c}, {0x102a0, 0x102d0}, {0x102e0, 0x102e0}, {0x10300, 0x1031f},
  {0x1032d, 0x1034a}, {0x10350, 0x1037a}, {0x10380, 0x1039d}, {0x103a0, 0x103c3}, {0x103c8, 0x103cf}, {0x103d1, 0x103d5}, {0x10400, 0x1049d}, {0x104a0, 0x104a9},
  {0x104b0, 0x104d3}, {0x104d8, 0x104fb}, {0x10500, 0x10527}, {0x10530, 0x10563}, {0x10570, 0x1057a}, {0x1057c, 0x1058a}, {0x1058c, 0x10592}, {0x10594, 0x10595},
  {0x10597, 0x105a1}, {0x105a3, 0x105b1}, {0x105b3, 0x105b9}, {0x105bb, 0x105bc}, {0x10600, 0x10736}, {0x10740, 0x10755}, {0x10760, 0x10767}, {0x10780, 0x10785},
  {0x10787, 0x107b0}, {0x107b2, 0x107ba}, {0x10800, 0x10805}, {0x10808, 0x10808}, {0x1080a, 0x10835}, {0x10837, 0x10838}, {0x1083c, 0x1083c}, {0x1083f, 0x10855},
  {0x10860, 0x10876}, {0x10880, 0x1089e}, {0x108e0, 0x108f2}, {0x108f4, 0x108f5}, {0x10900, 0x10915}, {0x10920, 0x10939}, {0x10980, 0x109b7}, {0x109be, 0x109bf},
  {0x10a00, 0x10a03}, {0x10a05, 0x10a06}, {0x10a0c, 0x10a13}, {0x10a15, 0x10a17}, {0x10a19, 0x10a35}, {0x10a38, 0x10a3a}, {0x10a3f, 0x10a3f}, {0x10a60, 0x10a7c},
  {0x10a80, 0x10a9c}, {0x10ac0, 0x10ac7}, {0x10ac9, 0x10ae6}, {0x10b00, 0x10b35}, {0x10b40, 0x10b55}, {0x10b60, 0x10b72}, {0x10b80, 0x10b91}, {0x10c00, 0x10c48},
  {0x10c80, 0x10cb2}, {0x10cc0, 0x10cf2}, {0x10d00, 0x10d27}, {0x10d30, 0x10d39}, {0x10e80, 0x10ea9}, {0x10eab, 0x10eac}, {0x10eb0, 0x10eb1}, {0x10efd, 0x10f1c},
  {0x10f27, 0x10f27}, {0x10f30, 0x10f50}, {0x10f70, 0x10f85}, {0x10fb0, 0x10fc4}, {0x10fe0, 0x10ff6}, {0x11000, 0x11046}, {0x11066, 0x11075}, {0x1107f, 0x110ba},
  {0x110c2, 0x110c2}, {0x110d0, 0x110e8}, {0x110f0, 0x110f9}, {0x11100, 0x11134}, {0x11136, 0x1113f}, {0x11144, 0x11147}, {0x11150, 0x11173}, {0x11176, 0x11176},
  {0x11180, 0x111c4}, {0x111c9, 0x111cc}, {0x111ce, 0x111da}, {0x111dc, 0x111dc}, {0x11200, 0x11211}, {0x11213, 0x11237}, {0x1123e, 0x11241}, {0x11280, 0x11286},
  {0x11288, 0x11288}, {0x1128a, 0x1128d}, {0x1128f, 0x1129d}, {0x1129f, 0x112a8}, {0x112b0, 0x112ea}, {0x112f0, 0x112f9}, {0x11300, 0x11303}, {0x11305, 0x1130c},
  {0x1130f, 0x11310}, {0x11313, 0x11328}, {0x1132a, 0x11330}, {0x11332, 0x11333}, {0x11335, 0x11339}, {0x1133b, 0x11344}, {0x11347, 0x11348}, {0x1134b, 0x1134d},
  {0x11350, 0x11350}, {0x11357, 0x11357}, {0x1135d, 0x11363}, {0x11366, 0x1136c}, {0x11370, 0x11374}, {0x11400, 0x1144a}, {0x11450, 0x11459}, {0x1145e, 0x11461},
  {0x11480, 0x114c5}, {0x114c7, 0x114c7}, {0x114d0, 0x114d9}, {0x11580, 0x115b5}, {0x115b8, 0x115c0}, {0x115d8, 0x115dd}, {0x11600, 0x11640}, {0x11644, 0x11644},
  {0x11650, 0x11659}, {0x11680, 0x116b8}, {0x116c0, 0x116c9}, {0x11700, 0x1171a}, {0x1171d, 0x1172b}, {0x11730, 0x11739}, {0x11740, 0x11746}, {0x11800, 0x1183a},
  {0x118a0, 0x118e9}, {0x118ff, 0x11906}, {0x11909, 0x11909}, {0x1190c, 0x11913}, {0x11915, 0x11916}, {0x11918, 0x11935}, {0x11937, 0x11938}, {0x1193b, 0x11943},
  {0x11950, 0x11959}, {0x119a0, 0x119a7}, {0x119aa, 0x119d7}, {0x119da, 0x119e1}, {0x119e3, 0x119e4}, {0x11a00, 0x11a3e}, {0x11a47, 0x11a47}, {0x11a50, 0x11a99},
  {0x11a9d, 0x11a9d}, {0x11ab0, 0x11af8}, {0x11c00, 0x11c08}, {0x11c0a, 0x11c36}, {0x11c38, 0x11c40}, {0x11c50, 0x11c59}, {0x11c72, 0x11c8f}, {0x11c92, 0x11ca7},
  {0x11ca9, 0x11cb6}, {0x11d00, 0x11d06}, {0x11d08, 0x11d09}, {0x11d0b, 0x11d36}, {0x11d3a, 0x11d3a}, {0x11d3c, 0x11d3d}, {0x11d3f, 0x11d47}, {0x11d50, 0x11d59},
  {0x11d60, 0x11d65}, {0x11d67, 0x11d68}, {0x11d6a, 0x11d8e}, {0x11d90, 0x11d91}, {0x11d93, 0x11d98}, {0x11da0, 0x11da9}, {0x11ee0, 0x11ef6}, {0x11f00, 0x11f10},
  {0x11f12, 0x11f3a}, {0x11f3e, 0x11f42}, {0x11f50, 0x11f59}, {0x11fb0, 0x11fb0}, {0x12000, 0x12399}, {0x12400, 0x1246e}, {0x12480, 0x12543}, {0x12f90, 0x12ff0},
  {0x13000, 0x1342f}, {0x13440, 0x13455}, {0x14400, 0x14646}, {0x16800, 0x16a38}, {0x16a40, 0x16a5e}, {0x16a60, 0x16a69}, {0x16a70, 0x16abe}, {0x16ac0, 0x16ac9},
  {0x16ad0, 0x16aed}, {0x16af0, 0x16af4}, {0x16b00, 0x16b36}, {0x16b40, 0x16b43}, {0x16b50, 0x16b59}, {0x16b63, 0x16b77}, {0x16b7d, 0x16b8f}, {0x16e40, 0x16e7f},
  {0x16f00, 0x16f4a}, {0x16f4f, 0x16f87}, {0x16f8f, 0x16f9f}, {0x16fe0, 0x16fe1}, {0x16fe3, 0x16fe4}, {0x16ff0, 0x16ff1}, {0x17000, 0x187f7}, {0x18800, 0x18cd5},
  {0x18d00, 0x18d08}, {0x1aff0, 0x1aff3}, {0x1aff5, 0x1affb}, {0x1affd, 0x1affe}, {0x1b000, 0x1b122}, {0x1b132, 0x1b132}, {0x1b150, 0x1b152}, {0x1b155, 0x1b155},
  {0x1b164, 0x1b167}, {0x1b170, 0x1b2fb}, {0x1bc00, 0x1bc6a}, {0x1bc70, 0x1bc7c}, {0x1bc80, 0x1bc88}, {0x1bc90, 0x1bc99}, {0x1bc9d, 0x1bc9e}, {0x1cf00, 0x1cf2d},
  {0x1cf30, 0x1cf46}, {0x1d165, 0x1d169}, {0x1d16d, 0x1d172}, {0x1d17b, 0x1d182}, {0x1d185, 0x1d18b}, {0x1d1aa, 0x1d1ad}, {0x1d242, 0x1d244}, {0x1d400, 0x1d454},
  {0x1d456, 0x1d49c}, {0x1d49e, 0x1d49f}, {0x1d4a2, 0x1d4a2}, {0x1d4a5, 0x1d4a6}, {0x1d4a9, 0x1d4ac}, {0x1d4ae, 0x1d4b9}, {0x1d4bb, 0x1d4bb}, {0x1d4bd, 0x1d4c3},
  {0x1d4c5, 0x1d505}, {0x1d507, 0x1d50a}, {0x1d50d, 0x1d514}, {0x1d516, 0x1d51c}, {0x1d51e, 0x1d539}, {0x1d53b, 0x1d53e}, {0x1d540, 0x1d544}, {0x1d546, 0x1d546},
  {0x1d54a, 0x1d550}, {0x1d552, 0x1d6a5}, {0x1d6a8, 0x1d6c0}, {0x1d6c2, 0x1d6da}, {0x1d6dc, 0x1d6fa}, {0x1d6fc, 0x1d714}, {0x1d716, 0x1d734}, {0x1d736, 0x1d74e},
  {0x1d750, 0x1d76e}, {0x1d770, 0x1d788}, {0x1d78a, 0x1d7a8}, {0x1d7aa, 0x1d7c2}, {0x1d7c4, 0x1d7cb}, {0x1d7ce, 0x1d7ff}, {0x1da00, 0x1da36}, {0x1da3b, 0x1da6c},
  {0x1da75, 0x1da75}, {0x1da84, 0x1da84}, {0x1da9b, 0x1da9f}, {0x1daa1, 0x1daaf}, {0x1df00, 0x1df1e}, {0x1df25, 0x1df2a}, {0x1e000, 0x1e006}, {0x1e008, 0x1e018},
  {0x1e01b, 0x1e021}, {0x1e023, 0x1e024}, {0x1e026, 0x1e02a}, {0x1e030, 0x1e06d}, {0x1e08f, 0x1e08f}, {0x1e100, 0x1e12c}, {0x1e130, 0x1e13d}, {0x1e140, 0x1e149},
  {0x1e14e, 0x1e14e}, {0x1e290, 0x1e2ae}, {0x1e2c0, 0x1e2f9}, {0x1e4d0, 0x1e4f9}, {0x1e7e0, 0x1e7e6}, {0x1e7e8, 0x1e7eb}, {0x1e7ed, 0x1e7ee}, {0x1e7f0, 0x1e7fe},
  {0x1e800, 0x1e8c4}, {0x1e8d0, 0x1e8d6}, {0x1e900, 0x1e94b}, {0x1e950, 0x1e959}, {0x1ee00, 0x1ee03}, {0x1ee05, 0x1ee1f}, {0x1ee21, 0x1ee22}, {0x1ee24, 0x1ee24},
  {0x1ee27, 0x1ee27}, {0x1ee29, 0x1ee32}, {0x1ee34, 0x1ee37}, {0x1ee39, 0x1ee39}, {0x1ee3b, 0x1ee3b}, {0x1ee42, 0x1ee42}, {0x1ee47, 0x1ee47}, {0x1ee49, 0x1ee49},
  {0x1ee4b, 0x1ee4b}, {0x1ee4d, 0x1ee4f}, {0x1ee51, 0x1ee52}, {0x1ee54, 0x1ee54}, {0x1ee57, 0x1ee57}, {0x1ee59, 0x1ee59}, {0x1ee5b, 0x1ee5b}, {0x1ee5d, 0x1ee5d},
  {0x1ee5f, 0x1ee5f}, {0x1ee61, 0x1ee62}, {0x1ee64, 0x1ee64}, {0x1ee67, 0x1ee6a}, {0x1ee6c, 0x1ee72}, {0x1ee74, 0x1ee77}, {0x1ee79, 0x1ee7c}, {0x1ee7e, 0x1ee7e},
  {0x1ee80, 0x1ee89}, {0x1ee8b, 0x1ee9b}, {0x1eea1, 0x1eea3}, {0x1eea5, 0x1eea9}, {0x1eeab, 0x1eebb}, {0x1fbf0, 0x1fbf9}, {0x20000, 0x2a6df}, {0x2a700, 0x2b739},
  {0x2b740, 0x2b81d}, {0x2b820, 0x2cea1}, {0x2ceb0, 0x2ebe0}, {0x2ebf0, 0x2ee5d}, {0x2f800, 0x2fa1d}, {0x30000, 0x3134a}, {0x31350, 0x323af}, {0xe0100, 0xe01ef},
};

static TSCharacterRange sym_rune_literal_character_set_1[] = {
  {'"', '"'}, {'\'', '\''}, {'0', '7'}, {'U', 'U'}, {'\\', '\\'}, {'a', 'b'}, {'f', 'f'}, {'n', 'n'},
  {'r', 'r'}, {'t', 'v'}, {'x', 'x'},
};

static bool ts_lex(TSLexer *lexer, TSStateId state) {
  START_LEXER();
  eof = lexer->eof(lexer);
  switch (state) {
    case 0:
      if (eof) ADVANCE(60);
      ADVANCE_MAP(
        0, 63,
        '!', 107,
        '"', 138,
        '%', 116,
        '&', 111,
        '\'', 22,
        '(', 67,
        ')', 68,
        '*', 76,
        '+', 101,
        ',', 69,
        '-', 104,
        '.', 66,
        '/', 114,
        '0', 147,
        ':', 99,
        ';', 62,
        '<', 125,
        '=', 71,
        '>', 130,
        '[', 72,
        '\\', 20,
        ']', 73,
        '^', 109,
        '`', 26,
        '{', 78,
        '|', 81,
        '}', 79,
        '~', 77,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(58);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(149);
      if (set_contains(sym_identifier_character_set_1, 668, lookahead)) ADVANCE(135);
      END_STATE();
    case 1:
      ADVANCE_MAP(
        0, 63,
        '\n', 61,
        '!', 17,
        '%', 115,
        '&', 112,
        '(', 67,
        '*', 75,
        '+', 100,
        ',', 69,
        '-', 103,
        '.', 64,
        '/', 113,
        ';', 62,
        '<', 128,
        '=', 19,
        '>', 131,
        '[', 72,
        '^', 108,
        '{', 78,
        '|', 82,
        '}', 79,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(1);
      if (set_contains(sym_identifier_character_set_1, 668, lookahead)) ADVANCE(135);
      END_STATE();
    case 2:
      if (lookahead == '\n') SKIP(16);
      if (lookahead == '"') ADVANCE(138);
      if (lookahead == '/') ADVANCE(139);
      if (lookahead == '\\') ADVANCE(20);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(142);
      if (lookahead != 0) ADVANCE(143);
      END_STATE();
    case 3:
      ADVANCE_MAP(
        '!', 17,
        '"', 137,
        '%', 115,
        '&', 112,
        '(', 67,
        ')', 68,
        '*', 75,
        '+', 100,
        ',', 69,
        '-', 103,
        '.', 65,
        '/', 113,
        ':', 99,
        '<', 126,
        '=', 71,
        '>', 131,
        '[', 72,
        ']', 73,
        '^', 108,
        '`', 26,
        '{', 78,
        '|', 82,
        '~', 77,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(3);
      if (set_contains(sym_identifier_character_set_1, 668, lookahead)) ADVANCE(135);
      END_STATE();
    case 4:
      ADVANCE_MAP(
        '!', 17,
        '%', 116,
        '&', 111,
        '(', 67,
        '*', 76,
        '+', 101,
        ',', 69,
        '-', 104,
        '.', 64,
        '/', 114,
        ':', 18,
        ';', 62,
        '<', 125,
        '=', 71,
        '>', 130,
        '[', 72,
        '^', 109,
        '{', 78,
        '|', 81,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(4);
      END_STATE();
    case 5:
      ADVANCE_MAP(
        '!', 17,
        '%', 116,
        '&', 111,
        '(', 67,
        '*', 76,
        '+', 102,
        ',', 69,
        '-', 105,
        '.', 64,
        '/', 114,
        ':', 18,
        '<', 127,
        '=', 71,
        '>', 130,
        '[', 72,
        '^', 109,
        '{', 78,
        '|', 81,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(5);
      END_STATE();
    case 6:
      ADVANCE_MAP(
        '!', 17,
        '%', 115,
        '&', 112,
        '(', 67,
        ')', 68,
        '*', 75,
        '+', 100,
        ',', 69,
        '-', 103,
        '.', 65,
        '/', 113,
        ':', 99,
        ';', 62,
        '<', 128,
        '=', 71,
        '>', 131,
        '[', 72,
        ']', 73,
        '^', 108,
        '{', 78,
        '|', 82,
        '}', 79,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(6);
      END_STATE();
    case 7:
      if (lookahead == '\'') ADVANCE(157);
      END_STATE();
    case 8:
      if (lookahead == '*') ADVANCE(10);
      if (lookahead == '/') ADVANCE(159);
      END_STATE();
    case 9:
      if (lookahead == '*') ADVANCE(9);
      if (lookahead == '/') ADVANCE(158);
      if (lookahead != 0) ADVANCE(10);
      END_STATE();
    case 10:
      if (lookahead == '*') ADVANCE(9);
      if (lookahead != 0) ADVANCE(10);
      END_STATE();
    case 11:
      if (lookahead == '-') ADVANCE(83);
      END_STATE();
    case 12:
      if (lookahead == '.') ADVANCE(14);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(153);
      END_STATE();
    case 13:
      if (lookahead == '.') ADVANCE(155);
      if (lookahead == '_') ADVANCE(36);
      if (lookahead == 'i') ADVANCE(156);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(27);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(13);
      END_STATE();
    case 14:
      if (lookahead == '.') ADVANCE(74);
      END_STATE();
    case 15:
      if (lookahead == '.') ADVANCE(41);
      if (lookahead == '_') ADVANCE(40);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(150);
      END_STATE();
    case 16:
      if (lookahead == '/') ADVANCE(8);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(16);
      END_STATE();
    case 17:
      if (lookahead == '=') ADVANCE(124);
      END_STATE();
    case 18:
      if (lookahead == '=') ADVANCE(84);
      END_STATE();
    case 19:
      if (lookahead == '=') ADVANCE(123);
      END_STATE();
    case 20:
      if (lookahead == 'U') ADVANCE(54);
      if (lookahead == 'u') ADVANCE(46);
      if (lookahead == 'x') ADVANCE(42);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(146);
      if (lookahead != 0) ADVANCE(144);
      END_STATE();
    case 21:
      if (lookahead == 'U') ADVANCE(55);
      if (lookahead == 'u') ADVANCE(47);
      if (lookahead == 'x') ADVANCE(43);
      if (('0' <= lookahead && lookahead <= '7')) ADVANCE(33);
      if (set_contains(sym_rune_literal_character_set_1, 11, lookahead)) ADVANCE(7);
      END_STATE();
    case 22:
      if (lookahead == '\\') ADVANCE(21);
      if (lookahead != 0 &&
          lookahead != '\'') ADVANCE(7);
      END_STATE();
    case 23:
      if (lookahead == '_') ADVANCE(29);
      if (lookahead == '0' ||
          lookahead == '1') ADVANCE(151);
      END_STATE();
    case 24:
      if (lookahead == '_') ADVANCE(41);
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(27);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(24);
      END_STATE();
    case 25:
      if (lookahead == '_') ADVANCE(32);
      if (('0' <= lookahead && lookahead <= '7')) ADVANCE(152);
      END_STATE();
    case 26:
      if (lookahead == '`') ADVANCE(136);
      if (lookahead != 0) ADVANCE(26);
      END_STATE();
    case 27:
      if (lookahead == '+' ||
          lookahead == '-') ADVANCE(37);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(154);
      END_STATE();
    case 28:
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(27);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(24);
      END_STATE();
    case 29:
      if (lookahead == '0' ||
          lookahead == '1') ADVANCE(151);
      END_STATE();
    case 30:
      if (lookahead == '8' ||
          lookahead == '9') ADVANCE(13);
      if (('0' <= lookahead && lookahead <= '7')) ADVANCE(148);
      END_STATE();
    case 31:
      if (('0' <= lookahead && lookahead <= '7')) ADVANCE(7);
      END_STATE();
    case 32:
      if (('0' <= lookahead && lookahead <= '7')) ADVANCE(152);
      END_STATE();
    case 33:
      if (('0' <= lookahead && lookahead <= '7')) ADVANCE(31);
      END_STATE();
    case 34:
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(149);
      END_STATE();
    case 35:
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(153);
      END_STATE();
    case 36:
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(13);
      END_STATE();
    case 37:
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(154);
      END_STATE();
    case 38:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(7);
      END_STATE();
    case 39:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(144);
      END_STATE();
    case 40:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(150);
      END_STATE();
    case 41:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(24);
      END_STATE();
    case 42:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(39);
      END_STATE();
    case 43:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(38);
      END_STATE();
    case 44:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(42);
      END_STATE();
    case 45:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(43);
      END_STATE();
    case 46:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(44);
      END_STATE();
    case 47:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(45);
      END_STATE();
    case 48:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(46);
      END_STATE();
    case 49:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(47);
      END_STATE();
    case 50:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(48);
      END_STATE();
    case 51:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(49);
      END_STATE();
    case 52:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(50);
      END_STATE();
    case 53:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(51);
      END_STATE();
    case 54:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(52);
      END_STATE();
    case 55:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(53);
      END_STATE();
    case 56:
      if (eof) ADVANCE(60);
      ADVANCE_MAP(
        0, 63,
        '\n', 61,
        '!', 106,
        '"', 137,
        '&', 110,
        '\'', 22,
        '(', 67,
        ')', 68,
        '*', 75,
        '+', 100,
        ',', 69,
        '-', 103,
        '.', 35,
        '/', 8,
        '0', 147,
        ';', 62,
        '<', 11,
        '=', 70,
        '[', 72,
        '^', 108,
        '`', 26,
        '{', 78,
        '|', 80,
        '}', 79,
        '~', 77,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(56);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(149);
      if (set_contains(sym_identifier_character_set_1, 668, lookahead)) ADVANCE(135);
      END_STATE();
    case 57:
      if (eof) ADVANCE(60);
      ADVANCE_MAP(
        0, 63,
        '\n', 61,
        '!', 17,
        '"', 137,
        '%', 116,
        '&', 111,
        '(', 67,
        ')', 68,
        '*', 76,
        '+', 101,
        ',', 69,
        '-', 104,
        '.', 64,
        '/', 114,
        ':', 99,
        ';', 62,
        '<', 125,
        '=', 71,
        '>', 130,
        '[', 72,
        '^', 109,
        '`', 26,
        '{', 78,
        '|', 81,
        '}', 79,
        '~', 77,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(57);
      if (set_contains(sym_identifier_character_set_1, 668, lookahead)) ADVANCE(135);
      END_STATE();
    case 58:
      if (eof) ADVANCE(60);
      ADVANCE_MAP(
        0, 63,
        '!', 107,
        '"', 137,
        '%', 116,
        '&', 111,
        '\'', 22,
        '(', 67,
        ')', 68,
        '*', 76,
        '+', 101,
        ',', 69,
        '-', 104,
        '.', 66,
        '/', 114,
        '0', 147,
        ':', 99,
        ';', 62,
        '<', 125,
        '=', 71,
        '>', 130,
        '[', 72,
        ']', 73,
        '^', 109,
        '`', 26,
        '{', 78,
        '|', 81,
        '}', 79,
        '~', 77,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(58);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(149);
      if (set_contains(sym_identifier_character_set_1, 668, lookahead)) ADVANCE(135);
      END_STATE();
    case 59:
      if (eof) ADVANCE(60);
      ADVANCE_MAP(
        '!', 106,
        '"', 137,
        '&', 110,
        '\'', 22,
        '(', 67,
        ')', 68,
        '*', 75,
        '+', 100,
        ',', 69,
        '-', 103,
        '.', 12,
        '/', 8,
        '0', 147,
        ':', 98,
        ';', 62,
        '<', 11,
        '[', 72,
        ']', 73,
        '^', 108,
        '`', 26,
        '{', 78,
        '}', 79,
        '~', 77,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(59);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(149);
      if (set_contains(sym_identifier_character_set_1, 668, lookahead)) ADVANCE(135);
      END_STATE();
    case 60:
      ACCEPT_TOKEN(ts_builtin_sym_end);
      END_STATE();
    case 61:
      ACCEPT_TOKEN(aux_sym_source_file_token1);
      if (lookahead == '\n') ADVANCE(61);
      END_STATE();
    case 62:
      ACCEPT_TOKEN(anon_sym_SEMI);
      END_STATE();
    case 63:
      ACCEPT_TOKEN(anon_sym_NULL);
      END_STATE();
    case 64:
      ACCEPT_TOKEN(anon_sym_DOT);
      END_STATE();
    case 65:
      ACCEPT_TOKEN(anon_sym_DOT);
      if (lookahead == '.') ADVANCE(14);
      END_STATE();
    case 66:
      ACCEPT_TOKEN(anon_sym_DOT);
      if (lookahead == '.') ADVANCE(14);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(153);
      END_STATE();
    case 67:
      ACCEPT_TOKEN(anon_sym_LPAREN);
      END_STATE();
    case 68:
      ACCEPT_TOKEN(anon_sym_RPAREN);
      END_STATE();
    case 69:
      ACCEPT_TOKEN(anon_sym_COMMA);
      END_STATE();
    case 70:
      ACCEPT_TOKEN(anon_sym_EQ);
      END_STATE();
    case 71:
      ACCEPT_TOKEN(anon_sym_EQ);
      if (lookahead == '=') ADVANCE(123);
      END_STATE();
    case 72:
      ACCEPT_TOKEN(anon_sym_LBRACK);
      END_STATE();
    case 73:
      ACCEPT_TOKEN(anon_sym_RBRACK);
      END_STATE();
    case 74:
      ACCEPT_TOKEN(anon_sym_DOT_DOT_DOT);
      END_STATE();
    case 75:
      ACCEPT_TOKEN(anon_sym_STAR);
      END_STATE();
    case 76:
      ACCEPT_TOKEN(anon_sym_STAR);
      if (lookahead == '=') ADVANCE(87);
      END_STATE();
    case 77:
      ACCEPT_TOKEN(anon_sym_TILDE);
      END_STATE();
    case 78:
      ACCEPT_TOKEN(anon_sym_LBRACE);
      END_STATE();
    case 79:
      ACCEPT_TOKEN(anon_sym_RBRACE);
      END_STATE();
    case 80:
      ACCEPT_TOKEN(anon_sym_PIPE);
      END_STATE();
    case 81:
      ACCEPT_TOKEN(anon_sym_PIPE);
      if (lookahead == '=') ADVANCE(96);
      if (lookahead == '|') ADVANCE(134);
      END_STATE();
    case 82:
      ACCEPT_TOKEN(anon_sym_PIPE);
      if (lookahead == '|') ADVANCE(134);
      END_STATE();
    case 83:
      ACCEPT_TOKEN(anon_sym_LT_DASH);
      END_STATE();
    case 84:
      ACCEPT_TOKEN(anon_sym_COLON_EQ);
      END_STATE();
    case 85:
      ACCEPT_TOKEN(anon_sym_PLUS_PLUS);
      END_STATE();
    case 86:
      ACCEPT_TOKEN(anon_sym_DASH_DASH);
      END_STATE();
    case 87:
      ACCEPT_TOKEN(anon_sym_STAR_EQ);
      END_STATE();
    case 88:
      ACCEPT_TOKEN(anon_sym_SLASH_EQ);
      END_STATE();
    case 89:
      ACCEPT_TOKEN(anon_sym_PERCENT_EQ);
      END_STATE();
    case 90:
      ACCEPT_TOKEN(anon_sym_LT_LT_EQ);
      END_STATE();
    case 91:
      ACCEPT_TOKEN(anon_sym_GT_GT_EQ);
      END_STATE();
    case 92:
      ACCEPT_TOKEN(anon_sym_AMP_EQ);
      END_STATE();
    case 93:
      ACCEPT_TOKEN(anon_sym_AMP_CARET_EQ);
      END_STATE();
    case 94:
      ACCEPT_TOKEN(anon_sym_PLUS_EQ);
      END_STATE();
    case 95:
      ACCEPT_TOKEN(anon_sym_DASH_EQ);
      END_STATE();
    case 96:
      ACCEPT_TOKEN(anon_sym_PIPE_EQ);
      END_STATE();
    case 97:
      ACCEPT_TOKEN(anon_sym_CARET_EQ);
      END_STATE();
    case 98:
      ACCEPT_TOKEN(anon_sym_COLON);
      END_STATE();
    case 99:
      ACCEPT_TOKEN(anon_sym_COLON);
      if (lookahead == '=') ADVANCE(84);
      END_STATE();
    case 100:
      ACCEPT_TOKEN(anon_sym_PLUS);
      END_STATE();
    case 101:
      ACCEPT_TOKEN(anon_sym_PLUS);
      if (lookahead == '+') ADVANCE(85);
      if (lookahead == '=') ADVANCE(94);
      END_STATE();
    case 102:
      ACCEPT_TOKEN(anon_sym_PLUS);
      if (lookahead == '=') ADVANCE(94);
      END_STATE();
    case 103:
      ACCEPT_TOKEN(anon_sym_DASH);
      END_STATE();
    case 104:
      ACCEPT_TOKEN(anon_sym_DASH);
      if (lookahead == '-') ADVANCE(86);
      if (lookahead == '=') ADVANCE(95);
      END_STATE();
    case 105:
      ACCEPT_TOKEN(anon_sym_DASH);
      if (lookahead == '=') ADVANCE(95);
      END_STATE();
    case 106:
      ACCEPT_TOKEN(anon_sym_BANG);
      END_STATE();
    case 107:
      ACCEPT_TOKEN(anon_sym_BANG);
      if (lookahead == '=') ADVANCE(124);
      END_STATE();
    case 108:
      ACCEPT_TOKEN(anon_sym_CARET);
      END_STATE();
    case 109:
      ACCEPT_TOKEN(anon_sym_CARET);
      if (lookahead == '=') ADVANCE(97);
      END_STATE();
    case 110:
      ACCEPT_TOKEN(anon_sym_AMP);
      END_STATE();
    case 111:
      ACCEPT_TOKEN(anon_sym_AMP);
      if (lookahead == '&') ADVANCE(133);
      if (lookahead == '=') ADVANCE(92);
      if (lookahead == '^') ADVANCE(122);
      END_STATE();
    case 112:
      ACCEPT_TOKEN(anon_sym_AMP);
      if (lookahead == '&') ADVANCE(133);
      if (lookahead == '^') ADVANCE(121);
      END_STATE();
    case 113:
      ACCEPT_TOKEN(anon_sym_SLASH);
      if (lookahead == '*') ADVANCE(10);
      if (lookahead == '/') ADVANCE(159);
      END_STATE();
    case 114:
      ACCEPT_TOKEN(anon_sym_SLASH);
      if (lookahead == '*') ADVANCE(10);
      if (lookahead == '/') ADVANCE(159);
      if (lookahead == '=') ADVANCE(88);
      END_STATE();
    case 115:
      ACCEPT_TOKEN(anon_sym_PERCENT);
      END_STATE();
    case 116:
      ACCEPT_TOKEN(anon_sym_PERCENT);
      if (lookahead == '=') ADVANCE(89);
      END_STATE();
    case 117:
      ACCEPT_TOKEN(anon_sym_LT_LT);
      END_STATE();
    case 118:
      ACCEPT_TOKEN(anon_sym_LT_LT);
      if (lookahead == '=') ADVANCE(90);
      END_STATE();
    case 119:
      ACCEPT_TOKEN(anon_sym_GT_GT);
      END_STATE();
    case 120:
      ACCEPT_TOKEN(anon_sym_GT_GT);
      if (lookahead == '=') ADVANCE(91);
      END_STATE();
    case 121:
      ACCEPT_TOKEN(anon_sym_AMP_CARET);
      END_STATE();
    case 122:
      ACCEPT_TOKEN(anon_sym_AMP_CARET);
      if (lookahead == '=') ADVANCE(93);
      END_STATE();
    case 123:
      ACCEPT_TOKEN(anon_sym_EQ_EQ);
      END_STATE();
    case 124:
      ACCEPT_TOKEN(anon_sym_BANG_EQ);
      END_STATE();
    case 125:
      ACCEPT_TOKEN(anon_sym_LT);
      if (lookahead == '-') ADVANCE(83);
      if (lookahead == '<') ADVANCE(118);
      if (lookahead == '=') ADVANCE(129);
      END_STATE();
    case 126:
      ACCEPT_TOKEN(anon_sym_LT);
      if (lookahead == '-') ADVANCE(83);
      if (lookahead == '<') ADVANCE(117);
      if (lookahead == '=') ADVANCE(129);
      END_STATE();
    case 127:
      ACCEPT_TOKEN(anon_sym_LT);
      if (lookahead == '<') ADVANCE(118);
      if (lookahead == '=') ADVANCE(129);
      END_STATE();
    case 128:
      ACCEPT_TOKEN(anon_sym_LT);
      if (lookahead == '<') ADVANCE(117);
      if (lookahead == '=') ADVANCE(129);
      END_STATE();
    case 129:
      ACCEPT_TOKEN(anon_sym_LT_EQ);
      END_STATE();
    case 130:
      ACCEPT_TOKEN(anon_sym_GT);
      if (lookahead == '=') ADVANCE(132);
      if (lookahead == '>') ADVANCE(120);
      END_STATE();
    case 131:
      ACCEPT_TOKEN(anon_sym_GT);
      if (lookahead == '=') ADVANCE(132);
      if (lookahead == '>') ADVANCE(119);
      END_STATE();
    case 132:
      ACCEPT_TOKEN(anon_sym_GT_EQ);
      END_STATE();
    case 133:
      ACCEPT_TOKEN(anon_sym_AMP_AMP);
      END_STATE();
    case 134:
      ACCEPT_TOKEN(anon_sym_PIPE_PIPE);
      END_STATE();
    case 135:
      ACCEPT_TOKEN(sym_identifier);
      if (set_contains(sym_identifier_character_set_2, 776, lookahead)) ADVANCE(135);
      END_STATE();
    case 136:
      ACCEPT_TOKEN(sym_raw_string_literal);
      END_STATE();
    case 137:
      ACCEPT_TOKEN(anon_sym_DQUOTE);
      END_STATE();
    case 138:
      ACCEPT_TOKEN(anon_sym_DQUOTE2);
      END_STATE();
    case 139:
      ACCEPT_TOKEN(sym__interpreted_string_literal_basic_content);
      if (lookahead == '*') ADVANCE(141);
      if (lookahead == '/') ADVANCE(143);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '"' &&
          lookahead != '\\') ADVANCE(143);
      END_STATE();
    case 140:
      ACCEPT_TOKEN(sym__interpreted_string_literal_basic_content);
      if (lookahead == '*') ADVANCE(140);
      if (lookahead == '/') ADVANCE(143);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '"' &&
          lookahead != '\\') ADVANCE(141);
      END_STATE();
    case 141:
      ACCEPT_TOKEN(sym__interpreted_string_literal_basic_content);
      if (lookahead == '*') ADVANCE(140);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '"' &&
          lookahead != '\\') ADVANCE(141);
      END_STATE();
    case 142:
      ACCEPT_TOKEN(sym__interpreted_string_literal_basic_content);
      if (lookahead == '/') ADVANCE(139);
      if (lookahead == '\t' ||
          (0x0b <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(142);
      if (lookahead != 0 &&
          (lookahead < '\t' || '\r' < lookahead) &&
          lookahead != '"' &&
          lookahead != '\\') ADVANCE(143);
      END_STATE();
    case 143:
      ACCEPT_TOKEN(sym__interpreted_string_literal_basic_content);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '"' &&
          lookahead != '\\') ADVANCE(143);
      END_STATE();
    case 144:
      ACCEPT_TOKEN(sym_escape_sequence);
      END_STATE();
    case 145:
      ACCEPT_TOKEN(sym_escape_sequence);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(144);
      END_STATE();
    case 146:
      ACCEPT_TOKEN(sym_escape_sequence);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(145);
      END_STATE();
    case 147:
      ACCEPT_TOKEN(sym_int_literal);
      ADVANCE_MAP(
        '.', 155,
        '_', 30,
        'i', 156,
        'B', 23,
        'b', 23,
        'E', 27,
        'e', 27,
        'O', 25,
        'o', 25,
        'X', 15,
        'x', 15,
        '8', 13,
        '9', 13,
      );
      if (('0' <= lookahead && lookahead <= '7')) ADVANCE(148);
      END_STATE();
    case 148:
      ACCEPT_TOKEN(sym_int_literal);
      if (lookahead == '.') ADVANCE(155);
      if (lookahead == '_') ADVANCE(30);
      if (lookahead == 'i') ADVANCE(156);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(27);
      if (lookahead == '8' ||
          lookahead == '9') ADVANCE(13);
      if (('0' <= lookahead && lookahead <= '7')) ADVANCE(148);
      END_STATE();
    case 149:
      ACCEPT_TOKEN(sym_int_literal);
      if (lookahead == '.') ADVANCE(155);
      if (lookahead == '_') ADVANCE(34);
      if (lookahead == 'i') ADVANCE(156);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(27);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(149);
      END_STATE();
    case 150:
      ACCEPT_TOKEN(sym_int_literal);
      if (lookahead == '.') ADVANCE(28);
      if (lookahead == '_') ADVANCE(40);
      if (lookahead == 'i') ADVANCE(156);
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(27);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(150);
      END_STATE();
    case 151:
      ACCEPT_TOKEN(sym_int_literal);
      if (lookahead == '_') ADVANCE(29);
      if (lookahead == 'i') ADVANCE(156);
      if (lookahead == '0' ||
          lookahead == '1') ADVANCE(151);
      END_STATE();
    case 152:
      ACCEPT_TOKEN(sym_int_literal);
      if (lookahead == '_') ADVANCE(32);
      if (lookahead == 'i') ADVANCE(156);
      if (('0' <= lookahead && lookahead <= '7')) ADVANCE(152);
      END_STATE();
    case 153:
      ACCEPT_TOKEN(sym_float_literal);
      if (lookahead == '_') ADVANCE(35);
      if (lookahead == 'i') ADVANCE(156);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(27);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(153);
      END_STATE();
    case 154:
      ACCEPT_TOKEN(sym_float_literal);
      if (lookahead == '_') ADVANCE(37);
      if (lookahead == 'i') ADVANCE(156);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(154);
      END_STATE();
    case 155:
      ACCEPT_TOKEN(sym_float_literal);
      if (lookahead == 'i') ADVANCE(156);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(27);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(153);
      END_STATE();
    case 156:
      ACCEPT_TOKEN(sym_imaginary_literal);
      END_STATE();
    case 157:
      ACCEPT_TOKEN(sym_rune_literal);
      END_STATE();
    case 158:
      ACCEPT_TOKEN(sym_comment);
      END_STATE();
    case 159:
      ACCEPT_TOKEN(sym_comment);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(159);
      END_STATE();
    default:
      return false;
  }
}

static bool ts_lex_keywords(TSLexer *lexer, TSStateId state) {
  START_LEXER();
  eof = lexer->eof(lexer);
  switch (state) {
    case 0:
      ADVANCE_MAP(
        '_', 1,
        'b', 2,
        'c', 3,
        'd', 4,
        'e', 5,
        'f', 6,
        'g', 7,
        'i', 8,
        'm', 9,
        'n', 10,
        'p', 11,
        'r', 12,
        's', 13,
        't', 14,
        'v', 15,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(0);
      END_STATE();
    case 1:
      ACCEPT_TOKEN(sym_blank_identifier);
      END_STATE();
    case 2:
      if (lookahead == 'r') ADVANCE(16);
      END_STATE();
    case 3:
      if (lookahead == 'a') ADVANCE(17);
      if (lookahead == 'h') ADVANCE(18);
      if (lookahead == 'o') ADVANCE(19);
      END_STATE();
    case 4:
      if (lookahead == 'e') ADVANCE(20);
      END_STATE();
    case 5:
      if (lookahead == 'l') ADVANCE(21);
      END_STATE();
    case 6:
      if (lookahead == 'a') ADVANCE(22);
      if (lookahead == 'o') ADVANCE(23);
      if (lookahead == 'u') ADVANCE(24);
      END_STATE();
    case 7:
      if (lookahead == 'o') ADVANCE(25);
      END_STATE();
    case 8:
      if (lookahead == 'f') ADVANCE(26);
      if (lookahead == 'm') ADVANCE(27);
      if (lookahead == 'n') ADVANCE(28);
      if (lookahead == 'o') ADVANCE(29);
      END_STATE();
    case 9:
      if (lookahead == 'a') ADVANCE(30);
      END_STATE();
    case 10:
      if (lookahead == 'e') ADVANCE(31);
      if (lookahead == 'i') ADVANCE(32);
      END_STATE();
    case 11:
      if (lookahead == 'a') ADVANCE(33);
      END_STATE();
    case 12:
      if (lookahead == 'a') ADVANCE(34);
      if (lookahead == 'e') ADVANCE(35);
      END_STATE();
    case 13:
      if (lookahead == 'e') ADVANCE(36);
      if (lookahead == 't') ADVANCE(37);
      if (lookahead == 'w') ADVANCE(38);
      END_STATE();
    case 14:
      if (lookahead == 'r') ADVANCE(39);
      if (lookahead == 'y') ADVANCE(40);
      END_STATE();
    case 15:
      if (lookahead == 'a') ADVANCE(41);
      END_STATE();
    case 16:
      if (lookahead == 'e') ADVANCE(42);
      END_STATE();
    case 17:
      if (lookahead == 's') ADVANCE(43);
      END_STATE();
    case 18:
      if (lookahead == 'a') ADVANCE(44);
      END_STATE();
    case 19:
      if (lookahead == 'n') ADVANCE(45);
      END_STATE();
    case 20:
      if (lookahead == 'f') ADVANCE(46);
      END_STATE();
    case 21:
      if (lookahead == 's') ADVANCE(47);
      END_STATE();
    case 22:
      if (lookahead == 'l') ADVANCE(48);
      END_STATE();
    case 23:
      if (lookahead == 'r') ADVANCE(49);
      END_STATE();
    case 24:
      if (lookahead == 'n') ADVANCE(50);
      END_STATE();
    case 25:
      ACCEPT_TOKEN(anon_sym_go);
      if (lookahead == 't') ADVANCE(51);
      END_STATE();
    case 26:
      ACCEPT_TOKEN(anon_sym_if);
      END_STATE();
    case 27:
      if (lookahead == 'p') ADVANCE(52);
      END_STATE();
    case 28:
      if (lookahead == 't') ADVANCE(53);
      END_STATE();
    case 29:
      if (lookahead == 't') ADVANCE(54);
      END_STATE();
    case 30:
      if (lookahead == 'k') ADVANCE(55);
      if (lookahead == 'p') ADVANCE(56);
      END_STATE();
    case 31:
      if (lookahead == 'w') ADVANCE(57);
      END_STATE();
    case 32:
      if (lookahead == 'l') ADVANCE(58);
      END_STATE();
    case 33:
      if (lookahead == 'c') ADVANCE(59);
      END_STATE();
    case 34:
      if (lookahead == 'n') ADVANCE(60);
      END_STATE();
    case 35:
      if (lookahead == 't') ADVANCE(61);
      END_STATE();
    case 36:
      if (lookahead == 'l') ADVANCE(62);
      END_STATE();
    case 37:
      if (lookahead == 'r') ADVANCE(63);
      END_STATE();
    case 38:
      if (lookahead == 'i') ADVANCE(64);
      END_STATE();
    case 39:
      if (lookahead == 'u') ADVANCE(65);
      END_STATE();
    case 40:
      if (lookahead == 'p') ADVANCE(66);
      END_STATE();
    case 41:
      if (lookahead == 'r') ADVANCE(67);
      END_STATE();
    case 42:
      if (lookahead == 'a') ADVANCE(68);
      END_STATE();
    case 43:
      if (lookahead == 'e') ADVANCE(69);
      END_STATE();
    case 44:
      if (lookahead == 'n') ADVANCE(70);
      END_STATE();
    case 45:
      if (lookahead == 's') ADVANCE(71);
      if (lookahead == 't') ADVANCE(72);
      END_STATE();
    case 46:
      if (lookahead == 'a') ADVANCE(73);
      if (lookahead == 'e') ADVANCE(74);
      END_STATE();
    case 47:
      if (lookahead == 'e') ADVANCE(75);
      END_STATE();
    case 48:
      if (lookahead == 'l') ADVANCE(76);
      if (lookahead == 's') ADVANCE(77);
      END_STATE();
    case 49:
      ACCEPT_TOKEN(anon_sym_for);
      END_STATE();
    case 50:
      if (lookahead == 'c') ADVANCE(78);
      END_STATE();
    case 51:
      if (lookahead == 'o') ADVANCE(79);
      END_STATE();
    case 52:
      if (lookahead == 'o') ADVANCE(80);
      END_STATE();
    case 53:
      if (lookahead == 'e') ADVANCE(81);
      END_STATE();
    case 54:
      if (lookahead == 'a') ADVANCE(82);
      END_STATE();
    case 55:
      if (lookahead == 'e') ADVANCE(83);
      END_STATE();
    case 56:
      ACCEPT_TOKEN(anon_sym_map);
      END_STATE();
    case 57:
      ACCEPT_TOKEN(anon_sym_new);
      END_STATE();
    case 58:
      ACCEPT_TOKEN(sym_nil);
      END_STATE();
    case 59:
      if (lookahead == 'k') ADVANCE(84);
      END_STATE();
    case 60:
      if (lookahead == 'g') ADVANCE(85);
      END_STATE();
    case 61:
      if (lookahead == 'u') ADVANCE(86);
      END_STATE();
    case 62:
      if (lookahead == 'e') ADVANCE(87);
      END_STATE();
    case 63:
      if (lookahead == 'u') ADVANCE(88);
      END_STATE();
    case 64:
      if (lookahead == 't') ADVANCE(89);
      END_STATE();
    case 65:
      if (lookahead == 'e') ADVANCE(90);
      END_STATE();
    case 66:
      if (lookahead == 'e') ADVANCE(91);
      END_STATE();
    case 67:
      ACCEPT_TOKEN(anon_sym_var);
      END_STATE();
    case 68:
      if (lookahead == 'k') ADVANCE(92);
      END_STATE();
    case 69:
      ACCEPT_TOKEN(anon_sym_case);
      END_STATE();
    case 70:
      ACCEPT_TOKEN(anon_sym_chan);
      END_STATE();
    case 71:
      if (lookahead == 't') ADVANCE(93);
      END_STATE();
    case 72:
      if (lookahead == 'i') ADVANCE(94);
      END_STATE();
    case 73:
      if (lookahead == 'u') ADVANCE(95);
      END_STATE();
    case 74:
      if (lookahead == 'r') ADVANCE(96);
      END_STATE();
    case 75:
      ACCEPT_TOKEN(anon_sym_else);
      END_STATE();
    case 76:
      if (lookahead == 't') ADVANCE(97);
      END_STATE();
    case 77:
      if (lookahead == 'e') ADVANCE(98);
      END_STATE();
    case 78:
      ACCEPT_TOKEN(anon_sym_func);
      END_STATE();
    case 79:
      ACCEPT_TOKEN(anon_sym_goto);
      END_STATE();
    case 80:
      if (lookahead == 'r') ADVANCE(99);
      END_STATE();
    case 81:
      if (lookahead == 'r') ADVANCE(100);
      END_STATE();
    case 82:
      ACCEPT_TOKEN(sym_iota);
      END_STATE();
    case 83:
      ACCEPT_TOKEN(anon_sym_make);
      END_STATE();
    case 84:
      if (lookahead == 'a') ADVANCE(101);
      END_STATE();
    case 85:
      if (lookahead == 'e') ADVANCE(102);
      END_STATE();
    case 86:
      if (lookahead == 'r') ADVANCE(103);
      END_STATE();
    case 87:
      if (lookahead == 'c') ADVANCE(104);
      END_STATE();
    case 88:
      if (lookahead == 'c') ADVANCE(105);
      END_STATE();
    case 89:
      if (lookahead == 'c') ADVANCE(106);
      END_STATE();
    case 90:
      ACCEPT_TOKEN(sym_true);
      END_STATE();
    case 91:
      ACCEPT_TOKEN(anon_sym_type);
      END_STATE();
    case 92:
      ACCEPT_TOKEN(anon_sym_break);
      END_STATE();
    case 93:
      ACCEPT_TOKEN(anon_sym_const);
      END_STATE();
    case 94:
      if (lookahead == 'n') ADVANCE(107);
      END_STATE();
    case 95:
      if (lookahead == 'l') ADVANCE(108);
      END_STATE();
    case 96:
      ACCEPT_TOKEN(anon_sym_defer);
      END_STATE();
    case 97:
      if (lookahead == 'h') ADVANCE(109);
      END_STATE();
    case 98:
      ACCEPT_TOKEN(sym_false);
      END_STATE();
    case 99:
      if (lookahead == 't') ADVANCE(110);
      END_STATE();
    case 100:
      if (lookahead == 'f') ADVANCE(111);
      END_STATE();
    case 101:
      if (lookahead == 'g') ADVANCE(112);
      END_STATE();
    case 102:
      ACCEPT_TOKEN(anon_sym_range);
      END_STATE();
    case 103:
      if (lookahead == 'n') ADVANCE(113);
      END_STATE();
    case 104:
      if (lookahead == 't') ADVANCE(114);
      END_STATE();
    case 105:
      if (lookahead == 't') ADVANCE(115);
      END_STATE();
    case 106:
      if (lookahead == 'h') ADVANCE(116);
      END_STATE();
    case 107:
      if (lookahead == 'u') ADVANCE(117);
      END_STATE();
    case 108:
      if (lookahead == 't') ADVANCE(118);
      END_STATE();
    case 109:
      if (lookahead == 'r') ADVANCE(119);
      END_STATE();
    case 110:
      ACCEPT_TOKEN(anon_sym_import);
      END_STATE();
    case 111:
      if (lookahead == 'a') ADVANCE(120);
      END_STATE();
    case 112:
      if (lookahead == 'e') ADVANCE(121);
      END_STATE();
    case 113:
      ACCEPT_TOKEN(anon_sym_return);
      END_STATE();
    case 114:
      ACCEPT_TOKEN(anon_sym_select);
      END_STATE();
    case 115:
      ACCEPT_TOKEN(anon_sym_struct);
      END_STATE();
    case 116:
      ACCEPT_TOKEN(anon_sym_switch);
      END_STATE();
    case 117:
      if (lookahead == 'e') ADVANCE(122);
      END_STATE();
    case 118:
      ACCEPT_TOKEN(anon_sym_default);
      END_STATE();
    case 119:
      if (lookahead == 'o') ADVANCE(123);
      END_STATE();
    case 120:
      if (lookahead == 'c') ADVANCE(124);
      END_STATE();
    case 121:
      ACCEPT_TOKEN(anon_sym_package);
      END_STATE();
    case 122:
      ACCEPT_TOKEN(anon_sym_continue);
      END_STATE();
    case 123:
      if (lookahead == 'u') ADVANCE(125);
      END_STATE();
    case 124:
      if (lookahead == 'e') ADVANCE(126);
      END_STATE();
    case 125:
      if (lookahead == 'g') ADVANCE(127);
      END_STATE();
    case 126:
      ACCEPT_TOKEN(anon_sym_interface);
      END_STATE();
    case 127:
      if (lookahead == 'h') ADVANCE(128);
      END_STATE();
    case 128:
      ACCEPT_TOKEN(anon_sym_fallthrough);
      END_STATE();
    default:
      return false;
  }
}

static const TSLexMode ts_lex_modes[STATE_COUNT] = {
  [0] = {.lex_state = 0},
  [1] = {.lex_state = 59},
  [2] = {.lex_state = 59},
  [3] = {.lex_state = 59},
  [4] = {.lex_state = 59},
  [5] = {.lex_state = 59},
  [6] = {.lex_state = 59},
  [7] = {.lex_state = 59},
  [8] = {.lex_state = 59},
  [9] = {.lex_state = 59},
  [10] = {.lex_state = 59},
  [11] = {.lex_state = 59},
  [12] = {.lex_state = 59},
  [13] = {.lex_state = 59},
  [14] = {.lex_state = 59},
  [15] = {.lex_state = 59},
  [16] = {.lex_state = 59},
  [17] = {.lex_state = 59},
  [18] = {.lex_state = 59},
  [19] = {.lex_state = 59},
  [20] = {.lex_state = 59},
  [21] = {.lex_state = 59},
  [22] = {.lex_state = 59},
  [23] = {.lex_state = 59},
  [24] = {.lex_state = 59},
  [25] = {.lex_state = 59},
  [26] = {.lex_state = 59},
  [27] = {.lex_state = 59},
  [28] = {.lex_state = 56},
  [29] = {.lex_state = 59},
  [30] = {.lex_state = 59},
  [31] = {.lex_state = 59},
  [32] = {.lex_state = 59},
  [33] = {.lex_state = 59},
  [34] = {.lex_state = 59},
  [35] = {.lex_state = 59},
  [36] = {.lex_state = 59},
  [37] = {.lex_state = 59},
  [38] = {.lex_state = 59},
  [39] = {.lex_state = 59},
  [40] = {.lex_state = 59},
  [41] = {.lex_state = 59},
  [42] = {.lex_state = 59},
  [43] = {.lex_state = 59},
  [44] = {.lex_state = 59},
  [45] = {.lex_state = 59},
  [46] = {.lex_state = 59},
  [47] = {.lex_state = 59},
  [48] = {.lex_state = 59},
  [49] = {.lex_state = 59},
  [50] = {.lex_state = 59},
  [51] = {.lex_state = 59},
  [52] = {.lex_state = 59},
  [53] = {.lex_state = 59},
  [54] = {.lex_state = 59},
  [55] = {.lex_state = 59},
  [56] = {.lex_state = 59},
  [57] = {.lex_state = 59},
  [58] = {.lex_state = 59},
  [59] = {.lex_state = 59},
  [60] = {.lex_state = 59},
  [61] = {.lex_state = 59},
  [62] = {.lex_state = 59},
  [63] = {.lex_state = 59},
  [64] = {.lex_state = 59},
  [65] = {.lex_state = 59},
  [66] = {.lex_state = 59},
  [67] = {.lex_state = 59},
  [68] = {.lex_state = 59},
  [69] = {.lex_state = 59},
  [70] = {.lex_state = 59},
  [71] = {.lex_state = 59},
  [72] = {.lex_state = 59},
  [73] = {.lex_state = 59},
  [74] = {.lex_state = 59},
  [75] = {.lex_state = 59},
  [76] = {.lex_state = 59},
  [77] = {.lex_state = 59},
  [78] = {.lex_state = 59},
  [79] = {.lex_state = 59},
  [80] = {.lex_state = 59},
  [81] = {.lex_state = 59},
  [82] = {.lex_state = 59},
  [83] = {.lex_state = 59},
  [84] = {.lex_state = 59},
  [85] = {.lex_state = 59},
  [86] = {.lex_state = 59},
  [87] = {.lex_state = 59},
  [88] = {.lex_state = 59},
  [89] = {.lex_state = 59},
  [90] = {.lex_state = 59},
  [91] = {.lex_state = 59},
  [92] = {.lex_state = 59},
  [93] = {.lex_state = 59},
  [94] = {.lex_state = 59},
  [95] = {.lex_state = 59},
  [96] = {.lex_state = 59},
  [97] = {.lex_state = 59},
  [98] = {.lex_state = 59},
  [99] = {.lex_state = 59},
  [100] = {.lex_state = 59},
  [101] = {.lex_state = 59},
  [102] = {.lex_state = 59},
  [103] = {.lex_state = 59},
  [104] = {.lex_state = 59},
  [105] = {.lex_state = 59},
  [106] = {.lex_state = 59},
  [107] = {.lex_state = 59},
  [108] = {.lex_state = 59},
  [109] = {.lex_state = 59},
  [110] = {.lex_state = 59},
  [111] = {.lex_state = 59},
  [112] = {.lex_state = 59},
  [113] = {.lex_state = 59},
  [114] = {.lex_state = 59},
  [115] = {.lex_state = 59},
  [116] = {.lex_state = 59},
  [117] = {.lex_state = 59},
  [118] = {.lex_state = 59},
  [119] = {.lex_state = 59},
  [120] = {.lex_state = 59},
  [121] = {.lex_state = 59},
  [122] = {.lex_state = 59},
  [123] = {.lex_state = 59},
  [124] = {.lex_state = 59},
  [125] = {.lex_state = 59},
  [126] = {.lex_state = 59},
  [127] = {.lex_state = 59},
  [128] = {.lex_state = 59},
  [129] = {.lex_state = 59},
  [130] = {.lex_state = 59},
  [131] = {.lex_state = 59},
  [132] = {.lex_state = 59},
  [133] = {.lex_state = 59},
  [134] = {.lex_state = 59},
  [135] = {.lex_state = 59},
  [136] = {.lex_state = 59},
  [137] = {.lex_state = 59},
  [138] = {.lex_state = 59},
  [139] = {.lex_state = 59},
  [140] = {.lex_state = 59},
  [141] = {.lex_state = 59},
  [142] = {.lex_state = 59},
  [143] = {.lex_state = 59},
  [144] = {.lex_state = 59},
  [145] = {.lex_state = 59},
  [146] = {.lex_state = 59},
  [147] = {.lex_state = 59},
  [148] = {.lex_state = 59},
  [149] = {.lex_state = 59},
  [150] = {.lex_state = 59},
  [151] = {.lex_state = 59},
  [152] = {.lex_state = 59},
  [153] = {.lex_state = 59},
  [154] = {.lex_state = 59},
  [155] = {.lex_state = 59},
  [156] = {.lex_state = 59},
  [157] = {.lex_state = 59},
  [158] = {.lex_state = 59},
  [159] = {.lex_state = 59},
  [160] = {.lex_state = 59},
  [161] = {.lex_state = 59},
  [162] = {.lex_state = 59},
  [163] = {.lex_state = 59},
  [164] = {.lex_state = 59},
  [165] = {.lex_state = 59},
  [166] = {.lex_state = 59},
  [167] = {.lex_state = 59},
  [168] = {.lex_state = 59},
  [169] = {.lex_state = 59},
  [170] = {.lex_state = 59},
  [171] = {.lex_state = 59},
  [172] = {.lex_state = 59},
  [173] = {.lex_state = 59},
  [174] = {.lex_state = 59},
  [175] = {.lex_state = 59},
  [176] = {.lex_state = 59},
  [177] = {.lex_state = 59},
  [178] = {.lex_state = 59},
  [179] = {.lex_state = 59},
  [180] = {.lex_state = 59},
  [181] = {.lex_state = 59},
  [182] = {.lex_state = 59},
  [183] = {.lex_state = 59},
  [184] = {.lex_state = 59},
  [185] = {.lex_state = 59},
  [186] = {.lex_state = 59},
  [187] = {.lex_state = 59},
  [188] = {.lex_state = 59},
  [189] = {.lex_state = 59},
  [190] = {.lex_state = 59},
  [191] = {.lex_state = 59},
  [192] = {.lex_state = 59},
  [193] = {.lex_state = 59},
  [194] = {.lex_state = 59},
  [195] = {.lex_state = 59},
  [196] = {.lex_state = 59},
  [197] = {.lex_state = 59},
  [198] = {.lex_state = 59},
  [199] = {.lex_state = 59},
  [200] = {.lex_state = 59},
  [201] = {.lex_state = 59},
  [202] = {.lex_state = 59},
  [203] = {.lex_state = 59},
  [204] = {.lex_state = 59},
  [205] = {.lex_state = 59},
  [206] = {.lex_state = 59},
  [207] = {.lex_state = 59},
  [208] = {.lex_state = 59},
  [209] = {.lex_state = 59},
  [210] = {.lex_state = 59},
  [211] = {.lex_state = 59},
  [212] = {.lex_state = 59},
  [213] = {.lex_state = 59},
  [214] = {.lex_state = 59},
  [215] = {.lex_state = 59},
  [216] = {.lex_state = 59},
  [217] = {.lex_state = 59},
  [218] = {.lex_state = 59},
  [219] = {.lex_state = 59},
  [220] = {.lex_state = 59},
  [221] = {.lex_state = 59},
  [222] = {.lex_state = 59},
  [223] = {.lex_state = 59},
  [224] = {.lex_state = 59},
  [225] = {.lex_state = 59},
  [226] = {.lex_state = 59},
  [227] = {.lex_state = 59},
  [228] = {.lex_state = 59},
  [229] = {.lex_state = 59},
  [230] = {.lex_state = 59},
  [231] = {.lex_state = 59},
  [232] = {.lex_state = 59},
  [233] = {.lex_state = 59},
  [234] = {.lex_state = 59},
  [235] = {.lex_state = 59},
  [236] = {.lex_state = 3},
  [237] = {.lex_state = 57},
  [238] = {.lex_state = 57},
  [239] = {.lex_state = 57},
  [240] = {.lex_state = 57},
  [241] = {.lex_state = 57},
  [242] = {.lex_state = 57},
  [243] = {.lex_state = 57},
  [244] = {.lex_state = 57},
  [245] = {.lex_state = 59},
  [246] = {.lex_state = 57},
  [247] = {.lex_state = 57},
  [248] = {.lex_state = 57},
  [249] = {.lex_state = 57},
  [250] = {.lex_state = 57},
  [251] = {.lex_state = 57},
  [252] = {.lex_state = 57},
  [253] = {.lex_state = 57},
  [254] = {.lex_state = 57},
  [255] = {.lex_state = 4},
  [256] = {.lex_state = 57},
  [257] = {.lex_state = 57},
  [258] = {.lex_state = 57},
  [259] = {.lex_state = 4},
  [260] = {.lex_state = 57},
  [261] = {.lex_state = 57},
  [262] = {.lex_state = 57},
  [263] = {.lex_state = 57},
  [264] = {.lex_state = 57},
  [265] = {.lex_state = 57},
  [266] = {.lex_state = 57},
  [267] = {.lex_state = 57},
  [268] = {.lex_state = 57},
  [269] = {.lex_state = 57},
  [270] = {.lex_state = 57},
  [271] = {.lex_state = 57},
  [272] = {.lex_state = 57},
  [273] = {.lex_state = 57},
  [274] = {.lex_state = 57},
  [275] = {.lex_state = 57},
  [276] = {.lex_state = 57},
  [277] = {.lex_state = 57},
  [278] = {.lex_state = 57},
  [279] = {.lex_state = 57},
  [280] = {.lex_state = 57},
  [281] = {.lex_state = 57},
  [282] = {.lex_state = 57},
  [283] = {.lex_state = 57},
  [284] = {.lex_state = 57},
  [285] = {.lex_state = 57},
  [286] = {.lex_state = 57},
  [287] = {.lex_state = 57},
  [288] = {.lex_state = 57},
  [289] = {.lex_state = 4},
  [290] = {.lex_state = 4},
  [291] = {.lex_state = 4},
  [292] = {.lex_state = 4},
  [293] = {.lex_state = 4},
  [294] = {.lex_state = 4},
  [295] = {.lex_state = 4},
  [296] = {.lex_state = 4},
  [297] = {.lex_state = 4},
  [298] = {.lex_state = 4},
  [299] = {.lex_state = 4},
  [300] = {.lex_state = 4},
  [301] = {.lex_state = 4},
  [302] = {.lex_state = 4},
  [303] = {.lex_state = 4},
  [304] = {.lex_state = 4},
  [305] = {.lex_state = 4},
  [306] = {.lex_state = 4},
  [307] = {.lex_state = 4},
  [308] = {.lex_state = 4},
  [309] = {.lex_state = 4},
  [310] = {.lex_state = 4},
  [311] = {.lex_state = 4},
  [312] = {.lex_state = 4},
  [313] = {.lex_state = 4},
  [314] = {.lex_state = 4},
  [315] = {.lex_state = 4},
  [316] = {.lex_state = 4},
  [317] = {.lex_state = 4},
  [318] = {.lex_state = 4},
  [319] = {.lex_state = 4},
  [320] = {.lex_state = 4},
  [321] = {.lex_state = 4},
  [322] = {.lex_state = 4},
  [323] = {.lex_state = 4},
  [324] = {.lex_state = 4},
  [325] = {.lex_state = 4},
  [326] = {.lex_state = 4},
  [327] = {.lex_state = 4},
  [328] = {.lex_state = 4},
  [329] = {.lex_state = 4},
  [330] = {.lex_state = 4},
  [331] = {.lex_state = 4},
  [332] = {.lex_state = 4},
  [333] = {.lex_state = 4},
  [334] = {.lex_state = 4},
  [335] = {.lex_state = 4},
  [336] = {.lex_state = 4},
  [337] = {.lex_state = 5},
  [338] = {.lex_state = 5},
  [339] = {.lex_state = 5},
  [340] = {.lex_state = 5},
  [341] = {.lex_state = 5},
  [342] = {.lex_state = 5},
  [343] = {.lex_state = 5},
  [344] = {.lex_state = 5},
  [345] = {.lex_state = 5},
  [346] = {.lex_state = 5},
  [347] = {.lex_state = 5},
  [348] = {.lex_state = 5},
  [349] = {.lex_state = 5},
  [350] = {.lex_state = 5},
  [351] = {.lex_state = 5},
  [352] = {.lex_state = 5},
  [353] = {.lex_state = 5},
  [354] = {.lex_state = 5},
  [355] = {.lex_state = 5},
  [356] = {.lex_state = 5},
  [357] = {.lex_state = 5},
  [358] = {.lex_state = 5},
  [359] = {.lex_state = 5},
  [360] = {.lex_state = 5},
  [361] = {.lex_state = 5},
  [362] = {.lex_state = 5},
  [363] = {.lex_state = 5},
  [364] = {.lex_state = 5},
  [365] = {.lex_state = 5},
  [366] = {.lex_state = 5},
  [367] = {.lex_state = 5},
  [368] = {.lex_state = 5},
  [369] = {.lex_state = 5},
  [370] = {.lex_state = 5},
  [371] = {.lex_state = 5},
  [372] = {.lex_state = 5},
  [373] = {.lex_state = 5},
  [374] = {.lex_state = 5},
  [375] = {.lex_state = 5},
  [376] = {.lex_state = 5},
  [377] = {.lex_state = 5},
  [378] = {.lex_state = 5},
  [379] = {.lex_state = 5},
  [380] = {.lex_state = 5},
  [381] = {.lex_state = 5},
  [382] = {.lex_state = 5},
  [383] = {.lex_state = 5},
  [384] = {.lex_state = 56},
  [385] = {.lex_state = 57},
  [386] = {.lex_state = 56},
  [387] = {.lex_state = 6},
  [388] = {.lex_state = 6},
  [389] = {.lex_state = 6},
  [390] = {.lex_state = 6},
  [391] = {.lex_state = 56},
  [392] = {.lex_state = 56},
  [393] = {.lex_state = 6},
  [394] = {.lex_state = 6},
  [395] = {.lex_state = 1},
  [396] = {.lex_state = 6},
  [397] = {.lex_state = 6},
  [398] = {.lex_state = 6},
  [399] = {.lex_state = 6},
  [400] = {.lex_state = 6},
  [401] = {.lex_state = 6},
  [402] = {.lex_state = 6},
  [403] = {.lex_state = 6},
  [404] = {.lex_state = 6},
  [405] = {.lex_state = 6},
  [406] = {.lex_state = 6},
  [407] = {.lex_state = 6},
  [408] = {.lex_state = 6},
  [409] = {.lex_state = 6},
  [410] = {.lex_state = 6},
  [411] = {.lex_state = 6},
  [412] = {.lex_state = 6},
  [413] = {.lex_state = 6},
  [414] = {.lex_state = 6},
  [415] = {.lex_state = 6},
  [416] = {.lex_state = 6},
  [417] = {.lex_state = 6},
  [418] = {.lex_state = 6},
  [419] = {.lex_state = 6},
  [420] = {.lex_state = 6},
  [421] = {.lex_state = 6},
  [422] = {.lex_state = 6},
  [423] = {.lex_state = 6},
  [424] = {.lex_state = 6},
  [425] = {.lex_state = 6},
  [426] = {.lex_state = 6},
  [427] = {.lex_state = 6},
  [428] = {.lex_state = 6},
  [429] = {.lex_state = 6},
  [430] = {.lex_state = 6},
  [431] = {.lex_state = 1},
  [432] = {.lex_state = 6},
  [433] = {.lex_state = 1},
  [434] = {.lex_state = 1},
  [435] = {.lex_state = 0},
  [436] = {.lex_state = 1},
  [437] = {.lex_state = 6},
  [438] = {.lex_state = 1},
  [439] = {.lex_state = 1},
  [440] = {.lex_state = 1},
  [441] = {.lex_state = 1},
  [442] = {.lex_state = 6},
  [443] = {.lex_state = 6},
  [444] = {.lex_state = 6},
  [445] = {.lex_state = 0},
  [446] = {.lex_state = 1},
  [447] = {.lex_state = 1},
  [448] = {.lex_state = 0},
  [449] = {.lex_state = 3},
  [450] = {.lex_state = 3},
  [451] = {.lex_state = 1},
  [452] = {.lex_state = 3},
  [453] = {.lex_state = 1},
  [454] = {.lex_state = 56},
  [455] = {.lex_state = 56},
  [456] = {.lex_state = 56},
  [457] = {.lex_state = 1},
  [458] = {.lex_state = 1},
  [459] = {.lex_state = 1},
  [460] = {.lex_state = 3},
  [461] = {.lex_state = 3},
  [462] = {.lex_state = 3},
  [463] = {.lex_state = 3},
  [464] = {.lex_state = 1},
  [465] = {.lex_state = 1},
  [466] = {.lex_state = 1},
  [467] = {.lex_state = 0},
  [468] = {.lex_state = 1},
  [469] = {.lex_state = 1},
  [470] = {.lex_state = 1},
  [471] = {.lex_state = 1},
  [472] = {.lex_state = 1},
  [473] = {.lex_state = 1},
  [474] = {.lex_state = 1},
  [475] = {.lex_state = 1},
  [476] = {.lex_state = 1},
  [477] = {.lex_state = 1},
  [478] = {.lex_state = 0},
  [479] = {.lex_state = 1},
  [480] = {.lex_state = 1},
  [481] = {.lex_state = 1},
  [482] = {.lex_state = 6},
  [483] = {.lex_state = 1},
  [484] = {.lex_state = 1},
  [485] = {.lex_state = 1},
  [486] = {.lex_state = 1},
  [487] = {.lex_state = 3},
  [488] = {.lex_state = 0},
  [489] = {.lex_state = 1},
  [490] = {.lex_state = 1},
  [491] = {.lex_state = 56},
  [492] = {.lex_state = 56},
  [493] = {.lex_state = 56},
  [494] = {.lex_state = 1},
  [495] = {.lex_state = 3},
  [496] = {.lex_state = 1},
  [497] = {.lex_state = 1},
  [498] = {.lex_state = 1},
  [499] = {.lex_state = 56},
  [500] = {.lex_state = 56},
  [501] = {.lex_state = 1},
  [502] = {.lex_state = 1},
  [503] = {.lex_state = 1},
  [504] = {.lex_state = 1},
  [505] = {.lex_state = 1},
  [506] = {.lex_state = 1},
  [507] = {.lex_state = 1},
  [508] = {.lex_state = 1},
  [509] = {.lex_state = 1},
  [510] = {.lex_state = 0},
  [511] = {.lex_state = 6},
  [512] = {.lex_state = 6},
  [513] = {.lex_state = 6},
  [514] = {.lex_state = 6},
  [515] = {.lex_state = 3},
  [516] = {.lex_state = 6},
  [517] = {.lex_state = 0},
  [518] = {.lex_state = 0},
  [519] = {.lex_state = 0},
  [520] = {.lex_state = 6},
  [521] = {.lex_state = 6},
  [522] = {.lex_state = 6},
  [523] = {.lex_state = 0},
  [524] = {.lex_state = 56},
  [525] = {.lex_state = 6},
  [526] = {.lex_state = 0},
  [527] = {.lex_state = 6},
  [528] = {.lex_state = 3},
  [529] = {.lex_state = 3},
  [530] = {.lex_state = 0},
  [531] = {.lex_state = 0},
  [532] = {.lex_state = 0},
  [533] = {.lex_state = 0},
  [534] = {.lex_state = 3},
  [535] = {.lex_state = 6},
  [536] = {.lex_state = 0},
  [537] = {.lex_state = 3},
  [538] = {.lex_state = 3},
  [539] = {.lex_state = 3},
  [540] = {.lex_state = 0},
  [541] = {.lex_state = 6},
  [542] = {.lex_state = 6},
  [543] = {.lex_state = 3},
  [544] = {.lex_state = 0},
  [545] = {.lex_state = 3},
  [546] = {.lex_state = 6},
  [547] = {.lex_state = 0},
  [548] = {.lex_state = 3},
  [549] = {.lex_state = 6},
  [550] = {.lex_state = 6},
  [551] = {.lex_state = 6},
  [552] = {.lex_state = 3},
  [553] = {.lex_state = 3},
  [554] = {.lex_state = 3},
  [555] = {.lex_state = 3},
  [556] = {.lex_state = 0},
  [557] = {.lex_state = 0},
  [558] = {.lex_state = 6},
  [559] = {.lex_state = 6},
  [560] = {.lex_state = 6},
  [561] = {.lex_state = 6},
  [562] = {.lex_state = 0},
  [563] = {.lex_state = 0},
  [564] = {.lex_state = 0},
  [565] = {.lex_state = 6},
  [566] = {.lex_state = 3},
  [567] = {.lex_state = 3},
  [568] = {.lex_state = 3},
  [569] = {.lex_state = 3},
  [570] = {.lex_state = 3},
  [571] = {.lex_state = 3},
  [572] = {.lex_state = 3},
  [573] = {.lex_state = 3},
  [574] = {.lex_state = 3},
  [575] = {.lex_state = 3},
  [576] = {.lex_state = 3},
  [577] = {.lex_state = 3},
  [578] = {.lex_state = 3},
  [579] = {.lex_state = 3},
  [580] = {.lex_state = 3},
  [581] = {.lex_state = 3},
  [582] = {.lex_state = 3},
  [583] = {.lex_state = 3},
  [584] = {.lex_state = 3},
  [585] = {.lex_state = 3},
  [586] = {.lex_state = 3},
  [587] = {.lex_state = 3},
  [588] = {.lex_state = 3},
  [589] = {.lex_state = 0},
  [590] = {.lex_state = 6},
  [591] = {.lex_state = 3},
  [592] = {.lex_state = 3},
  [593] = {.lex_state = 0},
  [594] = {.lex_state = 6},
  [595] = {.lex_state = 0},
  [596] = {.lex_state = 0},
  [597] = {.lex_state = 6},
  [598] = {.lex_state = 6},
  [599] = {.lex_state = 6},
  [600] = {.lex_state = 0},
  [601] = {.lex_state = 0},
  [602] = {.lex_state = 6},
  [603] = {.lex_state = 6},
  [604] = {.lex_state = 0},
  [605] = {.lex_state = 6},
  [606] = {.lex_state = 6},
  [607] = {.lex_state = 6},
  [608] = {.lex_state = 6},
  [609] = {.lex_state = 6},
  [610] = {.lex_state = 0},
  [611] = {.lex_state = 6},
  [612] = {.lex_state = 6},
  [613] = {.lex_state = 0},
  [614] = {.lex_state = 0},
  [615] = {.lex_state = 0},
  [616] = {.lex_state = 6},
  [617] = {.lex_state = 6},
  [618] = {.lex_state = 6},
  [619] = {.lex_state = 0},
  [620] = {.lex_state = 0},
  [621] = {.lex_state = 6},
  [622] = {.lex_state = 6},
  [623] = {.lex_state = 6},
  [624] = {.lex_state = 0},
  [625] = {.lex_state = 0},
  [626] = {.lex_state = 6},
  [627] = {.lex_state = 0},
  [628] = {.lex_state = 0},
  [629] = {.lex_state = 6},
  [630] = {.lex_state = 6},
  [631] = {.lex_state = 6},
  [632] = {.lex_state = 6},
  [633] = {.lex_state = 6},
  [634] = {.lex_state = 6},
  [635] = {.lex_state = 0},
  [636] = {.lex_state = 6},
  [637] = {.lex_state = 6},
  [638] = {.lex_state = 6},
  [639] = {.lex_state = 6},
  [640] = {.lex_state = 0},
  [641] = {.lex_state = 6},
  [642] = {.lex_state = 0},
  [643] = {.lex_state = 0},
  [644] = {.lex_state = 0},
  [645] = {.lex_state = 6},
  [646] = {.lex_state = 6},
  [647] = {.lex_state = 6},
  [648] = {.lex_state = 0},
  [649] = {.lex_state = 6},
  [650] = {.lex_state = 0},
  [651] = {.lex_state = 0},
  [652] = {.lex_state = 0},
  [653] = {.lex_state = 6},
  [654] = {.lex_state = 6},
  [655] = {.lex_state = 0},
  [656] = {.lex_state = 0},
  [657] = {.lex_state = 6},
  [658] = {.lex_state = 6},
  [659] = {.lex_state = 0},
  [660] = {.lex_state = 6},
  [661] = {.lex_state = 0},
  [662] = {.lex_state = 6},
  [663] = {.lex_state = 0},
  [664] = {.lex_state = 0},
  [665] = {.lex_state = 6},
  [666] = {.lex_state = 6},
  [667] = {.lex_state = 6},
  [668] = {.lex_state = 0},
  [669] = {.lex_state = 6},
  [670] = {.lex_state = 6},
  [671] = {.lex_state = 0},
  [672] = {.lex_state = 0},
  [673] = {.lex_state = 0},
  [674] = {.lex_state = 6},
  [675] = {.lex_state = 6},
  [676] = {.lex_state = 6},
  [677] = {.lex_state = 0},
  [678] = {.lex_state = 0},
  [679] = {.lex_state = 0},
  [680] = {.lex_state = 6},
  [681] = {.lex_state = 6},
  [682] = {.lex_state = 6},
  [683] = {.lex_state = 6},
  [684] = {.lex_state = 0},
  [685] = {.lex_state = 0},
  [686] = {.lex_state = 0},
  [687] = {.lex_state = 6},
  [688] = {.lex_state = 6},
  [689] = {.lex_state = 6},
  [690] = {.lex_state = 0},
  [691] = {.lex_state = 0},
  [692] = {.lex_state = 6},
  [693] = {.lex_state = 6},
  [694] = {.lex_state = 0},
  [695] = {.lex_state = 0},
  [696] = {.lex_state = 0},
  [697] = {.lex_state = 0},
  [698] = {.lex_state = 0},
  [699] = {.lex_state = 0},
  [700] = {.lex_state = 0},
  [701] = {.lex_state = 0},
  [702] = {.lex_state = 0},
  [703] = {.lex_state = 0},
  [704] = {.lex_state = 0},
  [705] = {.lex_state = 0},
  [706] = {.lex_state = 0},
  [707] = {.lex_state = 0},
  [708] = {.lex_state = 0},
  [709] = {.lex_state = 0},
  [710] = {.lex_state = 0},
  [711] = {.lex_state = 0},
  [712] = {.lex_state = 0},
  [713] = {.lex_state = 0},
  [714] = {.lex_state = 0},
  [715] = {.lex_state = 0},
  [716] = {.lex_state = 0},
  [717] = {.lex_state = 0},
  [718] = {.lex_state = 0},
  [719] = {.lex_state = 0},
  [720] = {.lex_state = 6},
  [721] = {.lex_state = 0},
  [722] = {.lex_state = 0},
  [723] = {.lex_state = 0},
  [724] = {.lex_state = 0},
  [725] = {.lex_state = 0},
  [726] = {.lex_state = 0},
  [727] = {.lex_state = 0},
  [728] = {.lex_state = 0},
  [729] = {.lex_state = 0},
  [730] = {.lex_state = 0},
  [731] = {.lex_state = 0},
  [732] = {.lex_state = 0},
  [733] = {.lex_state = 0},
  [734] = {.lex_state = 0},
  [735] = {.lex_state = 0},
  [736] = {.lex_state = 0},
  [737] = {.lex_state = 0},
  [738] = {.lex_state = 0},
  [739] = {.lex_state = 0},
  [740] = {.lex_state = 0},
  [741] = {.lex_state = 0},
  [742] = {.lex_state = 0},
  [743] = {.lex_state = 0},
  [744] = {.lex_state = 0},
  [745] = {.lex_state = 0},
  [746] = {.lex_state = 0},
  [747] = {.lex_state = 0},
  [748] = {.lex_state = 0},
  [749] = {.lex_state = 0},
  [750] = {.lex_state = 0},
  [751] = {.lex_state = 0},
  [752] = {.lex_state = 0},
  [753] = {.lex_state = 0},
  [754] = {.lex_state = 0},
  [755] = {.lex_state = 0},
  [756] = {.lex_state = 0},
  [757] = {.lex_state = 0},
  [758] = {.lex_state = 0},
  [759] = {.lex_state = 0},
  [760] = {.lex_state = 0},
  [761] = {.lex_state = 0},
  [762] = {.lex_state = 0},
  [763] = {.lex_state = 0},
  [764] = {.lex_state = 0},
  [765] = {.lex_state = 0},
  [766] = {.lex_state = 0},
  [767] = {.lex_state = 0},
  [768] = {.lex_state = 0},
  [769] = {.lex_state = 0},
  [770] = {.lex_state = 0},
  [771] = {.lex_state = 0},
  [772] = {.lex_state = 0},
  [773] = {.lex_state = 0},
  [774] = {.lex_state = 0},
  [775] = {.lex_state = 0},
  [776] = {.lex_state = 56},
  [777] = {.lex_state = 56},
  [778] = {.lex_state = 56},
  [779] = {.lex_state = 56},
  [780] = {.lex_state = 56},
  [781] = {.lex_state = 56},
  [782] = {.lex_state = 0},
  [783] = {.lex_state = 0},
  [784] = {.lex_state = 0},
  [785] = {.lex_state = 0},
  [786] = {.lex_state = 56},
  [787] = {.lex_state = 56},
  [788] = {.lex_state = 56},
  [789] = {.lex_state = 56},
  [790] = {.lex_state = 0},
  [791] = {.lex_state = 0},
  [792] = {.lex_state = 57},
  [793] = {.lex_state = 57},
  [794] = {.lex_state = 0},
  [795] = {.lex_state = 0},
  [796] = {.lex_state = 56},
  [797] = {.lex_state = 0},
  [798] = {.lex_state = 0},
  [799] = {.lex_state = 56},
  [800] = {.lex_state = 0},
  [801] = {.lex_state = 0},
  [802] = {.lex_state = 0},
  [803] = {.lex_state = 0},
  [804] = {.lex_state = 56},
  [805] = {.lex_state = 0},
  [806] = {.lex_state = 56},
  [807] = {.lex_state = 56},
  [808] = {.lex_state = 56},
  [809] = {.lex_state = 56},
  [810] = {.lex_state = 56},
  [811] = {.lex_state = 56},
  [812] = {.lex_state = 56},
  [813] = {.lex_state = 56},
  [814] = {.lex_state = 56},
  [815] = {.lex_state = 56},
  [816] = {.lex_state = 56},
  [817] = {.lex_state = 56},
  [818] = {.lex_state = 56},
  [819] = {.lex_state = 56},
  [820] = {.lex_state = 56},
  [821] = {.lex_state = 56},
  [822] = {.lex_state = 56},
  [823] = {.lex_state = 56},
  [824] = {.lex_state = 56},
  [825] = {.lex_state = 56},
  [826] = {.lex_state = 56},
  [827] = {.lex_state = 56},
  [828] = {.lex_state = 56},
  [829] = {.lex_state = 56},
  [830] = {.lex_state = 56},
  [831] = {.lex_state = 56},
  [832] = {.lex_state = 3},
  [833] = {.lex_state = 0},
  [834] = {.lex_state = 0},
  [835] = {.lex_state = 0},
  [836] = {.lex_state = 0},
  [837] = {.lex_state = 3},
  [838] = {.lex_state = 3},
  [839] = {.lex_state = 57},
  [840] = {.lex_state = 57},
  [841] = {.lex_state = 3},
  [842] = {.lex_state = 0},
  [843] = {.lex_state = 0},
  [844] = {.lex_state = 0},
  [845] = {.lex_state = 3},
  [846] = {.lex_state = 0},
  [847] = {.lex_state = 0},
  [848] = {.lex_state = 0},
  [849] = {.lex_state = 3},
  [850] = {.lex_state = 0},
  [851] = {.lex_state = 0},
  [852] = {.lex_state = 0},
  [853] = {.lex_state = 0},
  [854] = {.lex_state = 0},
  [855] = {.lex_state = 0},
  [856] = {.lex_state = 0},
  [857] = {.lex_state = 0},
  [858] = {.lex_state = 0},
  [859] = {.lex_state = 0},
  [860] = {.lex_state = 0},
  [861] = {.lex_state = 3},
  [862] = {.lex_state = 0},
  [863] = {.lex_state = 3},
  [864] = {.lex_state = 3},
  [865] = {.lex_state = 0},
  [866] = {.lex_state = 0},
  [867] = {.lex_state = 0},
  [868] = {.lex_state = 56},
  [869] = {.lex_state = 56},
  [870] = {.lex_state = 0},
  [871] = {.lex_state = 0},
  [872] = {.lex_state = 3},
  [873] = {.lex_state = 0},
  [874] = {.lex_state = 0},
  [875] = {.lex_state = 0},
  [876] = {.lex_state = 0},
  [877] = {.lex_state = 0},
  [878] = {.lex_state = 0},
  [879] = {.lex_state = 0},
  [880] = {.lex_state = 0},
  [881] = {.lex_state = 56},
  [882] = {.lex_state = 3},
  [883] = {.lex_state = 0},
  [884] = {.lex_state = 0},
  [885] = {.lex_state = 0},
  [886] = {.lex_state = 0},
  [887] = {.lex_state = 57},
  [888] = {.lex_state = 56},
  [889] = {.lex_state = 0},
  [890] = {.lex_state = 0},
  [891] = {.lex_state = 57},
  [892] = {.lex_state = 0},
  [893] = {.lex_state = 0},
  [894] = {.lex_state = 0},
  [895] = {.lex_state = 56},
  [896] = {.lex_state = 56},
  [897] = {.lex_state = 56},
  [898] = {.lex_state = 56},
  [899] = {.lex_state = 56},
  [900] = {.lex_state = 56},
  [901] = {.lex_state = 56},
  [902] = {.lex_state = 0},
  [903] = {.lex_state = 56},
  [904] = {.lex_state = 56},
  [905] = {.lex_state = 56},
  [906] = {.lex_state = 56},
  [907] = {.lex_state = 56},
  [908] = {.lex_state = 56},
  [909] = {.lex_state = 56},
  [910] = {.lex_state = 56},
  [911] = {.lex_state = 56},
  [912] = {.lex_state = 56},
  [913] = {.lex_state = 56},
  [914] = {.lex_state = 56},
  [915] = {.lex_state = 56},
  [916] = {.lex_state = 0},
  [917] = {.lex_state = 56},
  [918] = {.lex_state = 56},
  [919] = {.lex_state = 56},
  [920] = {.lex_state = 56},
  [921] = {.lex_state = 56},
  [922] = {.lex_state = 56},
  [923] = {.lex_state = 56},
  [924] = {.lex_state = 56},
  [925] = {.lex_state = 56},
  [926] = {.lex_state = 56},
  [927] = {.lex_state = 56},
  [928] = {.lex_state = 0},
  [929] = {.lex_state = 0},
  [930] = {.lex_state = 56},
  [931] = {.lex_state = 0},
  [932] = {.lex_state = 56},
  [933] = {.lex_state = 56},
  [934] = {.lex_state = 56},
  [935] = {.lex_state = 56},
  [936] = {.lex_state = 56},
  [937] = {.lex_state = 56},
  [938] = {.lex_state = 56},
  [939] = {.lex_state = 56},
  [940] = {.lex_state = 56},
  [941] = {.lex_state = 56},
  [942] = {.lex_state = 56},
  [943] = {.lex_state = 56},
  [944] = {.lex_state = 56},
  [945] = {.lex_state = 3},
  [946] = {.lex_state = 56},
  [947] = {.lex_state = 56},
  [948] = {.lex_state = 56},
  [949] = {.lex_state = 56},
  [950] = {.lex_state = 56},
  [951] = {.lex_state = 56},
  [952] = {.lex_state = 0},
  [953] = {.lex_state = 56},
  [954] = {.lex_state = 56},
  [955] = {.lex_state = 56},
  [956] = {.lex_state = 56},
  [957] = {.lex_state = 56},
  [958] = {.lex_state = 0},
  [959] = {.lex_state = 56},
  [960] = {.lex_state = 56},
  [961] = {.lex_state = 56},
  [962] = {.lex_state = 56},
  [963] = {.lex_state = 56},
  [964] = {.lex_state = 0},
  [965] = {.lex_state = 56},
  [966] = {.lex_state = 56},
  [967] = {.lex_state = 0},
  [968] = {.lex_state = 56},
  [969] = {.lex_state = 56},
  [970] = {.lex_state = 56},
  [971] = {.lex_state = 56},
  [972] = {.lex_state = 0},
  [973] = {.lex_state = 56},
  [974] = {.lex_state = 56},
  [975] = {.lex_state = 56},
  [976] = {.lex_state = 3},
  [977] = {.lex_state = 56},
  [978] = {.lex_state = 56},
  [979] = {.lex_state = 0},
  [980] = {.lex_state = 56},
  [981] = {.lex_state = 0},
  [982] = {.lex_state = 0},
  [983] = {.lex_state = 56},
  [984] = {.lex_state = 56},
  [985] = {.lex_state = 0},
  [986] = {.lex_state = 0},
  [987] = {.lex_state = 56},
  [988] = {.lex_state = 0},
  [989] = {.lex_state = 56},
  [990] = {.lex_state = 56},
  [991] = {.lex_state = 56},
  [992] = {.lex_state = 56},
  [993] = {.lex_state = 0},
  [994] = {.lex_state = 56},
  [995] = {.lex_state = 56},
  [996] = {.lex_state = 0},
  [997] = {.lex_state = 56},
  [998] = {.lex_state = 0},
  [999] = {.lex_state = 56},
  [1000] = {.lex_state = 56},
  [1001] = {.lex_state = 56},
  [1002] = {.lex_state = 56},
  [1003] = {.lex_state = 56},
  [1004] = {.lex_state = 0},
  [1005] = {.lex_state = 56},
  [1006] = {.lex_state = 56},
  [1007] = {.lex_state = 56},
  [1008] = {.lex_state = 56},
  [1009] = {.lex_state = 56},
  [1010] = {.lex_state = 56},
  [1011] = {.lex_state = 56},
  [1012] = {.lex_state = 56},
  [1013] = {.lex_state = 56},
  [1014] = {.lex_state = 56},
  [1015] = {.lex_state = 56},
  [1016] = {.lex_state = 56},
  [1017] = {.lex_state = 56},
  [1018] = {.lex_state = 0},
  [1019] = {.lex_state = 0},
  [1020] = {.lex_state = 56},
  [1021] = {.lex_state = 56},
  [1022] = {.lex_state = 0},
  [1023] = {.lex_state = 56},
  [1024] = {.lex_state = 56},
  [1025] = {.lex_state = 56},
  [1026] = {.lex_state = 56},
  [1027] = {.lex_state = 56},
  [1028] = {.lex_state = 56},
  [1029] = {.lex_state = 56},
  [1030] = {.lex_state = 56},
  [1031] = {.lex_state = 0},
  [1032] = {.lex_state = 0},
  [1033] = {.lex_state = 56},
  [1034] = {.lex_state = 0},
  [1035] = {.lex_state = 56},
  [1036] = {.lex_state = 56},
  [1037] = {.lex_state = 56},
  [1038] = {.lex_state = 56},
  [1039] = {.lex_state = 56},
  [1040] = {.lex_state = 56},
  [1041] = {.lex_state = 0},
  [1042] = {.lex_state = 0},
  [1043] = {.lex_state = 56},
  [1044] = {.lex_state = 56},
  [1045] = {.lex_state = 56},
  [1046] = {.lex_state = 0},
  [1047] = {.lex_state = 56},
  [1048] = {.lex_state = 56},
  [1049] = {.lex_state = 56},
  [1050] = {.lex_state = 2},
  [1051] = {.lex_state = 2},
  [1052] = {.lex_state = 0},
  [1053] = {.lex_state = 56},
  [1054] = {.lex_state = 56},
  [1055] = {.lex_state = 56},
  [1056] = {.lex_state = 56},
  [1057] = {.lex_state = 56},
  [1058] = {.lex_state = 56},
  [1059] = {.lex_state = 56},
  [1060] = {.lex_state = 56},
  [1061] = {.lex_state = 0},
  [1062] = {.lex_state = 0},
  [1063] = {.lex_state = 56},
  [1064] = {.lex_state = 56},
  [1065] = {.lex_state = 56},
  [1066] = {.lex_state = 56},
  [1067] = {.lex_state = 2},
  [1068] = {.lex_state = 0},
  [1069] = {.lex_state = 56},
  [1070] = {.lex_state = 56},
  [1071] = {.lex_state = 2},
  [1072] = {.lex_state = 0},
  [1073] = {.lex_state = 0},
  [1074] = {.lex_state = 56},
  [1075] = {.lex_state = 0},
  [1076] = {.lex_state = 56},
  [1077] = {.lex_state = 56},
  [1078] = {.lex_state = 2},
  [1079] = {.lex_state = 56},
  [1080] = {.lex_state = 2},
  [1081] = {.lex_state = 56},
  [1082] = {.lex_state = 56},
  [1083] = {.lex_state = 2},
  [1084] = {.lex_state = 0},
  [1085] = {.lex_state = 56},
  [1086] = {.lex_state = 0},
  [1087] = {.lex_state = 0},
  [1088] = {.lex_state = 0},
  [1089] = {.lex_state = 0},
  [1090] = {.lex_state = 0},
  [1091] = {.lex_state = 56},
  [1092] = {.lex_state = 0},
  [1093] = {.lex_state = 0},
  [1094] = {.lex_state = 56},
  [1095] = {.lex_state = 2},
  [1096] = {.lex_state = 0},
  [1097] = {.lex_state = 2},
  [1098] = {.lex_state = 2},
  [1099] = {.lex_state = 0},
  [1100] = {.lex_state = 0},
  [1101] = {.lex_state = 0},
  [1102] = {.lex_state = 56},
  [1103] = {.lex_state = 0},
  [1104] = {.lex_state = 0},
  [1105] = {.lex_state = 0},
  [1106] = {.lex_state = 0},
  [1107] = {.lex_state = 2},
  [1108] = {.lex_state = 0},
  [1109] = {.lex_state = 56},
  [1110] = {.lex_state = 56},
  [1111] = {.lex_state = 2},
  [1112] = {.lex_state = 56},
  [1113] = {.lex_state = 0},
  [1114] = {.lex_state = 0},
  [1115] = {.lex_state = 56},
  [1116] = {.lex_state = 2},
  [1117] = {.lex_state = 0},
  [1118] = {.lex_state = 2},
  [1119] = {.lex_state = 2},
  [1120] = {.lex_state = 0},
  [1121] = {.lex_state = 56},
  [1122] = {.lex_state = 56},
  [1123] = {.lex_state = 56},
  [1124] = {.lex_state = 56},
  [1125] = {.lex_state = 56},
  [1126] = {.lex_state = 56},
  [1127] = {.lex_state = 0},
  [1128] = {.lex_state = 56},
  [1129] = {.lex_state = 56},
  [1130] = {.lex_state = 56},
  [1131] = {.lex_state = 0},
  [1132] = {.lex_state = 0},
  [1133] = {.lex_state = 0},
  [1134] = {.lex_state = 0},
  [1135] = {.lex_state = 0},
  [1136] = {.lex_state = 0},
  [1137] = {.lex_state = 56},
  [1138] = {.lex_state = 0},
  [1139] = {.lex_state = 0},
  [1140] = {.lex_state = 0},
  [1141] = {.lex_state = 0},
  [1142] = {.lex_state = 0},
  [1143] = {.lex_state = 0},
  [1144] = {.lex_state = 0},
  [1145] = {.lex_state = 0},
  [1146] = {.lex_state = 0},
  [1147] = {.lex_state = 0},
  [1148] = {.lex_state = 0},
  [1149] = {.lex_state = 59},
  [1150] = {.lex_state = 0},
  [1151] = {.lex_state = 59},
  [1152] = {.lex_state = 0},
  [1153] = {.lex_state = 0},
  [1154] = {.lex_state = 56},
  [1155] = {.lex_state = 0},
  [1156] = {.lex_state = 0},
  [1157] = {.lex_state = 0},
  [1158] = {.lex_state = 0},
  [1159] = {.lex_state = 0},
  [1160] = {.lex_state = 0},
  [1161] = {.lex_state = 0},
  [1162] = {.lex_state = 0},
  [1163] = {.lex_state = 0},
  [1164] = {.lex_state = 0},
  [1165] = {.lex_state = 0},
  [1166] = {.lex_state = 0},
  [1167] = {.lex_state = 0},
  [1168] = {.lex_state = 0},
  [1169] = {.lex_state = 56},
  [1170] = {.lex_state = 0},
  [1171] = {.lex_state = 56},
  [1172] = {.lex_state = 0},
  [1173] = {.lex_state = 0},
  [1174] = {.lex_state = 0},
  [1175] = {.lex_state = 56},
  [1176] = {.lex_state = 56},
  [1177] = {.lex_state = 0},
  [1178] = {.lex_state = 0},
  [1179] = {.lex_state = 0},
  [1180] = {.lex_state = 0},
  [1181] = {.lex_state = 0},
  [1182] = {.lex_state = 0},
  [1183] = {.lex_state = 0},
  [1184] = {.lex_state = 0},
  [1185] = {.lex_state = 0},
  [1186] = {.lex_state = 0},
  [1187] = {.lex_state = 0},
  [1188] = {.lex_state = 0},
  [1189] = {.lex_state = 0},
  [1190] = {.lex_state = 0},
  [1191] = {.lex_state = 56},
  [1192] = {.lex_state = 0},
  [1193] = {.lex_state = 0},
  [1194] = {.lex_state = 0},
  [1195] = {.lex_state = 0},
  [1196] = {.lex_state = 0},
  [1197] = {.lex_state = 0},
  [1198] = {.lex_state = 0},
  [1199] = {.lex_state = 0},
  [1200] = {.lex_state = 0},
  [1201] = {.lex_state = 0},
  [1202] = {.lex_state = 0},
  [1203] = {.lex_state = 56},
  [1204] = {.lex_state = 0},
  [1205] = {.lex_state = 0},
  [1206] = {.lex_state = 0},
  [1207] = {.lex_state = 56},
  [1208] = {.lex_state = 0},
  [1209] = {.lex_state = 0},
  [1210] = {.lex_state = 56},
  [1211] = {.lex_state = 56},
  [1212] = {.lex_state = 56},
  [1213] = {.lex_state = 0},
  [1214] = {.lex_state = 0},
  [1215] = {.lex_state = 0},
  [1216] = {.lex_state = 0},
  [1217] = {.lex_state = 0},
  [1218] = {.lex_state = 0},
  [1219] = {.lex_state = 0},
  [1220] = {.lex_state = 0},
  [1221] = {.lex_state = 0},
  [1222] = {.lex_state = 0},
  [1223] = {.lex_state = 0},
  [1224] = {.lex_state = 0},
  [1225] = {.lex_state = 0},
  [1226] = {.lex_state = 0},
  [1227] = {.lex_state = 59},
  [1228] = {.lex_state = 0},
  [1229] = {.lex_state = 0},
  [1230] = {.lex_state = 0},
  [1231] = {.lex_state = 59},
  [1232] = {.lex_state = 56},
  [1233] = {.lex_state = 0},
  [1234] = {.lex_state = 56},
  [1235] = {.lex_state = 56},
  [1236] = {.lex_state = 0},
  [1237] = {.lex_state = 0},
  [1238] = {.lex_state = 0},
  [1239] = {.lex_state = 0},
  [1240] = {.lex_state = 0},
  [1241] = {.lex_state = 56},
  [1242] = {.lex_state = 0},
  [1243] = {.lex_state = 0},
  [1244] = {.lex_state = 0},
  [1245] = {.lex_state = 0},
  [1246] = {.lex_state = 0},
  [1247] = {.lex_state = 0},
  [1248] = {.lex_state = 0},
  [1249] = {.lex_state = 0},
  [1250] = {.lex_state = 0},
  [1251] = {.lex_state = 0},
  [1252] = {.lex_state = 0},
  [1253] = {.lex_state = 0},
  [1254] = {.lex_state = 0},
  [1255] = {.lex_state = 0},
  [1256] = {.lex_state = 0},
  [1257] = {.lex_state = 0},
  [1258] = {.lex_state = 0},
  [1259] = {.lex_state = 0},
  [1260] = {.lex_state = 0},
  [1261] = {.lex_state = 0},
  [1262] = {.lex_state = 0},
  [1263] = {.lex_state = 0},
  [1264] = {.lex_state = 0},
  [1265] = {.lex_state = 0},
  [1266] = {.lex_state = 0},
  [1267] = {.lex_state = 0},
  [1268] = {.lex_state = 0},
  [1269] = {.lex_state = 0},
  [1270] = {.lex_state = 0},
  [1271] = {.lex_state = 0},
  [1272] = {.lex_state = 0},
  [1273] = {.lex_state = 0},
  [1274] = {.lex_state = 0},
  [1275] = {.lex_state = 0},
  [1276] = {.lex_state = 0},
  [1277] = {.lex_state = 0},
  [1278] = {.lex_state = 0},
  [1279] = {.lex_state = 0},
  [1280] = {.lex_state = 0},
  [1281] = {.lex_state = 0},
  [1282] = {.lex_state = 0},
  [1283] = {.lex_state = 0},
  [1284] = {.lex_state = 0},
  [1285] = {.lex_state = 0},
  [1286] = {.lex_state = 0},
  [1287] = {.lex_state = 59},
  [1288] = {.lex_state = 0},
  [1289] = {.lex_state = 0},
  [1290] = {.lex_state = 0},
  [1291] = {.lex_state = 0},
  [1292] = {.lex_state = 0},
  [1293] = {.lex_state = 0},
  [1294] = {.lex_state = 0},
  [1295] = {.lex_state = 0},
  [1296] = {.lex_state = 0},
  [1297] = {.lex_state = 0},
  [1298] = {.lex_state = 0},
  [1299] = {.lex_state = 0},
  [1300] = {.lex_state = 0},
  [1301] = {.lex_state = 0},
  [1302] = {.lex_state = 0},
  [1303] = {.lex_state = 0},
  [1304] = {.lex_state = 0},
  [1305] = {.lex_state = 0},
  [1306] = {.lex_state = 0},
  [1307] = {.lex_state = 0},
  [1308] = {.lex_state = 0},
  [1309] = {.lex_state = 0},
  [1310] = {.lex_state = 0},
  [1311] = {.lex_state = 0},
  [1312] = {.lex_state = 0},
  [1313] = {.lex_state = 0},
  [1314] = {.lex_state = 0},
  [1315] = {.lex_state = 0},
  [1316] = {.lex_state = 0},
  [1317] = {.lex_state = 0},
  [1318] = {.lex_state = 0},
  [1319] = {.lex_state = 0},
  [1320] = {.lex_state = 0},
  [1321] = {.lex_state = 0},
  [1322] = {.lex_state = 0},
  [1323] = {.lex_state = 0},
  [1324] = {.lex_state = 0},
  [1325] = {.lex_state = 0},
  [1326] = {.lex_state = 0},
  [1327] = {.lex_state = 0},
  [1328] = {.lex_state = 0},
  [1329] = {.lex_state = 0},
  [1330] = {.lex_state = 0},
  [1331] = {.lex_state = 0},
  [1332] = {.lex_state = 0},
  [1333] = {.lex_state = 0},
  [1334] = {.lex_state = 0},
  [1335] = {.lex_state = 0},
  [1336] = {.lex_state = 0},
  [1337] = {.lex_state = 0},
  [1338] = {.lex_state = 0},
  [1339] = {.lex_state = 0},
  [1340] = {.lex_state = 0},
  [1341] = {.lex_state = 0},
  [1342] = {.lex_state = 0},
  [1343] = {.lex_state = 0},
  [1344] = {.lex_state = 0},
  [1345] = {.lex_state = 0},
  [1346] = {.lex_state = 0},
  [1347] = {.lex_state = 0},
  [1348] = {.lex_state = 0},
  [1349] = {.lex_state = 0},
  [1350] = {.lex_state = 0},
  [1351] = {.lex_state = 0},
  [1352] = {.lex_state = 0},
  [1353] = {.lex_state = 0},
  [1354] = {.lex_state = 0},
  [1355] = {.lex_state = 0},
  [1356] = {.lex_state = 0},
  [1357] = {.lex_state = 0},
  [1358] = {.lex_state = 0},
  [1359] = {.lex_state = 0},
  [1360] = {.lex_state = 0},
  [1361] = {.lex_state = 0},
  [1362] = {.lex_state = 0},
  [1363] = {.lex_state = 0},
  [1364] = {.lex_state = 0},
  [1365] = {.lex_state = 0},
  [1366] = {.lex_state = 0},
  [1367] = {.lex_state = 0},
  [1368] = {.lex_state = 0},
  [1369] = {.lex_state = 0},
  [1370] = {.lex_state = 0},
  [1371] = {.lex_state = 0},
  [1372] = {.lex_state = 0},
  [1373] = {.lex_state = 0},
  [1374] = {.lex_state = 0},
  [1375] = {.lex_state = 0},
  [1376] = {.lex_state = 0},
  [1377] = {.lex_state = 0},
  [1378] = {.lex_state = 0},
  [1379] = {.lex_state = 0},
  [1380] = {.lex_state = 0},
  [1381] = {.lex_state = 0},
  [1382] = {.lex_state = 0},
  [1383] = {.lex_state = 0},
  [1384] = {.lex_state = 0},
  [1385] = {.lex_state = 0},
  [1386] = {.lex_state = 0},
  [1387] = {.lex_state = 0},
  [1388] = {.lex_state = 0},
  [1389] = {.lex_state = 0},
  [1390] = {.lex_state = 0},
  [1391] = {.lex_state = 0},
  [1392] = {.lex_state = 0},
  [1393] = {.lex_state = 0},
  [1394] = {.lex_state = 0},
  [1395] = {.lex_state = 0},
  [1396] = {.lex_state = 0},
  [1397] = {.lex_state = 0},
  [1398] = {.lex_state = 0},
  [1399] = {.lex_state = 0},
  [1400] = {.lex_state = 0},
  [1401] = {.lex_state = 0},
  [1402] = {.lex_state = 0},
  [1403] = {.lex_state = 0},
};

static const uint16_t ts_parse_table[LARGE_STATE_COUNT][SYMBOL_COUNT] = {
  [0] = {
    [ts_builtin_sym_end] = ACTIONS(1),
    [sym_identifier] = ACTIONS(1),
    [anon_sym_SEMI] = ACTIONS(1),
    [anon_sym_NULL] = ACTIONS(1),
    [anon_sym_package] = ACTIONS(1),
    [anon_sym_import] = ACTIONS(1),
    [anon_sym_DOT] = ACTIONS(1),
    [sym_blank_identifier] = ACTIONS(1),
    [anon_sym_LPAREN] = ACTIONS(1),
    [anon_sym_RPAREN] = ACTIONS(1),
    [anon_sym_const] = ACTIONS(1),
    [anon_sym_COMMA] = ACTIONS(1),
    [anon_sym_EQ] = ACTIONS(1),
    [anon_sym_var] = ACTIONS(1),
    [anon_sym_func] = ACTIONS(1),
    [anon_sym_LBRACK] = ACTIONS(1),
    [anon_sym_RBRACK] = ACTIONS(1),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1),
    [anon_sym_type] = ACTIONS(1),
    [anon_sym_STAR] = ACTIONS(1),
    [anon_sym_struct] = ACTIONS(1),
    [anon_sym_TILDE] = ACTIONS(1),
    [anon_sym_LBRACE] = ACTIONS(1),
    [anon_sym_RBRACE] = ACTIONS(1),
    [anon_sym_interface] = ACTIONS(1),
    [anon_sym_PIPE] = ACTIONS(1),
    [anon_sym_map] = ACTIONS(1),
    [anon_sym_chan] = ACTIONS(1),
    [anon_sym_LT_DASH] = ACTIONS(1),
    [anon_sym_COLON_EQ] = ACTIONS(1),
    [anon_sym_PLUS_PLUS] = ACTIONS(1),
    [anon_sym_DASH_DASH] = ACTIONS(1),
    [anon_sym_STAR_EQ] = ACTIONS(1),
    [anon_sym_SLASH_EQ] = ACTIONS(1),
    [anon_sym_PERCENT_EQ] = ACTIONS(1),
    [anon_sym_LT_LT_EQ] = ACTIONS(1),
    [anon_sym_GT_GT_EQ] = ACTIONS(1),
    [anon_sym_AMP_EQ] = ACTIONS(1),
    [anon_sym_AMP_CARET_EQ] = ACTIONS(1),
    [anon_sym_PLUS_EQ] = ACTIONS(1),
    [anon_sym_DASH_EQ] = ACTIONS(1),
    [anon_sym_PIPE_EQ] = ACTIONS(1),
    [anon_sym_CARET_EQ] = ACTIONS(1),
    [anon_sym_COLON] = ACTIONS(1),
    [anon_sym_fallthrough] = ACTIONS(1),
    [anon_sym_break] = ACTIONS(1),
    [anon_sym_continue] = ACTIONS(1),
    [anon_sym_goto] = ACTIONS(1),
    [anon_sym_return] = ACTIONS(1),
    [anon_sym_go] = ACTIONS(1),
    [anon_sym_defer] = ACTIONS(1),
    [anon_sym_if] = ACTIONS(1),
    [anon_sym_else] = ACTIONS(1),
    [anon_sym_for] = ACTIONS(1),
    [anon_sym_range] = ACTIONS(1),
    [anon_sym_switch] = ACTIONS(1),
    [anon_sym_case] = ACTIONS(1),
    [anon_sym_default] = ACTIONS(1),
    [anon_sym_select] = ACTIONS(1),
    [anon_sym_new] = ACTIONS(1),
    [anon_sym_make] = ACTIONS(1),
    [anon_sym_PLUS] = ACTIONS(1),
    [anon_sym_DASH] = ACTIONS(1),
    [anon_sym_BANG] = ACTIONS(1),
    [anon_sym_CARET] = ACTIONS(1),
    [anon_sym_AMP] = ACTIONS(1),
    [anon_sym_SLASH] = ACTIONS(1),
    [anon_sym_PERCENT] = ACTIONS(1),
    [anon_sym_LT_LT] = ACTIONS(1),
    [anon_sym_GT_GT] = ACTIONS(1),
    [anon_sym_AMP_CARET] = ACTIONS(1),
    [anon_sym_EQ_EQ] = ACTIONS(1),
    [anon_sym_BANG_EQ] = ACTIONS(1),
    [anon_sym_LT] = ACTIONS(1),
    [anon_sym_LT_EQ] = ACTIONS(1),
    [anon_sym_GT] = ACTIONS(1),
    [anon_sym_GT_EQ] = ACTIONS(1),
    [anon_sym_AMP_AMP] = ACTIONS(1),
    [anon_sym_PIPE_PIPE] = ACTIONS(1),
    [sym_raw_string_literal] = ACTIONS(1),
    [anon_sym_DQUOTE] = ACTIONS(1),
    [anon_sym_DQUOTE2] = ACTIONS(1),
    [sym_escape_sequence] = ACTIONS(1),
    [sym_int_literal] = ACTIONS(1),
    [sym_float_literal] = ACTIONS(1),
    [sym_imaginary_literal] = ACTIONS(1),
    [sym_rune_literal] = ACTIONS(1),
    [sym_nil] = ACTIONS(1),
    [sym_true] = ACTIONS(1),
    [sym_false] = ACTIONS(1),
    [sym_iota] = ACTIONS(1),
    [sym_comment] = ACTIONS(3),
  },
  [1] = {
    [sym_source_file] = STATE(1384),
    [sym_package_clause] = STATE(1070),
    [sym_import_declaration] = STATE(1070),
    [sym__declaration] = STATE(978),
    [sym_const_declaration] = STATE(978),
    [sym_var_declaration] = STATE(978),
    [sym_function_declaration] = STATE(1070),
    [sym_method_declaration] = STATE(1070),
    [sym_type_declaration] = STATE(978),
    [sym_expression_list] = STATE(803),
    [sym_parenthesized_type] = STATE(1306),
    [sym__simple_type] = STATE(1306),
    [sym_generic_type] = STATE(1104),
    [sym_pointer_type] = STATE(858),
    [sym_array_type] = STATE(1104),
    [sym_implicit_length_array_type] = STATE(1272),
    [sym_slice_type] = STATE(1104),
    [sym_struct_type] = STATE(1104),
    [sym_negated_type] = STATE(836),
    [sym_interface_type] = STATE(858),
    [sym_map_type] = STATE(1104),
    [sym_channel_type] = STATE(858),
    [sym_function_type] = STATE(858),
    [sym_block] = STATE(978),
    [sym__statement] = STATE(1207),
    [sym_empty_statement] = STATE(978),
    [sym__simple_statement] = STATE(978),
    [sym_expression_statement] = STATE(1003),
    [sym_send_statement] = STATE(1003),
    [sym_inc_statement] = STATE(1003),
    [sym_dec_statement] = STATE(1003),
    [sym_assignment_statement] = STATE(1003),
    [sym_short_var_declaration] = STATE(1003),
    [sym_labeled_statement] = STATE(978),
    [sym_fallthrough_statement] = STATE(978),
    [sym_break_statement] = STATE(978),
    [sym_continue_statement] = STATE(978),
    [sym_goto_statement] = STATE(978),
    [sym_return_statement] = STATE(978),
    [sym_go_statement] = STATE(978),
    [sym_defer_statement] = STATE(978),
    [sym_if_statement] = STATE(978),
    [sym_for_statement] = STATE(978),
    [sym_expression_switch_statement] = STATE(978),
    [sym_type_switch_statement] = STATE(978),
    [sym_select_statement] = STATE(978),
    [sym__expression] = STATE(239),
    [sym_parenthesized_expression] = STATE(266),
    [sym_call_expression] = STATE(266),
    [sym_selector_expression] = STATE(266),
    [sym_index_expression] = STATE(266),
    [sym_slice_expression] = STATE(266),
    [sym_type_assertion_expression] = STATE(266),
    [sym_type_conversion_expression] = STATE(266),
    [sym_type_instantiation_expression] = STATE(266),
    [sym_composite_literal] = STATE(266),
    [sym_func_literal] = STATE(266),
    [sym_unary_expression] = STATE(266),
    [sym_binary_expression] = STATE(266),
    [sym_qualified_type] = STATE(1032),
    [sym_interpreted_string_literal] = STATE(266),
    [aux_sym_source_file_repeat1] = STATE(2),
    [ts_builtin_sym_end] = ACTIONS(5),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9),
    [anon_sym_package] = ACTIONS(11),
    [anon_sym_import] = ACTIONS(13),
    [anon_sym_LPAREN] = ACTIONS(15),
    [anon_sym_const] = ACTIONS(17),
    [anon_sym_var] = ACTIONS(19),
    [anon_sym_func] = ACTIONS(21),
    [anon_sym_LBRACK] = ACTIONS(23),
    [anon_sym_type] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(27),
    [anon_sym_struct] = ACTIONS(29),
    [anon_sym_TILDE] = ACTIONS(31),
    [anon_sym_LBRACE] = ACTIONS(33),
    [anon_sym_interface] = ACTIONS(35),
    [anon_sym_map] = ACTIONS(37),
    [anon_sym_chan] = ACTIONS(39),
    [anon_sym_LT_DASH] = ACTIONS(41),
    [anon_sym_fallthrough] = ACTIONS(43),
    [anon_sym_break] = ACTIONS(45),
    [anon_sym_continue] = ACTIONS(47),
    [anon_sym_goto] = ACTIONS(49),
    [anon_sym_return] = ACTIONS(51),
    [anon_sym_go] = ACTIONS(53),
    [anon_sym_defer] = ACTIONS(55),
    [anon_sym_if] = ACTIONS(57),
    [anon_sym_for] = ACTIONS(59),
    [anon_sym_switch] = ACTIONS(61),
    [anon_sym_select] = ACTIONS(63),
    [anon_sym_new] = ACTIONS(65),
    [anon_sym_make] = ACTIONS(65),
    [anon_sym_PLUS] = ACTIONS(67),
    [anon_sym_DASH] = ACTIONS(67),
    [anon_sym_BANG] = ACTIONS(67),
    [anon_sym_CARET] = ACTIONS(67),
    [anon_sym_AMP] = ACTIONS(67),
    [sym_raw_string_literal] = ACTIONS(69),
    [anon_sym_DQUOTE] = ACTIONS(71),
    [sym_int_literal] = ACTIONS(73),
    [sym_float_literal] = ACTIONS(73),
    [sym_imaginary_literal] = ACTIONS(69),
    [sym_rune_literal] = ACTIONS(69),
    [sym_nil] = ACTIONS(73),
    [sym_true] = ACTIONS(73),
    [sym_false] = ACTIONS(73),
    [sym_iota] = ACTIONS(73),
    [sym_comment] = ACTIONS(3),
  },
  [2] = {
    [sym_package_clause] = STATE(1094),
    [sym_import_declaration] = STATE(1094),
    [sym__declaration] = STATE(978),
    [sym_const_declaration] = STATE(978),
    [sym_var_declaration] = STATE(978),
    [sym_function_declaration] = STATE(1094),
    [sym_method_declaration] = STATE(1094),
    [sym_type_declaration] = STATE(978),
    [sym_expression_list] = STATE(803),
    [sym_parenthesized_type] = STATE(1306),
    [sym__simple_type] = STATE(1306),
    [sym_generic_type] = STATE(1104),
    [sym_pointer_type] = STATE(858),
    [sym_array_type] = STATE(1104),
    [sym_implicit_length_array_type] = STATE(1272),
    [sym_slice_type] = STATE(1104),
    [sym_struct_type] = STATE(1104),
    [sym_negated_type] = STATE(836),
    [sym_interface_type] = STATE(858),
    [sym_map_type] = STATE(1104),
    [sym_channel_type] = STATE(858),
    [sym_function_type] = STATE(858),
    [sym_block] = STATE(978),
    [sym__statement] = STATE(1207),
    [sym_empty_statement] = STATE(978),
    [sym__simple_statement] = STATE(978),
    [sym_expression_statement] = STATE(1003),
    [sym_send_statement] = STATE(1003),
    [sym_inc_statement] = STATE(1003),
    [sym_dec_statement] = STATE(1003),
    [sym_assignment_statement] = STATE(1003),
    [sym_short_var_declaration] = STATE(1003),
    [sym_labeled_statement] = STATE(978),
    [sym_fallthrough_statement] = STATE(978),
    [sym_break_statement] = STATE(978),
    [sym_continue_statement] = STATE(978),
    [sym_goto_statement] = STATE(978),
    [sym_return_statement] = STATE(978),
    [sym_go_statement] = STATE(978),
    [sym_defer_statement] = STATE(978),
    [sym_if_statement] = STATE(978),
    [sym_for_statement] = STATE(978),
    [sym_expression_switch_statement] = STATE(978),
    [sym_type_switch_statement] = STATE(978),
    [sym_select_statement] = STATE(978),
    [sym__expression] = STATE(239),
    [sym_parenthesized_expression] = STATE(266),
    [sym_call_expression] = STATE(266),
    [sym_selector_expression] = STATE(266),
    [sym_index_expression] = STATE(266),
    [sym_slice_expression] = STATE(266),
    [sym_type_assertion_expression] = STATE(266),
    [sym_type_conversion_expression] = STATE(266),
    [sym_type_instantiation_expression] = STATE(266),
    [sym_composite_literal] = STATE(266),
    [sym_func_literal] = STATE(266),
    [sym_unary_expression] = STATE(266),
    [sym_binary_expression] = STATE(266),
    [sym_qualified_type] = STATE(1032),
    [sym_interpreted_string_literal] = STATE(266),
    [aux_sym_source_file_repeat1] = STATE(3),
    [ts_builtin_sym_end] = ACTIONS(75),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9),
    [anon_sym_package] = ACTIONS(11),
    [anon_sym_import] = ACTIONS(13),
    [anon_sym_LPAREN] = ACTIONS(15),
    [anon_sym_const] = ACTIONS(17),
    [anon_sym_var] = ACTIONS(19),
    [anon_sym_func] = ACTIONS(21),
    [anon_sym_LBRACK] = ACTIONS(23),
    [anon_sym_type] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(27),
    [anon_sym_struct] = ACTIONS(29),
    [anon_sym_TILDE] = ACTIONS(31),
    [anon_sym_LBRACE] = ACTIONS(33),
    [anon_sym_interface] = ACTIONS(35),
    [anon_sym_map] = ACTIONS(37),
    [anon_sym_chan] = ACTIONS(39),
    [anon_sym_LT_DASH] = ACTIONS(41),
    [anon_sym_fallthrough] = ACTIONS(43),
    [anon_sym_break] = ACTIONS(45),
    [anon_sym_continue] = ACTIONS(47),
    [anon_sym_goto] = ACTIONS(49),
    [anon_sym_return] = ACTIONS(51),
    [anon_sym_go] = ACTIONS(53),
    [anon_sym_defer] = ACTIONS(55),
    [anon_sym_if] = ACTIONS(57),
    [anon_sym_for] = ACTIONS(59),
    [anon_sym_switch] = ACTIONS(61),
    [anon_sym_select] = ACTIONS(63),
    [anon_sym_new] = ACTIONS(65),
    [anon_sym_make] = ACTIONS(65),
    [anon_sym_PLUS] = ACTIONS(67),
    [anon_sym_DASH] = ACTIONS(67),
    [anon_sym_BANG] = ACTIONS(67),
    [anon_sym_CARET] = ACTIONS(67),
    [anon_sym_AMP] = ACTIONS(67),
    [sym_raw_string_literal] = ACTIONS(69),
    [anon_sym_DQUOTE] = ACTIONS(71),
    [sym_int_literal] = ACTIONS(73),
    [sym_float_literal] = ACTIONS(73),
    [sym_imaginary_literal] = ACTIONS(69),
    [sym_rune_literal] = ACTIONS(69),
    [sym_nil] = ACTIONS(73),
    [sym_true] = ACTIONS(73),
    [sym_false] = ACTIONS(73),
    [sym_iota] = ACTIONS(73),
    [sym_comment] = ACTIONS(3),
  },
  [3] = {
    [sym_package_clause] = STATE(1207),
    [sym_import_declaration] = STATE(1207),
    [sym__declaration] = STATE(978),
    [sym_const_declaration] = STATE(978),
    [sym_var_declaration] = STATE(978),
    [sym_function_declaration] = STATE(1207),
    [sym_method_declaration] = STATE(1207),
    [sym_type_declaration] = STATE(978),
    [sym_expression_list] = STATE(803),
    [sym_parenthesized_type] = STATE(1306),
    [sym__simple_type] = STATE(1306),
    [sym_generic_type] = STATE(1104),
    [sym_pointer_type] = STATE(858),
    [sym_array_type] = STATE(1104),
    [sym_implicit_length_array_type] = STATE(1272),
    [sym_slice_type] = STATE(1104),
    [sym_struct_type] = STATE(1104),
    [sym_negated_type] = STATE(836),
    [sym_interface_type] = STATE(858),
    [sym_map_type] = STATE(1104),
    [sym_channel_type] = STATE(858),
    [sym_function_type] = STATE(858),
    [sym_block] = STATE(978),
    [sym__statement] = STATE(1207),
    [sym_empty_statement] = STATE(978),
    [sym__simple_statement] = STATE(978),
    [sym_expression_statement] = STATE(1003),
    [sym_send_statement] = STATE(1003),
    [sym_inc_statement] = STATE(1003),
    [sym_dec_statement] = STATE(1003),
    [sym_assignment_statement] = STATE(1003),
    [sym_short_var_declaration] = STATE(1003),
    [sym_labeled_statement] = STATE(978),
    [sym_fallthrough_statement] = STATE(978),
    [sym_break_statement] = STATE(978),
    [sym_continue_statement] = STATE(978),
    [sym_goto_statement] = STATE(978),
    [sym_return_statement] = STATE(978),
    [sym_go_statement] = STATE(978),
    [sym_defer_statement] = STATE(978),
    [sym_if_statement] = STATE(978),
    [sym_for_statement] = STATE(978),
    [sym_expression_switch_statement] = STATE(978),
    [sym_type_switch_statement] = STATE(978),
    [sym_select_statement] = STATE(978),
    [sym__expression] = STATE(239),
    [sym_parenthesized_expression] = STATE(266),
    [sym_call_expression] = STATE(266),
    [sym_selector_expression] = STATE(266),
    [sym_index_expression] = STATE(266),
    [sym_slice_expression] = STATE(266),
    [sym_type_assertion_expression] = STATE(266),
    [sym_type_conversion_expression] = STATE(266),
    [sym_type_instantiation_expression] = STATE(266),
    [sym_composite_literal] = STATE(266),
    [sym_func_literal] = STATE(266),
    [sym_unary_expression] = STATE(266),
    [sym_binary_expression] = STATE(266),
    [sym_qualified_type] = STATE(1032),
    [sym_interpreted_string_literal] = STATE(266),
    [aux_sym_source_file_repeat1] = STATE(3),
    [ts_builtin_sym_end] = ACTIONS(77),
    [sym_identifier] = ACTIONS(79),
    [anon_sym_SEMI] = ACTIONS(82),
    [anon_sym_package] = ACTIONS(85),
    [anon_sym_import] = ACTIONS(88),
    [anon_sym_LPAREN] = ACTIONS(91),
    [anon_sym_const] = ACTIONS(94),
    [anon_sym_var] = ACTIONS(97),
    [anon_sym_func] = ACTIONS(100),
    [anon_sym_LBRACK] = ACTIONS(103),
    [anon_sym_type] = ACTIONS(106),
    [anon_sym_STAR] = ACTIONS(109),
    [anon_sym_struct] = ACTIONS(112),
    [anon_sym_TILDE] = ACTIONS(115),
    [anon_sym_LBRACE] = ACTIONS(118),
    [anon_sym_interface] = ACTIONS(121),
    [anon_sym_map] = ACTIONS(124),
    [anon_sym_chan] = ACTIONS(127),
    [anon_sym_LT_DASH] = ACTIONS(130),
    [anon_sym_fallthrough] = ACTIONS(133),
    [anon_sym_break] = ACTIONS(136),
    [anon_sym_continue] = ACTIONS(139),
    [anon_sym_goto] = ACTIONS(142),
    [anon_sym_return] = ACTIONS(145),
    [anon_sym_go] = ACTIONS(148),
    [anon_sym_defer] = ACTIONS(151),
    [anon_sym_if] = ACTIONS(154),
    [anon_sym_for] = ACTIONS(157),
    [anon_sym_switch] = ACTIONS(160),
    [anon_sym_select] = ACTIONS(163),
    [anon_sym_new] = ACTIONS(166),
    [anon_sym_make] = ACTIONS(166),
    [anon_sym_PLUS] = ACTIONS(169),
    [anon_sym_DASH] = ACTIONS(169),
    [anon_sym_BANG] = ACTIONS(169),
    [anon_sym_CARET] = ACTIONS(169),
    [anon_sym_AMP] = ACTIONS(169),
    [sym_raw_string_literal] = ACTIONS(172),
    [anon_sym_DQUOTE] = ACTIONS(175),
    [sym_int_literal] = ACTIONS(178),
    [sym_float_literal] = ACTIONS(178),
    [sym_imaginary_literal] = ACTIONS(172),
    [sym_rune_literal] = ACTIONS(172),
    [sym_nil] = ACTIONS(178),
    [sym_true] = ACTIONS(178),
    [sym_false] = ACTIONS(178),
    [sym_iota] = ACTIONS(178),
    [sym_comment] = ACTIONS(3),
  },
  [4] = {
    [sym__declaration] = STATE(978),
    [sym_const_declaration] = STATE(978),
    [sym_var_declaration] = STATE(978),
    [sym_type_declaration] = STATE(978),
    [sym_expression_list] = STATE(803),
    [sym_parenthesized_type] = STATE(1306),
    [sym__simple_type] = STATE(1306),
    [sym_generic_type] = STATE(1104),
    [sym_pointer_type] = STATE(858),
    [sym_array_type] = STATE(1104),
    [sym_implicit_length_array_type] = STATE(1272),
    [sym_slice_type] = STATE(1104),
    [sym_struct_type] = STATE(1104),
    [sym_negated_type] = STATE(836),
    [sym_interface_type] = STATE(858),
    [sym_map_type] = STATE(1104),
    [sym_channel_type] = STATE(858),
    [sym_function_type] = STATE(858),
    [sym_block] = STATE(978),
    [sym__statement_list] = STATE(1157),
    [sym__statement] = STATE(898),
    [sym_empty_statement] = STATE(978),
    [sym__simple_statement] = STATE(978),
    [sym_expression_statement] = STATE(1003),
    [sym_send_statement] = STATE(1003),
    [sym_inc_statement] = STATE(1003),
    [sym_dec_statement] = STATE(1003),
    [sym_assignment_statement] = STATE(1003),
    [sym_short_var_declaration] = STATE(1003),
    [sym_labeled_statement] = STATE(978),
    [sym_empty_labeled_statement] = STATE(1157),
    [sym_fallthrough_statement] = STATE(978),
    [sym_break_statement] = STATE(978),
    [sym_continue_statement] = STATE(978),
    [sym_goto_statement] = STATE(978),
    [sym_return_statement] = STATE(978),
    [sym_go_statement] = STATE(978),
    [sym_defer_statement] = STATE(978),
    [sym_if_statement] = STATE(978),
    [sym_for_statement] = STATE(978),
    [sym_expression_switch_statement] = STATE(978),
    [sym_type_switch_statement] = STATE(978),
    [sym_select_statement] = STATE(978),
    [sym__expression] = STATE(239),
    [sym_parenthesized_expression] = STATE(266),
    [sym_call_expression] = STATE(266),
    [sym_selector_expression] = STATE(266),
    [sym_index_expression] = STATE(266),
    [sym_slice_expression] = STATE(266),
    [sym_type_assertion_expression] = STATE(266),
    [sym_type_conversion_expression] = STATE(266),
    [sym_type_instantiation_expression] = STATE(266),
    [sym_composite_literal] = STATE(266),
    [sym_func_literal] = STATE(266),
    [sym_unary_expression] = STATE(266),
    [sym_binary_expression] = STATE(266),
    [sym_qualified_type] = STATE(1032),
    [sym_interpreted_string_literal] = STATE(266),
    [sym_identifier] = ACTIONS(181),
    [anon_sym_SEMI] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(15),
    [anon_sym_const] = ACTIONS(17),
    [anon_sym_var] = ACTIONS(19),
    [anon_sym_func] = ACTIONS(183),
    [anon_sym_LBRACK] = ACTIONS(23),
    [anon_sym_type] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(27),
    [anon_sym_struct] = ACTIONS(29),
    [anon_sym_TILDE] = ACTIONS(31),
    [anon_sym_LBRACE] = ACTIONS(33),
    [anon_sym_RBRACE] = ACTIONS(185),
    [anon_sym_interface] = ACTIONS(35),
    [anon_sym_map] = ACTIONS(37),
    [anon_sym_chan] = ACTIONS(39),
    [anon_sym_LT_DASH] = ACTIONS(41),
    [anon_sym_fallthrough] = ACTIONS(43),
    [anon_sym_break] = ACTIONS(45),
    [anon_sym_continue] = ACTIONS(47),
    [anon_sym_goto] = ACTIONS(49),
    [anon_sym_return] = ACTIONS(51),
    [anon_sym_go] = ACTIONS(53),
    [anon_sym_defer] = ACTIONS(55),
    [anon_sym_if] = ACTIONS(57),
    [anon_sym_for] = ACTIONS(59),
    [anon_sym_switch] = ACTIONS(61),
    [anon_sym_case] = ACTIONS(187),
    [anon_sym_default] = ACTIONS(187),
    [anon_sym_select] = ACTIONS(63),
    [anon_sym_new] = ACTIONS(65),
    [anon_sym_make] = ACTIONS(65),
    [anon_sym_PLUS] = ACTIONS(67),
    [anon_sym_DASH] = ACTIONS(67),
    [anon_sym_BANG] = ACTIONS(67),
    [anon_sym_CARET] = ACTIONS(67),
    [anon_sym_AMP] = ACTIONS(67),
    [sym_raw_string_literal] = ACTIONS(69),
    [anon_sym_DQUOTE] = ACTIONS(71),
    [sym_int_literal] = ACTIONS(73),
    [sym_float_literal] = ACTIONS(73),
    [sym_imaginary_literal] = ACTIONS(69),
    [sym_rune_literal] = ACTIONS(69),
    [sym_nil] = ACTIONS(73),
    [sym_true] = ACTIONS(73),
    [sym_false] = ACTIONS(73),
    [sym_iota] = ACTIONS(73),
    [sym_comment] = ACTIONS(3),
  },
  [5] = {
    [sym__declaration] = STATE(978),
    [sym_const_declaration] = STATE(978),
    [sym_var_declaration] = STATE(978),
    [sym_type_declaration] = STATE(978),
    [sym_expression_list] = STATE(803),
    [sym_parenthesized_type] = STATE(1306),
    [sym__simple_type] = STATE(1306),
    [sym_generic_type] = STATE(1104),
    [sym_pointer_type] = STATE(858),
    [sym_array_type] = STATE(1104),
    [sym_implicit_length_array_type] = STATE(1272),
    [sym_slice_type] = STATE(1104),
    [sym_struct_type] = STATE(1104),
    [sym_negated_type] = STATE(836),
    [sym_interface_type] = STATE(858),
    [sym_map_type] = STATE(1104),
    [sym_channel_type] = STATE(858),
    [sym_function_type] = STATE(858),
    [sym_block] = STATE(978),
    [sym__statement_list] = STATE(1148),
    [sym__statement] = STATE(898),
    [sym_empty_statement] = STATE(978),
    [sym__simple_statement] = STATE(978),
    [sym_expression_statement] = STATE(1003),
    [sym_send_statement] = STATE(1003),
    [sym_inc_statement] = STATE(1003),
    [sym_dec_statement] = STATE(1003),
    [sym_assignment_statement] = STATE(1003),
    [sym_short_var_declaration] = STATE(1003),
    [sym_labeled_statement] = STATE(978),
    [sym_empty_labeled_statement] = STATE(1148),
    [sym_fallthrough_statement] = STATE(978),
    [sym_break_statement] = STATE(978),
    [sym_continue_statement] = STATE(978),
    [sym_goto_statement] = STATE(978),
    [sym_return_statement] = STATE(978),
    [sym_go_statement] = STATE(978),
    [sym_defer_statement] = STATE(978),
    [sym_if_statement] = STATE(978),
    [sym_for_statement] = STATE(978),
    [sym_expression_switch_statement] = STATE(978),
    [sym_type_switch_statement] = STATE(978),
    [sym_select_statement] = STATE(978),
    [sym__expression] = STATE(239),
    [sym_parenthesized_expression] = STATE(266),
    [sym_call_expression] = STATE(266),
    [sym_selector_expression] = STATE(266),
    [sym_index_expression] = STATE(266),
    [sym_slice_expression] = STATE(266),
    [sym_type_assertion_expression] = STATE(266),
    [sym_type_conversion_expression] = STATE(266),
    [sym_type_instantiation_expression] = STATE(266),
    [sym_composite_literal] = STATE(266),
    [sym_func_literal] = STATE(266),
    [sym_unary_expression] = STATE(266),
    [sym_binary_expression] = STATE(266),
    [sym_qualified_type] = STATE(1032),
    [sym_interpreted_string_literal] = STATE(266),
    [sym_identifier] = ACTIONS(181),
    [anon_sym_SEMI] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(15),
    [anon_sym_const] = ACTIONS(17),
    [anon_sym_var] = ACTIONS(19),
    [anon_sym_func] = ACTIONS(183),
    [anon_sym_LBRACK] = ACTIONS(23),
    [anon_sym_type] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(27),
    [anon_sym_struct] = ACTIONS(29),
    [anon_sym_TILDE] = ACTIONS(31),
    [anon_sym_LBRACE] = ACTIONS(33),
    [anon_sym_RBRACE] = ACTIONS(189),
    [anon_sym_interface] = ACTIONS(35),
    [anon_sym_map] = ACTIONS(37),
    [anon_sym_chan] = ACTIONS(39),
    [anon_sym_LT_DASH] = ACTIONS(41),
    [anon_sym_fallthrough] = ACTIONS(43),
    [anon_sym_break] = ACTIONS(45),
    [anon_sym_continue] = ACTIONS(47),
    [anon_sym_goto] = ACTIONS(49),
    [anon_sym_return] = ACTIONS(51),
    [anon_sym_go] = ACTIONS(53),
    [anon_sym_defer] = ACTIONS(55),
    [anon_sym_if] = ACTIONS(57),
    [anon_sym_for] = ACTIONS(59),
    [anon_sym_switch] = ACTIONS(61),
    [anon_sym_case] = ACTIONS(191),
    [anon_sym_default] = ACTIONS(191),
    [anon_sym_select] = ACTIONS(63),
    [anon_sym_new] = ACTIONS(65),
    [anon_sym_make] = ACTIONS(65),
    [anon_sym_PLUS] = ACTIONS(67),
    [anon_sym_DASH] = ACTIONS(67),
    [anon_sym_BANG] = ACTIONS(67),
    [anon_sym_CARET] = ACTIONS(67),
    [anon_sym_AMP] = ACTIONS(67),
    [sym_raw_string_literal] = ACTIONS(69),
    [anon_sym_DQUOTE] = ACTIONS(71),
    [sym_int_literal] = ACTIONS(73),
    [sym_float_literal] = ACTIONS(73),
    [sym_imaginary_literal] = ACTIONS(69),
    [sym_rune_literal] = ACTIONS(69),
    [sym_nil] = ACTIONS(73),
    [sym_true] = ACTIONS(73),
    [sym_false] = ACTIONS(73),
    [sym_iota] = ACTIONS(73),
    [sym_comment] = ACTIONS(3),
  },
  [6] = {
    [sym__declaration] = STATE(978),
    [sym_const_declaration] = STATE(978),
    [sym_var_declaration] = STATE(978),
    [sym_type_declaration] = STATE(978),
    [sym_expression_list] = STATE(803),
    [sym_parenthesized_type] = STATE(1306),
    [sym__simple_type] = STATE(1306),
    [sym_generic_type] = STATE(1104),
    [sym_pointer_type] = STATE(858),
    [sym_array_type] = STATE(1104),
    [sym_implicit_length_array_type] = STATE(1272),
    [sym_slice_type] = STATE(1104),
    [sym_struct_type] = STATE(1104),
    [sym_negated_type] = STATE(836),
    [sym_interface_type] = STATE(858),
    [sym_map_type] = STATE(1104),
    [sym_channel_type] = STATE(858),
    [sym_function_type] = STATE(858),
    [sym_block] = STATE(978),
    [sym__statement_list] = STATE(1147),
    [sym__statement] = STATE(898),
    [sym_empty_statement] = STATE(978),
    [sym__simple_statement] = STATE(978),
    [sym_expression_statement] = STATE(1003),
    [sym_send_statement] = STATE(1003),
    [sym_inc_statement] = STATE(1003),
    [sym_dec_statement] = STATE(1003),
    [sym_assignment_statement] = STATE(1003),
    [sym_short_var_declaration] = STATE(1003),
    [sym_labeled_statement] = STATE(978),
    [sym_empty_labeled_statement] = STATE(1147),
    [sym_fallthrough_statement] = STATE(978),
    [sym_break_statement] = STATE(978),
    [sym_continue_statement] = STATE(978),
    [sym_goto_statement] = STATE(978),
    [sym_return_statement] = STATE(978),
    [sym_go_statement] = STATE(978),
    [sym_defer_statement] = STATE(978),
    [sym_if_statement] = STATE(978),
    [sym_for_statement] = STATE(978),
    [sym_expression_switch_statement] = STATE(978),
    [sym_type_switch_statement] = STATE(978),
    [sym_select_statement] = STATE(978),
    [sym__expression] = STATE(239),
    [sym_parenthesized_expression] = STATE(266),
    [sym_call_expression] = STATE(266),
    [sym_selector_expression] = STATE(266),
    [sym_index_expression] = STATE(266),
    [sym_slice_expression] = STATE(266),
    [sym_type_assertion_expression] = STATE(266),
    [sym_type_conversion_expression] = STATE(266),
    [sym_type_instantiation_expression] = STATE(266),
    [sym_composite_literal] = STATE(266),
    [sym_func_literal] = STATE(266),
    [sym_unary_expression] = STATE(266),
    [sym_binary_expression] = STATE(266),
    [sym_qualified_type] = STATE(1032),
    [sym_interpreted_string_literal] = STATE(266),
    [sym_identifier] = ACTIONS(181),
    [anon_sym_SEMI] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(15),
    [anon_sym_const] = ACTIONS(17),
    [anon_sym_var] = ACTIONS(19),
    [anon_sym_func] = ACTIONS(183),
    [anon_sym_LBRACK] = ACTIONS(23),
    [anon_sym_type] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(27),
    [anon_sym_struct] = ACTIONS(29),
    [anon_sym_TILDE] = ACTIONS(31),
    [anon_sym_LBRACE] = ACTIONS(33),
    [anon_sym_RBRACE] = ACTIONS(193),
    [anon_sym_interface] = ACTIONS(35),
    [anon_sym_map] = ACTIONS(37),
    [anon_sym_chan] = ACTIONS(39),
    [anon_sym_LT_DASH] = ACTIONS(41),
    [anon_sym_fallthrough] = ACTIONS(43),
    [anon_sym_break] = ACTIONS(45),
    [anon_sym_continue] = ACTIONS(47),
    [anon_sym_goto] = ACTIONS(49),
    [anon_sym_return] = ACTIONS(51),
    [anon_sym_go] = ACTIONS(53),
    [anon_sym_defer] = ACTIONS(55),
    [anon_sym_if] = ACTIONS(57),
    [anon_sym_for] = ACTIONS(59),
    [anon_sym_switch] = ACTIONS(61),
    [anon_sym_case] = ACTIONS(195),
    [anon_sym_default] = ACTIONS(195),
    [anon_sym_select] = ACTIONS(63),
    [anon_sym_new] = ACTIONS(65),
    [anon_sym_make] = ACTIONS(65),
    [anon_sym_PLUS] = ACTIONS(67),
    [anon_sym_DASH] = ACTIONS(67),
    [anon_sym_BANG] = ACTIONS(67),
    [anon_sym_CARET] = ACTIONS(67),
    [anon_sym_AMP] = ACTIONS(67),
    [sym_raw_string_literal] = ACTIONS(69),
    [anon_sym_DQUOTE] = ACTIONS(71),
    [sym_int_literal] = ACTIONS(73),
    [sym_float_literal] = ACTIONS(73),
    [sym_imaginary_literal] = ACTIONS(69),
    [sym_rune_literal] = ACTIONS(69),
    [sym_nil] = ACTIONS(73),
    [sym_true] = ACTIONS(73),
    [sym_false] = ACTIONS(73),
    [sym_iota] = ACTIONS(73),
    [sym_comment] = ACTIONS(3),
  },
  [7] = {
    [sym__declaration] = STATE(978),
    [sym_const_declaration] = STATE(978),
    [sym_var_declaration] = STATE(978),
    [sym_type_declaration] = STATE(978),
    [sym_expression_list] = STATE(803),
    [sym_parenthesized_type] = STATE(1306),
    [sym__simple_type] = STATE(1306),
    [sym_generic_type] = STATE(1104),
    [sym_pointer_type] = STATE(858),
    [sym_array_type] = STATE(1104),
    [sym_implicit_length_array_type] = STATE(1272),
    [sym_slice_type] = STATE(1104),
    [sym_struct_type] = STATE(1104),
    [sym_negated_type] = STATE(836),
    [sym_interface_type] = STATE(858),
    [sym_map_type] = STATE(1104),
    [sym_channel_type] = STATE(858),
    [sym_function_type] = STATE(858),
    [sym_block] = STATE(978),
    [sym__statement_list] = STATE(1194),
    [sym__statement] = STATE(898),
    [sym_empty_statement] = STATE(978),
    [sym__simple_statement] = STATE(978),
    [sym_expression_statement] = STATE(1003),
    [sym_send_statement] = STATE(1003),
    [sym_inc_statement] = STATE(1003),
    [sym_dec_statement] = STATE(1003),
    [sym_assignment_statement] = STATE(1003),
    [sym_short_var_declaration] = STATE(1003),
    [sym_labeled_statement] = STATE(978),
    [sym_empty_labeled_statement] = STATE(1194),
    [sym_fallthrough_statement] = STATE(978),
    [sym_break_statement] = STATE(978),
    [sym_continue_statement] = STATE(978),
    [sym_goto_statement] = STATE(978),
    [sym_return_statement] = STATE(978),
    [sym_go_statement] = STATE(978),
    [sym_defer_statement] = STATE(978),
    [sym_if_statement] = STATE(978),
    [sym_for_statement] = STATE(978),
    [sym_expression_switch_statement] = STATE(978),
    [sym_type_switch_statement] = STATE(978),
    [sym_select_statement] = STATE(978),
    [sym__expression] = STATE(239),
    [sym_parenthesized_expression] = STATE(266),
    [sym_call_expression] = STATE(266),
    [sym_selector_expression] = STATE(266),
    [sym_index_expression] = STATE(266),
    [sym_slice_expression] = STATE(266),
    [sym_type_assertion_expression] = STATE(266),
    [sym_type_conversion_expression] = STATE(266),
    [sym_type_instantiation_expression] = STATE(266),
    [sym_composite_literal] = STATE(266),
    [sym_func_literal] = STATE(266),
    [sym_unary_expression] = STATE(266),
    [sym_binary_expression] = STATE(266),
    [sym_qualified_type] = STATE(1032),
    [sym_interpreted_string_literal] = STATE(266),
    [sym_identifier] = ACTIONS(181),
    [anon_sym_SEMI] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(15),
    [anon_sym_const] = ACTIONS(17),
    [anon_sym_var] = ACTIONS(19),
    [anon_sym_func] = ACTIONS(183),
    [anon_sym_LBRACK] = ACTIONS(23),
    [anon_sym_type] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(27),
    [anon_sym_struct] = ACTIONS(29),
    [anon_sym_TILDE] = ACTIONS(31),
    [anon_sym_LBRACE] = ACTIONS(33),
    [anon_sym_RBRACE] = ACTIONS(197),
    [anon_sym_interface] = ACTIONS(35),
    [anon_sym_map] = ACTIONS(37),
    [anon_sym_chan] = ACTIONS(39),
    [anon_sym_LT_DASH] = ACTIONS(41),
    [anon_sym_fallthrough] = ACTIONS(43),
    [anon_sym_break] = ACTIONS(45),
    [anon_sym_continue] = ACTIONS(47),
    [anon_sym_goto] = ACTIONS(49),
    [anon_sym_return] = ACTIONS(51),
    [anon_sym_go] = ACTIONS(53),
    [anon_sym_defer] = ACTIONS(55),
    [anon_sym_if] = ACTIONS(57),
    [anon_sym_for] = ACTIONS(59),
    [anon_sym_switch] = ACTIONS(61),
    [anon_sym_case] = ACTIONS(199),
    [anon_sym_default] = ACTIONS(199),
    [anon_sym_select] = ACTIONS(63),
    [anon_sym_new] = ACTIONS(65),
    [anon_sym_make] = ACTIONS(65),
    [anon_sym_PLUS] = ACTIONS(67),
    [anon_sym_DASH] = ACTIONS(67),
    [anon_sym_BANG] = ACTIONS(67),
    [anon_sym_CARET] = ACTIONS(67),
    [anon_sym_AMP] = ACTIONS(67),
    [sym_raw_string_literal] = ACTIONS(69),
    [anon_sym_DQUOTE] = ACTIONS(71),
    [sym_int_literal] = ACTIONS(73),
    [sym_float_literal] = ACTIONS(73),
    [sym_imaginary_literal] = ACTIONS(69),
    [sym_rune_literal] = ACTIONS(69),
    [sym_nil] = ACTIONS(73),
    [sym_true] = ACTIONS(73),
    [sym_false] = ACTIONS(73),
    [sym_iota] = ACTIONS(73),
    [sym_comment] = ACTIONS(3),
  },
  [8] = {
    [sym__declaration] = STATE(978),
    [sym_const_declaration] = STATE(978),
    [sym_var_declaration] = STATE(978),
    [sym_type_declaration] = STATE(978),
    [sym_expression_list] = STATE(803),
    [sym_parenthesized_type] = STATE(1306),
    [sym__simple_type] = STATE(1306),
    [sym_generic_type] = STATE(1104),
    [sym_pointer_type] = STATE(858),
    [sym_array_type] = STATE(1104),
    [sym_implicit_length_array_type] = STATE(1272),
    [sym_slice_type] = STATE(1104),
    [sym_struct_type] = STATE(1104),
    [sym_negated_type] = STATE(836),
    [sym_interface_type] = STATE(858),
    [sym_map_type] = STATE(1104),
    [sym_channel_type] = STATE(858),
    [sym_function_type] = STATE(858),
    [sym_block] = STATE(978),
    [sym__statement_list] = STATE(1190),
    [sym__statement] = STATE(898),
    [sym_empty_statement] = STATE(978),
    [sym__simple_statement] = STATE(978),
    [sym_expression_statement] = STATE(1003),
    [sym_send_statement] = STATE(1003),
    [sym_inc_statement] = STATE(1003),
    [sym_dec_statement] = STATE(1003),
    [sym_assignment_statement] = STATE(1003),
    [sym_short_var_declaration] = STATE(1003),
    [sym_labeled_statement] = STATE(978),
    [sym_empty_labeled_statement] = STATE(1190),
    [sym_fallthrough_statement] = STATE(978),
    [sym_break_statement] = STATE(978),
    [sym_continue_statement] = STATE(978),
    [sym_goto_statement] = STATE(978),
    [sym_return_statement] = STATE(978),
    [sym_go_statement] = STATE(978),
    [sym_defer_statement] = STATE(978),
    [sym_if_statement] = STATE(978),
    [sym_for_statement] = STATE(978),
    [sym_expression_switch_statement] = STATE(978),
    [sym_type_switch_statement] = STATE(978),
    [sym_select_statement] = STATE(978),
    [sym__expression] = STATE(239),
    [sym_parenthesized_expression] = STATE(266),
    [sym_call_expression] = STATE(266),
    [sym_selector_expression] = STATE(266),
    [sym_index_expression] = STATE(266),
    [sym_slice_expression] = STATE(266),
    [sym_type_assertion_expression] = STATE(266),
    [sym_type_conversion_expression] = STATE(266),
    [sym_type_instantiation_expression] = STATE(266),
    [sym_composite_literal] = STATE(266),
    [sym_func_literal] = STATE(266),
    [sym_unary_expression] = STATE(266),
    [sym_binary_expression] = STATE(266),
    [sym_qualified_type] = STATE(1032),
    [sym_interpreted_string_literal] = STATE(266),
    [sym_identifier] = ACTIONS(181),
    [anon_sym_SEMI] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(15),
    [anon_sym_const] = ACTIONS(17),
    [anon_sym_var] = ACTIONS(19),
    [anon_sym_func] = ACTIONS(183),
    [anon_sym_LBRACK] = ACTIONS(23),
    [anon_sym_type] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(27),
    [anon_sym_struct] = ACTIONS(29),
    [anon_sym_TILDE] = ACTIONS(31),
    [anon_sym_LBRACE] = ACTIONS(33),
    [anon_sym_RBRACE] = ACTIONS(201),
    [anon_sym_interface] = ACTIONS(35),
    [anon_sym_map] = ACTIONS(37),
    [anon_sym_chan] = ACTIONS(39),
    [anon_sym_LT_DASH] = ACTIONS(41),
    [anon_sym_fallthrough] = ACTIONS(43),
    [anon_sym_break] = ACTIONS(45),
    [anon_sym_continue] = ACTIONS(47),
    [anon_sym_goto] = ACTIONS(49),
    [anon_sym_return] = ACTIONS(51),
    [anon_sym_go] = ACTIONS(53),
    [anon_sym_defer] = ACTIONS(55),
    [anon_sym_if] = ACTIONS(57),
    [anon_sym_for] = ACTIONS(59),
    [anon_sym_switch] = ACTIONS(61),
    [anon_sym_case] = ACTIONS(203),
    [anon_sym_default] = ACTIONS(203),
    [anon_sym_select] = ACTIONS(63),
    [anon_sym_new] = ACTIONS(65),
    [anon_sym_make] = ACTIONS(65),
    [anon_sym_PLUS] = ACTIONS(67),
    [anon_sym_DASH] = ACTIONS(67),
    [anon_sym_BANG] = ACTIONS(67),
    [anon_sym_CARET] = ACTIONS(67),
    [anon_sym_AMP] = ACTIONS(67),
    [sym_raw_string_literal] = ACTIONS(69),
    [anon_sym_DQUOTE] = ACTIONS(71),
    [sym_int_literal] = ACTIONS(73),
    [sym_float_literal] = ACTIONS(73),
    [sym_imaginary_literal] = ACTIONS(69),
    [sym_rune_literal] = ACTIONS(69),
    [sym_nil] = ACTIONS(73),
    [sym_true] = ACTIONS(73),
    [sym_false] = ACTIONS(73),
    [sym_iota] = ACTIONS(73),
    [sym_comment] = ACTIONS(3),
  },
  [9] = {
    [sym__declaration] = STATE(978),
    [sym_const_declaration] = STATE(978),
    [sym_var_declaration] = STATE(978),
    [sym_type_declaration] = STATE(978),
    [sym_expression_list] = STATE(803),
    [sym_parenthesized_type] = STATE(1306),
    [sym__simple_type] = STATE(1306),
    [sym_generic_type] = STATE(1104),
    [sym_pointer_type] = STATE(858),
    [sym_array_type] = STATE(1104),
    [sym_implicit_length_array_type] = STATE(1272),
    [sym_slice_type] = STATE(1104),
    [sym_struct_type] = STATE(1104),
    [sym_negated_type] = STATE(836),
    [sym_interface_type] = STATE(858),
    [sym_map_type] = STATE(1104),
    [sym_channel_type] = STATE(858),
    [sym_function_type] = STATE(858),
    [sym_block] = STATE(978),
    [sym__statement] = STATE(974),
    [sym_empty_statement] = STATE(978),
    [sym__simple_statement] = STATE(978),
    [sym_expression_statement] = STATE(1003),
    [sym_send_statement] = STATE(1003),
    [sym_inc_statement] = STATE(1003),
    [sym_dec_statement] = STATE(1003),
    [sym_assignment_statement] = STATE(1003),
    [sym_short_var_declaration] = STATE(1003),
    [sym_labeled_statement] = STATE(978),
    [sym_empty_labeled_statement] = STATE(1156),
    [sym_fallthrough_statement] = STATE(978),
    [sym_break_statement] = STATE(978),
    [sym_continue_statement] = STATE(978),
    [sym_goto_statement] = STATE(978),
    [sym_return_statement] = STATE(978),
    [sym_go_statement] = STATE(978),
    [sym_defer_statement] = STATE(978),
    [sym_if_statement] = STATE(978),
    [sym_for_statement] = STATE(978),
    [sym_expression_switch_statement] = STATE(978),
    [sym_type_switch_statement] = STATE(978),
    [sym_select_statement] = STATE(978),
    [sym__expression] = STATE(239),
    [sym_parenthesized_expression] = STATE(266),
    [sym_call_expression] = STATE(266),
    [sym_selector_expression] = STATE(266),
    [sym_index_expression] = STATE(266),
    [sym_slice_expression] = STATE(266),
    [sym_type_assertion_expression] = STATE(266),
    [sym_type_conversion_expression] = STATE(266),
    [sym_type_instantiation_expression] = STATE(266),
    [sym_composite_literal] = STATE(266),
    [sym_func_literal] = STATE(266),
    [sym_unary_expression] = STATE(266),
    [sym_binary_expression] = STATE(266),
    [sym_qualified_type] = STATE(1032),
    [sym_interpreted_string_literal] = STATE(266),
    [sym_identifier] = ACTIONS(181),
    [anon_sym_SEMI] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(15),
    [anon_sym_const] = ACTIONS(17),
    [anon_sym_var] = ACTIONS(19),
    [anon_sym_func] = ACTIONS(183),
    [anon_sym_LBRACK] = ACTIONS(23),
    [anon_sym_type] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(27),
    [anon_sym_struct] = ACTIONS(29),
    [anon_sym_TILDE] = ACTIONS(31),
    [anon_sym_LBRACE] = ACTIONS(33),
    [anon_sym_RBRACE] = ACTIONS(205),
    [anon_sym_interface] = ACTIONS(35),
    [anon_sym_map] = ACTIONS(37),
    [anon_sym_chan] = ACTIONS(39),
    [anon_sym_LT_DASH] = ACTIONS(41),
    [anon_sym_fallthrough] = ACTIONS(43),
    [anon_sym_break] = ACTIONS(45),
    [anon_sym_continue] = ACTIONS(47),
    [anon_sym_goto] = ACTIONS(49),
    [anon_sym_return] = ACTIONS(51),
    [anon_sym_go] = ACTIONS(53),
    [anon_sym_defer] = ACTIONS(55),
    [anon_sym_if] = ACTIONS(57),
    [anon_sym_for] = ACTIONS(59),
    [anon_sym_switch] = ACTIONS(61),
    [anon_sym_case] = ACTIONS(207),
    [anon_sym_default] = ACTIONS(207),
    [anon_sym_select] = ACTIONS(63),
    [anon_sym_new] = ACTIONS(65),
    [anon_sym_make] = ACTIONS(65),
    [anon_sym_PLUS] = ACTIONS(67),
    [anon_sym_DASH] = ACTIONS(67),
    [anon_sym_BANG] = ACTIONS(67),
    [anon_sym_CARET] = ACTIONS(67),
    [anon_sym_AMP] = ACTIONS(67),
    [sym_raw_string_literal] = ACTIONS(69),
    [anon_sym_DQUOTE] = ACTIONS(71),
    [sym_int_literal] = ACTIONS(73),
    [sym_float_literal] = ACTIONS(73),
    [sym_imaginary_literal] = ACTIONS(69),
    [sym_rune_literal] = ACTIONS(69),
    [sym_nil] = ACTIONS(73),
    [sym_true] = ACTIONS(73),
    [sym_false] = ACTIONS(73),
    [sym_iota] = ACTIONS(73),
    [sym_comment] = ACTIONS(3),
  },
  [10] = {
    [sym__declaration] = STATE(978),
    [sym_const_declaration] = STATE(978),
    [sym_var_declaration] = STATE(978),
    [sym_type_declaration] = STATE(978),
    [sym_expression_list] = STATE(803),
    [sym_parenthesized_type] = STATE(1306),
    [sym__simple_type] = STATE(1306),
    [sym_generic_type] = STATE(1104),
    [sym_pointer_type] = STATE(858),
    [sym_array_type] = STATE(1104),
    [sym_implicit_length_array_type] = STATE(1272),
    [sym_slice_type] = STATE(1104),
    [sym_struct_type] = STATE(1104),
    [sym_negated_type] = STATE(836),
    [sym_interface_type] = STATE(858),
    [sym_map_type] = STATE(1104),
    [sym_channel_type] = STATE(858),
    [sym_function_type] = STATE(858),
    [sym_block] = STATE(978),
    [sym__statement] = STATE(974),
    [sym_empty_statement] = STATE(978),
    [sym__simple_statement] = STATE(978),
    [sym_expression_statement] = STATE(1003),
    [sym_send_statement] = STATE(1003),
    [sym_inc_statement] = STATE(1003),
    [sym_dec_statement] = STATE(1003),
    [sym_assignment_statement] = STATE(1003),
    [sym_short_var_declaration] = STATE(1003),
    [sym_labeled_statement] = STATE(978),
    [sym_empty_labeled_statement] = STATE(1230),
    [sym_fallthrough_statement] = STATE(978),
    [sym_break_statement] = STATE(978),
    [sym_continue_statement] = STATE(978),
    [sym_goto_statement] = STATE(978),
    [sym_return_statement] = STATE(978),
    [sym_go_statement] = STATE(978),
    [sym_defer_statement] = STATE(978),
    [sym_if_statement] = STATE(978),
    [sym_for_statement] = STATE(978),
    [sym_expression_switch_statement] = STATE(978),
    [sym_type_switch_statement] = STATE(978),
    [sym_select_statement] = STATE(978),
    [sym__expression] = STATE(239),
    [sym_parenthesized_expression] = STATE(266),
    [sym_call_expression] = STATE(266),
    [sym_selector_expression] = STATE(266),
    [sym_index_expression] = STATE(266),
    [sym_slice_expression] = STATE(266),
    [sym_type_assertion_expression] = STATE(266),
    [sym_type_conversion_expression] = STATE(266),
    [sym_type_instantiation_expression] = STATE(266),
    [sym_composite_literal] = STATE(266),
    [sym_func_literal] = STATE(266),
    [sym_unary_expression] = STATE(266),
    [sym_binary_expression] = STATE(266),
    [sym_qualified_type] = STATE(1032),
    [sym_interpreted_string_literal] = STATE(266),
    [sym_identifier] = ACTIONS(181),
    [anon_sym_SEMI] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(15),
    [anon_sym_const] = ACTIONS(17),
    [anon_sym_var] = ACTIONS(19),
    [anon_sym_func] = ACTIONS(183),
    [anon_sym_LBRACK] = ACTIONS(23),
    [anon_sym_type] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(27),
    [anon_sym_struct] = ACTIONS(29),
    [anon_sym_TILDE] = ACTIONS(31),
    [anon_sym_LBRACE] = ACTIONS(33),
    [anon_sym_RBRACE] = ACTIONS(209),
    [anon_sym_interface] = ACTIONS(35),
    [anon_sym_map] = ACTIONS(37),
    [anon_sym_chan] = ACTIONS(39),
    [anon_sym_LT_DASH] = ACTIONS(41),
    [anon_sym_fallthrough] = ACTIONS(43),
    [anon_sym_break] = ACTIONS(45),
    [anon_sym_continue] = ACTIONS(47),
    [anon_sym_goto] = ACTIONS(49),
    [anon_sym_return] = ACTIONS(51),
    [anon_sym_go] = ACTIONS(53),
    [anon_sym_defer] = ACTIONS(55),
    [anon_sym_if] = ACTIONS(57),
    [anon_sym_for] = ACTIONS(59),
    [anon_sym_switch] = ACTIONS(61),
    [anon_sym_case] = ACTIONS(211),
    [anon_sym_default] = ACTIONS(211),
    [anon_sym_select] = ACTIONS(63),
    [anon_sym_new] = ACTIONS(65),
    [anon_sym_make] = ACTIONS(65),
    [anon_sym_PLUS] = ACTIONS(67),
    [anon_sym_DASH] = ACTIONS(67),
    [anon_sym_BANG] = ACTIONS(67),
    [anon_sym_CARET] = ACTIONS(67),
    [anon_sym_AMP] = ACTIONS(67),
    [sym_raw_string_literal] = ACTIONS(69),
    [anon_sym_DQUOTE] = ACTIONS(71),
    [sym_int_literal] = ACTIONS(73),
    [sym_float_literal] = ACTIONS(73),
    [sym_imaginary_literal] = ACTIONS(69),
    [sym_rune_literal] = ACTIONS(69),
    [sym_nil] = ACTIONS(73),
    [sym_true] = ACTIONS(73),
    [sym_false] = ACTIONS(73),
    [sym_iota] = ACTIONS(73),
    [sym_comment] = ACTIONS(3),
  },
  [11] = {
    [sym__declaration] = STATE(978),
    [sym_const_declaration] = STATE(978),
    [sym_var_declaration] = STATE(978),
    [sym_type_declaration] = STATE(978),
    [sym_expression_list] = STATE(803),
    [sym_parenthesized_type] = STATE(1306),
    [sym__simple_type] = STATE(1306),
    [sym_generic_type] = STATE(1104),
    [sym_pointer_type] = STATE(858),
    [sym_array_type] = STATE(1104),
    [sym_implicit_length_array_type] = STATE(1272),
    [sym_slice_type] = STATE(1104),
    [sym_struct_type] = STATE(1104),
    [sym_negated_type] = STATE(836),
    [sym_interface_type] = STATE(858),
    [sym_map_type] = STATE(1104),
    [sym_channel_type] = STATE(858),
    [sym_function_type] = STATE(858),
    [sym_block] = STATE(978),
    [sym__statement] = STATE(966),
    [sym_empty_statement] = STATE(978),
    [sym__simple_statement] = STATE(978),
    [sym_expression_statement] = STATE(1003),
    [sym_send_statement] = STATE(1003),
    [sym_inc_statement] = STATE(1003),
    [sym_dec_statement] = STATE(1003),
    [sym_assignment_statement] = STATE(1003),
    [sym_short_var_declaration] = STATE(1003),
    [sym_labeled_statement] = STATE(978),
    [sym_fallthrough_statement] = STATE(978),
    [sym_break_statement] = STATE(978),
    [sym_continue_statement] = STATE(978),
    [sym_goto_statement] = STATE(978),
    [sym_return_statement] = STATE(978),
    [sym_go_statement] = STATE(978),
    [sym_defer_statement] = STATE(978),
    [sym_if_statement] = STATE(978),
    [sym_for_statement] = STATE(978),
    [sym_expression_switch_statement] = STATE(978),
    [sym_type_switch_statement] = STATE(978),
    [sym_select_statement] = STATE(978),
    [sym__expression] = STATE(239),
    [sym_parenthesized_expression] = STATE(266),
    [sym_call_expression] = STATE(266),
    [sym_selector_expression] = STATE(266),
    [sym_index_expression] = STATE(266),
    [sym_slice_expression] = STATE(266),
    [sym_type_assertion_expression] = STATE(266),
    [sym_type_conversion_expression] = STATE(266),
    [sym_type_instantiation_expression] = STATE(266),
    [sym_composite_literal] = STATE(266),
    [sym_func_literal] = STATE(266),
    [sym_unary_expression] = STATE(266),
    [sym_binary_expression] = STATE(266),
    [sym_qualified_type] = STATE(1032),
    [sym_interpreted_string_literal] = STATE(266),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(15),
    [anon_sym_const] = ACTIONS(17),
    [anon_sym_var] = ACTIONS(19),
    [anon_sym_func] = ACTIONS(183),
    [anon_sym_LBRACK] = ACTIONS(23),
    [anon_sym_type] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(27),
    [anon_sym_struct] = ACTIONS(29),
    [anon_sym_TILDE] = ACTIONS(31),
    [anon_sym_LBRACE] = ACTIONS(33),
    [anon_sym_RBRACE] = ACTIONS(213),
    [anon_sym_interface] = ACTIONS(35),
    [anon_sym_map] = ACTIONS(37),
    [anon_sym_chan] = ACTIONS(39),
    [anon_sym_LT_DASH] = ACTIONS(41),
    [anon_sym_fallthrough] = ACTIONS(43),
    [anon_sym_break] = ACTIONS(45),
    [anon_sym_continue] = ACTIONS(47),
    [anon_sym_goto] = ACTIONS(49),
    [anon_sym_return] = ACTIONS(51),
    [anon_sym_go] = ACTIONS(53),
    [anon_sym_defer] = ACTIONS(55),
    [anon_sym_if] = ACTIONS(57),
    [anon_sym_for] = ACTIONS(59),
    [anon_sym_switch] = ACTIONS(61),
    [anon_sym_case] = ACTIONS(215),
    [anon_sym_default] = ACTIONS(215),
    [anon_sym_select] = ACTIONS(63),
    [anon_sym_new] = ACTIONS(65),
    [anon_sym_make] = ACTIONS(65),
    [anon_sym_PLUS] = ACTIONS(67),
    [anon_sym_DASH] = ACTIONS(67),
    [anon_sym_BANG] = ACTIONS(67),
    [anon_sym_CARET] = ACTIONS(67),
    [anon_sym_AMP] = ACTIONS(67),
    [sym_raw_string_literal] = ACTIONS(69),
    [anon_sym_DQUOTE] = ACTIONS(71),
    [sym_int_literal] = ACTIONS(73),
    [sym_float_literal] = ACTIONS(73),
    [sym_imaginary_literal] = ACTIONS(69),
    [sym_rune_literal] = ACTIONS(69),
    [sym_nil] = ACTIONS(73),
    [sym_true] = ACTIONS(73),
    [sym_false] = ACTIONS(73),
    [sym_iota] = ACTIONS(73),
    [sym_comment] = ACTIONS(3),
  },
  [12] = {
    [sym__declaration] = STATE(978),
    [sym_const_declaration] = STATE(978),
    [sym_var_declaration] = STATE(978),
    [sym_type_declaration] = STATE(978),
    [sym_expression_list] = STATE(803),
    [sym_parenthesized_type] = STATE(1306),
    [sym__simple_type] = STATE(1306),
    [sym_generic_type] = STATE(1104),
    [sym_pointer_type] = STATE(858),
    [sym_array_type] = STATE(1104),
    [sym_implicit_length_array_type] = STATE(1272),
    [sym_slice_type] = STATE(1104),
    [sym_struct_type] = STATE(1104),
    [sym_negated_type] = STATE(836),
    [sym_interface_type] = STATE(858),
    [sym_map_type] = STATE(1104),
    [sym_channel_type] = STATE(858),
    [sym_function_type] = STATE(858),
    [sym_block] = STATE(978),
    [sym__statement_list] = STATE(1382),
    [sym__statement] = STATE(898),
    [sym_empty_statement] = STATE(978),
    [sym__simple_statement] = STATE(978),
    [sym_expression_statement] = STATE(1003),
    [sym_send_statement] = STATE(1003),
    [sym_inc_statement] = STATE(1003),
    [sym_dec_statement] = STATE(1003),
    [sym_assignment_statement] = STATE(1003),
    [sym_short_var_declaration] = STATE(1003),
    [sym_labeled_statement] = STATE(978),
    [sym_empty_labeled_statement] = STATE(1382),
    [sym_fallthrough_statement] = STATE(978),
    [sym_break_statement] = STATE(978),
    [sym_continue_statement] = STATE(978),
    [sym_goto_statement] = STATE(978),
    [sym_return_statement] = STATE(978),
    [sym_go_statement] = STATE(978),
    [sym_defer_statement] = STATE(978),
    [sym_if_statement] = STATE(978),
    [sym_for_statement] = STATE(978),
    [sym_expression_switch_statement] = STATE(978),
    [sym_type_switch_statement] = STATE(978),
    [sym_select_statement] = STATE(978),
    [sym__expression] = STATE(239),
    [sym_parenthesized_expression] = STATE(266),
    [sym_call_expression] = STATE(266),
    [sym_selector_expression] = STATE(266),
    [sym_index_expression] = STATE(266),
    [sym_slice_expression] = STATE(266),
    [sym_type_assertion_expression] = STATE(266),
    [sym_type_conversion_expression] = STATE(266),
    [sym_type_instantiation_expression] = STATE(266),
    [sym_composite_literal] = STATE(266),
    [sym_func_literal] = STATE(266),
    [sym_unary_expression] = STATE(266),
    [sym_binary_expression] = STATE(266),
    [sym_qualified_type] = STATE(1032),
    [sym_interpreted_string_literal] = STATE(266),
    [sym_identifier] = ACTIONS(181),
    [anon_sym_SEMI] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(15),
    [anon_sym_const] = ACTIONS(17),
    [anon_sym_var] = ACTIONS(19),
    [anon_sym_func] = ACTIONS(183),
    [anon_sym_LBRACK] = ACTIONS(23),
    [anon_sym_type] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(27),
    [anon_sym_struct] = ACTIONS(29),
    [anon_sym_TILDE] = ACTIONS(31),
    [anon_sym_LBRACE] = ACTIONS(33),
    [anon_sym_RBRACE] = ACTIONS(217),
    [anon_sym_interface] = ACTIONS(35),
    [anon_sym_map] = ACTIONS(37),
    [anon_sym_chan] = ACTIONS(39),
    [anon_sym_LT_DASH] = ACTIONS(41),
    [anon_sym_fallthrough] = ACTIONS(43),
    [anon_sym_break] = ACTIONS(45),
    [anon_sym_continue] = ACTIONS(47),
    [anon_sym_goto] = ACTIONS(49),
    [anon_sym_return] = ACTIONS(51),
    [anon_sym_go] = ACTIONS(53),
    [anon_sym_defer] = ACTIONS(55),
    [anon_sym_if] = ACTIONS(57),
    [anon_sym_for] = ACTIONS(59),
    [anon_sym_switch] = ACTIONS(61),
    [anon_sym_select] = ACTIONS(63),
    [anon_sym_new] = ACTIONS(65),
    [anon_sym_make] = ACTIONS(65),
    [anon_sym_PLUS] = ACTIONS(67),
    [anon_sym_DASH] = ACTIONS(67),
    [anon_sym_BANG] = ACTIONS(67),
    [anon_sym_CARET] = ACTIONS(67),
    [anon_sym_AMP] = ACTIONS(67),
    [sym_raw_string_literal] = ACTIONS(69),
    [anon_sym_DQUOTE] = ACTIONS(71),
    [sym_int_literal] = ACTIONS(73),
    [sym_float_literal] = ACTIONS(73),
    [sym_imaginary_literal] = ACTIONS(69),
    [sym_rune_literal] = ACTIONS(69),
    [sym_nil] = ACTIONS(73),
    [sym_true] = ACTIONS(73),
    [sym_false] = ACTIONS(73),
    [sym_iota] = ACTIONS(73),
    [sym_comment] = ACTIONS(3),
  },
  [13] = {
    [sym__declaration] = STATE(978),
    [sym_const_declaration] = STATE(978),
    [sym_var_declaration] = STATE(978),
    [sym_type_declaration] = STATE(978),
    [sym_expression_list] = STATE(803),
    [sym_parenthesized_type] = STATE(1306),
    [sym__simple_type] = STATE(1306),
    [sym_generic_type] = STATE(1104),
    [sym_pointer_type] = STATE(858),
    [sym_array_type] = STATE(1104),
    [sym_implicit_length_array_type] = STATE(1272),
    [sym_slice_type] = STATE(1104),
    [sym_struct_type] = STATE(1104),
    [sym_negated_type] = STATE(836),
    [sym_interface_type] = STATE(858),
    [sym_map_type] = STATE(1104),
    [sym_channel_type] = STATE(858),
    [sym_function_type] = STATE(858),
    [sym_block] = STATE(978),
    [sym__statement_list] = STATE(1369),
    [sym__statement] = STATE(898),
    [sym_empty_statement] = STATE(978),
    [sym__simple_statement] = STATE(978),
    [sym_expression_statement] = STATE(1003),
    [sym_send_statement] = STATE(1003),
    [sym_inc_statement] = STATE(1003),
    [sym_dec_statement] = STATE(1003),
    [sym_assignment_statement] = STATE(1003),
    [sym_short_var_declaration] = STATE(1003),
    [sym_labeled_statement] = STATE(978),
    [sym_empty_labeled_statement] = STATE(1369),
    [sym_fallthrough_statement] = STATE(978),
    [sym_break_statement] = STATE(978),
    [sym_continue_statement] = STATE(978),
    [sym_goto_statement] = STATE(978),
    [sym_return_statement] = STATE(978),
    [sym_go_statement] = STATE(978),
    [sym_defer_statement] = STATE(978),
    [sym_if_statement] = STATE(978),
    [sym_for_statement] = STATE(978),
    [sym_expression_switch_statement] = STATE(978),
    [sym_type_switch_statement] = STATE(978),
    [sym_select_statement] = STATE(978),
    [sym__expression] = STATE(239),
    [sym_parenthesized_expression] = STATE(266),
    [sym_call_expression] = STATE(266),
    [sym_selector_expression] = STATE(266),
    [sym_index_expression] = STATE(266),
    [sym_slice_expression] = STATE(266),
    [sym_type_assertion_expression] = STATE(266),
    [sym_type_conversion_expression] = STATE(266),
    [sym_type_instantiation_expression] = STATE(266),
    [sym_composite_literal] = STATE(266),
    [sym_func_literal] = STATE(266),
    [sym_unary_expression] = STATE(266),
    [sym_binary_expression] = STATE(266),
    [sym_qualified_type] = STATE(1032),
    [sym_interpreted_string_literal] = STATE(266),
    [sym_identifier] = ACTIONS(181),
    [anon_sym_SEMI] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(15),
    [anon_sym_const] = ACTIONS(17),
    [anon_sym_var] = ACTIONS(19),
    [anon_sym_func] = ACTIONS(183),
    [anon_sym_LBRACK] = ACTIONS(23),
    [anon_sym_type] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(27),
    [anon_sym_struct] = ACTIONS(29),
    [anon_sym_TILDE] = ACTIONS(31),
    [anon_sym_LBRACE] = ACTIONS(33),
    [anon_sym_RBRACE] = ACTIONS(219),
    [anon_sym_interface] = ACTIONS(35),
    [anon_sym_map] = ACTIONS(37),
    [anon_sym_chan] = ACTIONS(39),
    [anon_sym_LT_DASH] = ACTIONS(41),
    [anon_sym_fallthrough] = ACTIONS(43),
    [anon_sym_break] = ACTIONS(45),
    [anon_sym_continue] = ACTIONS(47),
    [anon_sym_goto] = ACTIONS(49),
    [anon_sym_return] = ACTIONS(51),
    [anon_sym_go] = ACTIONS(53),
    [anon_sym_defer] = ACTIONS(55),
    [anon_sym_if] = ACTIONS(57),
    [anon_sym_for] = ACTIONS(59),
    [anon_sym_switch] = ACTIONS(61),
    [anon_sym_select] = ACTIONS(63),
    [anon_sym_new] = ACTIONS(65),
    [anon_sym_make] = ACTIONS(65),
    [anon_sym_PLUS] = ACTIONS(67),
    [anon_sym_DASH] = ACTIONS(67),
    [anon_sym_BANG] = ACTIONS(67),
    [anon_sym_CARET] = ACTIONS(67),
    [anon_sym_AMP] = ACTIONS(67),
    [sym_raw_string_literal] = ACTIONS(69),
    [anon_sym_DQUOTE] = ACTIONS(71),
    [sym_int_literal] = ACTIONS(73),
    [sym_float_literal] = ACTIONS(73),
    [sym_imaginary_literal] = ACTIONS(69),
    [sym_rune_literal] = ACTIONS(69),
    [sym_nil] = ACTIONS(73),
    [sym_true] = ACTIONS(73),
    [sym_false] = ACTIONS(73),
    [sym_iota] = ACTIONS(73),
    [sym_comment] = ACTIONS(3),
  },
  [14] = {
    [sym__declaration] = STATE(978),
    [sym_const_declaration] = STATE(978),
    [sym_var_declaration] = STATE(978),
    [sym_type_declaration] = STATE(978),
    [sym_expression_list] = STATE(803),
    [sym_parenthesized_type] = STATE(1306),
    [sym__simple_type] = STATE(1306),
    [sym_generic_type] = STATE(1104),
    [sym_pointer_type] = STATE(858),
    [sym_array_type] = STATE(1104),
    [sym_implicit_length_array_type] = STATE(1272),
    [sym_slice_type] = STATE(1104),
    [sym_struct_type] = STATE(1104),
    [sym_negated_type] = STATE(836),
    [sym_interface_type] = STATE(858),
    [sym_map_type] = STATE(1104),
    [sym_channel_type] = STATE(858),
    [sym_function_type] = STATE(858),
    [sym_block] = STATE(978),
    [sym__statement_list] = STATE(1346),
    [sym__statement] = STATE(898),
    [sym_empty_statement] = STATE(978),
    [sym__simple_statement] = STATE(978),
    [sym_expression_statement] = STATE(1003),
    [sym_send_statement] = STATE(1003),
    [sym_inc_statement] = STATE(1003),
    [sym_dec_statement] = STATE(1003),
    [sym_assignment_statement] = STATE(1003),
    [sym_short_var_declaration] = STATE(1003),
    [sym_labeled_statement] = STATE(978),
    [sym_empty_labeled_statement] = STATE(1346),
    [sym_fallthrough_statement] = STATE(978),
    [sym_break_statement] = STATE(978),
    [sym_continue_statement] = STATE(978),
    [sym_goto_statement] = STATE(978),
    [sym_return_statement] = STATE(978),
    [sym_go_statement] = STATE(978),
    [sym_defer_statement] = STATE(978),
    [sym_if_statement] = STATE(978),
    [sym_for_statement] = STATE(978),
    [sym_expression_switch_statement] = STATE(978),
    [sym_type_switch_statement] = STATE(978),
    [sym_select_statement] = STATE(978),
    [sym__expression] = STATE(239),
    [sym_parenthesized_expression] = STATE(266),
    [sym_call_expression] = STATE(266),
    [sym_selector_expression] = STATE(266),
    [sym_index_expression] = STATE(266),
    [sym_slice_expression] = STATE(266),
    [sym_type_assertion_expression] = STATE(266),
    [sym_type_conversion_expression] = STATE(266),
    [sym_type_instantiation_expression] = STATE(266),
    [sym_composite_literal] = STATE(266),
    [sym_func_literal] = STATE(266),
    [sym_unary_expression] = STATE(266),
    [sym_binary_expression] = STATE(266),
    [sym_qualified_type] = STATE(1032),
    [sym_interpreted_string_literal] = STATE(266),
    [sym_identifier] = ACTIONS(181),
    [anon_sym_SEMI] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(15),
    [anon_sym_const] = ACTIONS(17),
    [anon_sym_var] = ACTIONS(19),
    [anon_sym_func] = ACTIONS(183),
    [anon_sym_LBRACK] = ACTIONS(23),
    [anon_sym_type] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(27),
    [anon_sym_struct] = ACTIONS(29),
    [anon_sym_TILDE] = ACTIONS(31),
    [anon_sym_LBRACE] = ACTIONS(33),
    [anon_sym_RBRACE] = ACTIONS(221),
    [anon_sym_interface] = ACTIONS(35),
    [anon_sym_map] = ACTIONS(37),
    [anon_sym_chan] = ACTIONS(39),
    [anon_sym_LT_DASH] = ACTIONS(41),
    [anon_sym_fallthrough] = ACTIONS(43),
    [anon_sym_break] = ACTIONS(45),
    [anon_sym_continue] = ACTIONS(47),
    [anon_sym_goto] = ACTIONS(49),
    [anon_sym_return] = ACTIONS(51),
    [anon_sym_go] = ACTIONS(53),
    [anon_sym_defer] = ACTIONS(55),
    [anon_sym_if] = ACTIONS(57),
    [anon_sym_for] = ACTIONS(59),
    [anon_sym_switch] = ACTIONS(61),
    [anon_sym_select] = ACTIONS(63),
    [anon_sym_new] = ACTIONS(65),
    [anon_sym_make] = ACTIONS(65),
    [anon_sym_PLUS] = ACTIONS(67),
    [anon_sym_DASH] = ACTIONS(67),
    [anon_sym_BANG] = ACTIONS(67),
    [anon_sym_CARET] = ACTIONS(67),
    [anon_sym_AMP] = ACTIONS(67),
    [sym_raw_string_literal] = ACTIONS(69),
    [anon_sym_DQUOTE] = ACTIONS(71),
    [sym_int_literal] = ACTIONS(73),
    [sym_float_literal] = ACTIONS(73),
    [sym_imaginary_literal] = ACTIONS(69),
    [sym_rune_literal] = ACTIONS(69),
    [sym_nil] = ACTIONS(73),
    [sym_true] = ACTIONS(73),
    [sym_false] = ACTIONS(73),
    [sym_iota] = ACTIONS(73),
    [sym_comment] = ACTIONS(3),
  },
  [15] = {
    [sym__declaration] = STATE(978),
    [sym_const_declaration] = STATE(978),
    [sym_var_declaration] = STATE(978),
    [sym_type_declaration] = STATE(978),
    [sym_expression_list] = STATE(803),
    [sym_parenthesized_type] = STATE(1306),
    [sym__simple_type] = STATE(1306),
    [sym_generic_type] = STATE(1104),
    [sym_pointer_type] = STATE(858),
    [sym_array_type] = STATE(1104),
    [sym_implicit_length_array_type] = STATE(1272),
    [sym_slice_type] = STATE(1104),
    [sym_struct_type] = STATE(1104),
    [sym_negated_type] = STATE(836),
    [sym_interface_type] = STATE(858),
    [sym_map_type] = STATE(1104),
    [sym_channel_type] = STATE(858),
    [sym_function_type] = STATE(858),
    [sym_block] = STATE(978),
    [sym__statement_list] = STATE(1319),
    [sym__statement] = STATE(898),
    [sym_empty_statement] = STATE(978),
    [sym__simple_statement] = STATE(978),
    [sym_expression_statement] = STATE(1003),
    [sym_send_statement] = STATE(1003),
    [sym_inc_statement] = STATE(1003),
    [sym_dec_statement] = STATE(1003),
    [sym_assignment_statement] = STATE(1003),
    [sym_short_var_declaration] = STATE(1003),
    [sym_labeled_statement] = STATE(978),
    [sym_empty_labeled_statement] = STATE(1319),
    [sym_fallthrough_statement] = STATE(978),
    [sym_break_statement] = STATE(978),
    [sym_continue_statement] = STATE(978),
    [sym_goto_statement] = STATE(978),
    [sym_return_statement] = STATE(978),
    [sym_go_statement] = STATE(978),
    [sym_defer_statement] = STATE(978),
    [sym_if_statement] = STATE(978),
    [sym_for_statement] = STATE(978),
    [sym_expression_switch_statement] = STATE(978),
    [sym_type_switch_statement] = STATE(978),
    [sym_select_statement] = STATE(978),
    [sym__expression] = STATE(239),
    [sym_parenthesized_expression] = STATE(266),
    [sym_call_expression] = STATE(266),
    [sym_selector_expression] = STATE(266),
    [sym_index_expression] = STATE(266),
    [sym_slice_expression] = STATE(266),
    [sym_type_assertion_expression] = STATE(266),
    [sym_type_conversion_expression] = STATE(266),
    [sym_type_instantiation_expression] = STATE(266),
    [sym_composite_literal] = STATE(266),
    [sym_func_literal] = STATE(266),
    [sym_unary_expression] = STATE(266),
    [sym_binary_expression] = STATE(266),
    [sym_qualified_type] = STATE(1032),
    [sym_interpreted_string_literal] = STATE(266),
    [sym_identifier] = ACTIONS(181),
    [anon_sym_SEMI] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(15),
    [anon_sym_const] = ACTIONS(17),
    [anon_sym_var] = ACTIONS(19),
    [anon_sym_func] = ACTIONS(183),
    [anon_sym_LBRACK] = ACTIONS(23),
    [anon_sym_type] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(27),
    [anon_sym_struct] = ACTIONS(29),
    [anon_sym_TILDE] = ACTIONS(31),
    [anon_sym_LBRACE] = ACTIONS(33),
    [anon_sym_RBRACE] = ACTIONS(223),
    [anon_sym_interface] = ACTIONS(35),
    [anon_sym_map] = ACTIONS(37),
    [anon_sym_chan] = ACTIONS(39),
    [anon_sym_LT_DASH] = ACTIONS(41),
    [anon_sym_fallthrough] = ACTIONS(43),
    [anon_sym_break] = ACTIONS(45),
    [anon_sym_continue] = ACTIONS(47),
    [anon_sym_goto] = ACTIONS(49),
    [anon_sym_return] = ACTIONS(51),
    [anon_sym_go] = ACTIONS(53),
    [anon_sym_defer] = ACTIONS(55),
    [anon_sym_if] = ACTIONS(57),
    [anon_sym_for] = ACTIONS(59),
    [anon_sym_switch] = ACTIONS(61),
    [anon_sym_select] = ACTIONS(63),
    [anon_sym_new] = ACTIONS(65),
    [anon_sym_make] = ACTIONS(65),
    [anon_sym_PLUS] = ACTIONS(67),
    [anon_sym_DASH] = ACTIONS(67),
    [anon_sym_BANG] = ACTIONS(67),
    [anon_sym_CARET] = ACTIONS(67),
    [anon_sym_AMP] = ACTIONS(67),
    [sym_raw_string_literal] = ACTIONS(69),
    [anon_sym_DQUOTE] = ACTIONS(71),
    [sym_int_literal] = ACTIONS(73),
    [sym_float_literal] = ACTIONS(73),
    [sym_imaginary_literal] = ACTIONS(69),
    [sym_rune_literal] = ACTIONS(69),
    [sym_nil] = ACTIONS(73),
    [sym_true] = ACTIONS(73),
    [sym_false] = ACTIONS(73),
    [sym_iota] = ACTIONS(73),
    [sym_comment] = ACTIONS(3),
  },
  [16] = {
    [sym__declaration] = STATE(978),
    [sym_const_declaration] = STATE(978),
    [sym_var_declaration] = STATE(978),
    [sym_type_declaration] = STATE(978),
    [sym_expression_list] = STATE(803),
    [sym_parenthesized_type] = STATE(1306),
    [sym__simple_type] = STATE(1306),
    [sym_generic_type] = STATE(1104),
    [sym_pointer_type] = STATE(858),
    [sym_array_type] = STATE(1104),
    [sym_implicit_length_array_type] = STATE(1272),
    [sym_slice_type] = STATE(1104),
    [sym_struct_type] = STATE(1104),
    [sym_negated_type] = STATE(836),
    [sym_interface_type] = STATE(858),
    [sym_map_type] = STATE(1104),
    [sym_channel_type] = STATE(858),
    [sym_function_type] = STATE(858),
    [sym_block] = STATE(978),
    [sym__statement_list] = STATE(1339),
    [sym__statement] = STATE(898),
    [sym_empty_statement] = STATE(978),
    [sym__simple_statement] = STATE(978),
    [sym_expression_statement] = STATE(1003),
    [sym_send_statement] = STATE(1003),
    [sym_inc_statement] = STATE(1003),
    [sym_dec_statement] = STATE(1003),
    [sym_assignment_statement] = STATE(1003),
    [sym_short_var_declaration] = STATE(1003),
    [sym_labeled_statement] = STATE(978),
    [sym_empty_labeled_statement] = STATE(1339),
    [sym_fallthrough_statement] = STATE(978),
    [sym_break_statement] = STATE(978),
    [sym_continue_statement] = STATE(978),
    [sym_goto_statement] = STATE(978),
    [sym_return_statement] = STATE(978),
    [sym_go_statement] = STATE(978),
    [sym_defer_statement] = STATE(978),
    [sym_if_statement] = STATE(978),
    [sym_for_statement] = STATE(978),
    [sym_expression_switch_statement] = STATE(978),
    [sym_type_switch_statement] = STATE(978),
    [sym_select_statement] = STATE(978),
    [sym__expression] = STATE(239),
    [sym_parenthesized_expression] = STATE(266),
    [sym_call_expression] = STATE(266),
    [sym_selector_expression] = STATE(266),
    [sym_index_expression] = STATE(266),
    [sym_slice_expression] = STATE(266),
    [sym_type_assertion_expression] = STATE(266),
    [sym_type_conversion_expression] = STATE(266),
    [sym_type_instantiation_expression] = STATE(266),
    [sym_composite_literal] = STATE(266),
    [sym_func_literal] = STATE(266),
    [sym_unary_expression] = STATE(266),
    [sym_binary_expression] = STATE(266),
    [sym_qualified_type] = STATE(1032),
    [sym_interpreted_string_literal] = STATE(266),
    [sym_identifier] = ACTIONS(181),
    [anon_sym_SEMI] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(15),
    [anon_sym_const] = ACTIONS(17),
    [anon_sym_var] = ACTIONS(19),
    [anon_sym_func] = ACTIONS(183),
    [anon_sym_LBRACK] = ACTIONS(23),
    [anon_sym_type] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(27),
    [anon_sym_struct] = ACTIONS(29),
    [anon_sym_TILDE] = ACTIONS(31),
    [anon_sym_LBRACE] = ACTIONS(33),
    [anon_sym_RBRACE] = ACTIONS(225),
    [anon_sym_interface] = ACTIONS(35),
    [anon_sym_map] = ACTIONS(37),
    [anon_sym_chan] = ACTIONS(39),
    [anon_sym_LT_DASH] = ACTIONS(41),
    [anon_sym_fallthrough] = ACTIONS(43),
    [anon_sym_break] = ACTIONS(45),
    [anon_sym_continue] = ACTIONS(47),
    [anon_sym_goto] = ACTIONS(49),
    [anon_sym_return] = ACTIONS(51),
    [anon_sym_go] = ACTIONS(53),
    [anon_sym_defer] = ACTIONS(55),
    [anon_sym_if] = ACTIONS(57),
    [anon_sym_for] = ACTIONS(59),
    [anon_sym_switch] = ACTIONS(61),
    [anon_sym_select] = ACTIONS(63),
    [anon_sym_new] = ACTIONS(65),
    [anon_sym_make] = ACTIONS(65),
    [anon_sym_PLUS] = ACTIONS(67),
    [anon_sym_DASH] = ACTIONS(67),
    [anon_sym_BANG] = ACTIONS(67),
    [anon_sym_CARET] = ACTIONS(67),
    [anon_sym_AMP] = ACTIONS(67),
    [sym_raw_string_literal] = ACTIONS(69),
    [anon_sym_DQUOTE] = ACTIONS(71),
    [sym_int_literal] = ACTIONS(73),
    [sym_float_literal] = ACTIONS(73),
    [sym_imaginary_literal] = ACTIONS(69),
    [sym_rune_literal] = ACTIONS(69),
    [sym_nil] = ACTIONS(73),
    [sym_true] = ACTIONS(73),
    [sym_false] = ACTIONS(73),
    [sym_iota] = ACTIONS(73),
    [sym_comment] = ACTIONS(3),
  },
  [17] = {
    [sym__declaration] = STATE(978),
    [sym_const_declaration] = STATE(978),
    [sym_var_declaration] = STATE(978),
    [sym_type_declaration] = STATE(978),
    [sym_expression_list] = STATE(803),
    [sym_parenthesized_type] = STATE(1306),
    [sym__simple_type] = STATE(1306),
    [sym_generic_type] = STATE(1104),
    [sym_pointer_type] = STATE(858),
    [sym_array_type] = STATE(1104),
    [sym_implicit_length_array_type] = STATE(1272),
    [sym_slice_type] = STATE(1104),
    [sym_struct_type] = STATE(1104),
    [sym_negated_type] = STATE(836),
    [sym_interface_type] = STATE(858),
    [sym_map_type] = STATE(1104),
    [sym_channel_type] = STATE(858),
    [sym_function_type] = STATE(858),
    [sym_block] = STATE(978),
    [sym__statement_list] = STATE(1357),
    [sym__statement] = STATE(898),
    [sym_empty_statement] = STATE(978),
    [sym__simple_statement] = STATE(978),
    [sym_expression_statement] = STATE(1003),
    [sym_send_statement] = STATE(1003),
    [sym_inc_statement] = STATE(1003),
    [sym_dec_statement] = STATE(1003),
    [sym_assignment_statement] = STATE(1003),
    [sym_short_var_declaration] = STATE(1003),
    [sym_labeled_statement] = STATE(978),
    [sym_empty_labeled_statement] = STATE(1357),
    [sym_fallthrough_statement] = STATE(978),
    [sym_break_statement] = STATE(978),
    [sym_continue_statement] = STATE(978),
    [sym_goto_statement] = STATE(978),
    [sym_return_statement] = STATE(978),
    [sym_go_statement] = STATE(978),
    [sym_defer_statement] = STATE(978),
    [sym_if_statement] = STATE(978),
    [sym_for_statement] = STATE(978),
    [sym_expression_switch_statement] = STATE(978),
    [sym_type_switch_statement] = STATE(978),
    [sym_select_statement] = STATE(978),
    [sym__expression] = STATE(239),
    [sym_parenthesized_expression] = STATE(266),
    [sym_call_expression] = STATE(266),
    [sym_selector_expression] = STATE(266),
    [sym_index_expression] = STATE(266),
    [sym_slice_expression] = STATE(266),
    [sym_type_assertion_expression] = STATE(266),
    [sym_type_conversion_expression] = STATE(266),
    [sym_type_instantiation_expression] = STATE(266),
    [sym_composite_literal] = STATE(266),
    [sym_func_literal] = STATE(266),
    [sym_unary_expression] = STATE(266),
    [sym_binary_expression] = STATE(266),
    [sym_qualified_type] = STATE(1032),
    [sym_interpreted_string_literal] = STATE(266),
    [sym_identifier] = ACTIONS(181),
    [anon_sym_SEMI] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(15),
    [anon_sym_const] = ACTIONS(17),
    [anon_sym_var] = ACTIONS(19),
    [anon_sym_func] = ACTIONS(183),
    [anon_sym_LBRACK] = ACTIONS(23),
    [anon_sym_type] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(27),
    [anon_sym_struct] = ACTIONS(29),
    [anon_sym_TILDE] = ACTIONS(31),
    [anon_sym_LBRACE] = ACTIONS(33),
    [anon_sym_RBRACE] = ACTIONS(227),
    [anon_sym_interface] = ACTIONS(35),
    [anon_sym_map] = ACTIONS(37),
    [anon_sym_chan] = ACTIONS(39),
    [anon_sym_LT_DASH] = ACTIONS(41),
    [anon_sym_fallthrough] = ACTIONS(43),
    [anon_sym_break] = ACTIONS(45),
    [anon_sym_continue] = ACTIONS(47),
    [anon_sym_goto] = ACTIONS(49),
    [anon_sym_return] = ACTIONS(51),
    [anon_sym_go] = ACTIONS(53),
    [anon_sym_defer] = ACTIONS(55),
    [anon_sym_if] = ACTIONS(57),
    [anon_sym_for] = ACTIONS(59),
    [anon_sym_switch] = ACTIONS(61),
    [anon_sym_select] = ACTIONS(63),
    [anon_sym_new] = ACTIONS(65),
    [anon_sym_make] = ACTIONS(65),
    [anon_sym_PLUS] = ACTIONS(67),
    [anon_sym_DASH] = ACTIONS(67),
    [anon_sym_BANG] = ACTIONS(67),
    [anon_sym_CARET] = ACTIONS(67),
    [anon_sym_AMP] = ACTIONS(67),
    [sym_raw_string_literal] = ACTIONS(69),
    [anon_sym_DQUOTE] = ACTIONS(71),
    [sym_int_literal] = ACTIONS(73),
    [sym_float_literal] = ACTIONS(73),
    [sym_imaginary_literal] = ACTIONS(69),
    [sym_rune_literal] = ACTIONS(69),
    [sym_nil] = ACTIONS(73),
    [sym_true] = ACTIONS(73),
    [sym_false] = ACTIONS(73),
    [sym_iota] = ACTIONS(73),
    [sym_comment] = ACTIONS(3),
  },
  [18] = {
    [sym__declaration] = STATE(978),
    [sym_const_declaration] = STATE(978),
    [sym_var_declaration] = STATE(978),
    [sym_type_declaration] = STATE(978),
    [sym_expression_list] = STATE(803),
    [sym_parenthesized_type] = STATE(1306),
    [sym__simple_type] = STATE(1306),
    [sym_generic_type] = STATE(1104),
    [sym_pointer_type] = STATE(858),
    [sym_array_type] = STATE(1104),
    [sym_implicit_length_array_type] = STATE(1272),
    [sym_slice_type] = STATE(1104),
    [sym_struct_type] = STATE(1104),
    [sym_negated_type] = STATE(836),
    [sym_interface_type] = STATE(858),
    [sym_map_type] = STATE(1104),
    [sym_channel_type] = STATE(858),
    [sym_function_type] = STATE(858),
    [sym_block] = STATE(978),
    [sym__statement_list] = STATE(1334),
    [sym__statement] = STATE(898),
    [sym_empty_statement] = STATE(978),
    [sym__simple_statement] = STATE(978),
    [sym_expression_statement] = STATE(1003),
    [sym_send_statement] = STATE(1003),
    [sym_inc_statement] = STATE(1003),
    [sym_dec_statement] = STATE(1003),
    [sym_assignment_statement] = STATE(1003),
    [sym_short_var_declaration] = STATE(1003),
    [sym_labeled_statement] = STATE(978),
    [sym_empty_labeled_statement] = STATE(1334),
    [sym_fallthrough_statement] = STATE(978),
    [sym_break_statement] = STATE(978),
    [sym_continue_statement] = STATE(978),
    [sym_goto_statement] = STATE(978),
    [sym_return_statement] = STATE(978),
    [sym_go_statement] = STATE(978),
    [sym_defer_statement] = STATE(978),
    [sym_if_statement] = STATE(978),
    [sym_for_statement] = STATE(978),
    [sym_expression_switch_statement] = STATE(978),
    [sym_type_switch_statement] = STATE(978),
    [sym_select_statement] = STATE(978),
    [sym__expression] = STATE(239),
    [sym_parenthesized_expression] = STATE(266),
    [sym_call_expression] = STATE(266),
    [sym_selector_expression] = STATE(266),
    [sym_index_expression] = STATE(266),
    [sym_slice_expression] = STATE(266),
    [sym_type_assertion_expression] = STATE(266),
    [sym_type_conversion_expression] = STATE(266),
    [sym_type_instantiation_expression] = STATE(266),
    [sym_composite_literal] = STATE(266),
    [sym_func_literal] = STATE(266),
    [sym_unary_expression] = STATE(266),
    [sym_binary_expression] = STATE(266),
    [sym_qualified_type] = STATE(1032),
    [sym_interpreted_string_literal] = STATE(266),
    [sym_identifier] = ACTIONS(181),
    [anon_sym_SEMI] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(15),
    [anon_sym_const] = ACTIONS(17),
    [anon_sym_var] = ACTIONS(19),
    [anon_sym_func] = ACTIONS(183),
    [anon_sym_LBRACK] = ACTIONS(23),
    [anon_sym_type] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(27),
    [anon_sym_struct] = ACTIONS(29),
    [anon_sym_TILDE] = ACTIONS(31),
    [anon_sym_LBRACE] = ACTIONS(33),
    [anon_sym_RBRACE] = ACTIONS(229),
    [anon_sym_interface] = ACTIONS(35),
    [anon_sym_map] = ACTIONS(37),
    [anon_sym_chan] = ACTIONS(39),
    [anon_sym_LT_DASH] = ACTIONS(41),
    [anon_sym_fallthrough] = ACTIONS(43),
    [anon_sym_break] = ACTIONS(45),
    [anon_sym_continue] = ACTIONS(47),
    [anon_sym_goto] = ACTIONS(49),
    [anon_sym_return] = ACTIONS(51),
    [anon_sym_go] = ACTIONS(53),
    [anon_sym_defer] = ACTIONS(55),
    [anon_sym_if] = ACTIONS(57),
    [anon_sym_for] = ACTIONS(59),
    [anon_sym_switch] = ACTIONS(61),
    [anon_sym_select] = ACTIONS(63),
    [anon_sym_new] = ACTIONS(65),
    [anon_sym_make] = ACTIONS(65),
    [anon_sym_PLUS] = ACTIONS(67),
    [anon_sym_DASH] = ACTIONS(67),
    [anon_sym_BANG] = ACTIONS(67),
    [anon_sym_CARET] = ACTIONS(67),
    [anon_sym_AMP] = ACTIONS(67),
    [sym_raw_string_literal] = ACTIONS(69),
    [anon_sym_DQUOTE] = ACTIONS(71),
    [sym_int_literal] = ACTIONS(73),
    [sym_float_literal] = ACTIONS(73),
    [sym_imaginary_literal] = ACTIONS(69),
    [sym_rune_literal] = ACTIONS(69),
    [sym_nil] = ACTIONS(73),
    [sym_true] = ACTIONS(73),
    [sym_false] = ACTIONS(73),
    [sym_iota] = ACTIONS(73),
    [sym_comment] = ACTIONS(3),
  },
  [19] = {
    [sym__declaration] = STATE(978),
    [sym_const_declaration] = STATE(978),
    [sym_var_declaration] = STATE(978),
    [sym_type_declaration] = STATE(978),
    [sym_expression_list] = STATE(803),
    [sym_parenthesized_type] = STATE(1306),
    [sym__simple_type] = STATE(1306),
    [sym_generic_type] = STATE(1104),
    [sym_pointer_type] = STATE(858),
    [sym_array_type] = STATE(1104),
    [sym_implicit_length_array_type] = STATE(1272),
    [sym_slice_type] = STATE(1104),
    [sym_struct_type] = STATE(1104),
    [sym_negated_type] = STATE(836),
    [sym_interface_type] = STATE(858),
    [sym_map_type] = STATE(1104),
    [sym_channel_type] = STATE(858),
    [sym_function_type] = STATE(858),
    [sym_block] = STATE(978),
    [sym__statement] = STATE(966),
    [sym_empty_statement] = STATE(978),
    [sym__simple_statement] = STATE(978),
    [sym_expression_statement] = STATE(1003),
    [sym_send_statement] = STATE(1003),
    [sym_inc_statement] = STATE(1003),
    [sym_dec_statement] = STATE(1003),
    [sym_assignment_statement] = STATE(1003),
    [sym_short_var_declaration] = STATE(1003),
    [sym_labeled_statement] = STATE(978),
    [sym_fallthrough_statement] = STATE(978),
    [sym_break_statement] = STATE(978),
    [sym_continue_statement] = STATE(978),
    [sym_goto_statement] = STATE(978),
    [sym_return_statement] = STATE(978),
    [sym_go_statement] = STATE(978),
    [sym_defer_statement] = STATE(978),
    [sym_if_statement] = STATE(978),
    [sym_for_statement] = STATE(978),
    [sym_expression_switch_statement] = STATE(978),
    [sym_type_switch_statement] = STATE(978),
    [sym_select_statement] = STATE(978),
    [sym__expression] = STATE(239),
    [sym_parenthesized_expression] = STATE(266),
    [sym_call_expression] = STATE(266),
    [sym_selector_expression] = STATE(266),
    [sym_index_expression] = STATE(266),
    [sym_slice_expression] = STATE(266),
    [sym_type_assertion_expression] = STATE(266),
    [sym_type_conversion_expression] = STATE(266),
    [sym_type_instantiation_expression] = STATE(266),
    [sym_composite_literal] = STATE(266),
    [sym_func_literal] = STATE(266),
    [sym_unary_expression] = STATE(266),
    [sym_binary_expression] = STATE(266),
    [sym_qualified_type] = STATE(1032),
    [sym_interpreted_string_literal] = STATE(266),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(15),
    [anon_sym_const] = ACTIONS(17),
    [anon_sym_var] = ACTIONS(19),
    [anon_sym_func] = ACTIONS(183),
    [anon_sym_LBRACK] = ACTIONS(23),
    [anon_sym_type] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(27),
    [anon_sym_struct] = ACTIONS(29),
    [anon_sym_TILDE] = ACTIONS(31),
    [anon_sym_LBRACE] = ACTIONS(33),
    [anon_sym_interface] = ACTIONS(35),
    [anon_sym_map] = ACTIONS(37),
    [anon_sym_chan] = ACTIONS(39),
    [anon_sym_LT_DASH] = ACTIONS(41),
    [anon_sym_fallthrough] = ACTIONS(43),
    [anon_sym_break] = ACTIONS(45),
    [anon_sym_continue] = ACTIONS(47),
    [anon_sym_goto] = ACTIONS(49),
    [anon_sym_return] = ACTIONS(51),
    [anon_sym_go] = ACTIONS(53),
    [anon_sym_defer] = ACTIONS(55),
    [anon_sym_if] = ACTIONS(57),
    [anon_sym_for] = ACTIONS(59),
    [anon_sym_switch] = ACTIONS(61),
    [anon_sym_select] = ACTIONS(63),
    [anon_sym_new] = ACTIONS(65),
    [anon_sym_make] = ACTIONS(65),
    [anon_sym_PLUS] = ACTIONS(67),
    [anon_sym_DASH] = ACTIONS(67),
    [anon_sym_BANG] = ACTIONS(67),
    [anon_sym_CARET] = ACTIONS(67),
    [anon_sym_AMP] = ACTIONS(67),
    [sym_raw_string_literal] = ACTIONS(69),
    [anon_sym_DQUOTE] = ACTIONS(71),
    [sym_int_literal] = ACTIONS(73),
    [sym_float_literal] = ACTIONS(73),
    [sym_imaginary_literal] = ACTIONS(69),
    [sym_rune_literal] = ACTIONS(69),
    [sym_nil] = ACTIONS(73),
    [sym_true] = ACTIONS(73),
    [sym_false] = ACTIONS(73),
    [sym_iota] = ACTIONS(73),
    [sym_comment] = ACTIONS(3),
  },
  [20] = {
    [sym__declaration] = STATE(978),
    [sym_const_declaration] = STATE(978),
    [sym_var_declaration] = STATE(978),
    [sym_type_declaration] = STATE(978),
    [sym_expression_list] = STATE(803),
    [sym_parenthesized_type] = STATE(1306),
    [sym__simple_type] = STATE(1306),
    [sym_generic_type] = STATE(1104),
    [sym_pointer_type] = STATE(858),
    [sym_array_type] = STATE(1104),
    [sym_implicit_length_array_type] = STATE(1272),
    [sym_slice_type] = STATE(1104),
    [sym_struct_type] = STATE(1104),
    [sym_negated_type] = STATE(836),
    [sym_interface_type] = STATE(858),
    [sym_map_type] = STATE(1104),
    [sym_channel_type] = STATE(858),
    [sym_function_type] = STATE(858),
    [sym_block] = STATE(978),
    [sym__statement] = STATE(974),
    [sym_empty_statement] = STATE(978),
    [sym__simple_statement] = STATE(978),
    [sym_expression_statement] = STATE(1003),
    [sym_send_statement] = STATE(1003),
    [sym_inc_statement] = STATE(1003),
    [sym_dec_statement] = STATE(1003),
    [sym_assignment_statement] = STATE(1003),
    [sym_short_var_declaration] = STATE(1003),
    [sym_labeled_statement] = STATE(978),
    [sym_fallthrough_statement] = STATE(978),
    [sym_break_statement] = STATE(978),
    [sym_continue_statement] = STATE(978),
    [sym_goto_statement] = STATE(978),
    [sym_return_statement] = STATE(978),
    [sym_go_statement] = STATE(978),
    [sym_defer_statement] = STATE(978),
    [sym_if_statement] = STATE(978),
    [sym_for_statement] = STATE(978),
    [sym_expression_switch_statement] = STATE(978),
    [sym_type_switch_statement] = STATE(978),
    [sym_select_statement] = STATE(978),
    [sym__expression] = STATE(239),
    [sym_parenthesized_expression] = STATE(266),
    [sym_call_expression] = STATE(266),
    [sym_selector_expression] = STATE(266),
    [sym_index_expression] = STATE(266),
    [sym_slice_expression] = STATE(266),
    [sym_type_assertion_expression] = STATE(266),
    [sym_type_conversion_expression] = STATE(266),
    [sym_type_instantiation_expression] = STATE(266),
    [sym_composite_literal] = STATE(266),
    [sym_func_literal] = STATE(266),
    [sym_unary_expression] = STATE(266),
    [sym_binary_expression] = STATE(266),
    [sym_qualified_type] = STATE(1032),
    [sym_interpreted_string_literal] = STATE(266),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(15),
    [anon_sym_const] = ACTIONS(17),
    [anon_sym_var] = ACTIONS(19),
    [anon_sym_func] = ACTIONS(183),
    [anon_sym_LBRACK] = ACTIONS(23),
    [anon_sym_type] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(27),
    [anon_sym_struct] = ACTIONS(29),
    [anon_sym_TILDE] = ACTIONS(31),
    [anon_sym_LBRACE] = ACTIONS(33),
    [anon_sym_interface] = ACTIONS(35),
    [anon_sym_map] = ACTIONS(37),
    [anon_sym_chan] = ACTIONS(39),
    [anon_sym_LT_DASH] = ACTIONS(41),
    [anon_sym_fallthrough] = ACTIONS(43),
    [anon_sym_break] = ACTIONS(45),
    [anon_sym_continue] = ACTIONS(47),
    [anon_sym_goto] = ACTIONS(49),
    [anon_sym_return] = ACTIONS(51),
    [anon_sym_go] = ACTIONS(53),
    [anon_sym_defer] = ACTIONS(55),
    [anon_sym_if] = ACTIONS(57),
    [anon_sym_for] = ACTIONS(59),
    [anon_sym_switch] = ACTIONS(61),
    [anon_sym_select] = ACTIONS(63),
    [anon_sym_new] = ACTIONS(65),
    [anon_sym_make] = ACTIONS(65),
    [anon_sym_PLUS] = ACTIONS(67),
    [anon_sym_DASH] = ACTIONS(67),
    [anon_sym_BANG] = ACTIONS(67),
    [anon_sym_CARET] = ACTIONS(67),
    [anon_sym_AMP] = ACTIONS(67),
    [sym_raw_string_literal] = ACTIONS(69),
    [anon_sym_DQUOTE] = ACTIONS(71),
    [sym_int_literal] = ACTIONS(73),
    [sym_float_literal] = ACTIONS(73),
    [sym_imaginary_literal] = ACTIONS(69),
    [sym_rune_literal] = ACTIONS(69),
    [sym_nil] = ACTIONS(73),
    [sym_true] = ACTIONS(73),
    [sym_false] = ACTIONS(73),
    [sym_iota] = ACTIONS(73),
    [sym_comment] = ACTIONS(3),
  },
  [21] = {
    [sym_expression_list] = STATE(797),
    [sym_parenthesized_type] = STATE(1314),
    [sym__simple_type] = STATE(1314),
    [sym_generic_type] = STATE(1084),
    [sym_pointer_type] = STATE(858),
    [sym_array_type] = STATE(1084),
    [sym_implicit_length_array_type] = STATE(1293),
    [sym_slice_type] = STATE(1084),
    [sym_struct_type] = STATE(1084),
    [sym_negated_type] = STATE(836),
    [sym_interface_type] = STATE(858),
    [sym_map_type] = STATE(1084),
    [sym_channel_type] = STATE(858),
    [sym_function_type] = STATE(858),
    [sym_block] = STATE(956),
    [sym__simple_statement] = STATE(1394),
    [sym_expression_statement] = STATE(1276),
    [sym_send_statement] = STATE(1276),
    [sym_inc_statement] = STATE(1276),
    [sym_dec_statement] = STATE(1276),
    [sym_assignment_statement] = STATE(1276),
    [sym_short_var_declaration] = STATE(1276),
    [sym_for_clause] = STATE(1308),
    [sym_range_clause] = STATE(1308),
    [sym__expression] = STATE(259),
    [sym_parenthesized_expression] = STATE(306),
    [sym_call_expression] = STATE(306),
    [sym_selector_expression] = STATE(306),
    [sym_index_expression] = STATE(306),
    [sym_slice_expression] = STATE(306),
    [sym_type_assertion_expression] = STATE(306),
    [sym_type_conversion_expression] = STATE(306),
    [sym_type_instantiation_expression] = STATE(306),
    [sym_composite_literal] = STATE(306),
    [sym_func_literal] = STATE(306),
    [sym_unary_expression] = STATE(306),
    [sym_binary_expression] = STATE(306),
    [sym_qualified_type] = STATE(1018),
    [sym_interpreted_string_literal] = STATE(306),
    [sym_identifier] = ACTIONS(231),
    [anon_sym_SEMI] = ACTIONS(233),
    [anon_sym_LPAREN] = ACTIONS(235),
    [anon_sym_func] = ACTIONS(237),
    [anon_sym_LBRACK] = ACTIONS(23),
    [anon_sym_STAR] = ACTIONS(239),
    [anon_sym_struct] = ACTIONS(29),
    [anon_sym_TILDE] = ACTIONS(31),
    [anon_sym_LBRACE] = ACTIONS(33),
    [anon_sym_interface] = ACTIONS(35),
    [anon_sym_map] = ACTIONS(37),
    [anon_sym_chan] = ACTIONS(39),
    [anon_sym_LT_DASH] = ACTIONS(241),
    [anon_sym_range] = ACTIONS(243),
    [anon_sym_new] = ACTIONS(245),
    [anon_sym_make] = ACTIONS(245),
    [anon_sym_PLUS] = ACTIONS(247),
    [anon_sym_DASH] = ACTIONS(247),
    [anon_sym_BANG] = ACTIONS(247),
    [anon_sym_CARET] = ACTIONS(247),
    [anon_sym_AMP] = ACTIONS(247),
    [sym_raw_string_literal] = ACTIONS(249),
    [anon_sym_DQUOTE] = ACTIONS(251),
    [sym_int_literal] = ACTIONS(253),
    [sym_float_literal] = ACTIONS(253),
    [sym_imaginary_literal] = ACTIONS(249),
    [sym_rune_literal] = ACTIONS(249),
    [sym_nil] = ACTIONS(253),
    [sym_true] = ACTIONS(253),
    [sym_false] = ACTIONS(253),
    [sym_iota] = ACTIONS(253),
    [sym_comment] = ACTIONS(3),
  },
  [22] = {
    [sym_expression_list] = STATE(798),
    [sym_parenthesized_type] = STATE(1314),
    [sym__simple_type] = STATE(1314),
    [sym_generic_type] = STATE(1084),
    [sym_pointer_type] = STATE(858),
    [sym_array_type] = STATE(1084),
    [sym_implicit_length_array_type] = STATE(1293),
    [sym_slice_type] = STATE(1084),
    [sym_struct_type] = STATE(1084),
    [sym_negated_type] = STATE(836),
    [sym_interface_type] = STATE(858),
    [sym_map_type] = STATE(1084),
    [sym_channel_type] = STATE(858),
    [sym_function_type] = STATE(858),
    [sym__simple_statement] = STATE(1386),
    [sym_expression_statement] = STATE(1276),
    [sym_send_statement] = STATE(1276),
    [sym_inc_statement] = STATE(1276),
    [sym_dec_statement] = STATE(1276),
    [sym_assignment_statement] = STATE(1276),
    [sym_short_var_declaration] = STATE(1276),
    [sym__type_switch_header] = STATE(1402),
    [sym__expression] = STATE(289),
    [sym_parenthesized_expression] = STATE(306),
    [sym_call_expression] = STATE(306),
    [sym_selector_expression] = STATE(306),
    [sym_index_expression] = STATE(306),
    [sym_slice_expression] = STATE(306),
    [sym_type_assertion_expression] = STATE(306),
    [sym_type_conversion_expression] = STATE(306),
    [sym_type_instantiation_expression] = STATE(306),
    [sym_composite_literal] = STATE(306),
    [sym_func_literal] = STATE(306),
    [sym_unary_expression] = STATE(306),
    [sym_binary_expression] = STATE(306),
    [sym_qualified_type] = STATE(1018),
    [sym_interpreted_string_literal] = STATE(306),
    [sym_identifier] = ACTIONS(231),
    [anon_sym_LPAREN] = ACTIONS(235),
    [anon_sym_func] = ACTIONS(237),
    [anon_sym_LBRACK] = ACTIONS(23),
    [anon_sym_STAR] = ACTIONS(239),
    [anon_sym_struct] = ACTIONS(29),
    [anon_sym_TILDE] = ACTIONS(31),
    [anon_sym_LBRACE] = ACTIONS(255),
    [anon_sym_interface] = ACTIONS(35),
    [anon_sym_map] = ACTIONS(37),
    [anon_sym_chan] = ACTIONS(39),
    [anon_sym_LT_DASH] = ACTIONS(241),
    [anon_sym_new] = ACTIONS(245),
    [anon_sym_make] = ACTIONS(245),
    [anon_sym_PLUS] = ACTIONS(247),
    [anon_sym_DASH] = ACTIONS(247),
    [anon_sym_BANG] = ACTIONS(247),
    [anon_sym_CARET] = ACTIONS(247),
    [anon_sym_AMP] = ACTIONS(247),
    [sym_raw_string_literal] = ACTIONS(249),
    [anon_sym_DQUOTE] = ACTIONS(251),
    [sym_int_literal] = ACTIONS(253),
    [sym_float_literal] = ACTIONS(253),
    [sym_imaginary_literal] = ACTIONS(249),
    [sym_rune_literal] = ACTIONS(249),
    [sym_nil] = ACTIONS(253),
    [sym_true] = ACTIONS(253),
    [sym_false] = ACTIONS(253),
    [sym_iota] = ACTIONS(253),
    [sym_comment] = ACTIONS(3),
  },
  [23] = {
    [sym_expression_list] = STATE(795),
    [sym_parenthesized_type] = STATE(1314),
    [sym__simple_type] = STATE(1314),
    [sym_generic_type] = STATE(1084),
    [sym_pointer_type] = STATE(858),
    [sym_array_type] = STATE(1084),
    [sym_implicit_length_array_type] = STATE(1293),
    [sym_slice_type] = STATE(1084),
    [sym_struct_type] = STATE(1084),
    [sym_negated_type] = STATE(836),
    [sym_interface_type] = STATE(858),
    [sym_map_type] = STATE(1084),
    [sym_channel_type] = STATE(858),
    [sym_function_type] = STATE(858),
    [sym__simple_statement] = STATE(1341),
    [sym_expression_statement] = STATE(1276),
    [sym_send_statement] = STATE(1276),
    [sym_inc_statement] = STATE(1276),
    [sym_dec_statement] = STATE(1276),
    [sym_assignment_statement] = STATE(1276),
    [sym_short_var_declaration] = STATE(1276),
    [sym__expression] = STATE(291),
    [sym_parenthesized_expression] = STATE(306),
    [sym_call_expression] = STATE(306),
    [sym_selector_expression] = STATE(306),
    [sym_index_expression] = STATE(306),
    [sym_slice_expression] = STATE(306),
    [sym_type_assertion_expression] = STATE(306),
    [sym_type_conversion_expression] = STATE(306),
    [sym_type_instantiation_expression] = STATE(306),
    [sym_composite_literal] = STATE(306),
    [sym_func_literal] = STATE(306),
    [sym_unary_expression] = STATE(306),
    [sym_binary_expression] = STATE(306),
    [sym_qualified_type] = STATE(1018),
    [sym_interpreted_string_literal] = STATE(306),
    [sym_identifier] = ACTIONS(231),
    [anon_sym_LPAREN] = ACTIONS(235),
    [anon_sym_func] = ACTIONS(237),
    [anon_sym_LBRACK] = ACTIONS(23),
    [anon_sym_STAR] = ACTIONS(239),
    [anon_sym_struct] = ACTIONS(29),
    [anon_sym_TILDE] = ACTIONS(31),
    [anon_sym_LBRACE] = ACTIONS(257),
    [anon_sym_interface] = ACTIONS(35),
    [anon_sym_map] = ACTIONS(37),
    [anon_sym_chan] = ACTIONS(39),
    [anon_sym_LT_DASH] = ACTIONS(241),
    [anon_sym_new] = ACTIONS(245),
    [anon_sym_make] = ACTIONS(245),
    [anon_sym_PLUS] = ACTIONS(247),
    [anon_sym_DASH] = ACTIONS(247),
    [anon_sym_BANG] = ACTIONS(247),
    [anon_sym_CARET] = ACTIONS(247),
    [anon_sym_AMP] = ACTIONS(247),
    [sym_raw_string_literal] = ACTIONS(249),
    [anon_sym_DQUOTE] = ACTIONS(251),
    [sym_int_literal] = ACTIONS(253),
    [sym_float_literal] = ACTIONS(253),
    [sym_imaginary_literal] = ACTIONS(249),
    [sym_rune_literal] = ACTIONS(249),
    [sym_nil] = ACTIONS(253),
    [sym_true] = ACTIONS(253),
    [sym_false] = ACTIONS(253),
    [sym_iota] = ACTIONS(253),
    [sym_comment] = ACTIONS(3),
  },
  [24] = {
    [sym_expression_list] = STATE(795),
    [sym_parenthesized_type] = STATE(1314),
    [sym__simple_type] = STATE(1314),
    [sym_generic_type] = STATE(1084),
    [sym_pointer_type] = STATE(858),
    [sym_array_type] = STATE(1084),
    [sym_implicit_length_array_type] = STATE(1293),
    [sym_slice_type] = STATE(1084),
    [sym_struct_type] = STATE(1084),
    [sym_negated_type] = STATE(836),
    [sym_interface_type] = STATE(858),
    [sym_map_type] = STATE(1084),
    [sym_channel_type] = STATE(858),
    [sym_function_type] = STATE(858),
    [sym__simple_statement] = STATE(1358),
    [sym_expression_statement] = STATE(1276),
    [sym_send_statement] = STATE(1276),
    [sym_inc_statement] = STATE(1276),
    [sym_dec_statement] = STATE(1276),
    [sym_assignment_statement] = STATE(1276),
    [sym_short_var_declaration] = STATE(1276),
    [sym__expression] = STATE(291),
    [sym_parenthesized_expression] = STATE(306),
    [sym_call_expression] = STATE(306),
    [sym_selector_expression] = STATE(306),
    [sym_index_expression] = STATE(306),
    [sym_slice_expression] = STATE(306),
    [sym_type_assertion_expression] = STATE(306),
    [sym_type_conversion_expression] = STATE(306),
    [sym_type_instantiation_expression] = STATE(306),
    [sym_composite_literal] = STATE(306),
    [sym_func_literal] = STATE(306),
    [sym_unary_expression] = STATE(306),
    [sym_binary_expression] = STATE(306),
    [sym_qualified_type] = STATE(1018),
    [sym_interpreted_string_literal] = STATE(306),
    [sym_identifier] = ACTIONS(231),
    [anon_sym_LPAREN] = ACTIONS(235),
    [anon_sym_func] = ACTIONS(237),
    [anon_sym_LBRACK] = ACTIONS(23),
    [anon_sym_STAR] = ACTIONS(239),
    [anon_sym_struct] = ACTIONS(29),
    [anon_sym_TILDE] = ACTIONS(31),
    [anon_sym_LBRACE] = ACTIONS(259),
    [anon_sym_interface] = ACTIONS(35),
    [anon_sym_map] = ACTIONS(37),
    [anon_sym_chan] = ACTIONS(39),
    [anon_sym_LT_DASH] = ACTIONS(241),
    [anon_sym_new] = ACTIONS(245),
    [anon_sym_make] = ACTIONS(245),
    [anon_sym_PLUS] = ACTIONS(247),
    [anon_sym_DASH] = ACTIONS(247),
    [anon_sym_BANG] = ACTIONS(247),
    [anon_sym_CARET] = ACTIONS(247),
    [anon_sym_AMP] = ACTIONS(247),
    [sym_raw_string_literal] = ACTIONS(249),
    [anon_sym_DQUOTE] = ACTIONS(251),
    [sym_int_literal] = ACTIONS(253),
    [sym_float_literal] = ACTIONS(253),
    [sym_imaginary_literal] = ACTIONS(249),
    [sym_rune_literal] = ACTIONS(249),
    [sym_nil] = ACTIONS(253),
    [sym_true] = ACTIONS(253),
    [sym_false] = ACTIONS(253),
    [sym_iota] = ACTIONS(253),
    [sym_comment] = ACTIONS(3),
  },
  [25] = {
    [sym_expression_list] = STATE(795),
    [sym_parenthesized_type] = STATE(1314),
    [sym__simple_type] = STATE(1314),
    [sym_generic_type] = STATE(1084),
    [sym_pointer_type] = STATE(858),
    [sym_array_type] = STATE(1084),
    [sym_implicit_length_array_type] = STATE(1293),
    [sym_slice_type] = STATE(1084),
    [sym_struct_type] = STATE(1084),
    [sym_negated_type] = STATE(836),
    [sym_interface_type] = STATE(858),
    [sym_map_type] = STATE(1084),
    [sym_channel_type] = STATE(858),
    [sym_function_type] = STATE(858),
    [sym__simple_statement] = STATE(1373),
    [sym_expression_statement] = STATE(1276),
    [sym_send_statement] = STATE(1276),
    [sym_inc_statement] = STATE(1276),
    [sym_dec_statement] = STATE(1276),
    [sym_assignment_statement] = STATE(1276),
    [sym_short_var_declaration] = STATE(1276),
    [sym__expression] = STATE(291),
    [sym_parenthesized_expression] = STATE(306),
    [sym_call_expression] = STATE(306),
    [sym_selector_expression] = STATE(306),
    [sym_index_expression] = STATE(306),
    [sym_slice_expression] = STATE(306),
    [sym_type_assertion_expression] = STATE(306),
    [sym_type_conversion_expression] = STATE(306),
    [sym_type_instantiation_expression] = STATE(306),
    [sym_composite_literal] = STATE(306),
    [sym_func_literal] = STATE(306),
    [sym_unary_expression] = STATE(306),
    [sym_binary_expression] = STATE(306),
    [sym_qualified_type] = STATE(1018),
    [sym_interpreted_string_literal] = STATE(306),
    [sym_identifier] = ACTIONS(231),
    [anon_sym_LPAREN] = ACTIONS(235),
    [anon_sym_func] = ACTIONS(237),
    [anon_sym_LBRACK] = ACTIONS(23),
    [anon_sym_STAR] = ACTIONS(239),
    [anon_sym_struct] = ACTIONS(29),
    [anon_sym_TILDE] = ACTIONS(31),
    [anon_sym_LBRACE] = ACTIONS(261),
    [anon_sym_interface] = ACTIONS(35),
    [anon_sym_map] = ACTIONS(37),
    [anon_sym_chan] = ACTIONS(39),
    [anon_sym_LT_DASH] = ACTIONS(241),
    [anon_sym_new] = ACTIONS(245),
    [anon_sym_make] = ACTIONS(245),
    [anon_sym_PLUS] = ACTIONS(247),
    [anon_sym_DASH] = ACTIONS(247),
    [anon_sym_BANG] = ACTIONS(247),
    [anon_sym_CARET] = ACTIONS(247),
    [anon_sym_AMP] = ACTIONS(247),
    [sym_raw_string_literal] = ACTIONS(249),
    [anon_sym_DQUOTE] = ACTIONS(251),
    [sym_int_literal] = ACTIONS(253),
    [sym_float_literal] = ACTIONS(253),
    [sym_imaginary_literal] = ACTIONS(249),
    [sym_rune_literal] = ACTIONS(249),
    [sym_nil] = ACTIONS(253),
    [sym_true] = ACTIONS(253),
    [sym_false] = ACTIONS(253),
    [sym_iota] = ACTIONS(253),
    [sym_comment] = ACTIONS(3),
  },
  [26] = {
    [sym_expression_list] = STATE(795),
    [sym_parenthesized_type] = STATE(1314),
    [sym__simple_type] = STATE(1314),
    [sym_generic_type] = STATE(1084),
    [sym_pointer_type] = STATE(858),
    [sym_array_type] = STATE(1084),
    [sym_implicit_length_array_type] = STATE(1293),
    [sym_slice_type] = STATE(1084),
    [sym_struct_type] = STATE(1084),
    [sym_negated_type] = STATE(836),
    [sym_interface_type] = STATE(858),
    [sym_map_type] = STATE(1084),
    [sym_channel_type] = STATE(858),
    [sym_function_type] = STATE(858),
    [sym__simple_statement] = STATE(1351),
    [sym_expression_statement] = STATE(1276),
    [sym_send_statement] = STATE(1276),
    [sym_inc_statement] = STATE(1276),
    [sym_dec_statement] = STATE(1276),
    [sym_assignment_statement] = STATE(1276),
    [sym_short_var_declaration] = STATE(1276),
    [sym__expression] = STATE(291),
    [sym_parenthesized_expression] = STATE(306),
    [sym_call_expression] = STATE(306),
    [sym_selector_expression] = STATE(306),
    [sym_index_expression] = STATE(306),
    [sym_slice_expression] = STATE(306),
    [sym_type_assertion_expression] = STATE(306),
    [sym_type_conversion_expression] = STATE(306),
    [sym_type_instantiation_expression] = STATE(306),
    [sym_composite_literal] = STATE(306),
    [sym_func_literal] = STATE(306),
    [sym_unary_expression] = STATE(306),
    [sym_binary_expression] = STATE(306),
    [sym_qualified_type] = STATE(1018),
    [sym_interpreted_string_literal] = STATE(306),
    [sym_identifier] = ACTIONS(231),
    [anon_sym_LPAREN] = ACTIONS(235),
    [anon_sym_func] = ACTIONS(237),
    [anon_sym_LBRACK] = ACTIONS(23),
    [anon_sym_STAR] = ACTIONS(239),
    [anon_sym_struct] = ACTIONS(29),
    [anon_sym_TILDE] = ACTIONS(31),
    [anon_sym_LBRACE] = ACTIONS(263),
    [anon_sym_interface] = ACTIONS(35),
    [anon_sym_map] = ACTIONS(37),
    [anon_sym_chan] = ACTIONS(39),
    [anon_sym_LT_DASH] = ACTIONS(241),
    [anon_sym_new] = ACTIONS(245),
    [anon_sym_make] = ACTIONS(245),
    [anon_sym_PLUS] = ACTIONS(247),
    [anon_sym_DASH] = ACTIONS(247),
    [anon_sym_BANG] = ACTIONS(247),
    [anon_sym_CARET] = ACTIONS(247),
    [anon_sym_AMP] = ACTIONS(247),
    [sym_raw_string_literal] = ACTIONS(249),
    [anon_sym_DQUOTE] = ACTIONS(251),
    [sym_int_literal] = ACTIONS(253),
    [sym_float_literal] = ACTIONS(253),
    [sym_imaginary_literal] = ACTIONS(249),
    [sym_rune_literal] = ACTIONS(249),
    [sym_nil] = ACTIONS(253),
    [sym_true] = ACTIONS(253),
    [sym_false] = ACTIONS(253),
    [sym_iota] = ACTIONS(253),
    [sym_comment] = ACTIONS(3),
  },
  [27] = {
    [sym_expression_list] = STATE(800),
    [sym_parenthesized_type] = STATE(1314),
    [sym__simple_type] = STATE(1314),
    [sym_generic_type] = STATE(1084),
    [sym_pointer_type] = STATE(858),
    [sym_array_type] = STATE(1084),
    [sym_implicit_length_array_type] = STATE(1293),
    [sym_slice_type] = STATE(1084),
    [sym_struct_type] = STATE(1084),
    [sym_negated_type] = STATE(836),
    [sym_interface_type] = STATE(858),
    [sym_map_type] = STATE(1084),
    [sym_channel_type] = STATE(858),
    [sym_function_type] = STATE(858),
    [sym__simple_statement] = STATE(1360),
    [sym_expression_statement] = STATE(1276),
    [sym_send_statement] = STATE(1276),
    [sym_inc_statement] = STATE(1276),
    [sym_dec_statement] = STATE(1276),
    [sym_assignment_statement] = STATE(1276),
    [sym_short_var_declaration] = STATE(1276),
    [sym__expression] = STATE(255),
    [sym_parenthesized_expression] = STATE(306),
    [sym_call_expression] = STATE(306),
    [sym_selector_expression] = STATE(306),
    [sym_index_expression] = STATE(306),
    [sym_slice_expression] = STATE(306),
    [sym_type_assertion_expression] = STATE(306),
    [sym_type_conversion_expression] = STATE(306),
    [sym_type_instantiation_expression] = STATE(306),
    [sym_composite_literal] = STATE(306),
    [sym_func_literal] = STATE(306),
    [sym_unary_expression] = STATE(306),
    [sym_binary_expression] = STATE(306),
    [sym_qualified_type] = STATE(1018),
    [sym_interpreted_string_literal] = STATE(306),
    [sym_identifier] = ACTIONS(231),
    [anon_sym_LPAREN] = ACTIONS(235),
    [anon_sym_func] = ACTIONS(237),
    [anon_sym_LBRACK] = ACTIONS(23),
    [anon_sym_STAR] = ACTIONS(239),
    [anon_sym_struct] = ACTIONS(29),
    [anon_sym_TILDE] = ACTIONS(31),
    [anon_sym_interface] = ACTIONS(35),
    [anon_sym_map] = ACTIONS(37),
    [anon_sym_chan] = ACTIONS(39),
    [anon_sym_LT_DASH] = ACTIONS(241),
    [anon_sym_new] = ACTIONS(245),
    [anon_sym_make] = ACTIONS(245),
    [anon_sym_PLUS] = ACTIONS(247),
    [anon_sym_DASH] = ACTIONS(247),
    [anon_sym_BANG] = ACTIONS(247),
    [anon_sym_CARET] = ACTIONS(247),
    [anon_sym_AMP] = ACTIONS(247),
    [sym_raw_string_literal] = ACTIONS(249),
    [anon_sym_DQUOTE] = ACTIONS(251),
    [sym_int_literal] = ACTIONS(253),
    [sym_float_literal] = ACTIONS(253),
    [sym_imaginary_literal] = ACTIONS(249),
    [sym_rune_literal] = ACTIONS(249),
    [sym_nil] = ACTIONS(253),
    [sym_true] = ACTIONS(253),
    [sym_false] = ACTIONS(253),
    [sym_iota] = ACTIONS(253),
    [sym_comment] = ACTIONS(3),
  },
};

static const uint16_t ts_small_parse_table[] = {
  [0] = 27,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(265), 1,
      sym_identifier,
    ACTIONS(267), 1,
      aux_sym_source_file_token1,
    ACTIONS(271), 1,
      anon_sym_LPAREN,
    ACTIONS(273), 1,
      anon_sym_func,
    ACTIONS(275), 1,
      anon_sym_LBRACK,
    ACTIONS(277), 1,
      anon_sym_STAR,
    ACTIONS(279), 1,
      anon_sym_TILDE,
    ACTIONS(281), 1,
      anon_sym_LT_DASH,
    ACTIONS(289), 1,
      anon_sym_DQUOTE,
    ACTIONS(291), 1,
      sym_comment,
    STATE(395), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(1013), 1,
      sym_expression_list,
    STATE(1041), 1,
      sym_qualified_type,
    STATE(1292), 1,
      sym_implicit_length_array_type,
    ACTIONS(283), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(1312), 2,
      sym_parenthesized_type,
      sym__simple_type,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(269), 5,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
    ACTIONS(285), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(1068), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(287), 9,
      sym_raw_string_literal,
      sym_int_literal,
      sym_float_literal,
      sym_imaginary_literal,
      sym_rune_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(502), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [119] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(293), 1,
      sym_identifier,
    ACTIONS(295), 1,
      anon_sym_LPAREN,
    ACTIONS(297), 1,
      anon_sym_COMMA,
    ACTIONS(299), 1,
      anon_sym_func,
    ACTIONS(301), 1,
      anon_sym_STAR,
    ACTIONS(303), 1,
      anon_sym_LBRACE,
    ACTIONS(305), 1,
      anon_sym_RBRACE,
    ACTIONS(307), 1,
      anon_sym_LT_DASH,
    ACTIONS(315), 1,
      anon_sym_DQUOTE,
    STATE(565), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(855), 1,
      sym_qualified_type,
    STATE(1100), 1,
      sym_literal_element,
    STATE(1178), 1,
      sym_keyed_element,
    STATE(1237), 1,
      sym_literal_value,
    STATE(1268), 1,
      sym_implicit_length_array_type,
    ACTIONS(309), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(1311), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(313), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(311), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(894), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(317), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(394), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [245] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(293), 1,
      sym_identifier,
    ACTIONS(295), 1,
      anon_sym_LPAREN,
    ACTIONS(299), 1,
      anon_sym_func,
    ACTIONS(301), 1,
      anon_sym_STAR,
    ACTIONS(303), 1,
      anon_sym_LBRACE,
    ACTIONS(307), 1,
      anon_sym_LT_DASH,
    ACTIONS(315), 1,
      anon_sym_DQUOTE,
    ACTIONS(319), 1,
      anon_sym_COMMA,
    ACTIONS(321), 1,
      anon_sym_RBRACE,
    STATE(565), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(855), 1,
      sym_qualified_type,
    STATE(1073), 1,
      sym_literal_element,
    STATE(1233), 1,
      sym_keyed_element,
    STATE(1237), 1,
      sym_literal_value,
    STATE(1268), 1,
      sym_implicit_length_array_type,
    ACTIONS(309), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(1311), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(313), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(311), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(894), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(317), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(394), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [371] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(293), 1,
      sym_identifier,
    ACTIONS(295), 1,
      anon_sym_LPAREN,
    ACTIONS(299), 1,
      anon_sym_func,
    ACTIONS(301), 1,
      anon_sym_STAR,
    ACTIONS(303), 1,
      anon_sym_LBRACE,
    ACTIONS(307), 1,
      anon_sym_LT_DASH,
    ACTIONS(315), 1,
      anon_sym_DQUOTE,
    ACTIONS(323), 1,
      anon_sym_COMMA,
    ACTIONS(325), 1,
      anon_sym_RBRACE,
    STATE(565), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(855), 1,
      sym_qualified_type,
    STATE(1087), 1,
      sym_literal_element,
    STATE(1161), 1,
      sym_keyed_element,
    STATE(1237), 1,
      sym_literal_value,
    STATE(1268), 1,
      sym_implicit_length_array_type,
    ACTIONS(309), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(1311), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(313), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(311), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(894), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(317), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(394), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [497] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(293), 1,
      sym_identifier,
    ACTIONS(295), 1,
      anon_sym_LPAREN,
    ACTIONS(299), 1,
      anon_sym_func,
    ACTIONS(301), 1,
      anon_sym_STAR,
    ACTIONS(303), 1,
      anon_sym_LBRACE,
    ACTIONS(307), 1,
      anon_sym_LT_DASH,
    ACTIONS(315), 1,
      anon_sym_DQUOTE,
    ACTIONS(327), 1,
      anon_sym_COMMA,
    ACTIONS(329), 1,
      anon_sym_RBRACE,
    STATE(565), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(855), 1,
      sym_qualified_type,
    STATE(1052), 1,
      sym_literal_element,
    STATE(1192), 1,
      sym_keyed_element,
    STATE(1237), 1,
      sym_literal_value,
    STATE(1268), 1,
      sym_implicit_length_array_type,
    ACTIONS(309), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(1311), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(313), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(311), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(894), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(317), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(394), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [623] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(293), 1,
      sym_identifier,
    ACTIONS(295), 1,
      anon_sym_LPAREN,
    ACTIONS(299), 1,
      anon_sym_func,
    ACTIONS(301), 1,
      anon_sym_STAR,
    ACTIONS(303), 1,
      anon_sym_LBRACE,
    ACTIONS(307), 1,
      anon_sym_LT_DASH,
    ACTIONS(315), 1,
      anon_sym_DQUOTE,
    ACTIONS(331), 1,
      anon_sym_COMMA,
    ACTIONS(333), 1,
      anon_sym_RBRACE,
    STATE(565), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(855), 1,
      sym_qualified_type,
    STATE(1114), 1,
      sym_literal_element,
    STATE(1195), 1,
      sym_keyed_element,
    STATE(1237), 1,
      sym_literal_value,
    STATE(1268), 1,
      sym_implicit_length_array_type,
    ACTIONS(309), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(1311), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(313), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(311), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(894), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(317), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(394), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [749] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(293), 1,
      sym_identifier,
    ACTIONS(295), 1,
      anon_sym_LPAREN,
    ACTIONS(299), 1,
      anon_sym_func,
    ACTIONS(301), 1,
      anon_sym_STAR,
    ACTIONS(303), 1,
      anon_sym_LBRACE,
    ACTIONS(307), 1,
      anon_sym_LT_DASH,
    ACTIONS(315), 1,
      anon_sym_DQUOTE,
    ACTIONS(335), 1,
      anon_sym_COMMA,
    ACTIONS(337), 1,
      anon_sym_RBRACE,
    STATE(565), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(855), 1,
      sym_qualified_type,
    STATE(1120), 1,
      sym_literal_element,
    STATE(1217), 1,
      sym_keyed_element,
    STATE(1237), 1,
      sym_literal_value,
    STATE(1268), 1,
      sym_implicit_length_array_type,
    ACTIONS(309), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(1311), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(313), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(311), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(894), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(317), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(394), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [875] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(293), 1,
      sym_identifier,
    ACTIONS(295), 1,
      anon_sym_LPAREN,
    ACTIONS(299), 1,
      anon_sym_func,
    ACTIONS(301), 1,
      anon_sym_STAR,
    ACTIONS(303), 1,
      anon_sym_LBRACE,
    ACTIONS(307), 1,
      anon_sym_LT_DASH,
    ACTIONS(315), 1,
      anon_sym_DQUOTE,
    ACTIONS(339), 1,
      anon_sym_RBRACE,
    STATE(565), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(855), 1,
      sym_qualified_type,
    STATE(1187), 1,
      sym_literal_element,
    STATE(1237), 1,
      sym_literal_value,
    STATE(1263), 1,
      sym_keyed_element,
    STATE(1268), 1,
      sym_implicit_length_array_type,
    ACTIONS(309), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(1311), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(313), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(311), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(894), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(317), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(394), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [998] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(293), 1,
      sym_identifier,
    ACTIONS(295), 1,
      anon_sym_LPAREN,
    ACTIONS(299), 1,
      anon_sym_func,
    ACTIONS(301), 1,
      anon_sym_STAR,
    ACTIONS(303), 1,
      anon_sym_LBRACE,
    ACTIONS(307), 1,
      anon_sym_LT_DASH,
    ACTIONS(315), 1,
      anon_sym_DQUOTE,
    ACTIONS(341), 1,
      anon_sym_RBRACE,
    STATE(565), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(855), 1,
      sym_qualified_type,
    STATE(1187), 1,
      sym_literal_element,
    STATE(1237), 1,
      sym_literal_value,
    STATE(1263), 1,
      sym_keyed_element,
    STATE(1268), 1,
      sym_implicit_length_array_type,
    ACTIONS(309), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(1311), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(313), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(311), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(894), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(317), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(394), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [1121] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(293), 1,
      sym_identifier,
    ACTIONS(295), 1,
      anon_sym_LPAREN,
    ACTIONS(299), 1,
      anon_sym_func,
    ACTIONS(301), 1,
      anon_sym_STAR,
    ACTIONS(303), 1,
      anon_sym_LBRACE,
    ACTIONS(307), 1,
      anon_sym_LT_DASH,
    ACTIONS(315), 1,
      anon_sym_DQUOTE,
    ACTIONS(343), 1,
      anon_sym_RBRACE,
    STATE(565), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(855), 1,
      sym_qualified_type,
    STATE(1187), 1,
      sym_literal_element,
    STATE(1237), 1,
      sym_literal_value,
    STATE(1263), 1,
      sym_keyed_element,
    STATE(1268), 1,
      sym_implicit_length_array_type,
    ACTIONS(309), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(1311), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(313), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(311), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(894), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(317), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(394), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [1244] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(293), 1,
      sym_identifier,
    ACTIONS(295), 1,
      anon_sym_LPAREN,
    ACTIONS(299), 1,
      anon_sym_func,
    ACTIONS(301), 1,
      anon_sym_STAR,
    ACTIONS(303), 1,
      anon_sym_LBRACE,
    ACTIONS(307), 1,
      anon_sym_LT_DASH,
    ACTIONS(315), 1,
      anon_sym_DQUOTE,
    ACTIONS(345), 1,
      anon_sym_RBRACE,
    STATE(565), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(855), 1,
      sym_qualified_type,
    STATE(1187), 1,
      sym_literal_element,
    STATE(1237), 1,
      sym_literal_value,
    STATE(1263), 1,
      sym_keyed_element,
    STATE(1268), 1,
      sym_implicit_length_array_type,
    ACTIONS(309), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(1311), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(313), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(311), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(894), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(317), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(394), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [1367] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(293), 1,
      sym_identifier,
    ACTIONS(295), 1,
      anon_sym_LPAREN,
    ACTIONS(299), 1,
      anon_sym_func,
    ACTIONS(301), 1,
      anon_sym_STAR,
    ACTIONS(303), 1,
      anon_sym_LBRACE,
    ACTIONS(307), 1,
      anon_sym_LT_DASH,
    ACTIONS(315), 1,
      anon_sym_DQUOTE,
    ACTIONS(347), 1,
      anon_sym_RBRACE,
    STATE(565), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(855), 1,
      sym_qualified_type,
    STATE(1187), 1,
      sym_literal_element,
    STATE(1237), 1,
      sym_literal_value,
    STATE(1263), 1,
      sym_keyed_element,
    STATE(1268), 1,
      sym_implicit_length_array_type,
    ACTIONS(309), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(1311), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(313), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(311), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(894), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(317), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(394), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [1490] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(293), 1,
      sym_identifier,
    ACTIONS(295), 1,
      anon_sym_LPAREN,
    ACTIONS(299), 1,
      anon_sym_func,
    ACTIONS(301), 1,
      anon_sym_STAR,
    ACTIONS(303), 1,
      anon_sym_LBRACE,
    ACTIONS(307), 1,
      anon_sym_LT_DASH,
    ACTIONS(315), 1,
      anon_sym_DQUOTE,
    ACTIONS(349), 1,
      anon_sym_RBRACE,
    STATE(565), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(855), 1,
      sym_qualified_type,
    STATE(1187), 1,
      sym_literal_element,
    STATE(1237), 1,
      sym_literal_value,
    STATE(1263), 1,
      sym_keyed_element,
    STATE(1268), 1,
      sym_implicit_length_array_type,
    ACTIONS(309), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(1311), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(313), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(311), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(894), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(317), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(394), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [1613] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(293), 1,
      sym_identifier,
    ACTIONS(295), 1,
      anon_sym_LPAREN,
    ACTIONS(299), 1,
      anon_sym_func,
    ACTIONS(301), 1,
      anon_sym_STAR,
    ACTIONS(303), 1,
      anon_sym_LBRACE,
    ACTIONS(307), 1,
      anon_sym_LT_DASH,
    ACTIONS(315), 1,
      anon_sym_DQUOTE,
    ACTIONS(351), 1,
      anon_sym_RBRACE,
    STATE(565), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(855), 1,
      sym_qualified_type,
    STATE(1187), 1,
      sym_literal_element,
    STATE(1237), 1,
      sym_literal_value,
    STATE(1263), 1,
      sym_keyed_element,
    STATE(1268), 1,
      sym_implicit_length_array_type,
    ACTIONS(309), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(1311), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(313), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(311), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(894), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(317), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(394), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [1736] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(293), 1,
      sym_identifier,
    ACTIONS(295), 1,
      anon_sym_LPAREN,
    ACTIONS(299), 1,
      anon_sym_func,
    ACTIONS(301), 1,
      anon_sym_STAR,
    ACTIONS(303), 1,
      anon_sym_LBRACE,
    ACTIONS(307), 1,
      anon_sym_LT_DASH,
    ACTIONS(315), 1,
      anon_sym_DQUOTE,
    ACTIONS(353), 1,
      anon_sym_RBRACE,
    STATE(565), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(855), 1,
      sym_qualified_type,
    STATE(1187), 1,
      sym_literal_element,
    STATE(1237), 1,
      sym_literal_value,
    STATE(1263), 1,
      sym_keyed_element,
    STATE(1268), 1,
      sym_implicit_length_array_type,
    ACTIONS(309), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(1311), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(313), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(311), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(894), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(317), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(394), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [1859] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(293), 1,
      sym_identifier,
    ACTIONS(295), 1,
      anon_sym_LPAREN,
    ACTIONS(299), 1,
      anon_sym_func,
    ACTIONS(301), 1,
      anon_sym_STAR,
    ACTIONS(303), 1,
      anon_sym_LBRACE,
    ACTIONS(307), 1,
      anon_sym_LT_DASH,
    ACTIONS(315), 1,
      anon_sym_DQUOTE,
    ACTIONS(355), 1,
      anon_sym_RBRACE,
    STATE(565), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(855), 1,
      sym_qualified_type,
    STATE(1187), 1,
      sym_literal_element,
    STATE(1237), 1,
      sym_literal_value,
    STATE(1263), 1,
      sym_keyed_element,
    STATE(1268), 1,
      sym_implicit_length_array_type,
    ACTIONS(309), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(1311), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(313), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(311), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(894), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(317), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(394), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [1982] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(293), 1,
      sym_identifier,
    ACTIONS(295), 1,
      anon_sym_LPAREN,
    ACTIONS(299), 1,
      anon_sym_func,
    ACTIONS(301), 1,
      anon_sym_STAR,
    ACTIONS(303), 1,
      anon_sym_LBRACE,
    ACTIONS(307), 1,
      anon_sym_LT_DASH,
    ACTIONS(315), 1,
      anon_sym_DQUOTE,
    ACTIONS(357), 1,
      anon_sym_RBRACE,
    STATE(565), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(855), 1,
      sym_qualified_type,
    STATE(1187), 1,
      sym_literal_element,
    STATE(1237), 1,
      sym_literal_value,
    STATE(1263), 1,
      sym_keyed_element,
    STATE(1268), 1,
      sym_implicit_length_array_type,
    ACTIONS(309), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(1311), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(313), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(311), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(894), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(317), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(394), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [2105] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(293), 1,
      sym_identifier,
    ACTIONS(295), 1,
      anon_sym_LPAREN,
    ACTIONS(299), 1,
      anon_sym_func,
    ACTIONS(301), 1,
      anon_sym_STAR,
    ACTIONS(303), 1,
      anon_sym_LBRACE,
    ACTIONS(307), 1,
      anon_sym_LT_DASH,
    ACTIONS(315), 1,
      anon_sym_DQUOTE,
    ACTIONS(359), 1,
      anon_sym_RBRACE,
    STATE(565), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(855), 1,
      sym_qualified_type,
    STATE(1187), 1,
      sym_literal_element,
    STATE(1237), 1,
      sym_literal_value,
    STATE(1263), 1,
      sym_keyed_element,
    STATE(1268), 1,
      sym_implicit_length_array_type,
    ACTIONS(309), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(1311), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(313), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(311), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(894), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(317), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(394), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [2228] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(293), 1,
      sym_identifier,
    ACTIONS(295), 1,
      anon_sym_LPAREN,
    ACTIONS(299), 1,
      anon_sym_func,
    ACTIONS(301), 1,
      anon_sym_STAR,
    ACTIONS(303), 1,
      anon_sym_LBRACE,
    ACTIONS(307), 1,
      anon_sym_LT_DASH,
    ACTIONS(315), 1,
      anon_sym_DQUOTE,
    ACTIONS(361), 1,
      anon_sym_RBRACE,
    STATE(565), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(855), 1,
      sym_qualified_type,
    STATE(1187), 1,
      sym_literal_element,
    STATE(1237), 1,
      sym_literal_value,
    STATE(1263), 1,
      sym_keyed_element,
    STATE(1268), 1,
      sym_implicit_length_array_type,
    ACTIONS(309), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(1311), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(313), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(311), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(894), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(317), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(394), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [2351] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(293), 1,
      sym_identifier,
    ACTIONS(295), 1,
      anon_sym_LPAREN,
    ACTIONS(299), 1,
      anon_sym_func,
    ACTIONS(301), 1,
      anon_sym_STAR,
    ACTIONS(303), 1,
      anon_sym_LBRACE,
    ACTIONS(307), 1,
      anon_sym_LT_DASH,
    ACTIONS(315), 1,
      anon_sym_DQUOTE,
    STATE(565), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(855), 1,
      sym_qualified_type,
    STATE(1187), 1,
      sym_literal_element,
    STATE(1237), 1,
      sym_literal_value,
    STATE(1263), 1,
      sym_keyed_element,
    STATE(1268), 1,
      sym_implicit_length_array_type,
    ACTIONS(309), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(1311), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(313), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(311), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(894), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(317), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(394), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [2471] = 28,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(293), 1,
      sym_identifier,
    ACTIONS(295), 1,
      anon_sym_LPAREN,
    ACTIONS(299), 1,
      anon_sym_func,
    ACTIONS(301), 1,
      anon_sym_STAR,
    ACTIONS(303), 1,
      anon_sym_LBRACE,
    ACTIONS(307), 1,
      anon_sym_LT_DASH,
    ACTIONS(315), 1,
      anon_sym_DQUOTE,
    STATE(565), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(855), 1,
      sym_qualified_type,
    STATE(1237), 1,
      sym_literal_value,
    STATE(1264), 1,
      sym_literal_element,
    STATE(1268), 1,
      sym_implicit_length_array_type,
    ACTIONS(309), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(1311), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(313), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(311), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(894), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(317), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(394), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [2588] = 27,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(363), 1,
      sym_identifier,
    ACTIONS(365), 1,
      anon_sym_LPAREN,
    ACTIONS(367), 1,
      anon_sym_func,
    ACTIONS(369), 1,
      anon_sym_STAR,
    ACTIONS(371), 1,
      anon_sym_LT_DASH,
    ACTIONS(379), 1,
      anon_sym_DQUOTE,
    STATE(449), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(1022), 1,
      sym_qualified_type,
    STATE(1258), 1,
      sym_implicit_length_array_type,
    STATE(1261), 1,
      sym_expression_list,
    ACTIONS(373), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(1283), 2,
      sym_parenthesized_type,
      sym__simple_type,
    STATE(1349), 2,
      sym_send_statement,
      sym_receive_statement,
    ACTIONS(377), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(375), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(1108), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(381), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(534), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [2703] = 27,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(293), 1,
      sym_identifier,
    ACTIONS(295), 1,
      anon_sym_LPAREN,
    ACTIONS(299), 1,
      anon_sym_func,
    ACTIONS(301), 1,
      anon_sym_STAR,
    ACTIONS(307), 1,
      anon_sym_LT_DASH,
    ACTIONS(315), 1,
      anon_sym_DQUOTE,
    ACTIONS(383), 1,
      anon_sym_RBRACK,
    ACTIONS(385), 1,
      anon_sym_DOT_DOT_DOT,
    STATE(689), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(855), 1,
      sym_qualified_type,
    STATE(1268), 1,
      sym_implicit_length_array_type,
    ACTIONS(309), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(1311), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(313), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(311), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(894), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(317), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(394), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [2817] = 27,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(295), 1,
      anon_sym_LPAREN,
    ACTIONS(299), 1,
      anon_sym_func,
    ACTIONS(307), 1,
      anon_sym_LT_DASH,
    ACTIONS(315), 1,
      anon_sym_DQUOTE,
    ACTIONS(387), 1,
      sym_identifier,
    ACTIONS(389), 1,
      anon_sym_STAR,
    ACTIONS(391), 1,
      anon_sym_COLON,
    STATE(594), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(855), 1,
      sym_qualified_type,
    STATE(1150), 1,
      sym_type_elem,
    STATE(1268), 1,
      sym_implicit_length_array_type,
    ACTIONS(309), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(1004), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(313), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(311), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(894), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(317), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(394), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [2931] = 27,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(295), 1,
      anon_sym_LPAREN,
    ACTIONS(299), 1,
      anon_sym_func,
    ACTIONS(315), 1,
      anon_sym_DQUOTE,
    ACTIONS(393), 1,
      sym_identifier,
    ACTIONS(395), 1,
      anon_sym_RPAREN,
    ACTIONS(397), 1,
      anon_sym_STAR,
    ACTIONS(399), 1,
      anon_sym_LT_DASH,
    STATE(541), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(855), 1,
      sym_qualified_type,
    STATE(1245), 1,
      sym_variadic_argument,
    STATE(1268), 1,
      sym_implicit_length_array_type,
    ACTIONS(309), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(1311), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(313), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(401), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(894), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(317), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(394), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [3045] = 27,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(295), 1,
      anon_sym_LPAREN,
    ACTIONS(299), 1,
      anon_sym_func,
    ACTIONS(315), 1,
      anon_sym_DQUOTE,
    ACTIONS(403), 1,
      sym_identifier,
    ACTIONS(405), 1,
      anon_sym_STAR,
    ACTIONS(407), 1,
      anon_sym_LBRACE,
    ACTIONS(409), 1,
      anon_sym_LT_DASH,
    STATE(513), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(855), 1,
      sym_qualified_type,
    STATE(1268), 1,
      sym_implicit_length_array_type,
    STATE(1396), 1,
      sym_expression_list,
    ACTIONS(309), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(1311), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(313), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(411), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(894), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(317), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(394), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [3159] = 27,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(295), 1,
      anon_sym_LPAREN,
    ACTIONS(299), 1,
      anon_sym_func,
    ACTIONS(315), 1,
      anon_sym_DQUOTE,
    ACTIONS(393), 1,
      sym_identifier,
    ACTIONS(397), 1,
      anon_sym_STAR,
    ACTIONS(399), 1,
      anon_sym_LT_DASH,
    ACTIONS(413), 1,
      anon_sym_RPAREN,
    STATE(527), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(855), 1,
      sym_qualified_type,
    STATE(1174), 1,
      sym_variadic_argument,
    STATE(1268), 1,
      sym_implicit_length_array_type,
    ACTIONS(309), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(1311), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(313), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(401), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(894), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(317), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(394), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [3273] = 27,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(295), 1,
      anon_sym_LPAREN,
    ACTIONS(299), 1,
      anon_sym_func,
    ACTIONS(315), 1,
      anon_sym_DQUOTE,
    ACTIONS(393), 1,
      sym_identifier,
    ACTIONS(397), 1,
      anon_sym_STAR,
    ACTIONS(399), 1,
      anon_sym_LT_DASH,
    ACTIONS(415), 1,
      anon_sym_RPAREN,
    STATE(512), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(855), 1,
      sym_qualified_type,
    STATE(1225), 1,
      sym_variadic_argument,
    STATE(1268), 1,
      sym_implicit_length_array_type,
    ACTIONS(309), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(1311), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(313), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(401), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(894), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(317), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(394), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [3387] = 27,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(295), 1,
      anon_sym_LPAREN,
    ACTIONS(299), 1,
      anon_sym_func,
    ACTIONS(307), 1,
      anon_sym_LT_DASH,
    ACTIONS(315), 1,
      anon_sym_DQUOTE,
    ACTIONS(387), 1,
      sym_identifier,
    ACTIONS(389), 1,
      anon_sym_STAR,
    ACTIONS(417), 1,
      anon_sym_RBRACK,
    STATE(658), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(855), 1,
      sym_qualified_type,
    STATE(1208), 1,
      sym_type_elem,
    STATE(1268), 1,
      sym_implicit_length_array_type,
    ACTIONS(309), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(1004), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(313), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(311), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(894), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(317), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(394), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [3501] = 27,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(295), 1,
      anon_sym_LPAREN,
    ACTIONS(299), 1,
      anon_sym_func,
    ACTIONS(315), 1,
      anon_sym_DQUOTE,
    ACTIONS(393), 1,
      sym_identifier,
    ACTIONS(397), 1,
      anon_sym_STAR,
    ACTIONS(399), 1,
      anon_sym_LT_DASH,
    ACTIONS(419), 1,
      anon_sym_RPAREN,
    STATE(541), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(855), 1,
      sym_qualified_type,
    STATE(1245), 1,
      sym_variadic_argument,
    STATE(1268), 1,
      sym_implicit_length_array_type,
    ACTIONS(309), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(1311), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(313), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(401), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(894), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(317), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(394), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [3615] = 27,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(295), 1,
      anon_sym_LPAREN,
    ACTIONS(299), 1,
      anon_sym_func,
    ACTIONS(315), 1,
      anon_sym_DQUOTE,
    ACTIONS(393), 1,
      sym_identifier,
    ACTIONS(397), 1,
      anon_sym_STAR,
    ACTIONS(399), 1,
      anon_sym_LT_DASH,
    ACTIONS(421), 1,
      anon_sym_RPAREN,
    STATE(541), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(855), 1,
      sym_qualified_type,
    STATE(1245), 1,
      sym_variadic_argument,
    STATE(1268), 1,
      sym_implicit_length_array_type,
    ACTIONS(309), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(1311), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(313), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(401), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(894), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(317), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(394), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [3729] = 27,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(295), 1,
      anon_sym_LPAREN,
    ACTIONS(299), 1,
      anon_sym_func,
    ACTIONS(315), 1,
      anon_sym_DQUOTE,
    ACTIONS(393), 1,
      sym_identifier,
    ACTIONS(397), 1,
      anon_sym_STAR,
    ACTIONS(399), 1,
      anon_sym_LT_DASH,
    ACTIONS(423), 1,
      anon_sym_RPAREN,
    STATE(525), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(855), 1,
      sym_qualified_type,
    STATE(1135), 1,
      sym_variadic_argument,
    STATE(1268), 1,
      sym_implicit_length_array_type,
    ACTIONS(309), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(1311), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(313), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(401), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(894), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(317), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(394), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [3843] = 27,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(295), 1,
      anon_sym_LPAREN,
    ACTIONS(299), 1,
      anon_sym_func,
    ACTIONS(307), 1,
      anon_sym_LT_DASH,
    ACTIONS(315), 1,
      anon_sym_DQUOTE,
    ACTIONS(387), 1,
      sym_identifier,
    ACTIONS(389), 1,
      anon_sym_STAR,
    ACTIONS(425), 1,
      anon_sym_RBRACK,
    STATE(649), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(855), 1,
      sym_qualified_type,
    STATE(1150), 1,
      sym_type_elem,
    STATE(1268), 1,
      sym_implicit_length_array_type,
    ACTIONS(309), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(1004), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(313), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(311), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(894), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(317), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(394), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [3957] = 27,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(295), 1,
      anon_sym_LPAREN,
    ACTIONS(299), 1,
      anon_sym_func,
    ACTIONS(315), 1,
      anon_sym_DQUOTE,
    ACTIONS(393), 1,
      sym_identifier,
    ACTIONS(397), 1,
      anon_sym_STAR,
    ACTIONS(399), 1,
      anon_sym_LT_DASH,
    ACTIONS(427), 1,
      anon_sym_RPAREN,
    STATE(541), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(855), 1,
      sym_qualified_type,
    STATE(1245), 1,
      sym_variadic_argument,
    STATE(1268), 1,
      sym_implicit_length_array_type,
    ACTIONS(309), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(1311), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(313), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(401), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(894), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(317), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(394), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [4071] = 27,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(295), 1,
      anon_sym_LPAREN,
    ACTIONS(299), 1,
      anon_sym_func,
    ACTIONS(307), 1,
      anon_sym_LT_DASH,
    ACTIONS(315), 1,
      anon_sym_DQUOTE,
    ACTIONS(387), 1,
      sym_identifier,
    ACTIONS(389), 1,
      anon_sym_STAR,
    ACTIONS(429), 1,
      anon_sym_COLON,
    STATE(623), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(855), 1,
      sym_qualified_type,
    STATE(1150), 1,
      sym_type_elem,
    STATE(1268), 1,
      sym_implicit_length_array_type,
    ACTIONS(309), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(1004), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(313), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(311), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(894), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(317), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(394), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [4185] = 27,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(295), 1,
      anon_sym_LPAREN,
    ACTIONS(299), 1,
      anon_sym_func,
    ACTIONS(315), 1,
      anon_sym_DQUOTE,
    ACTIONS(393), 1,
      sym_identifier,
    ACTIONS(397), 1,
      anon_sym_STAR,
    ACTIONS(399), 1,
      anon_sym_LT_DASH,
    ACTIONS(431), 1,
      anon_sym_RPAREN,
    STATE(541), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(855), 1,
      sym_qualified_type,
    STATE(1245), 1,
      sym_variadic_argument,
    STATE(1268), 1,
      sym_implicit_length_array_type,
    ACTIONS(309), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(1311), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(313), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(401), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(894), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(317), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(394), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [4299] = 27,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(293), 1,
      sym_identifier,
    ACTIONS(295), 1,
      anon_sym_LPAREN,
    ACTIONS(299), 1,
      anon_sym_func,
    ACTIONS(301), 1,
      anon_sym_STAR,
    ACTIONS(307), 1,
      anon_sym_LT_DASH,
    ACTIONS(315), 1,
      anon_sym_DQUOTE,
    ACTIONS(433), 1,
      anon_sym_range,
    STATE(522), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(855), 1,
      sym_qualified_type,
    STATE(1268), 1,
      sym_implicit_length_array_type,
    STATE(1284), 1,
      sym_expression_list,
    ACTIONS(309), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(1311), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(313), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(311), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(894), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(317), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(394), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [4413] = 27,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(295), 1,
      anon_sym_LPAREN,
    ACTIONS(299), 1,
      anon_sym_func,
    ACTIONS(315), 1,
      anon_sym_DQUOTE,
    ACTIONS(393), 1,
      sym_identifier,
    ACTIONS(397), 1,
      anon_sym_STAR,
    ACTIONS(399), 1,
      anon_sym_LT_DASH,
    ACTIONS(435), 1,
      anon_sym_RPAREN,
    STATE(541), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(855), 1,
      sym_qualified_type,
    STATE(1245), 1,
      sym_variadic_argument,
    STATE(1268), 1,
      sym_implicit_length_array_type,
    ACTIONS(309), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(1311), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(313), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(401), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(894), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(317), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(394), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [4527] = 27,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(295), 1,
      anon_sym_LPAREN,
    ACTIONS(299), 1,
      anon_sym_func,
    ACTIONS(315), 1,
      anon_sym_DQUOTE,
    ACTIONS(393), 1,
      sym_identifier,
    ACTIONS(397), 1,
      anon_sym_STAR,
    ACTIONS(399), 1,
      anon_sym_LT_DASH,
    ACTIONS(437), 1,
      anon_sym_RPAREN,
    STATE(541), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(855), 1,
      sym_qualified_type,
    STATE(1245), 1,
      sym_variadic_argument,
    STATE(1268), 1,
      sym_implicit_length_array_type,
    ACTIONS(309), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(1311), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(313), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(401), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(894), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(317), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(394), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [4641] = 27,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(295), 1,
      anon_sym_LPAREN,
    ACTIONS(299), 1,
      anon_sym_func,
    ACTIONS(301), 1,
      anon_sym_STAR,
    ACTIONS(307), 1,
      anon_sym_LT_DASH,
    ACTIONS(315), 1,
      anon_sym_DQUOTE,
    ACTIONS(417), 1,
      anon_sym_RBRACK,
    ACTIONS(439), 1,
      sym_identifier,
    STATE(658), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(855), 1,
      sym_qualified_type,
    STATE(1159), 1,
      sym_type_parameter_declaration,
    STATE(1268), 1,
      sym_implicit_length_array_type,
    ACTIONS(309), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(1311), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(313), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(311), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(894), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(317), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(394), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [4755] = 27,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(295), 1,
      anon_sym_LPAREN,
    ACTIONS(299), 1,
      anon_sym_func,
    ACTIONS(315), 1,
      anon_sym_DQUOTE,
    ACTIONS(393), 1,
      sym_identifier,
    ACTIONS(397), 1,
      anon_sym_STAR,
    ACTIONS(399), 1,
      anon_sym_LT_DASH,
    ACTIONS(441), 1,
      anon_sym_RPAREN,
    STATE(541), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(855), 1,
      sym_qualified_type,
    STATE(1245), 1,
      sym_variadic_argument,
    STATE(1268), 1,
      sym_implicit_length_array_type,
    ACTIONS(309), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(1311), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(313), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(401), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(894), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(317), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(394), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [4869] = 27,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(295), 1,
      anon_sym_LPAREN,
    ACTIONS(299), 1,
      anon_sym_func,
    ACTIONS(315), 1,
      anon_sym_DQUOTE,
    ACTIONS(393), 1,
      sym_identifier,
    ACTIONS(397), 1,
      anon_sym_STAR,
    ACTIONS(399), 1,
      anon_sym_LT_DASH,
    ACTIONS(443), 1,
      anon_sym_RPAREN,
    STATE(511), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(855), 1,
      sym_qualified_type,
    STATE(1180), 1,
      sym_variadic_argument,
    STATE(1268), 1,
      sym_implicit_length_array_type,
    ACTIONS(309), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(1311), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(313), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(401), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(894), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(317), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(394), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [4983] = 27,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(295), 1,
      anon_sym_LPAREN,
    ACTIONS(299), 1,
      anon_sym_func,
    ACTIONS(315), 1,
      anon_sym_DQUOTE,
    ACTIONS(393), 1,
      sym_identifier,
    ACTIONS(397), 1,
      anon_sym_STAR,
    ACTIONS(399), 1,
      anon_sym_LT_DASH,
    ACTIONS(445), 1,
      anon_sym_RPAREN,
    STATE(541), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(855), 1,
      sym_qualified_type,
    STATE(1245), 1,
      sym_variadic_argument,
    STATE(1268), 1,
      sym_implicit_length_array_type,
    ACTIONS(309), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(1311), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(313), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(401), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(894), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(317), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(394), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [5097] = 27,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(295), 1,
      anon_sym_LPAREN,
    ACTIONS(299), 1,
      anon_sym_func,
    ACTIONS(315), 1,
      anon_sym_DQUOTE,
    ACTIONS(393), 1,
      sym_identifier,
    ACTIONS(397), 1,
      anon_sym_STAR,
    ACTIONS(399), 1,
      anon_sym_LT_DASH,
    ACTIONS(447), 1,
      anon_sym_RPAREN,
    STATE(541), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(855), 1,
      sym_qualified_type,
    STATE(1245), 1,
      sym_variadic_argument,
    STATE(1268), 1,
      sym_implicit_length_array_type,
    ACTIONS(309), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(1311), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(313), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(401), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(894), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(317), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(394), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [5211] = 27,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(295), 1,
      anon_sym_LPAREN,
    ACTIONS(299), 1,
      anon_sym_func,
    ACTIONS(315), 1,
      anon_sym_DQUOTE,
    ACTIONS(393), 1,
      sym_identifier,
    ACTIONS(397), 1,
      anon_sym_STAR,
    ACTIONS(399), 1,
      anon_sym_LT_DASH,
    ACTIONS(449), 1,
      anon_sym_RPAREN,
    STATE(516), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(855), 1,
      sym_qualified_type,
    STATE(1198), 1,
      sym_variadic_argument,
    STATE(1268), 1,
      sym_implicit_length_array_type,
    ACTIONS(309), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(1311), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(313), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(401), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(894), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(317), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(394), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [5325] = 27,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(295), 1,
      anon_sym_LPAREN,
    ACTIONS(299), 1,
      anon_sym_func,
    ACTIONS(315), 1,
      anon_sym_DQUOTE,
    ACTIONS(393), 1,
      sym_identifier,
    ACTIONS(397), 1,
      anon_sym_STAR,
    ACTIONS(399), 1,
      anon_sym_LT_DASH,
    ACTIONS(451), 1,
      anon_sym_RPAREN,
    STATE(541), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(855), 1,
      sym_qualified_type,
    STATE(1245), 1,
      sym_variadic_argument,
    STATE(1268), 1,
      sym_implicit_length_array_type,
    ACTIONS(309), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(1311), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(313), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(401), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(894), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(317), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(394), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [5439] = 27,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(295), 1,
      anon_sym_LPAREN,
    ACTIONS(299), 1,
      anon_sym_func,
    ACTIONS(315), 1,
      anon_sym_DQUOTE,
    ACTIONS(393), 1,
      sym_identifier,
    ACTIONS(397), 1,
      anon_sym_STAR,
    ACTIONS(399), 1,
      anon_sym_LT_DASH,
    ACTIONS(453), 1,
      anon_sym_RPAREN,
    STATE(541), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(855), 1,
      sym_qualified_type,
    STATE(1245), 1,
      sym_variadic_argument,
    STATE(1268), 1,
      sym_implicit_length_array_type,
    ACTIONS(309), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(1311), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(313), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(401), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(894), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(317), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(394), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [5553] = 27,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(293), 1,
      sym_identifier,
    ACTIONS(295), 1,
      anon_sym_LPAREN,
    ACTIONS(299), 1,
      anon_sym_func,
    ACTIONS(301), 1,
      anon_sym_STAR,
    ACTIONS(307), 1,
      anon_sym_LT_DASH,
    ACTIONS(315), 1,
      anon_sym_DQUOTE,
    ACTIONS(433), 1,
      anon_sym_range,
    STATE(522), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(855), 1,
      sym_qualified_type,
    STATE(1268), 1,
      sym_implicit_length_array_type,
    STATE(1281), 1,
      sym_expression_list,
    ACTIONS(309), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(1311), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(313), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(311), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(894), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(317), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(394), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [5667] = 27,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(295), 1,
      anon_sym_LPAREN,
    ACTIONS(299), 1,
      anon_sym_func,
    ACTIONS(307), 1,
      anon_sym_LT_DASH,
    ACTIONS(315), 1,
      anon_sym_DQUOTE,
    ACTIONS(387), 1,
      sym_identifier,
    ACTIONS(389), 1,
      anon_sym_STAR,
    ACTIONS(455), 1,
      anon_sym_COLON,
    STATE(621), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(855), 1,
      sym_qualified_type,
    STATE(1150), 1,
      sym_type_elem,
    STATE(1268), 1,
      sym_implicit_length_array_type,
    ACTIONS(309), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(1004), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(313), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(311), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(894), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(317), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(394), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [5781] = 27,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(295), 1,
      anon_sym_LPAREN,
    ACTIONS(299), 1,
      anon_sym_func,
    ACTIONS(307), 1,
      anon_sym_LT_DASH,
    ACTIONS(315), 1,
      anon_sym_DQUOTE,
    ACTIONS(387), 1,
      sym_identifier,
    ACTIONS(389), 1,
      anon_sym_STAR,
    ACTIONS(457), 1,
      anon_sym_COLON,
    STATE(632), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(855), 1,
      sym_qualified_type,
    STATE(1150), 1,
      sym_type_elem,
    STATE(1268), 1,
      sym_implicit_length_array_type,
    ACTIONS(309), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(1004), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(313), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(311), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(894), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(317), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(394), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [5895] = 27,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(295), 1,
      anon_sym_LPAREN,
    ACTIONS(299), 1,
      anon_sym_func,
    ACTIONS(307), 1,
      anon_sym_LT_DASH,
    ACTIONS(315), 1,
      anon_sym_DQUOTE,
    ACTIONS(387), 1,
      sym_identifier,
    ACTIONS(389), 1,
      anon_sym_STAR,
    ACTIONS(459), 1,
      anon_sym_COLON,
    STATE(609), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(855), 1,
      sym_qualified_type,
    STATE(1150), 1,
      sym_type_elem,
    STATE(1268), 1,
      sym_implicit_length_array_type,
    ACTIONS(309), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(1004), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(313), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(311), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(894), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(317), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(394), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [6009] = 27,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(295), 1,
      anon_sym_LPAREN,
    ACTIONS(299), 1,
      anon_sym_func,
    ACTIONS(307), 1,
      anon_sym_LT_DASH,
    ACTIONS(315), 1,
      anon_sym_DQUOTE,
    ACTIONS(387), 1,
      sym_identifier,
    ACTIONS(389), 1,
      anon_sym_STAR,
    ACTIONS(461), 1,
      anon_sym_COLON,
    STATE(608), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(855), 1,
      sym_qualified_type,
    STATE(1150), 1,
      sym_type_elem,
    STATE(1268), 1,
      sym_implicit_length_array_type,
    ACTIONS(309), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(1004), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(313), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(311), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(894), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(317), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(394), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [6123] = 27,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(295), 1,
      anon_sym_LPAREN,
    ACTIONS(299), 1,
      anon_sym_func,
    ACTIONS(315), 1,
      anon_sym_DQUOTE,
    ACTIONS(393), 1,
      sym_identifier,
    ACTIONS(397), 1,
      anon_sym_STAR,
    ACTIONS(399), 1,
      anon_sym_LT_DASH,
    ACTIONS(463), 1,
      anon_sym_RPAREN,
    STATE(521), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(855), 1,
      sym_qualified_type,
    STATE(1163), 1,
      sym_variadic_argument,
    STATE(1268), 1,
      sym_implicit_length_array_type,
    ACTIONS(309), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(1311), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(313), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(401), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(894), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(317), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(394), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [6237] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(293), 1,
      sym_identifier,
    ACTIONS(295), 1,
      anon_sym_LPAREN,
    ACTIONS(299), 1,
      anon_sym_func,
    ACTIONS(301), 1,
      anon_sym_STAR,
    ACTIONS(307), 1,
      anon_sym_LT_DASH,
    ACTIONS(315), 1,
      anon_sym_DQUOTE,
    ACTIONS(465), 1,
      anon_sym_RBRACK,
    STATE(637), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(855), 1,
      sym_qualified_type,
    STATE(1268), 1,
      sym_implicit_length_array_type,
    ACTIONS(309), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(1311), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(313), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(311), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(894), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(317), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(394), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [6348] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(293), 1,
      sym_identifier,
    ACTIONS(295), 1,
      anon_sym_LPAREN,
    ACTIONS(299), 1,
      anon_sym_func,
    ACTIONS(301), 1,
      anon_sym_STAR,
    ACTIONS(307), 1,
      anon_sym_LT_DASH,
    ACTIONS(315), 1,
      anon_sym_DQUOTE,
    ACTIONS(425), 1,
      anon_sym_RBRACK,
    STATE(649), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(855), 1,
      sym_qualified_type,
    STATE(1268), 1,
      sym_implicit_length_array_type,
    ACTIONS(309), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(1311), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(313), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(311), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(894), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(317), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(394), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [6459] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(293), 1,
      sym_identifier,
    ACTIONS(295), 1,
      anon_sym_LPAREN,
    ACTIONS(299), 1,
      anon_sym_func,
    ACTIONS(301), 1,
      anon_sym_STAR,
    ACTIONS(307), 1,
      anon_sym_LT_DASH,
    ACTIONS(315), 1,
      anon_sym_DQUOTE,
    ACTIONS(467), 1,
      anon_sym_RBRACK,
    STATE(606), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(855), 1,
      sym_qualified_type,
    STATE(1268), 1,
      sym_implicit_length_array_type,
    ACTIONS(309), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(1311), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(313), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(311), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(894), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(317), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(394), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [6570] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(295), 1,
      anon_sym_LPAREN,
    ACTIONS(299), 1,
      anon_sym_func,
    ACTIONS(315), 1,
      anon_sym_DQUOTE,
    ACTIONS(393), 1,
      sym_identifier,
    ACTIONS(397), 1,
      anon_sym_STAR,
    ACTIONS(399), 1,
      anon_sym_LT_DASH,
    ACTIONS(469), 1,
      anon_sym_RPAREN,
    STATE(597), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(855), 1,
      sym_qualified_type,
    STATE(1268), 1,
      sym_implicit_length_array_type,
    ACTIONS(309), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(1311), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(313), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(401), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(894), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(317), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(394), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [6681] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(293), 1,
      sym_identifier,
    ACTIONS(295), 1,
      anon_sym_LPAREN,
    ACTIONS(299), 1,
      anon_sym_func,
    ACTIONS(301), 1,
      anon_sym_STAR,
    ACTIONS(307), 1,
      anon_sym_LT_DASH,
    ACTIONS(315), 1,
      anon_sym_DQUOTE,
    ACTIONS(471), 1,
      anon_sym_RBRACK,
    STATE(636), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(855), 1,
      sym_qualified_type,
    STATE(1268), 1,
      sym_implicit_length_array_type,
    ACTIONS(309), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(1311), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(313), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(311), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(894), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(317), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(394), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [6792] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(295), 1,
      anon_sym_LPAREN,
    ACTIONS(299), 1,
      anon_sym_func,
    ACTIONS(315), 1,
      anon_sym_DQUOTE,
    ACTIONS(403), 1,
      sym_identifier,
    ACTIONS(405), 1,
      anon_sym_STAR,
    ACTIONS(409), 1,
      anon_sym_LT_DASH,
    STATE(590), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(855), 1,
      sym_qualified_type,
    STATE(1268), 1,
      sym_implicit_length_array_type,
    STATE(1281), 1,
      sym_expression_list,
    ACTIONS(309), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(1311), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(313), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(411), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(894), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(317), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(394), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [6903] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(293), 1,
      sym_identifier,
    ACTIONS(295), 1,
      anon_sym_LPAREN,
    ACTIONS(299), 1,
      anon_sym_func,
    ACTIONS(301), 1,
      anon_sym_STAR,
    ACTIONS(307), 1,
      anon_sym_LT_DASH,
    ACTIONS(315), 1,
      anon_sym_DQUOTE,
    ACTIONS(473), 1,
      anon_sym_SEMI,
    STATE(692), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(855), 1,
      sym_qualified_type,
    STATE(1268), 1,
      sym_implicit_length_array_type,
    ACTIONS(309), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(1311), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(313), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(311), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(894), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(317), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(394), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [7014] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(293), 1,
      sym_identifier,
    ACTIONS(295), 1,
      anon_sym_LPAREN,
    ACTIONS(299), 1,
      anon_sym_func,
    ACTIONS(301), 1,
      anon_sym_STAR,
    ACTIONS(307), 1,
      anon_sym_LT_DASH,
    ACTIONS(315), 1,
      anon_sym_DQUOTE,
    ACTIONS(475), 1,
      anon_sym_RBRACK,
    STATE(670), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(855), 1,
      sym_qualified_type,
    STATE(1268), 1,
      sym_implicit_length_array_type,
    ACTIONS(309), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(1311), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(313), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(311), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(894), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(317), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(394), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [7125] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(265), 1,
      sym_identifier,
    ACTIONS(273), 1,
      anon_sym_func,
    ACTIONS(477), 1,
      anon_sym_LPAREN,
    ACTIONS(479), 1,
      anon_sym_STAR,
    ACTIONS(481), 1,
      anon_sym_LT_DASH,
    ACTIONS(487), 1,
      anon_sym_DQUOTE,
    STATE(395), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(934), 1,
      sym_expression_list,
    STATE(1041), 1,
      sym_qualified_type,
    STATE(1292), 1,
      sym_implicit_length_array_type,
    ACTIONS(283), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(1312), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(485), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(483), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(1068), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(287), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(502), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [7236] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(295), 1,
      anon_sym_LPAREN,
    ACTIONS(299), 1,
      anon_sym_func,
    ACTIONS(315), 1,
      anon_sym_DQUOTE,
    ACTIONS(403), 1,
      sym_identifier,
    ACTIONS(405), 1,
      anon_sym_STAR,
    ACTIONS(409), 1,
      anon_sym_LT_DASH,
    STATE(590), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(855), 1,
      sym_qualified_type,
    STATE(1268), 1,
      sym_implicit_length_array_type,
    STATE(1284), 1,
      sym_expression_list,
    ACTIONS(309), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(1311), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(313), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(411), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(894), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(317), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(394), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [7347] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(293), 1,
      sym_identifier,
    ACTIONS(295), 1,
      anon_sym_LPAREN,
    ACTIONS(299), 1,
      anon_sym_func,
    ACTIONS(301), 1,
      anon_sym_STAR,
    ACTIONS(307), 1,
      anon_sym_LT_DASH,
    ACTIONS(315), 1,
      anon_sym_DQUOTE,
    ACTIONS(489), 1,
      anon_sym_RBRACK,
    STATE(617), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(855), 1,
      sym_qualified_type,
    STATE(1268), 1,
      sym_implicit_length_array_type,
    ACTIONS(309), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(1311), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(313), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(311), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(894), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(317), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(394), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [7458] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(295), 1,
      anon_sym_LPAREN,
    ACTIONS(299), 1,
      anon_sym_func,
    ACTIONS(315), 1,
      anon_sym_DQUOTE,
    ACTIONS(393), 1,
      sym_identifier,
    ACTIONS(397), 1,
      anon_sym_STAR,
    ACTIONS(399), 1,
      anon_sym_LT_DASH,
    ACTIONS(491), 1,
      anon_sym_RPAREN,
    STATE(597), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(855), 1,
      sym_qualified_type,
    STATE(1268), 1,
      sym_implicit_length_array_type,
    ACTIONS(309), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(1311), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(313), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(401), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(894), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(317), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(394), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [7569] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(265), 1,
      sym_identifier,
    ACTIONS(273), 1,
      anon_sym_func,
    ACTIONS(477), 1,
      anon_sym_LPAREN,
    ACTIONS(479), 1,
      anon_sym_STAR,
    ACTIONS(481), 1,
      anon_sym_LT_DASH,
    ACTIONS(487), 1,
      anon_sym_DQUOTE,
    STATE(395), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(941), 1,
      sym_expression_list,
    STATE(1041), 1,
      sym_qualified_type,
    STATE(1292), 1,
      sym_implicit_length_array_type,
    ACTIONS(283), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(1312), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(485), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(483), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(1068), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(287), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(502), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [7680] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(293), 1,
      sym_identifier,
    ACTIONS(295), 1,
      anon_sym_LPAREN,
    ACTIONS(299), 1,
      anon_sym_func,
    ACTIONS(301), 1,
      anon_sym_STAR,
    ACTIONS(307), 1,
      anon_sym_LT_DASH,
    ACTIONS(315), 1,
      anon_sym_DQUOTE,
    STATE(542), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(855), 1,
      sym_qualified_type,
    STATE(1268), 1,
      sym_implicit_length_array_type,
    STATE(1284), 1,
      sym_expression_list,
    ACTIONS(309), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(1311), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(313), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(311), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(894), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(317), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(394), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [7791] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(293), 1,
      sym_identifier,
    ACTIONS(295), 1,
      anon_sym_LPAREN,
    ACTIONS(299), 1,
      anon_sym_func,
    ACTIONS(301), 1,
      anon_sym_STAR,
    ACTIONS(307), 1,
      anon_sym_LT_DASH,
    ACTIONS(315), 1,
      anon_sym_DQUOTE,
    ACTIONS(493), 1,
      anon_sym_RBRACK,
    STATE(612), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(855), 1,
      sym_qualified_type,
    STATE(1268), 1,
      sym_implicit_length_array_type,
    ACTIONS(309), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(1311), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(313), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(311), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(894), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(317), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(394), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [7902] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(295), 1,
      anon_sym_LPAREN,
    ACTIONS(299), 1,
      anon_sym_func,
    ACTIONS(315), 1,
      anon_sym_DQUOTE,
    ACTIONS(393), 1,
      sym_identifier,
    ACTIONS(397), 1,
      anon_sym_STAR,
    ACTIONS(399), 1,
      anon_sym_LT_DASH,
    ACTIONS(495), 1,
      anon_sym_RPAREN,
    STATE(597), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(855), 1,
      sym_qualified_type,
    STATE(1268), 1,
      sym_implicit_length_array_type,
    ACTIONS(309), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(1311), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(313), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(401), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(894), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(317), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(394), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [8013] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(295), 1,
      anon_sym_LPAREN,
    ACTIONS(299), 1,
      anon_sym_func,
    ACTIONS(315), 1,
      anon_sym_DQUOTE,
    ACTIONS(393), 1,
      sym_identifier,
    ACTIONS(397), 1,
      anon_sym_STAR,
    ACTIONS(399), 1,
      anon_sym_LT_DASH,
    ACTIONS(497), 1,
      anon_sym_RPAREN,
    STATE(597), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(855), 1,
      sym_qualified_type,
    STATE(1268), 1,
      sym_implicit_length_array_type,
    ACTIONS(309), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(1311), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(313), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(401), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(894), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(317), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(394), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [8124] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(293), 1,
      sym_identifier,
    ACTIONS(295), 1,
      anon_sym_LPAREN,
    ACTIONS(299), 1,
      anon_sym_func,
    ACTIONS(301), 1,
      anon_sym_STAR,
    ACTIONS(307), 1,
      anon_sym_LT_DASH,
    ACTIONS(315), 1,
      anon_sym_DQUOTE,
    ACTIONS(499), 1,
      anon_sym_RBRACK,
    STATE(631), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(855), 1,
      sym_qualified_type,
    STATE(1268), 1,
      sym_implicit_length_array_type,
    ACTIONS(309), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(1311), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(313), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(311), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(894), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(317), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(394), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [8235] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(295), 1,
      anon_sym_LPAREN,
    ACTIONS(299), 1,
      anon_sym_func,
    ACTIONS(315), 1,
      anon_sym_DQUOTE,
    ACTIONS(393), 1,
      sym_identifier,
    ACTIONS(397), 1,
      anon_sym_STAR,
    ACTIONS(399), 1,
      anon_sym_LT_DASH,
    STATE(541), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(855), 1,
      sym_qualified_type,
    STATE(1245), 1,
      sym_variadic_argument,
    STATE(1268), 1,
      sym_implicit_length_array_type,
    ACTIONS(309), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(1311), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(313), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(401), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(894), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(317), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(394), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [8346] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(293), 1,
      sym_identifier,
    ACTIONS(295), 1,
      anon_sym_LPAREN,
    ACTIONS(299), 1,
      anon_sym_func,
    ACTIONS(301), 1,
      anon_sym_STAR,
    ACTIONS(307), 1,
      anon_sym_LT_DASH,
    ACTIONS(315), 1,
      anon_sym_DQUOTE,
    ACTIONS(383), 1,
      anon_sym_RBRACK,
    STATE(689), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(855), 1,
      sym_qualified_type,
    STATE(1268), 1,
      sym_implicit_length_array_type,
    ACTIONS(309), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(1311), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(313), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(311), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(894), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(317), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(394), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [8457] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(293), 1,
      sym_identifier,
    ACTIONS(295), 1,
      anon_sym_LPAREN,
    ACTIONS(299), 1,
      anon_sym_func,
    ACTIONS(301), 1,
      anon_sym_STAR,
    ACTIONS(307), 1,
      anon_sym_LT_DASH,
    ACTIONS(315), 1,
      anon_sym_DQUOTE,
    ACTIONS(501), 1,
      anon_sym_RBRACK,
    STATE(638), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(855), 1,
      sym_qualified_type,
    STATE(1268), 1,
      sym_implicit_length_array_type,
    ACTIONS(309), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(1311), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(313), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(311), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(894), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(317), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(394), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [8568] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(295), 1,
      anon_sym_LPAREN,
    ACTIONS(299), 1,
      anon_sym_func,
    ACTIONS(315), 1,
      anon_sym_DQUOTE,
    ACTIONS(393), 1,
      sym_identifier,
    ACTIONS(397), 1,
      anon_sym_STAR,
    ACTIONS(399), 1,
      anon_sym_LT_DASH,
    ACTIONS(503), 1,
      anon_sym_RPAREN,
    STATE(597), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(855), 1,
      sym_qualified_type,
    STATE(1268), 1,
      sym_implicit_length_array_type,
    ACTIONS(309), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(1311), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(313), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(401), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(894), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(317), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(394), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [8679] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(265), 1,
      sym_identifier,
    ACTIONS(273), 1,
      anon_sym_func,
    ACTIONS(477), 1,
      anon_sym_LPAREN,
    ACTIONS(479), 1,
      anon_sym_STAR,
    ACTIONS(481), 1,
      anon_sym_LT_DASH,
    ACTIONS(487), 1,
      anon_sym_DQUOTE,
    STATE(395), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(1008), 1,
      sym_expression_list,
    STATE(1041), 1,
      sym_qualified_type,
    STATE(1292), 1,
      sym_implicit_length_array_type,
    ACTIONS(283), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(1312), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(485), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(483), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(1068), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(287), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(502), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [8790] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(295), 1,
      anon_sym_LPAREN,
    ACTIONS(299), 1,
      anon_sym_func,
    ACTIONS(315), 1,
      anon_sym_DQUOTE,
    ACTIONS(393), 1,
      sym_identifier,
    ACTIONS(397), 1,
      anon_sym_STAR,
    ACTIONS(399), 1,
      anon_sym_LT_DASH,
    ACTIONS(505), 1,
      anon_sym_RPAREN,
    STATE(597), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(855), 1,
      sym_qualified_type,
    STATE(1268), 1,
      sym_implicit_length_array_type,
    ACTIONS(309), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(1311), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(313), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(401), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(894), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(317), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(394), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [8901] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(293), 1,
      sym_identifier,
    ACTIONS(295), 1,
      anon_sym_LPAREN,
    ACTIONS(299), 1,
      anon_sym_func,
    ACTIONS(301), 1,
      anon_sym_STAR,
    ACTIONS(307), 1,
      anon_sym_LT_DASH,
    ACTIONS(315), 1,
      anon_sym_DQUOTE,
    STATE(522), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(855), 1,
      sym_qualified_type,
    STATE(1268), 1,
      sym_implicit_length_array_type,
    STATE(1372), 1,
      sym_expression_list,
    ACTIONS(309), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(1311), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(313), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(311), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(894), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(317), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(394), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [9012] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(293), 1,
      sym_identifier,
    ACTIONS(295), 1,
      anon_sym_LPAREN,
    ACTIONS(299), 1,
      anon_sym_func,
    ACTIONS(301), 1,
      anon_sym_STAR,
    ACTIONS(307), 1,
      anon_sym_LT_DASH,
    ACTIONS(315), 1,
      anon_sym_DQUOTE,
    ACTIONS(507), 1,
      anon_sym_RBRACK,
    STATE(616), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(855), 1,
      sym_qualified_type,
    STATE(1268), 1,
      sym_implicit_length_array_type,
    ACTIONS(309), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(1311), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(313), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(311), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(894), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(317), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(394), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [9123] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(293), 1,
      sym_identifier,
    ACTIONS(295), 1,
      anon_sym_LPAREN,
    ACTIONS(299), 1,
      anon_sym_func,
    ACTIONS(301), 1,
      anon_sym_STAR,
    ACTIONS(307), 1,
      anon_sym_LT_DASH,
    ACTIONS(315), 1,
      anon_sym_DQUOTE,
    ACTIONS(509), 1,
      anon_sym_SEMI,
    STATE(641), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(855), 1,
      sym_qualified_type,
    STATE(1268), 1,
      sym_implicit_length_array_type,
    ACTIONS(309), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(1311), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(313), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(311), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(894), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(317), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(394), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [9234] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(293), 1,
      sym_identifier,
    ACTIONS(295), 1,
      anon_sym_LPAREN,
    ACTIONS(299), 1,
      anon_sym_func,
    ACTIONS(301), 1,
      anon_sym_STAR,
    ACTIONS(307), 1,
      anon_sym_LT_DASH,
    ACTIONS(315), 1,
      anon_sym_DQUOTE,
    ACTIONS(511), 1,
      anon_sym_RBRACK,
    STATE(618), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(855), 1,
      sym_qualified_type,
    STATE(1268), 1,
      sym_implicit_length_array_type,
    ACTIONS(309), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(1311), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(313), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(311), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(894), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(317), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(394), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [9345] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(295), 1,
      anon_sym_LPAREN,
    ACTIONS(299), 1,
      anon_sym_func,
    ACTIONS(315), 1,
      anon_sym_DQUOTE,
    ACTIONS(393), 1,
      sym_identifier,
    ACTIONS(397), 1,
      anon_sym_STAR,
    ACTIONS(399), 1,
      anon_sym_LT_DASH,
    ACTIONS(513), 1,
      anon_sym_RPAREN,
    STATE(597), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(855), 1,
      sym_qualified_type,
    STATE(1268), 1,
      sym_implicit_length_array_type,
    ACTIONS(309), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(1311), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(313), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(401), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(894), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(317), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(394), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [9456] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(265), 1,
      sym_identifier,
    ACTIONS(273), 1,
      anon_sym_func,
    ACTIONS(477), 1,
      anon_sym_LPAREN,
    ACTIONS(479), 1,
      anon_sym_STAR,
    ACTIONS(481), 1,
      anon_sym_LT_DASH,
    ACTIONS(487), 1,
      anon_sym_DQUOTE,
    STATE(395), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(948), 1,
      sym_expression_list,
    STATE(1041), 1,
      sym_qualified_type,
    STATE(1292), 1,
      sym_implicit_length_array_type,
    ACTIONS(283), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(1312), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(485), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(483), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(1068), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(287), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(502), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [9567] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(293), 1,
      sym_identifier,
    ACTIONS(295), 1,
      anon_sym_LPAREN,
    ACTIONS(299), 1,
      anon_sym_func,
    ACTIONS(301), 1,
      anon_sym_STAR,
    ACTIONS(307), 1,
      anon_sym_LT_DASH,
    ACTIONS(315), 1,
      anon_sym_DQUOTE,
    ACTIONS(515), 1,
      anon_sym_RBRACK,
    STATE(626), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(855), 1,
      sym_qualified_type,
    STATE(1268), 1,
      sym_implicit_length_array_type,
    ACTIONS(309), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(1311), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(313), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(311), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(894), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(317), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(394), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [9678] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(265), 1,
      sym_identifier,
    ACTIONS(273), 1,
      anon_sym_func,
    ACTIONS(477), 1,
      anon_sym_LPAREN,
    ACTIONS(479), 1,
      anon_sym_STAR,
    ACTIONS(481), 1,
      anon_sym_LT_DASH,
    ACTIONS(487), 1,
      anon_sym_DQUOTE,
    STATE(395), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(949), 1,
      sym_expression_list,
    STATE(1041), 1,
      sym_qualified_type,
    STATE(1292), 1,
      sym_implicit_length_array_type,
    ACTIONS(283), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(1312), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(485), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(483), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(1068), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(287), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(502), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [9789] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(293), 1,
      sym_identifier,
    ACTIONS(295), 1,
      anon_sym_LPAREN,
    ACTIONS(299), 1,
      anon_sym_func,
    ACTIONS(301), 1,
      anon_sym_STAR,
    ACTIONS(307), 1,
      anon_sym_LT_DASH,
    ACTIONS(315), 1,
      anon_sym_DQUOTE,
    ACTIONS(517), 1,
      anon_sym_RBRACK,
    STATE(683), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(855), 1,
      sym_qualified_type,
    STATE(1268), 1,
      sym_implicit_length_array_type,
    ACTIONS(309), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(1311), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(313), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(311), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(894), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(317), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(394), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [9900] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(265), 1,
      sym_identifier,
    ACTIONS(273), 1,
      anon_sym_func,
    ACTIONS(477), 1,
      anon_sym_LPAREN,
    ACTIONS(479), 1,
      anon_sym_STAR,
    ACTIONS(481), 1,
      anon_sym_LT_DASH,
    ACTIONS(487), 1,
      anon_sym_DQUOTE,
    STATE(395), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(951), 1,
      sym_expression_list,
    STATE(1041), 1,
      sym_qualified_type,
    STATE(1292), 1,
      sym_implicit_length_array_type,
    ACTIONS(283), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(1312), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(485), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(483), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(1068), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(287), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(502), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [10011] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(295), 1,
      anon_sym_LPAREN,
    ACTIONS(299), 1,
      anon_sym_func,
    ACTIONS(315), 1,
      anon_sym_DQUOTE,
    ACTIONS(393), 1,
      sym_identifier,
    ACTIONS(397), 1,
      anon_sym_STAR,
    ACTIONS(399), 1,
      anon_sym_LT_DASH,
    ACTIONS(519), 1,
      anon_sym_RPAREN,
    STATE(597), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(855), 1,
      sym_qualified_type,
    STATE(1268), 1,
      sym_implicit_length_array_type,
    ACTIONS(309), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(1311), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(313), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(401), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(894), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(317), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(394), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [10122] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(293), 1,
      sym_identifier,
    ACTIONS(295), 1,
      anon_sym_LPAREN,
    ACTIONS(299), 1,
      anon_sym_func,
    ACTIONS(301), 1,
      anon_sym_STAR,
    ACTIONS(307), 1,
      anon_sym_LT_DASH,
    ACTIONS(315), 1,
      anon_sym_DQUOTE,
    ACTIONS(521), 1,
      anon_sym_RBRACK,
    STATE(598), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(855), 1,
      sym_qualified_type,
    STATE(1268), 1,
      sym_implicit_length_array_type,
    ACTIONS(309), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(1311), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(313), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(311), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(894), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(317), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(394), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [10233] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(295), 1,
      anon_sym_LPAREN,
    ACTIONS(299), 1,
      anon_sym_func,
    ACTIONS(315), 1,
      anon_sym_DQUOTE,
    ACTIONS(393), 1,
      sym_identifier,
    ACTIONS(397), 1,
      anon_sym_STAR,
    ACTIONS(399), 1,
      anon_sym_LT_DASH,
    ACTIONS(523), 1,
      anon_sym_RPAREN,
    STATE(597), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(855), 1,
      sym_qualified_type,
    STATE(1268), 1,
      sym_implicit_length_array_type,
    ACTIONS(309), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(1311), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(313), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(401), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(894), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(317), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(394), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [10344] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(265), 1,
      sym_identifier,
    ACTIONS(273), 1,
      anon_sym_func,
    ACTIONS(477), 1,
      anon_sym_LPAREN,
    ACTIONS(479), 1,
      anon_sym_STAR,
    ACTIONS(481), 1,
      anon_sym_LT_DASH,
    ACTIONS(487), 1,
      anon_sym_DQUOTE,
    STATE(395), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(970), 1,
      sym_expression_list,
    STATE(1041), 1,
      sym_qualified_type,
    STATE(1292), 1,
      sym_implicit_length_array_type,
    ACTIONS(283), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(1312), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(485), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(483), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(1068), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(287), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(502), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [10455] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(265), 1,
      sym_identifier,
    ACTIONS(273), 1,
      anon_sym_func,
    ACTIONS(477), 1,
      anon_sym_LPAREN,
    ACTIONS(479), 1,
      anon_sym_STAR,
    ACTIONS(481), 1,
      anon_sym_LT_DASH,
    ACTIONS(487), 1,
      anon_sym_DQUOTE,
    STATE(395), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(1009), 1,
      sym_expression_list,
    STATE(1041), 1,
      sym_qualified_type,
    STATE(1292), 1,
      sym_implicit_length_array_type,
    ACTIONS(283), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(1312), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(485), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(483), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(1068), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(287), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(502), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [10566] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(293), 1,
      sym_identifier,
    ACTIONS(295), 1,
      anon_sym_LPAREN,
    ACTIONS(299), 1,
      anon_sym_func,
    ACTIONS(301), 1,
      anon_sym_STAR,
    ACTIONS(307), 1,
      anon_sym_LT_DASH,
    ACTIONS(315), 1,
      anon_sym_DQUOTE,
    ACTIONS(525), 1,
      anon_sym_RBRACK,
    STATE(603), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(855), 1,
      sym_qualified_type,
    STATE(1268), 1,
      sym_implicit_length_array_type,
    ACTIONS(309), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(1311), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(313), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(311), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(894), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(317), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(394), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [10677] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(295), 1,
      anon_sym_LPAREN,
    ACTIONS(299), 1,
      anon_sym_func,
    ACTIONS(315), 1,
      anon_sym_DQUOTE,
    ACTIONS(393), 1,
      sym_identifier,
    ACTIONS(397), 1,
      anon_sym_STAR,
    ACTIONS(399), 1,
      anon_sym_LT_DASH,
    ACTIONS(527), 1,
      anon_sym_RPAREN,
    STATE(597), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(855), 1,
      sym_qualified_type,
    STATE(1268), 1,
      sym_implicit_length_array_type,
    ACTIONS(309), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(1311), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(313), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(401), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(894), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(317), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(394), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [10788] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(265), 1,
      sym_identifier,
    ACTIONS(273), 1,
      anon_sym_func,
    ACTIONS(477), 1,
      anon_sym_LPAREN,
    ACTIONS(479), 1,
      anon_sym_STAR,
    ACTIONS(481), 1,
      anon_sym_LT_DASH,
    ACTIONS(487), 1,
      anon_sym_DQUOTE,
    STATE(395), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(1017), 1,
      sym_expression_list,
    STATE(1041), 1,
      sym_qualified_type,
    STATE(1292), 1,
      sym_implicit_length_array_type,
    ACTIONS(283), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(1312), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(485), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(483), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(1068), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(287), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(502), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [10899] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(293), 1,
      sym_identifier,
    ACTIONS(295), 1,
      anon_sym_LPAREN,
    ACTIONS(299), 1,
      anon_sym_func,
    ACTIONS(301), 1,
      anon_sym_STAR,
    ACTIONS(307), 1,
      anon_sym_LT_DASH,
    ACTIONS(315), 1,
      anon_sym_DQUOTE,
    STATE(522), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(855), 1,
      sym_qualified_type,
    STATE(1268), 1,
      sym_implicit_length_array_type,
    STATE(1281), 1,
      sym_expression_list,
    ACTIONS(309), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(1311), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(313), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(311), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(894), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(317), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(394), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [11010] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(265), 1,
      sym_identifier,
    ACTIONS(273), 1,
      anon_sym_func,
    ACTIONS(477), 1,
      anon_sym_LPAREN,
    ACTIONS(479), 1,
      anon_sym_STAR,
    ACTIONS(481), 1,
      anon_sym_LT_DASH,
    ACTIONS(487), 1,
      anon_sym_DQUOTE,
    STATE(395), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(1010), 1,
      sym_expression_list,
    STATE(1041), 1,
      sym_qualified_type,
    STATE(1292), 1,
      sym_implicit_length_array_type,
    ACTIONS(283), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(1312), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(485), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(483), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(1068), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(287), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(502), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [11121] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(293), 1,
      sym_identifier,
    ACTIONS(295), 1,
      anon_sym_LPAREN,
    ACTIONS(299), 1,
      anon_sym_func,
    ACTIONS(301), 1,
      anon_sym_STAR,
    ACTIONS(307), 1,
      anon_sym_LT_DASH,
    ACTIONS(315), 1,
      anon_sym_DQUOTE,
    ACTIONS(417), 1,
      anon_sym_RBRACK,
    STATE(658), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(855), 1,
      sym_qualified_type,
    STATE(1268), 1,
      sym_implicit_length_array_type,
    ACTIONS(309), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(1311), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(313), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(311), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(894), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(317), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(394), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [11232] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(265), 1,
      sym_identifier,
    ACTIONS(273), 1,
      anon_sym_func,
    ACTIONS(477), 1,
      anon_sym_LPAREN,
    ACTIONS(479), 1,
      anon_sym_STAR,
    ACTIONS(481), 1,
      anon_sym_LT_DASH,
    ACTIONS(487), 1,
      anon_sym_DQUOTE,
    STATE(395), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(1011), 1,
      sym_expression_list,
    STATE(1041), 1,
      sym_qualified_type,
    STATE(1292), 1,
      sym_implicit_length_array_type,
    ACTIONS(283), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(1312), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(485), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(483), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(1068), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(287), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(502), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [11343] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(293), 1,
      sym_identifier,
    ACTIONS(295), 1,
      anon_sym_LPAREN,
    ACTIONS(299), 1,
      anon_sym_func,
    ACTIONS(301), 1,
      anon_sym_STAR,
    ACTIONS(307), 1,
      anon_sym_LT_DASH,
    ACTIONS(315), 1,
      anon_sym_DQUOTE,
    STATE(522), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(855), 1,
      sym_qualified_type,
    STATE(1268), 1,
      sym_implicit_length_array_type,
    STATE(1284), 1,
      sym_expression_list,
    ACTIONS(309), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(1311), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(313), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(311), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(894), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(317), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(394), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [11454] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(293), 1,
      sym_identifier,
    ACTIONS(295), 1,
      anon_sym_LPAREN,
    ACTIONS(299), 1,
      anon_sym_func,
    ACTIONS(301), 1,
      anon_sym_STAR,
    ACTIONS(307), 1,
      anon_sym_LT_DASH,
    ACTIONS(315), 1,
      anon_sym_DQUOTE,
    ACTIONS(529), 1,
      anon_sym_RBRACK,
    STATE(599), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(855), 1,
      sym_qualified_type,
    STATE(1268), 1,
      sym_implicit_length_array_type,
    ACTIONS(309), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(1311), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(313), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(311), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(894), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(317), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(394), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [11565] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(295), 1,
      anon_sym_LPAREN,
    ACTIONS(299), 1,
      anon_sym_func,
    ACTIONS(315), 1,
      anon_sym_DQUOTE,
    ACTIONS(393), 1,
      sym_identifier,
    ACTIONS(397), 1,
      anon_sym_STAR,
    ACTIONS(399), 1,
      anon_sym_LT_DASH,
    ACTIONS(531), 1,
      anon_sym_RPAREN,
    STATE(597), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(855), 1,
      sym_qualified_type,
    STATE(1268), 1,
      sym_implicit_length_array_type,
    ACTIONS(309), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(1311), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(313), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(401), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(894), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(317), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(394), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [11676] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(295), 1,
      anon_sym_LPAREN,
    ACTIONS(299), 1,
      anon_sym_func,
    ACTIONS(315), 1,
      anon_sym_DQUOTE,
    ACTIONS(393), 1,
      sym_identifier,
    ACTIONS(397), 1,
      anon_sym_STAR,
    ACTIONS(399), 1,
      anon_sym_LT_DASH,
    ACTIONS(533), 1,
      anon_sym_RPAREN,
    STATE(597), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(855), 1,
      sym_qualified_type,
    STATE(1268), 1,
      sym_implicit_length_array_type,
    ACTIONS(309), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(1311), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(313), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(401), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(894), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(317), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(394), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [11787] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(363), 1,
      sym_identifier,
    ACTIONS(365), 1,
      anon_sym_LPAREN,
    ACTIONS(367), 1,
      anon_sym_func,
    ACTIONS(369), 1,
      anon_sym_STAR,
    ACTIONS(371), 1,
      anon_sym_LT_DASH,
    ACTIONS(379), 1,
      anon_sym_DQUOTE,
    STATE(463), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(1022), 1,
      sym_qualified_type,
    STATE(1258), 1,
      sym_implicit_length_array_type,
    ACTIONS(373), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(1283), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(377), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(375), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(1108), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(381), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(534), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [11895] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(363), 1,
      sym_identifier,
    ACTIONS(365), 1,
      anon_sym_LPAREN,
    ACTIONS(367), 1,
      anon_sym_func,
    ACTIONS(369), 1,
      anon_sym_STAR,
    ACTIONS(371), 1,
      anon_sym_LT_DASH,
    ACTIONS(379), 1,
      anon_sym_DQUOTE,
    STATE(460), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(1022), 1,
      sym_qualified_type,
    STATE(1258), 1,
      sym_implicit_length_array_type,
    ACTIONS(373), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(1283), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(377), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(375), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(1108), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(381), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(534), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [12003] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(363), 1,
      sym_identifier,
    ACTIONS(365), 1,
      anon_sym_LPAREN,
    ACTIONS(367), 1,
      anon_sym_func,
    ACTIONS(369), 1,
      anon_sym_STAR,
    ACTIONS(371), 1,
      anon_sym_LT_DASH,
    ACTIONS(379), 1,
      anon_sym_DQUOTE,
    STATE(461), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(1022), 1,
      sym_qualified_type,
    STATE(1258), 1,
      sym_implicit_length_array_type,
    ACTIONS(373), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(1283), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(377), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(375), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(1108), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(381), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(534), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [12111] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(363), 1,
      sym_identifier,
    ACTIONS(365), 1,
      anon_sym_LPAREN,
    ACTIONS(367), 1,
      anon_sym_func,
    ACTIONS(369), 1,
      anon_sym_STAR,
    ACTIONS(371), 1,
      anon_sym_LT_DASH,
    ACTIONS(379), 1,
      anon_sym_DQUOTE,
    STATE(462), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(1022), 1,
      sym_qualified_type,
    STATE(1258), 1,
      sym_implicit_length_array_type,
    ACTIONS(373), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(1283), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(377), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(375), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(1108), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(381), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(534), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [12219] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(293), 1,
      sym_identifier,
    ACTIONS(295), 1,
      anon_sym_LPAREN,
    ACTIONS(299), 1,
      anon_sym_func,
    ACTIONS(315), 1,
      anon_sym_DQUOTE,
    ACTIONS(399), 1,
      anon_sym_LT_DASH,
    ACTIONS(535), 1,
      anon_sym_STAR,
    STATE(646), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(855), 1,
      sym_qualified_type,
    STATE(1268), 1,
      sym_implicit_length_array_type,
    ACTIONS(309), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(1197), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(313), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(401), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(894), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(317), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(394), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [12327] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(293), 1,
      sym_identifier,
    ACTIONS(295), 1,
      anon_sym_LPAREN,
    ACTIONS(299), 1,
      anon_sym_func,
    ACTIONS(315), 1,
      anon_sym_DQUOTE,
    ACTIONS(399), 1,
      anon_sym_LT_DASH,
    ACTIONS(535), 1,
      anon_sym_STAR,
    STATE(387), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(855), 1,
      sym_qualified_type,
    STATE(1268), 1,
      sym_implicit_length_array_type,
    ACTIONS(309), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(952), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(313), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(401), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(894), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(317), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(394), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [12435] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(295), 1,
      anon_sym_LPAREN,
    ACTIONS(299), 1,
      anon_sym_func,
    ACTIONS(315), 1,
      anon_sym_DQUOTE,
    ACTIONS(393), 1,
      sym_identifier,
    ACTIONS(397), 1,
      anon_sym_STAR,
    ACTIONS(399), 1,
      anon_sym_LT_DASH,
    ACTIONS(537), 1,
      anon_sym_chan,
    STATE(387), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(855), 1,
      sym_qualified_type,
    STATE(1268), 1,
      sym_implicit_length_array_type,
    ACTIONS(309), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(1311), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(313), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(401), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(894), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(317), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(394), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [12543] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15), 1,
      anon_sym_LPAREN,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(27), 1,
      anon_sym_STAR,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(41), 1,
      anon_sym_LT_DASH,
    ACTIONS(71), 1,
      anon_sym_DQUOTE,
    ACTIONS(183), 1,
      anon_sym_func,
    ACTIONS(539), 1,
      sym_identifier,
    STATE(246), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(1032), 1,
      sym_qualified_type,
    STATE(1272), 1,
      sym_implicit_length_array_type,
    ACTIONS(65), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(1306), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(69), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(67), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(1104), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(73), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(266), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [12651] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15), 1,
      anon_sym_LPAREN,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(27), 1,
      anon_sym_STAR,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(41), 1,
      anon_sym_LT_DASH,
    ACTIONS(71), 1,
      anon_sym_DQUOTE,
    ACTIONS(183), 1,
      anon_sym_func,
    ACTIONS(539), 1,
      sym_identifier,
    STATE(247), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(1032), 1,
      sym_qualified_type,
    STATE(1272), 1,
      sym_implicit_length_array_type,
    ACTIONS(65), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(1306), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(69), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(67), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(1104), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(73), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(266), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [12759] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(265), 1,
      sym_identifier,
    ACTIONS(273), 1,
      anon_sym_func,
    ACTIONS(477), 1,
      anon_sym_LPAREN,
    ACTIONS(479), 1,
      anon_sym_STAR,
    ACTIONS(481), 1,
      anon_sym_LT_DASH,
    ACTIONS(487), 1,
      anon_sym_DQUOTE,
    STATE(447), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(1041), 1,
      sym_qualified_type,
    STATE(1292), 1,
      sym_implicit_length_array_type,
    ACTIONS(283), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(1312), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(485), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(483), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(1068), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(287), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(502), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [12867] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15), 1,
      anon_sym_LPAREN,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(27), 1,
      anon_sym_STAR,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(41), 1,
      anon_sym_LT_DASH,
    ACTIONS(71), 1,
      anon_sym_DQUOTE,
    ACTIONS(183), 1,
      anon_sym_func,
    ACTIONS(539), 1,
      sym_identifier,
    STATE(243), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(1032), 1,
      sym_qualified_type,
    STATE(1272), 1,
      sym_implicit_length_array_type,
    ACTIONS(65), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(1306), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(69), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(67), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(1104), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(73), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(266), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [12975] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(265), 1,
      sym_identifier,
    ACTIONS(273), 1,
      anon_sym_func,
    ACTIONS(477), 1,
      anon_sym_LPAREN,
    ACTIONS(479), 1,
      anon_sym_STAR,
    ACTIONS(481), 1,
      anon_sym_LT_DASH,
    ACTIONS(487), 1,
      anon_sym_DQUOTE,
    STATE(439), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(1041), 1,
      sym_qualified_type,
    STATE(1292), 1,
      sym_implicit_length_array_type,
    ACTIONS(283), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(1312), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(485), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(483), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(1068), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(287), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(502), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [13083] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(295), 1,
      anon_sym_LPAREN,
    ACTIONS(299), 1,
      anon_sym_func,
    ACTIONS(315), 1,
      anon_sym_DQUOTE,
    ACTIONS(403), 1,
      sym_identifier,
    ACTIONS(405), 1,
      anon_sym_STAR,
    ACTIONS(409), 1,
      anon_sym_LT_DASH,
    STATE(639), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(855), 1,
      sym_qualified_type,
    STATE(1268), 1,
      sym_implicit_length_array_type,
    ACTIONS(309), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(1311), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(313), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(411), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(894), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(317), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(394), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [13191] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15), 1,
      anon_sym_LPAREN,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(27), 1,
      anon_sym_STAR,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(41), 1,
      anon_sym_LT_DASH,
    ACTIONS(71), 1,
      anon_sym_DQUOTE,
    ACTIONS(183), 1,
      anon_sym_func,
    ACTIONS(539), 1,
      sym_identifier,
    STATE(241), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(1032), 1,
      sym_qualified_type,
    STATE(1272), 1,
      sym_implicit_length_array_type,
    ACTIONS(65), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(1306), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(69), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(67), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(1104), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(73), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(266), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [13299] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15), 1,
      anon_sym_LPAREN,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(27), 1,
      anon_sym_STAR,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(41), 1,
      anon_sym_LT_DASH,
    ACTIONS(71), 1,
      anon_sym_DQUOTE,
    ACTIONS(183), 1,
      anon_sym_func,
    ACTIONS(539), 1,
      sym_identifier,
    STATE(244), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(1032), 1,
      sym_qualified_type,
    STATE(1272), 1,
      sym_implicit_length_array_type,
    ACTIONS(65), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(1306), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(69), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(67), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(1104), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(73), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(266), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [13407] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(295), 1,
      anon_sym_LPAREN,
    ACTIONS(299), 1,
      anon_sym_func,
    ACTIONS(315), 1,
      anon_sym_DQUOTE,
    ACTIONS(403), 1,
      sym_identifier,
    ACTIONS(405), 1,
      anon_sym_STAR,
    ACTIONS(409), 1,
      anon_sym_LT_DASH,
    STATE(645), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(855), 1,
      sym_qualified_type,
    STATE(1268), 1,
      sym_implicit_length_array_type,
    ACTIONS(309), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(1311), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(313), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(411), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(894), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(317), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(394), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [13515] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15), 1,
      anon_sym_LPAREN,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(27), 1,
      anon_sym_STAR,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(41), 1,
      anon_sym_LT_DASH,
    ACTIONS(71), 1,
      anon_sym_DQUOTE,
    ACTIONS(183), 1,
      anon_sym_func,
    ACTIONS(537), 1,
      anon_sym_chan,
    ACTIONS(539), 1,
      sym_identifier,
    STATE(242), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(1032), 1,
      sym_qualified_type,
    STATE(1272), 1,
      sym_implicit_length_array_type,
    ACTIONS(65), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(1306), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(69), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(67), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(1104), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(73), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(266), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [13623] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15), 1,
      anon_sym_LPAREN,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(27), 1,
      anon_sym_STAR,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(41), 1,
      anon_sym_LT_DASH,
    ACTIONS(71), 1,
      anon_sym_DQUOTE,
    ACTIONS(183), 1,
      anon_sym_func,
    ACTIONS(539), 1,
      sym_identifier,
    STATE(242), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(1032), 1,
      sym_qualified_type,
    STATE(1272), 1,
      sym_implicit_length_array_type,
    ACTIONS(65), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(952), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(69), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(67), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(1104), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(73), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(266), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [13731] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(295), 1,
      anon_sym_LPAREN,
    ACTIONS(299), 1,
      anon_sym_func,
    ACTIONS(315), 1,
      anon_sym_DQUOTE,
    ACTIONS(403), 1,
      sym_identifier,
    ACTIONS(405), 1,
      anon_sym_STAR,
    ACTIONS(409), 1,
      anon_sym_LT_DASH,
    STATE(662), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(855), 1,
      sym_qualified_type,
    STATE(1268), 1,
      sym_implicit_length_array_type,
    ACTIONS(309), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(1311), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(313), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(411), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(894), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(317), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(394), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [13839] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(295), 1,
      anon_sym_LPAREN,
    ACTIONS(299), 1,
      anon_sym_func,
    ACTIONS(315), 1,
      anon_sym_DQUOTE,
    ACTIONS(403), 1,
      sym_identifier,
    ACTIONS(405), 1,
      anon_sym_STAR,
    ACTIONS(409), 1,
      anon_sym_LT_DASH,
    STATE(387), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(855), 1,
      sym_qualified_type,
    STATE(1268), 1,
      sym_implicit_length_array_type,
    ACTIONS(309), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(1311), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(313), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(411), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(894), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(317), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(394), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [13947] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(295), 1,
      anon_sym_LPAREN,
    ACTIONS(299), 1,
      anon_sym_func,
    ACTIONS(315), 1,
      anon_sym_DQUOTE,
    ACTIONS(403), 1,
      sym_identifier,
    ACTIONS(405), 1,
      anon_sym_STAR,
    ACTIONS(409), 1,
      anon_sym_LT_DASH,
    STATE(388), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(855), 1,
      sym_qualified_type,
    STATE(1268), 1,
      sym_implicit_length_array_type,
    ACTIONS(309), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(1311), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(313), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(411), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(894), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(317), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(394), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [14055] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(295), 1,
      anon_sym_LPAREN,
    ACTIONS(299), 1,
      anon_sym_func,
    ACTIONS(315), 1,
      anon_sym_DQUOTE,
    ACTIONS(403), 1,
      sym_identifier,
    ACTIONS(405), 1,
      anon_sym_STAR,
    ACTIONS(409), 1,
      anon_sym_LT_DASH,
    STATE(546), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(855), 1,
      sym_qualified_type,
    STATE(1268), 1,
      sym_implicit_length_array_type,
    ACTIONS(309), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(1311), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(313), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(411), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(894), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(317), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(394), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [14163] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(295), 1,
      anon_sym_LPAREN,
    ACTIONS(299), 1,
      anon_sym_func,
    ACTIONS(315), 1,
      anon_sym_DQUOTE,
    ACTIONS(403), 1,
      sym_identifier,
    ACTIONS(405), 1,
      anon_sym_STAR,
    ACTIONS(409), 1,
      anon_sym_LT_DASH,
    STATE(549), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(855), 1,
      sym_qualified_type,
    STATE(1268), 1,
      sym_implicit_length_array_type,
    ACTIONS(309), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(1311), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(313), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(411), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(894), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(317), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(394), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [14271] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(295), 1,
      anon_sym_LPAREN,
    ACTIONS(299), 1,
      anon_sym_func,
    ACTIONS(315), 1,
      anon_sym_DQUOTE,
    ACTIONS(403), 1,
      sym_identifier,
    ACTIONS(405), 1,
      anon_sym_STAR,
    ACTIONS(409), 1,
      anon_sym_LT_DASH,
    STATE(550), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(855), 1,
      sym_qualified_type,
    STATE(1268), 1,
      sym_implicit_length_array_type,
    ACTIONS(309), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(1311), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(313), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(411), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(894), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(317), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(394), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [14379] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(295), 1,
      anon_sym_LPAREN,
    ACTIONS(299), 1,
      anon_sym_func,
    ACTIONS(315), 1,
      anon_sym_DQUOTE,
    ACTIONS(403), 1,
      sym_identifier,
    ACTIONS(405), 1,
      anon_sym_STAR,
    ACTIONS(409), 1,
      anon_sym_LT_DASH,
    STATE(551), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(855), 1,
      sym_qualified_type,
    STATE(1268), 1,
      sym_implicit_length_array_type,
    ACTIONS(309), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(1311), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(313), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(411), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(894), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(317), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(394), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [14487] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(293), 1,
      sym_identifier,
    ACTIONS(295), 1,
      anon_sym_LPAREN,
    ACTIONS(299), 1,
      anon_sym_func,
    ACTIONS(301), 1,
      anon_sym_STAR,
    ACTIONS(307), 1,
      anon_sym_LT_DASH,
    ACTIONS(315), 1,
      anon_sym_DQUOTE,
    STATE(387), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(855), 1,
      sym_qualified_type,
    STATE(1268), 1,
      sym_implicit_length_array_type,
    ACTIONS(309), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(952), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(313), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(311), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(894), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(317), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(394), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [14595] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(265), 1,
      sym_identifier,
    ACTIONS(273), 1,
      anon_sym_func,
    ACTIONS(477), 1,
      anon_sym_LPAREN,
    ACTIONS(479), 1,
      anon_sym_STAR,
    ACTIONS(481), 1,
      anon_sym_LT_DASH,
    ACTIONS(487), 1,
      anon_sym_DQUOTE,
    STATE(446), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(1041), 1,
      sym_qualified_type,
    STATE(1292), 1,
      sym_implicit_length_array_type,
    ACTIONS(283), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(1312), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(485), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(483), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(1068), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(287), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(502), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [14703] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(293), 1,
      sym_identifier,
    ACTIONS(295), 1,
      anon_sym_LPAREN,
    ACTIONS(299), 1,
      anon_sym_func,
    ACTIONS(301), 1,
      anon_sym_STAR,
    ACTIONS(307), 1,
      anon_sym_LT_DASH,
    ACTIONS(315), 1,
      anon_sym_DQUOTE,
    ACTIONS(537), 1,
      anon_sym_chan,
    STATE(387), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(855), 1,
      sym_qualified_type,
    STATE(1268), 1,
      sym_implicit_length_array_type,
    ACTIONS(309), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(1311), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(313), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(311), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(894), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(317), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(394), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [14811] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(295), 1,
      anon_sym_LPAREN,
    ACTIONS(299), 1,
      anon_sym_func,
    ACTIONS(315), 1,
      anon_sym_DQUOTE,
    ACTIONS(403), 1,
      sym_identifier,
    ACTIONS(405), 1,
      anon_sym_STAR,
    ACTIONS(409), 1,
      anon_sym_LT_DASH,
    STATE(630), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(855), 1,
      sym_qualified_type,
    STATE(1268), 1,
      sym_implicit_length_array_type,
    ACTIONS(309), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(1311), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(313), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(411), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(894), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(317), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(394), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [14919] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15), 1,
      anon_sym_LPAREN,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(27), 1,
      anon_sym_STAR,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(41), 1,
      anon_sym_LT_DASH,
    ACTIONS(71), 1,
      anon_sym_DQUOTE,
    ACTIONS(183), 1,
      anon_sym_func,
    ACTIONS(539), 1,
      sym_identifier,
    STATE(242), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(1032), 1,
      sym_qualified_type,
    STATE(1272), 1,
      sym_implicit_length_array_type,
    ACTIONS(65), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(1306), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(69), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(67), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(1104), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(73), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(266), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [15027] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(295), 1,
      anon_sym_LPAREN,
    ACTIONS(299), 1,
      anon_sym_func,
    ACTIONS(315), 1,
      anon_sym_DQUOTE,
    ACTIONS(393), 1,
      sym_identifier,
    ACTIONS(397), 1,
      anon_sym_STAR,
    ACTIONS(399), 1,
      anon_sym_LT_DASH,
    STATE(597), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(855), 1,
      sym_qualified_type,
    STATE(1268), 1,
      sym_implicit_length_array_type,
    ACTIONS(309), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(1311), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(313), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(401), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(894), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(317), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(394), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [15135] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(293), 1,
      sym_identifier,
    ACTIONS(295), 1,
      anon_sym_LPAREN,
    ACTIONS(299), 1,
      anon_sym_func,
    ACTIONS(301), 1,
      anon_sym_STAR,
    ACTIONS(307), 1,
      anon_sym_LT_DASH,
    ACTIONS(315), 1,
      anon_sym_DQUOTE,
    STATE(720), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(855), 1,
      sym_qualified_type,
    STATE(1268), 1,
      sym_implicit_length_array_type,
    ACTIONS(309), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(1311), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(313), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(311), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(894), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(317), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(394), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [15243] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(293), 1,
      sym_identifier,
    ACTIONS(295), 1,
      anon_sym_LPAREN,
    ACTIONS(299), 1,
      anon_sym_func,
    ACTIONS(301), 1,
      anon_sym_STAR,
    ACTIONS(307), 1,
      anon_sym_LT_DASH,
    ACTIONS(315), 1,
      anon_sym_DQUOTE,
    STATE(660), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(855), 1,
      sym_qualified_type,
    STATE(1268), 1,
      sym_implicit_length_array_type,
    ACTIONS(309), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(1311), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(313), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(311), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(894), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(317), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(394), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [15351] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(295), 1,
      anon_sym_LPAREN,
    ACTIONS(299), 1,
      anon_sym_func,
    ACTIONS(315), 1,
      anon_sym_DQUOTE,
    ACTIONS(393), 1,
      sym_identifier,
    ACTIONS(397), 1,
      anon_sym_STAR,
    ACTIONS(399), 1,
      anon_sym_LT_DASH,
    STATE(634), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(855), 1,
      sym_qualified_type,
    STATE(1268), 1,
      sym_implicit_length_array_type,
    ACTIONS(309), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(1311), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(313), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(401), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(894), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(317), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(394), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [15459] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(265), 1,
      sym_identifier,
    ACTIONS(273), 1,
      anon_sym_func,
    ACTIONS(477), 1,
      anon_sym_LPAREN,
    ACTIONS(479), 1,
      anon_sym_STAR,
    ACTIONS(481), 1,
      anon_sym_LT_DASH,
    ACTIONS(487), 1,
      anon_sym_DQUOTE,
    STATE(451), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(1041), 1,
      sym_qualified_type,
    STATE(1292), 1,
      sym_implicit_length_array_type,
    ACTIONS(283), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(1312), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(485), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(483), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(1068), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(287), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(502), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [15567] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(265), 1,
      sym_identifier,
    ACTIONS(273), 1,
      anon_sym_func,
    ACTIONS(477), 1,
      anon_sym_LPAREN,
    ACTIONS(479), 1,
      anon_sym_STAR,
    ACTIONS(481), 1,
      anon_sym_LT_DASH,
    ACTIONS(487), 1,
      anon_sym_DQUOTE,
    STATE(433), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(1041), 1,
      sym_qualified_type,
    STATE(1292), 1,
      sym_implicit_length_array_type,
    ACTIONS(283), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(952), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(485), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(483), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(1068), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(287), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(502), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [15675] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(265), 1,
      sym_identifier,
    ACTIONS(273), 1,
      anon_sym_func,
    ACTIONS(477), 1,
      anon_sym_LPAREN,
    ACTIONS(479), 1,
      anon_sym_STAR,
    ACTIONS(481), 1,
      anon_sym_LT_DASH,
    ACTIONS(487), 1,
      anon_sym_DQUOTE,
    ACTIONS(537), 1,
      anon_sym_chan,
    STATE(433), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(1041), 1,
      sym_qualified_type,
    STATE(1292), 1,
      sym_implicit_length_array_type,
    ACTIONS(283), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(1312), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(485), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(483), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(1068), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(287), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(502), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [15783] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(293), 1,
      sym_identifier,
    ACTIONS(295), 1,
      anon_sym_LPAREN,
    ACTIONS(299), 1,
      anon_sym_func,
    ACTIONS(301), 1,
      anon_sym_STAR,
    ACTIONS(307), 1,
      anon_sym_LT_DASH,
    ACTIONS(315), 1,
      anon_sym_DQUOTE,
    STATE(693), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(855), 1,
      sym_qualified_type,
    STATE(1268), 1,
      sym_implicit_length_array_type,
    ACTIONS(309), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(1311), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(313), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(311), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(894), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(317), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(394), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [15891] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(541), 1,
      sym_identifier,
    ACTIONS(543), 1,
      anon_sym_LPAREN,
    ACTIONS(545), 1,
      anon_sym_func,
    ACTIONS(547), 1,
      anon_sym_STAR,
    ACTIONS(549), 1,
      anon_sym_LT_DASH,
    ACTIONS(557), 1,
      anon_sym_DQUOTE,
    STATE(344), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(1031), 1,
      sym_qualified_type,
    STATE(1295), 1,
      sym_implicit_length_array_type,
    ACTIONS(551), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(1315), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(555), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(553), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(1096), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(559), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(362), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [15999] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(295), 1,
      anon_sym_LPAREN,
    ACTIONS(299), 1,
      anon_sym_func,
    ACTIONS(315), 1,
      anon_sym_DQUOTE,
    ACTIONS(403), 1,
      sym_identifier,
    ACTIONS(405), 1,
      anon_sym_STAR,
    ACTIONS(409), 1,
      anon_sym_LT_DASH,
    STATE(611), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(855), 1,
      sym_qualified_type,
    STATE(1268), 1,
      sym_implicit_length_array_type,
    ACTIONS(309), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(1311), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(313), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(411), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(894), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(317), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(394), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [16107] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(293), 1,
      sym_identifier,
    ACTIONS(295), 1,
      anon_sym_LPAREN,
    ACTIONS(299), 1,
      anon_sym_func,
    ACTIONS(301), 1,
      anon_sym_STAR,
    ACTIONS(307), 1,
      anon_sym_LT_DASH,
    ACTIONS(315), 1,
      anon_sym_DQUOTE,
    STATE(667), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(855), 1,
      sym_qualified_type,
    STATE(1268), 1,
      sym_implicit_length_array_type,
    ACTIONS(309), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(1311), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(313), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(311), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(894), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(317), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(394), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [16215] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(295), 1,
      anon_sym_LPAREN,
    ACTIONS(299), 1,
      anon_sym_func,
    ACTIONS(315), 1,
      anon_sym_DQUOTE,
    ACTIONS(393), 1,
      sym_identifier,
    ACTIONS(397), 1,
      anon_sym_STAR,
    ACTIONS(399), 1,
      anon_sym_LT_DASH,
    STATE(387), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(855), 1,
      sym_qualified_type,
    STATE(1268), 1,
      sym_implicit_length_array_type,
    ACTIONS(309), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(1311), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(313), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(401), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(894), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(317), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(394), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [16323] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(293), 1,
      sym_identifier,
    ACTIONS(295), 1,
      anon_sym_LPAREN,
    ACTIONS(299), 1,
      anon_sym_func,
    ACTIONS(301), 1,
      anon_sym_STAR,
    ACTIONS(307), 1,
      anon_sym_LT_DASH,
    ACTIONS(315), 1,
      anon_sym_DQUOTE,
    STATE(482), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(855), 1,
      sym_qualified_type,
    STATE(1268), 1,
      sym_implicit_length_array_type,
    ACTIONS(309), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(1311), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(313), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(311), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(894), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(317), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(394), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [16431] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(231), 1,
      sym_identifier,
    ACTIONS(235), 1,
      anon_sym_LPAREN,
    ACTIONS(237), 1,
      anon_sym_func,
    ACTIONS(239), 1,
      anon_sym_STAR,
    ACTIONS(241), 1,
      anon_sym_LT_DASH,
    ACTIONS(251), 1,
      anon_sym_DQUOTE,
    STATE(292), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(1018), 1,
      sym_qualified_type,
    STATE(1293), 1,
      sym_implicit_length_array_type,
    ACTIONS(245), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(952), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(249), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(247), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(1084), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(253), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(306), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [16539] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(295), 1,
      anon_sym_LPAREN,
    ACTIONS(299), 1,
      anon_sym_func,
    ACTIONS(315), 1,
      anon_sym_DQUOTE,
    ACTIONS(393), 1,
      sym_identifier,
    ACTIONS(397), 1,
      anon_sym_STAR,
    ACTIONS(399), 1,
      anon_sym_LT_DASH,
    STATE(388), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(855), 1,
      sym_qualified_type,
    STATE(1268), 1,
      sym_implicit_length_array_type,
    ACTIONS(309), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(1311), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(313), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(401), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(894), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(317), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(394), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [16647] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(231), 1,
      sym_identifier,
    ACTIONS(235), 1,
      anon_sym_LPAREN,
    ACTIONS(237), 1,
      anon_sym_func,
    ACTIONS(239), 1,
      anon_sym_STAR,
    ACTIONS(241), 1,
      anon_sym_LT_DASH,
    ACTIONS(251), 1,
      anon_sym_DQUOTE,
    ACTIONS(537), 1,
      anon_sym_chan,
    STATE(292), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(1018), 1,
      sym_qualified_type,
    STATE(1293), 1,
      sym_implicit_length_array_type,
    ACTIONS(245), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(1314), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(249), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(247), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(1084), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(253), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(306), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [16755] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(295), 1,
      anon_sym_LPAREN,
    ACTIONS(299), 1,
      anon_sym_func,
    ACTIONS(315), 1,
      anon_sym_DQUOTE,
    ACTIONS(393), 1,
      sym_identifier,
    ACTIONS(397), 1,
      anon_sym_STAR,
    ACTIONS(399), 1,
      anon_sym_LT_DASH,
    STATE(558), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(855), 1,
      sym_qualified_type,
    STATE(1268), 1,
      sym_implicit_length_array_type,
    ACTIONS(309), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(1311), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(313), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(401), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(894), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(317), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(394), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [16863] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(363), 1,
      sym_identifier,
    ACTIONS(365), 1,
      anon_sym_LPAREN,
    ACTIONS(367), 1,
      anon_sym_func,
    ACTIONS(369), 1,
      anon_sym_STAR,
    ACTIONS(371), 1,
      anon_sym_LT_DASH,
    ACTIONS(379), 1,
      anon_sym_DQUOTE,
    STATE(495), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(1022), 1,
      sym_qualified_type,
    STATE(1258), 1,
      sym_implicit_length_array_type,
    ACTIONS(373), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(1283), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(377), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(375), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(1108), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(381), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(534), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [16971] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(295), 1,
      anon_sym_LPAREN,
    ACTIONS(299), 1,
      anon_sym_func,
    ACTIONS(315), 1,
      anon_sym_DQUOTE,
    ACTIONS(393), 1,
      sym_identifier,
    ACTIONS(397), 1,
      anon_sym_STAR,
    ACTIONS(399), 1,
      anon_sym_LT_DASH,
    STATE(559), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(855), 1,
      sym_qualified_type,
    STATE(1268), 1,
      sym_implicit_length_array_type,
    ACTIONS(309), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(1311), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(313), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(401), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(894), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(317), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(394), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [17079] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(295), 1,
      anon_sym_LPAREN,
    ACTIONS(299), 1,
      anon_sym_func,
    ACTIONS(315), 1,
      anon_sym_DQUOTE,
    ACTIONS(393), 1,
      sym_identifier,
    ACTIONS(397), 1,
      anon_sym_STAR,
    ACTIONS(399), 1,
      anon_sym_LT_DASH,
    STATE(560), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(855), 1,
      sym_qualified_type,
    STATE(1268), 1,
      sym_implicit_length_array_type,
    ACTIONS(309), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(1311), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(313), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(401), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(894), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(317), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(394), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [17187] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(295), 1,
      anon_sym_LPAREN,
    ACTIONS(299), 1,
      anon_sym_func,
    ACTIONS(315), 1,
      anon_sym_DQUOTE,
    ACTIONS(393), 1,
      sym_identifier,
    ACTIONS(397), 1,
      anon_sym_STAR,
    ACTIONS(399), 1,
      anon_sym_LT_DASH,
    STATE(561), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(855), 1,
      sym_qualified_type,
    STATE(1268), 1,
      sym_implicit_length_array_type,
    ACTIONS(309), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(1311), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(313), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(401), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(894), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(317), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(394), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [17295] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(293), 1,
      sym_identifier,
    ACTIONS(295), 1,
      anon_sym_LPAREN,
    ACTIONS(299), 1,
      anon_sym_func,
    ACTIONS(301), 1,
      anon_sym_STAR,
    ACTIONS(307), 1,
      anon_sym_LT_DASH,
    ACTIONS(315), 1,
      anon_sym_DQUOTE,
    STATE(387), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(855), 1,
      sym_qualified_type,
    STATE(1268), 1,
      sym_implicit_length_array_type,
    ACTIONS(309), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(1311), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(313), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(311), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(894), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(317), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(394), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [17403] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(293), 1,
      sym_identifier,
    ACTIONS(295), 1,
      anon_sym_LPAREN,
    ACTIONS(299), 1,
      anon_sym_func,
    ACTIONS(301), 1,
      anon_sym_STAR,
    ACTIONS(307), 1,
      anon_sym_LT_DASH,
    ACTIONS(315), 1,
      anon_sym_DQUOTE,
    STATE(388), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(855), 1,
      sym_qualified_type,
    STATE(1268), 1,
      sym_implicit_length_array_type,
    ACTIONS(309), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(1311), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(313), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(311), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(894), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(317), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(394), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [17511] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(293), 1,
      sym_identifier,
    ACTIONS(295), 1,
      anon_sym_LPAREN,
    ACTIONS(299), 1,
      anon_sym_func,
    ACTIONS(301), 1,
      anon_sym_STAR,
    ACTIONS(307), 1,
      anon_sym_LT_DASH,
    ACTIONS(315), 1,
      anon_sym_DQUOTE,
    STATE(437), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(855), 1,
      sym_qualified_type,
    STATE(1268), 1,
      sym_implicit_length_array_type,
    ACTIONS(309), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(1311), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(313), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(311), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(894), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(317), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(394), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [17619] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(293), 1,
      sym_identifier,
    ACTIONS(295), 1,
      anon_sym_LPAREN,
    ACTIONS(299), 1,
      anon_sym_func,
    ACTIONS(301), 1,
      anon_sym_STAR,
    ACTIONS(307), 1,
      anon_sym_LT_DASH,
    ACTIONS(315), 1,
      anon_sym_DQUOTE,
    STATE(442), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(855), 1,
      sym_qualified_type,
    STATE(1268), 1,
      sym_implicit_length_array_type,
    ACTIONS(309), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(1311), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(313), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(311), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(894), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(317), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(394), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [17727] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(293), 1,
      sym_identifier,
    ACTIONS(295), 1,
      anon_sym_LPAREN,
    ACTIONS(299), 1,
      anon_sym_func,
    ACTIONS(301), 1,
      anon_sym_STAR,
    ACTIONS(307), 1,
      anon_sym_LT_DASH,
    ACTIONS(315), 1,
      anon_sym_DQUOTE,
    STATE(444), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(855), 1,
      sym_qualified_type,
    STATE(1268), 1,
      sym_implicit_length_array_type,
    ACTIONS(309), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(1311), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(313), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(311), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(894), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(317), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(394), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [17835] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(293), 1,
      sym_identifier,
    ACTIONS(295), 1,
      anon_sym_LPAREN,
    ACTIONS(299), 1,
      anon_sym_func,
    ACTIONS(301), 1,
      anon_sym_STAR,
    ACTIONS(307), 1,
      anon_sym_LT_DASH,
    ACTIONS(315), 1,
      anon_sym_DQUOTE,
    STATE(443), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(855), 1,
      sym_qualified_type,
    STATE(1268), 1,
      sym_implicit_length_array_type,
    ACTIONS(309), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(1311), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(313), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(311), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(894), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(317), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(394), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [17943] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(265), 1,
      sym_identifier,
    ACTIONS(273), 1,
      anon_sym_func,
    ACTIONS(477), 1,
      anon_sym_LPAREN,
    ACTIONS(479), 1,
      anon_sym_STAR,
    ACTIONS(481), 1,
      anon_sym_LT_DASH,
    ACTIONS(487), 1,
      anon_sym_DQUOTE,
    STATE(433), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(1041), 1,
      sym_qualified_type,
    STATE(1292), 1,
      sym_implicit_length_array_type,
    ACTIONS(283), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(1312), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(485), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(483), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(1068), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(287), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(502), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [18051] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(295), 1,
      anon_sym_LPAREN,
    ACTIONS(299), 1,
      anon_sym_func,
    ACTIONS(315), 1,
      anon_sym_DQUOTE,
    ACTIONS(393), 1,
      sym_identifier,
    ACTIONS(397), 1,
      anon_sym_STAR,
    ACTIONS(399), 1,
      anon_sym_LT_DASH,
    STATE(387), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(855), 1,
      sym_qualified_type,
    STATE(1268), 1,
      sym_implicit_length_array_type,
    ACTIONS(309), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(952), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(313), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(401), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(894), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(317), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(394), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [18159] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(265), 1,
      sym_identifier,
    ACTIONS(273), 1,
      anon_sym_func,
    ACTIONS(477), 1,
      anon_sym_LPAREN,
    ACTIONS(479), 1,
      anon_sym_STAR,
    ACTIONS(481), 1,
      anon_sym_LT_DASH,
    ACTIONS(487), 1,
      anon_sym_DQUOTE,
    STATE(436), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(1041), 1,
      sym_qualified_type,
    STATE(1292), 1,
      sym_implicit_length_array_type,
    ACTIONS(283), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(1312), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(485), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(483), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(1068), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(287), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(502), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [18267] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(295), 1,
      anon_sym_LPAREN,
    ACTIONS(299), 1,
      anon_sym_func,
    ACTIONS(315), 1,
      anon_sym_DQUOTE,
    ACTIONS(403), 1,
      sym_identifier,
    ACTIONS(405), 1,
      anon_sym_STAR,
    ACTIONS(409), 1,
      anon_sym_LT_DASH,
    ACTIONS(537), 1,
      anon_sym_chan,
    STATE(387), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(855), 1,
      sym_qualified_type,
    STATE(1268), 1,
      sym_implicit_length_array_type,
    ACTIONS(309), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(1311), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(313), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(411), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(894), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(317), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(394), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [18375] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(265), 1,
      sym_identifier,
    ACTIONS(273), 1,
      anon_sym_func,
    ACTIONS(477), 1,
      anon_sym_LPAREN,
    ACTIONS(479), 1,
      anon_sym_STAR,
    ACTIONS(481), 1,
      anon_sym_LT_DASH,
    ACTIONS(487), 1,
      anon_sym_DQUOTE,
    STATE(440), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(1041), 1,
      sym_qualified_type,
    STATE(1292), 1,
      sym_implicit_length_array_type,
    ACTIONS(283), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(1312), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(485), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(483), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(1068), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(287), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(502), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [18483] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(265), 1,
      sym_identifier,
    ACTIONS(273), 1,
      anon_sym_func,
    ACTIONS(477), 1,
      anon_sym_LPAREN,
    ACTIONS(479), 1,
      anon_sym_STAR,
    ACTIONS(481), 1,
      anon_sym_LT_DASH,
    ACTIONS(487), 1,
      anon_sym_DQUOTE,
    STATE(438), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(1041), 1,
      sym_qualified_type,
    STATE(1292), 1,
      sym_implicit_length_array_type,
    ACTIONS(283), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(1312), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(485), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(483), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(1068), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(287), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(502), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [18591] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(265), 1,
      sym_identifier,
    ACTIONS(273), 1,
      anon_sym_func,
    ACTIONS(477), 1,
      anon_sym_LPAREN,
    ACTIONS(479), 1,
      anon_sym_STAR,
    ACTIONS(481), 1,
      anon_sym_LT_DASH,
    ACTIONS(487), 1,
      anon_sym_DQUOTE,
    STATE(434), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(1041), 1,
      sym_qualified_type,
    STATE(1292), 1,
      sym_implicit_length_array_type,
    ACTIONS(283), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(1312), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(485), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(483), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(1068), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(287), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(502), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [18699] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(265), 1,
      sym_identifier,
    ACTIONS(273), 1,
      anon_sym_func,
    ACTIONS(477), 1,
      anon_sym_LPAREN,
    ACTIONS(479), 1,
      anon_sym_STAR,
    ACTIONS(481), 1,
      anon_sym_LT_DASH,
    ACTIONS(487), 1,
      anon_sym_DQUOTE,
    STATE(441), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(1041), 1,
      sym_qualified_type,
    STATE(1292), 1,
      sym_implicit_length_array_type,
    ACTIONS(283), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(1312), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(485), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(483), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(1068), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(287), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(502), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [18807] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(231), 1,
      sym_identifier,
    ACTIONS(235), 1,
      anon_sym_LPAREN,
    ACTIONS(237), 1,
      anon_sym_func,
    ACTIONS(239), 1,
      anon_sym_STAR,
    ACTIONS(241), 1,
      anon_sym_LT_DASH,
    ACTIONS(251), 1,
      anon_sym_DQUOTE,
    STATE(292), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(1018), 1,
      sym_qualified_type,
    STATE(1293), 1,
      sym_implicit_length_array_type,
    ACTIONS(245), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(1314), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(249), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(247), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(1084), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(253), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(306), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [18915] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(231), 1,
      sym_identifier,
    ACTIONS(235), 1,
      anon_sym_LPAREN,
    ACTIONS(237), 1,
      anon_sym_func,
    ACTIONS(239), 1,
      anon_sym_STAR,
    ACTIONS(241), 1,
      anon_sym_LT_DASH,
    ACTIONS(251), 1,
      anon_sym_DQUOTE,
    STATE(297), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(1018), 1,
      sym_qualified_type,
    STATE(1293), 1,
      sym_implicit_length_array_type,
    ACTIONS(245), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(1314), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(249), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(247), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(1084), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(253), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(306), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [19023] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(231), 1,
      sym_identifier,
    ACTIONS(235), 1,
      anon_sym_LPAREN,
    ACTIONS(237), 1,
      anon_sym_func,
    ACTIONS(239), 1,
      anon_sym_STAR,
    ACTIONS(241), 1,
      anon_sym_LT_DASH,
    ACTIONS(251), 1,
      anon_sym_DQUOTE,
    STATE(293), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(1018), 1,
      sym_qualified_type,
    STATE(1293), 1,
      sym_implicit_length_array_type,
    ACTIONS(245), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(1314), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(249), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(247), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(1084), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(253), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(306), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [19131] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(231), 1,
      sym_identifier,
    ACTIONS(235), 1,
      anon_sym_LPAREN,
    ACTIONS(237), 1,
      anon_sym_func,
    ACTIONS(239), 1,
      anon_sym_STAR,
    ACTIONS(241), 1,
      anon_sym_LT_DASH,
    ACTIONS(251), 1,
      anon_sym_DQUOTE,
    STATE(290), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(1018), 1,
      sym_qualified_type,
    STATE(1293), 1,
      sym_implicit_length_array_type,
    ACTIONS(245), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(1314), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(249), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(247), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(1084), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(253), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(306), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [19239] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(231), 1,
      sym_identifier,
    ACTIONS(235), 1,
      anon_sym_LPAREN,
    ACTIONS(237), 1,
      anon_sym_func,
    ACTIONS(239), 1,
      anon_sym_STAR,
    ACTIONS(241), 1,
      anon_sym_LT_DASH,
    ACTIONS(251), 1,
      anon_sym_DQUOTE,
    STATE(294), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(1018), 1,
      sym_qualified_type,
    STATE(1293), 1,
      sym_implicit_length_array_type,
    ACTIONS(245), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(1314), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(249), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(247), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(1084), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(253), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(306), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [19347] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(231), 1,
      sym_identifier,
    ACTIONS(235), 1,
      anon_sym_LPAREN,
    ACTIONS(237), 1,
      anon_sym_func,
    ACTIONS(239), 1,
      anon_sym_STAR,
    ACTIONS(241), 1,
      anon_sym_LT_DASH,
    ACTIONS(251), 1,
      anon_sym_DQUOTE,
    STATE(295), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(1018), 1,
      sym_qualified_type,
    STATE(1293), 1,
      sym_implicit_length_array_type,
    ACTIONS(245), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(1314), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(249), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(247), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(1084), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(253), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(306), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [19455] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(541), 1,
      sym_identifier,
    ACTIONS(543), 1,
      anon_sym_LPAREN,
    ACTIONS(545), 1,
      anon_sym_func,
    ACTIONS(547), 1,
      anon_sym_STAR,
    ACTIONS(549), 1,
      anon_sym_LT_DASH,
    ACTIONS(557), 1,
      anon_sym_DQUOTE,
    STATE(343), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(1031), 1,
      sym_qualified_type,
    STATE(1295), 1,
      sym_implicit_length_array_type,
    ACTIONS(551), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(1315), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(555), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(553), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(1096), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(559), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(362), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [19563] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(295), 1,
      anon_sym_LPAREN,
    ACTIONS(299), 1,
      anon_sym_func,
    ACTIONS(315), 1,
      anon_sym_DQUOTE,
    ACTIONS(403), 1,
      sym_identifier,
    ACTIONS(405), 1,
      anon_sym_STAR,
    ACTIONS(409), 1,
      anon_sym_LT_DASH,
    STATE(387), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(855), 1,
      sym_qualified_type,
    STATE(1268), 1,
      sym_implicit_length_array_type,
    ACTIONS(309), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(952), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(313), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(411), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(894), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(317), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(394), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [19671] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(541), 1,
      sym_identifier,
    ACTIONS(543), 1,
      anon_sym_LPAREN,
    ACTIONS(545), 1,
      anon_sym_func,
    ACTIONS(547), 1,
      anon_sym_STAR,
    ACTIONS(549), 1,
      anon_sym_LT_DASH,
    ACTIONS(557), 1,
      anon_sym_DQUOTE,
    STATE(339), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(1031), 1,
      sym_qualified_type,
    STATE(1295), 1,
      sym_implicit_length_array_type,
    ACTIONS(551), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(1315), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(555), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(553), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(1096), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(559), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(362), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [19779] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(537), 1,
      anon_sym_chan,
    ACTIONS(541), 1,
      sym_identifier,
    ACTIONS(543), 1,
      anon_sym_LPAREN,
    ACTIONS(545), 1,
      anon_sym_func,
    ACTIONS(547), 1,
      anon_sym_STAR,
    ACTIONS(549), 1,
      anon_sym_LT_DASH,
    ACTIONS(557), 1,
      anon_sym_DQUOTE,
    STATE(343), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(1031), 1,
      sym_qualified_type,
    STATE(1295), 1,
      sym_implicit_length_array_type,
    ACTIONS(551), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(1315), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(555), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(553), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(1096), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(559), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(362), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [19887] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(541), 1,
      sym_identifier,
    ACTIONS(543), 1,
      anon_sym_LPAREN,
    ACTIONS(545), 1,
      anon_sym_func,
    ACTIONS(547), 1,
      anon_sym_STAR,
    ACTIONS(549), 1,
      anon_sym_LT_DASH,
    ACTIONS(557), 1,
      anon_sym_DQUOTE,
    STATE(343), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(1031), 1,
      sym_qualified_type,
    STATE(1295), 1,
      sym_implicit_length_array_type,
    ACTIONS(551), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(952), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(555), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(553), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(1096), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(559), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(362), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [19995] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(363), 1,
      sym_identifier,
    ACTIONS(365), 1,
      anon_sym_LPAREN,
    ACTIONS(367), 1,
      anon_sym_func,
    ACTIONS(369), 1,
      anon_sym_STAR,
    ACTIONS(371), 1,
      anon_sym_LT_DASH,
    ACTIONS(379), 1,
      anon_sym_DQUOTE,
    ACTIONS(537), 1,
      anon_sym_chan,
    STATE(487), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(1022), 1,
      sym_qualified_type,
    STATE(1258), 1,
      sym_implicit_length_array_type,
    ACTIONS(373), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(1283), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(377), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(375), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(1108), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(381), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(534), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [20103] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(295), 1,
      anon_sym_LPAREN,
    ACTIONS(299), 1,
      anon_sym_func,
    ACTIONS(307), 1,
      anon_sym_LT_DASH,
    ACTIONS(315), 1,
      anon_sym_DQUOTE,
    ACTIONS(387), 1,
      sym_identifier,
    ACTIONS(389), 1,
      anon_sym_STAR,
    STATE(387), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(855), 1,
      sym_qualified_type,
    STATE(1268), 1,
      sym_implicit_length_array_type,
    ACTIONS(309), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(952), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(313), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(311), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(894), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(317), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(394), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [20211] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(363), 1,
      sym_identifier,
    ACTIONS(365), 1,
      anon_sym_LPAREN,
    ACTIONS(367), 1,
      anon_sym_func,
    ACTIONS(369), 1,
      anon_sym_STAR,
    ACTIONS(371), 1,
      anon_sym_LT_DASH,
    ACTIONS(379), 1,
      anon_sym_DQUOTE,
    STATE(487), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(1022), 1,
      sym_qualified_type,
    STATE(1258), 1,
      sym_implicit_length_array_type,
    ACTIONS(373), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(952), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(377), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(375), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(1108), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(381), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(534), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [20319] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(293), 1,
      sym_identifier,
    ACTIONS(295), 1,
      anon_sym_LPAREN,
    ACTIONS(299), 1,
      anon_sym_func,
    ACTIONS(315), 1,
      anon_sym_DQUOTE,
    ACTIONS(399), 1,
      anon_sym_LT_DASH,
    ACTIONS(535), 1,
      anon_sym_STAR,
    STATE(647), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(855), 1,
      sym_qualified_type,
    STATE(1268), 1,
      sym_implicit_length_array_type,
    ACTIONS(309), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(1197), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(313), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(401), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(894), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(317), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(394), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [20427] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(295), 1,
      anon_sym_LPAREN,
    ACTIONS(299), 1,
      anon_sym_func,
    ACTIONS(315), 1,
      anon_sym_DQUOTE,
    ACTIONS(393), 1,
      sym_identifier,
    ACTIONS(397), 1,
      anon_sym_STAR,
    ACTIONS(399), 1,
      anon_sym_LT_DASH,
    STATE(607), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(855), 1,
      sym_qualified_type,
    STATE(1268), 1,
      sym_implicit_length_array_type,
    ACTIONS(309), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(1311), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(313), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(401), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(894), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(317), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(394), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [20535] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(541), 1,
      sym_identifier,
    ACTIONS(543), 1,
      anon_sym_LPAREN,
    ACTIONS(545), 1,
      anon_sym_func,
    ACTIONS(547), 1,
      anon_sym_STAR,
    ACTIONS(549), 1,
      anon_sym_LT_DASH,
    ACTIONS(557), 1,
      anon_sym_DQUOTE,
    STATE(340), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(1031), 1,
      sym_qualified_type,
    STATE(1295), 1,
      sym_implicit_length_array_type,
    ACTIONS(551), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(1315), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(555), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(553), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(1096), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(559), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(362), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [20643] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(293), 1,
      sym_identifier,
    ACTIONS(295), 1,
      anon_sym_LPAREN,
    ACTIONS(299), 1,
      anon_sym_func,
    ACTIONS(301), 1,
      anon_sym_STAR,
    ACTIONS(307), 1,
      anon_sym_LT_DASH,
    ACTIONS(315), 1,
      anon_sym_DQUOTE,
    STATE(653), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(855), 1,
      sym_qualified_type,
    STATE(1268), 1,
      sym_implicit_length_array_type,
    ACTIONS(309), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(1311), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(313), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(311), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(894), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(317), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(394), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [20751] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(293), 1,
      sym_identifier,
    ACTIONS(295), 1,
      anon_sym_LPAREN,
    ACTIONS(299), 1,
      anon_sym_func,
    ACTIONS(301), 1,
      anon_sym_STAR,
    ACTIONS(307), 1,
      anon_sym_LT_DASH,
    ACTIONS(315), 1,
      anon_sym_DQUOTE,
    STATE(654), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(855), 1,
      sym_qualified_type,
    STATE(1268), 1,
      sym_implicit_length_array_type,
    ACTIONS(309), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(1311), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(313), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(311), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(894), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(317), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(394), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [20859] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(293), 1,
      sym_identifier,
    ACTIONS(295), 1,
      anon_sym_LPAREN,
    ACTIONS(299), 1,
      anon_sym_func,
    ACTIONS(315), 1,
      anon_sym_DQUOTE,
    ACTIONS(399), 1,
      anon_sym_LT_DASH,
    ACTIONS(535), 1,
      anon_sym_STAR,
    STATE(657), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(855), 1,
      sym_qualified_type,
    STATE(1268), 1,
      sym_implicit_length_array_type,
    ACTIONS(309), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(1197), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(313), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(401), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(894), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(317), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(394), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [20967] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(295), 1,
      anon_sym_LPAREN,
    ACTIONS(299), 1,
      anon_sym_func,
    ACTIONS(315), 1,
      anon_sym_DQUOTE,
    ACTIONS(393), 1,
      sym_identifier,
    ACTIONS(397), 1,
      anon_sym_STAR,
    ACTIONS(399), 1,
      anon_sym_LT_DASH,
    STATE(629), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(855), 1,
      sym_qualified_type,
    STATE(1268), 1,
      sym_implicit_length_array_type,
    ACTIONS(309), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(1311), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(313), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(401), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(894), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(317), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(394), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [21075] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(541), 1,
      sym_identifier,
    ACTIONS(543), 1,
      anon_sym_LPAREN,
    ACTIONS(545), 1,
      anon_sym_func,
    ACTIONS(547), 1,
      anon_sym_STAR,
    ACTIONS(549), 1,
      anon_sym_LT_DASH,
    ACTIONS(557), 1,
      anon_sym_DQUOTE,
    STATE(338), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(1031), 1,
      sym_qualified_type,
    STATE(1295), 1,
      sym_implicit_length_array_type,
    ACTIONS(551), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(1315), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(555), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(553), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(1096), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(559), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(362), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [21183] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(293), 1,
      sym_identifier,
    ACTIONS(295), 1,
      anon_sym_LPAREN,
    ACTIONS(299), 1,
      anon_sym_func,
    ACTIONS(301), 1,
      anon_sym_STAR,
    ACTIONS(307), 1,
      anon_sym_LT_DASH,
    ACTIONS(315), 1,
      anon_sym_DQUOTE,
    STATE(665), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(855), 1,
      sym_qualified_type,
    STATE(1268), 1,
      sym_implicit_length_array_type,
    ACTIONS(309), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(1311), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(313), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(311), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(894), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(317), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(394), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [21291] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(293), 1,
      sym_identifier,
    ACTIONS(295), 1,
      anon_sym_LPAREN,
    ACTIONS(299), 1,
      anon_sym_func,
    ACTIONS(301), 1,
      anon_sym_STAR,
    ACTIONS(307), 1,
      anon_sym_LT_DASH,
    ACTIONS(315), 1,
      anon_sym_DQUOTE,
    STATE(666), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(855), 1,
      sym_qualified_type,
    STATE(1268), 1,
      sym_implicit_length_array_type,
    ACTIONS(309), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(1311), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(313), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(311), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(894), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(317), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(394), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [21399] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(293), 1,
      sym_identifier,
    ACTIONS(295), 1,
      anon_sym_LPAREN,
    ACTIONS(299), 1,
      anon_sym_func,
    ACTIONS(315), 1,
      anon_sym_DQUOTE,
    ACTIONS(399), 1,
      anon_sym_LT_DASH,
    ACTIONS(535), 1,
      anon_sym_STAR,
    STATE(669), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(855), 1,
      sym_qualified_type,
    STATE(1268), 1,
      sym_implicit_length_array_type,
    ACTIONS(309), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(1197), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(313), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(401), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(894), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(317), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(394), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [21507] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(295), 1,
      anon_sym_LPAREN,
    ACTIONS(299), 1,
      anon_sym_func,
    ACTIONS(315), 1,
      anon_sym_DQUOTE,
    ACTIONS(393), 1,
      sym_identifier,
    ACTIONS(397), 1,
      anon_sym_STAR,
    ACTIONS(399), 1,
      anon_sym_LT_DASH,
    STATE(602), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(855), 1,
      sym_qualified_type,
    STATE(1268), 1,
      sym_implicit_length_array_type,
    ACTIONS(309), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(1311), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(313), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(401), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(894), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(317), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(394), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [21615] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(541), 1,
      sym_identifier,
    ACTIONS(543), 1,
      anon_sym_LPAREN,
    ACTIONS(545), 1,
      anon_sym_func,
    ACTIONS(547), 1,
      anon_sym_STAR,
    ACTIONS(549), 1,
      anon_sym_LT_DASH,
    ACTIONS(557), 1,
      anon_sym_DQUOTE,
    STATE(341), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(1031), 1,
      sym_qualified_type,
    STATE(1295), 1,
      sym_implicit_length_array_type,
    ACTIONS(551), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(1315), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(555), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(553), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(1096), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(559), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(362), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [21723] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(293), 1,
      sym_identifier,
    ACTIONS(295), 1,
      anon_sym_LPAREN,
    ACTIONS(299), 1,
      anon_sym_func,
    ACTIONS(301), 1,
      anon_sym_STAR,
    ACTIONS(307), 1,
      anon_sym_LT_DASH,
    ACTIONS(315), 1,
      anon_sym_DQUOTE,
    STATE(674), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(855), 1,
      sym_qualified_type,
    STATE(1268), 1,
      sym_implicit_length_array_type,
    ACTIONS(309), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(1311), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(313), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(311), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(894), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(317), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(394), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [21831] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(293), 1,
      sym_identifier,
    ACTIONS(295), 1,
      anon_sym_LPAREN,
    ACTIONS(299), 1,
      anon_sym_func,
    ACTIONS(301), 1,
      anon_sym_STAR,
    ACTIONS(307), 1,
      anon_sym_LT_DASH,
    ACTIONS(315), 1,
      anon_sym_DQUOTE,
    STATE(675), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(855), 1,
      sym_qualified_type,
    STATE(1268), 1,
      sym_implicit_length_array_type,
    ACTIONS(309), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(1311), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(313), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(311), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(894), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(317), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(394), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [21939] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(293), 1,
      sym_identifier,
    ACTIONS(295), 1,
      anon_sym_LPAREN,
    ACTIONS(299), 1,
      anon_sym_func,
    ACTIONS(315), 1,
      anon_sym_DQUOTE,
    ACTIONS(399), 1,
      anon_sym_LT_DASH,
    ACTIONS(535), 1,
      anon_sym_STAR,
    STATE(676), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(855), 1,
      sym_qualified_type,
    STATE(1268), 1,
      sym_implicit_length_array_type,
    ACTIONS(309), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(1197), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(313), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(401), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(894), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(317), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(394), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [22047] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(295), 1,
      anon_sym_LPAREN,
    ACTIONS(299), 1,
      anon_sym_func,
    ACTIONS(315), 1,
      anon_sym_DQUOTE,
    ACTIONS(393), 1,
      sym_identifier,
    ACTIONS(397), 1,
      anon_sym_STAR,
    ACTIONS(399), 1,
      anon_sym_LT_DASH,
    STATE(605), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(855), 1,
      sym_qualified_type,
    STATE(1268), 1,
      sym_implicit_length_array_type,
    ACTIONS(309), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(1311), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(313), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(401), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(894), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(317), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(394), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [22155] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(541), 1,
      sym_identifier,
    ACTIONS(543), 1,
      anon_sym_LPAREN,
    ACTIONS(545), 1,
      anon_sym_func,
    ACTIONS(547), 1,
      anon_sym_STAR,
    ACTIONS(549), 1,
      anon_sym_LT_DASH,
    ACTIONS(557), 1,
      anon_sym_DQUOTE,
    STATE(342), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(1031), 1,
      sym_qualified_type,
    STATE(1295), 1,
      sym_implicit_length_array_type,
    ACTIONS(551), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(1315), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(555), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(553), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(1096), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(559), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(362), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [22263] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(293), 1,
      sym_identifier,
    ACTIONS(295), 1,
      anon_sym_LPAREN,
    ACTIONS(299), 1,
      anon_sym_func,
    ACTIONS(301), 1,
      anon_sym_STAR,
    ACTIONS(307), 1,
      anon_sym_LT_DASH,
    ACTIONS(315), 1,
      anon_sym_DQUOTE,
    STATE(680), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(855), 1,
      sym_qualified_type,
    STATE(1268), 1,
      sym_implicit_length_array_type,
    ACTIONS(309), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(1311), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(313), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(311), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(894), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(317), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(394), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [22371] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(293), 1,
      sym_identifier,
    ACTIONS(295), 1,
      anon_sym_LPAREN,
    ACTIONS(299), 1,
      anon_sym_func,
    ACTIONS(301), 1,
      anon_sym_STAR,
    ACTIONS(307), 1,
      anon_sym_LT_DASH,
    ACTIONS(315), 1,
      anon_sym_DQUOTE,
    STATE(681), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(855), 1,
      sym_qualified_type,
    STATE(1268), 1,
      sym_implicit_length_array_type,
    ACTIONS(309), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(1311), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(313), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(311), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(894), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(317), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(394), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [22479] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(293), 1,
      sym_identifier,
    ACTIONS(295), 1,
      anon_sym_LPAREN,
    ACTIONS(299), 1,
      anon_sym_func,
    ACTIONS(315), 1,
      anon_sym_DQUOTE,
    ACTIONS(399), 1,
      anon_sym_LT_DASH,
    ACTIONS(535), 1,
      anon_sym_STAR,
    STATE(682), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(855), 1,
      sym_qualified_type,
    STATE(1268), 1,
      sym_implicit_length_array_type,
    ACTIONS(309), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(1197), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(313), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(401), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(894), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(317), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(394), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [22587] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(295), 1,
      anon_sym_LPAREN,
    ACTIONS(299), 1,
      anon_sym_func,
    ACTIONS(315), 1,
      anon_sym_DQUOTE,
    ACTIONS(393), 1,
      sym_identifier,
    ACTIONS(397), 1,
      anon_sym_STAR,
    ACTIONS(399), 1,
      anon_sym_LT_DASH,
    STATE(633), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(855), 1,
      sym_qualified_type,
    STATE(1268), 1,
      sym_implicit_length_array_type,
    ACTIONS(309), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(1311), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(313), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(401), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(894), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(317), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(394), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [22695] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(363), 1,
      sym_identifier,
    ACTIONS(365), 1,
      anon_sym_LPAREN,
    ACTIONS(367), 1,
      anon_sym_func,
    ACTIONS(369), 1,
      anon_sym_STAR,
    ACTIONS(371), 1,
      anon_sym_LT_DASH,
    ACTIONS(379), 1,
      anon_sym_DQUOTE,
    STATE(487), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(1022), 1,
      sym_qualified_type,
    STATE(1258), 1,
      sym_implicit_length_array_type,
    ACTIONS(373), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(1283), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(377), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(375), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(1108), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(381), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(534), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [22803] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(293), 1,
      sym_identifier,
    ACTIONS(295), 1,
      anon_sym_LPAREN,
    ACTIONS(299), 1,
      anon_sym_func,
    ACTIONS(301), 1,
      anon_sym_STAR,
    ACTIONS(307), 1,
      anon_sym_LT_DASH,
    ACTIONS(315), 1,
      anon_sym_DQUOTE,
    STATE(687), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(855), 1,
      sym_qualified_type,
    STATE(1268), 1,
      sym_implicit_length_array_type,
    ACTIONS(309), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(1311), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(313), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(311), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(894), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(317), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(394), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [22911] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(293), 1,
      sym_identifier,
    ACTIONS(295), 1,
      anon_sym_LPAREN,
    ACTIONS(299), 1,
      anon_sym_func,
    ACTIONS(301), 1,
      anon_sym_STAR,
    ACTIONS(307), 1,
      anon_sym_LT_DASH,
    ACTIONS(315), 1,
      anon_sym_DQUOTE,
    STATE(688), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(855), 1,
      sym_qualified_type,
    STATE(1268), 1,
      sym_implicit_length_array_type,
    ACTIONS(309), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(1311), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(313), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(311), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(894), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(317), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(394), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [23019] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_LBRACK,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(293), 1,
      sym_identifier,
    ACTIONS(295), 1,
      anon_sym_LPAREN,
    ACTIONS(299), 1,
      anon_sym_func,
    ACTIONS(301), 1,
      anon_sym_STAR,
    ACTIONS(307), 1,
      anon_sym_LT_DASH,
    ACTIONS(315), 1,
      anon_sym_DQUOTE,
    STATE(622), 1,
      sym__expression,
    STATE(836), 1,
      sym_negated_type,
    STATE(855), 1,
      sym_qualified_type,
    STATE(1268), 1,
      sym_implicit_length_array_type,
    ACTIONS(309), 2,
      anon_sym_new,
      anon_sym_make,
    STATE(1311), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(313), 3,
      sym_raw_string_literal,
      sym_imaginary_literal,
      sym_rune_literal,
    STATE(858), 4,
      sym_pointer_type,
      sym_interface_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(311), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
    STATE(894), 5,
      sym_generic_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_map_type,
    ACTIONS(317), 6,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
    STATE(394), 13,
      sym_parenthesized_expression,
      sym_call_expression,
      sym_selector_expression,
      sym_index_expression,
      sym_slice_expression,
      sym_type_assertion_expression,
      sym_type_conversion_expression,
      sym_type_instantiation_expression,
      sym_composite_literal,
      sym_func_literal,
      sym_unary_expression,
      sym_binary_expression,
      sym_interpreted_string_literal,
  [23127] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(303), 1,
      anon_sym_LBRACE,
    ACTIONS(561), 1,
      sym_identifier,
    ACTIONS(563), 1,
      anon_sym_DOT,
    ACTIONS(566), 1,
      anon_sym_LPAREN,
    ACTIONS(570), 1,
      anon_sym_COMMA,
    ACTIONS(572), 1,
      anon_sym_func,
    ACTIONS(574), 1,
      anon_sym_LBRACK,
    ACTIONS(580), 1,
      anon_sym_STAR,
    ACTIONS(585), 1,
      anon_sym_map,
    ACTIONS(587), 1,
      anon_sym_chan,
    ACTIONS(589), 1,
      anon_sym_LT_DASH,
    STATE(398), 1,
      sym_literal_value,
    STATE(533), 1,
      aux_sym_var_spec_repeat1,
    STATE(854), 1,
      sym_type_arguments,
    STATE(1310), 1,
      sym_type_elem,
    STATE(848), 2,
      sym_negated_type,
      sym_qualified_type,
    STATE(1117), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(583), 5,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    STATE(858), 9,
      sym_generic_type,
      sym_pointer_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_interface_type,
      sym_map_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(578), 14,
      anon_sym_RBRACK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [23227] = 10,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(578), 1,
      aux_sym_source_file_token1,
    ACTIONS(591), 1,
      anon_sym_DOT,
    ACTIONS(594), 1,
      anon_sym_LPAREN,
    ACTIONS(597), 1,
      anon_sym_LBRACK,
    ACTIONS(601), 1,
      anon_sym_LBRACE,
    ACTIONS(603), 1,
      anon_sym_COLON,
    STATE(253), 1,
      sym_literal_value,
    STATE(854), 1,
      sym_type_arguments,
    ACTIONS(583), 41,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_RBRACE,
      anon_sym_PIPE,
      anon_sym_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_AMP_CARET_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_case,
      anon_sym_default,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [23298] = 10,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(578), 1,
      aux_sym_source_file_token1,
    ACTIONS(591), 1,
      anon_sym_DOT,
    ACTIONS(594), 1,
      anon_sym_LPAREN,
    ACTIONS(597), 1,
      anon_sym_LBRACK,
    ACTIONS(601), 1,
      anon_sym_LBRACE,
    ACTIONS(605), 1,
      anon_sym_COLON,
    STATE(253), 1,
      sym_literal_value,
    STATE(854), 1,
      sym_type_arguments,
    ACTIONS(583), 41,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_RBRACE,
      anon_sym_PIPE,
      anon_sym_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_AMP_CARET_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_case,
      anon_sym_default,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [23369] = 19,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(607), 1,
      aux_sym_source_file_token1,
    ACTIONS(611), 1,
      anon_sym_DOT,
    ACTIONS(613), 1,
      anon_sym_LPAREN,
    ACTIONS(615), 1,
      anon_sym_COMMA,
    ACTIONS(619), 1,
      anon_sym_LBRACK,
    ACTIONS(625), 1,
      anon_sym_LT_DASH,
    ACTIONS(627), 1,
      anon_sym_PLUS_PLUS,
    ACTIONS(629), 1,
      anon_sym_DASH_DASH,
    ACTIONS(633), 1,
      anon_sym_AMP_AMP,
    ACTIONS(635), 1,
      anon_sym_PIPE_PIPE,
    STATE(265), 1,
      sym_argument_list,
    STATE(790), 1,
      aux_sym_expression_list_repeat1,
    STATE(1256), 1,
      sym_type_arguments,
    ACTIONS(623), 4,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
    ACTIONS(609), 5,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
    ACTIONS(631), 6,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_GT,
      anon_sym_GT_EQ,
    ACTIONS(621), 7,
      anon_sym_STAR,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
    ACTIONS(617), 13,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_AMP_CARET_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
  [23457] = 9,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(578), 1,
      aux_sym_source_file_token1,
    ACTIONS(591), 1,
      anon_sym_DOT,
    ACTIONS(594), 1,
      anon_sym_LPAREN,
    ACTIONS(597), 1,
      anon_sym_LBRACK,
    ACTIONS(601), 1,
      anon_sym_LBRACE,
    STATE(253), 1,
      sym_literal_value,
    STATE(854), 1,
      sym_type_arguments,
    ACTIONS(583), 41,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_RBRACE,
      anon_sym_PIPE,
      anon_sym_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_AMP_CARET_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_case,
      anon_sym_default,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [23525] = 11,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(611), 1,
      anon_sym_DOT,
    ACTIONS(613), 1,
      anon_sym_LPAREN,
    ACTIONS(619), 1,
      anon_sym_LBRACK,
    ACTIONS(637), 1,
      aux_sym_source_file_token1,
    STATE(265), 1,
      sym_argument_list,
    STATE(1256), 1,
      sym_type_arguments,
    ACTIONS(623), 4,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
    ACTIONS(631), 6,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_GT,
      anon_sym_GT_EQ,
    ACTIONS(621), 7,
      anon_sym_STAR,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
    ACTIONS(639), 24,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_RBRACE,
      anon_sym_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_AMP_CARET_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_case,
      anon_sym_default,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [23596] = 8,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(611), 1,
      anon_sym_DOT,
    ACTIONS(613), 1,
      anon_sym_LPAREN,
    ACTIONS(619), 1,
      anon_sym_LBRACK,
    ACTIONS(641), 1,
      aux_sym_source_file_token1,
    STATE(265), 1,
      sym_argument_list,
    STATE(1256), 1,
      sym_type_arguments,
    ACTIONS(643), 41,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_RBRACE,
      anon_sym_PIPE,
      anon_sym_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_AMP_CARET_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_case,
      anon_sym_default,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [23661] = 10,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(611), 1,
      anon_sym_DOT,
    ACTIONS(613), 1,
      anon_sym_LPAREN,
    ACTIONS(619), 1,
      anon_sym_LBRACK,
    ACTIONS(637), 1,
      aux_sym_source_file_token1,
    STATE(265), 1,
      sym_argument_list,
    STATE(1256), 1,
      sym_type_arguments,
    ACTIONS(623), 4,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
    ACTIONS(621), 7,
      anon_sym_STAR,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
    ACTIONS(639), 30,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_RBRACE,
      anon_sym_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_AMP_CARET_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_case,
      anon_sym_default,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [23730] = 12,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(611), 1,
      anon_sym_DOT,
    ACTIONS(613), 1,
      anon_sym_LPAREN,
    ACTIONS(619), 1,
      anon_sym_LBRACK,
    ACTIONS(633), 1,
      anon_sym_AMP_AMP,
    ACTIONS(637), 1,
      aux_sym_source_file_token1,
    STATE(265), 1,
      sym_argument_list,
    STATE(1256), 1,
      sym_type_arguments,
    ACTIONS(623), 4,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
    ACTIONS(631), 6,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_GT,
      anon_sym_GT_EQ,
    ACTIONS(621), 7,
      anon_sym_STAR,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
    ACTIONS(639), 23,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_RBRACE,
      anon_sym_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_AMP_CARET_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_case,
      anon_sym_default,
      anon_sym_PIPE_PIPE,
  [23803] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(77), 17,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_STAR,
      anon_sym_TILDE,
      anon_sym_LBRACE,
      anon_sym_LT_DASH,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
      anon_sym_CARET,
      anon_sym_AMP,
      sym_raw_string_literal,
      anon_sym_DQUOTE,
      sym_imaginary_literal,
      sym_rune_literal,
    ACTIONS(645), 30,
      anon_sym_package,
      anon_sym_import,
      anon_sym_const,
      anon_sym_var,
      anon_sym_func,
      anon_sym_type,
      anon_sym_struct,
      anon_sym_interface,
      anon_sym_map,
      anon_sym_chan,
      anon_sym_fallthrough,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_goto,
      anon_sym_return,
      anon_sym_go,
      anon_sym_defer,
      anon_sym_if,
      anon_sym_for,
      anon_sym_switch,
      anon_sym_select,
      anon_sym_new,
      anon_sym_make,
      sym_identifier,
      sym_int_literal,
      sym_float_literal,
      sym_nil,
      sym_true,
      sym_false,
      sym_iota,
  [23858] = 8,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(611), 1,
      anon_sym_DOT,
    ACTIONS(613), 1,
      anon_sym_LPAREN,
    ACTIONS(619), 1,
      anon_sym_LBRACK,
    ACTIONS(637), 1,
      aux_sym_source_file_token1,
    STATE(265), 1,
      sym_argument_list,
    STATE(1256), 1,
      sym_type_arguments,
    ACTIONS(639), 41,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_RBRACE,
      anon_sym_PIPE,
      anon_sym_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_AMP_CARET_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_case,
      anon_sym_default,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [23923] = 9,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(611), 1,
      anon_sym_DOT,
    ACTIONS(613), 1,
      anon_sym_LPAREN,
    ACTIONS(619), 1,
      anon_sym_LBRACK,
    ACTIONS(637), 1,
      aux_sym_source_file_token1,
    STATE(265), 1,
      sym_argument_list,
    STATE(1256), 1,
      sym_type_arguments,
    ACTIONS(621), 7,
      anon_sym_STAR,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
    ACTIONS(639), 34,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_RBRACE,
      anon_sym_PIPE,
      anon_sym_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_AMP_CARET_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_case,
      anon_sym_default,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [23990] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(647), 1,
      aux_sym_source_file_token1,
    ACTIONS(649), 45,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_LBRACK,
      anon_sym_STAR,
      anon_sym_RBRACE,
      anon_sym_PIPE,
      anon_sym_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_AMP_CARET_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_else,
      anon_sym_case,
      anon_sym_default,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [24044] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(651), 1,
      aux_sym_source_file_token1,
    ACTIONS(653), 45,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_LBRACK,
      anon_sym_STAR,
      anon_sym_RBRACE,
      anon_sym_PIPE,
      anon_sym_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_AMP_CARET_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_else,
      anon_sym_case,
      anon_sym_default,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [24098] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(655), 1,
      aux_sym_source_file_token1,
    ACTIONS(657), 45,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_LBRACK,
      anon_sym_STAR,
      anon_sym_RBRACE,
      anon_sym_PIPE,
      anon_sym_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_AMP_CARET_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_case,
      anon_sym_default,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [24152] = 5,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(578), 1,
      aux_sym_source_file_token1,
    ACTIONS(659), 1,
      anon_sym_LPAREN,
    STATE(265), 1,
      sym_special_argument_list,
    ACTIONS(583), 43,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_DOT,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_LBRACK,
      anon_sym_STAR,
      anon_sym_RBRACE,
      anon_sym_PIPE,
      anon_sym_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_AMP_CARET_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_case,
      anon_sym_default,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [24210] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(661), 1,
      aux_sym_source_file_token1,
    ACTIONS(663), 45,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_LBRACK,
      anon_sym_STAR,
      anon_sym_RBRACE,
      anon_sym_PIPE,
      anon_sym_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_AMP_CARET_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_case,
      anon_sym_default,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [24264] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(665), 1,
      aux_sym_source_file_token1,
    ACTIONS(667), 44,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_LBRACK,
      anon_sym_STAR,
      anon_sym_RBRACE,
      anon_sym_PIPE,
      anon_sym_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_AMP_CARET_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_case,
      anon_sym_default,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [24317] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(669), 1,
      aux_sym_source_file_token1,
    ACTIONS(671), 44,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_LBRACK,
      anon_sym_STAR,
      anon_sym_RBRACE,
      anon_sym_PIPE,
      anon_sym_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_AMP_CARET_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_case,
      anon_sym_default,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [24370] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(33), 1,
      anon_sym_LBRACE,
    ACTIONS(607), 1,
      anon_sym_SEMI,
    ACTIONS(617), 1,
      anon_sym_EQ,
    ACTIONS(673), 1,
      anon_sym_DOT,
    ACTIONS(675), 1,
      anon_sym_LPAREN,
    ACTIONS(677), 1,
      anon_sym_COMMA,
    ACTIONS(679), 1,
      anon_sym_LBRACK,
    ACTIONS(685), 1,
      anon_sym_LT_DASH,
    ACTIONS(689), 1,
      anon_sym_PLUS_PLUS,
    ACTIONS(691), 1,
      anon_sym_DASH_DASH,
    ACTIONS(697), 1,
      anon_sym_AMP_AMP,
    ACTIONS(699), 1,
      anon_sym_PIPE_PIPE,
    STATE(303), 1,
      sym_argument_list,
    STATE(790), 1,
      aux_sym_expression_list_repeat1,
    STATE(901), 1,
      sym_block,
    STATE(1259), 1,
      sym_type_arguments,
    ACTIONS(695), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(683), 4,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
    ACTIONS(693), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(681), 7,
      anon_sym_STAR,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
    ACTIONS(687), 12,
      anon_sym_COLON_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_AMP_CARET_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
  [24461] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(701), 1,
      aux_sym_source_file_token1,
    ACTIONS(703), 44,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_LBRACK,
      anon_sym_STAR,
      anon_sym_RBRACE,
      anon_sym_PIPE,
      anon_sym_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_AMP_CARET_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_case,
      anon_sym_default,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [24514] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(705), 1,
      aux_sym_source_file_token1,
    ACTIONS(707), 44,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_LBRACK,
      anon_sym_STAR,
      anon_sym_RBRACE,
      anon_sym_PIPE,
      anon_sym_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_AMP_CARET_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_case,
      anon_sym_default,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [24567] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(709), 1,
      aux_sym_source_file_token1,
    ACTIONS(711), 44,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_LBRACK,
      anon_sym_STAR,
      anon_sym_RBRACE,
      anon_sym_PIPE,
      anon_sym_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_AMP_CARET_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_case,
      anon_sym_default,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [24620] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(33), 1,
      anon_sym_LBRACE,
    ACTIONS(607), 1,
      anon_sym_SEMI,
    ACTIONS(617), 1,
      anon_sym_EQ,
    ACTIONS(673), 1,
      anon_sym_DOT,
    ACTIONS(675), 1,
      anon_sym_LPAREN,
    ACTIONS(677), 1,
      anon_sym_COMMA,
    ACTIONS(679), 1,
      anon_sym_LBRACK,
    ACTIONS(685), 1,
      anon_sym_LT_DASH,
    ACTIONS(689), 1,
      anon_sym_PLUS_PLUS,
    ACTIONS(691), 1,
      anon_sym_DASH_DASH,
    ACTIONS(697), 1,
      anon_sym_AMP_AMP,
    ACTIONS(699), 1,
      anon_sym_PIPE_PIPE,
    STATE(303), 1,
      sym_argument_list,
    STATE(790), 1,
      aux_sym_expression_list_repeat1,
    STATE(913), 1,
      sym_block,
    STATE(1259), 1,
      sym_type_arguments,
    ACTIONS(695), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(683), 4,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
    ACTIONS(693), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(681), 7,
      anon_sym_STAR,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
    ACTIONS(687), 12,
      anon_sym_COLON_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_AMP_CARET_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
  [24711] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(713), 1,
      aux_sym_source_file_token1,
    ACTIONS(715), 44,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_LBRACK,
      anon_sym_STAR,
      anon_sym_RBRACE,
      anon_sym_PIPE,
      anon_sym_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_AMP_CARET_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_case,
      anon_sym_default,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [24764] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(717), 1,
      aux_sym_source_file_token1,
    ACTIONS(719), 44,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_LBRACK,
      anon_sym_STAR,
      anon_sym_RBRACE,
      anon_sym_PIPE,
      anon_sym_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_AMP_CARET_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_case,
      anon_sym_default,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [24817] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(721), 1,
      aux_sym_source_file_token1,
    ACTIONS(723), 44,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_LBRACK,
      anon_sym_STAR,
      anon_sym_RBRACE,
      anon_sym_PIPE,
      anon_sym_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_AMP_CARET_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_case,
      anon_sym_default,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [24870] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(725), 1,
      aux_sym_source_file_token1,
    ACTIONS(727), 44,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_LBRACK,
      anon_sym_STAR,
      anon_sym_RBRACE,
      anon_sym_PIPE,
      anon_sym_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_AMP_CARET_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_case,
      anon_sym_default,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [24923] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(729), 1,
      aux_sym_source_file_token1,
    ACTIONS(731), 44,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_LBRACK,
      anon_sym_STAR,
      anon_sym_RBRACE,
      anon_sym_PIPE,
      anon_sym_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_AMP_CARET_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_case,
      anon_sym_default,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [24976] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(733), 1,
      aux_sym_source_file_token1,
    ACTIONS(735), 44,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_LBRACK,
      anon_sym_STAR,
      anon_sym_RBRACE,
      anon_sym_PIPE,
      anon_sym_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_AMP_CARET_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_case,
      anon_sym_default,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [25029] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(578), 1,
      aux_sym_source_file_token1,
    ACTIONS(583), 44,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_LBRACK,
      anon_sym_STAR,
      anon_sym_RBRACE,
      anon_sym_PIPE,
      anon_sym_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_AMP_CARET_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_case,
      anon_sym_default,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [25082] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(737), 1,
      aux_sym_source_file_token1,
    ACTIONS(739), 44,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_LBRACK,
      anon_sym_STAR,
      anon_sym_RBRACE,
      anon_sym_PIPE,
      anon_sym_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_AMP_CARET_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_case,
      anon_sym_default,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [25135] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(741), 1,
      aux_sym_source_file_token1,
    ACTIONS(743), 44,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_LBRACK,
      anon_sym_STAR,
      anon_sym_RBRACE,
      anon_sym_PIPE,
      anon_sym_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_AMP_CARET_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_case,
      anon_sym_default,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [25188] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(745), 1,
      aux_sym_source_file_token1,
    ACTIONS(747), 44,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_LBRACK,
      anon_sym_STAR,
      anon_sym_RBRACE,
      anon_sym_PIPE,
      anon_sym_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_AMP_CARET_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_case,
      anon_sym_default,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [25241] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(749), 1,
      aux_sym_source_file_token1,
    ACTIONS(751), 44,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_LBRACK,
      anon_sym_STAR,
      anon_sym_RBRACE,
      anon_sym_PIPE,
      anon_sym_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_AMP_CARET_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_case,
      anon_sym_default,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [25294] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(753), 1,
      aux_sym_source_file_token1,
    ACTIONS(755), 44,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_LBRACK,
      anon_sym_STAR,
      anon_sym_RBRACE,
      anon_sym_PIPE,
      anon_sym_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_AMP_CARET_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_case,
      anon_sym_default,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [25347] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(757), 1,
      aux_sym_source_file_token1,
    ACTIONS(759), 44,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_LBRACK,
      anon_sym_STAR,
      anon_sym_RBRACE,
      anon_sym_PIPE,
      anon_sym_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_AMP_CARET_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_case,
      anon_sym_default,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [25400] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(761), 1,
      aux_sym_source_file_token1,
    ACTIONS(763), 44,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_LBRACK,
      anon_sym_STAR,
      anon_sym_RBRACE,
      anon_sym_PIPE,
      anon_sym_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_AMP_CARET_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_case,
      anon_sym_default,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [25453] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(765), 1,
      aux_sym_source_file_token1,
    ACTIONS(767), 44,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_LBRACK,
      anon_sym_STAR,
      anon_sym_RBRACE,
      anon_sym_PIPE,
      anon_sym_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_AMP_CARET_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_case,
      anon_sym_default,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [25506] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(769), 1,
      aux_sym_source_file_token1,
    ACTIONS(771), 44,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_LBRACK,
      anon_sym_STAR,
      anon_sym_RBRACE,
      anon_sym_PIPE,
      anon_sym_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_AMP_CARET_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_case,
      anon_sym_default,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [25559] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(773), 1,
      aux_sym_source_file_token1,
    ACTIONS(775), 44,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_LBRACK,
      anon_sym_STAR,
      anon_sym_RBRACE,
      anon_sym_PIPE,
      anon_sym_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_AMP_CARET_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_case,
      anon_sym_default,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [25612] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(777), 1,
      aux_sym_source_file_token1,
    ACTIONS(779), 44,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_LBRACK,
      anon_sym_STAR,
      anon_sym_RBRACE,
      anon_sym_PIPE,
      anon_sym_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_AMP_CARET_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_case,
      anon_sym_default,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [25665] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(781), 1,
      aux_sym_source_file_token1,
    ACTIONS(783), 44,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_LBRACK,
      anon_sym_STAR,
      anon_sym_RBRACE,
      anon_sym_PIPE,
      anon_sym_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_AMP_CARET_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_case,
      anon_sym_default,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [25718] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(785), 1,
      aux_sym_source_file_token1,
    ACTIONS(787), 44,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_LBRACK,
      anon_sym_STAR,
      anon_sym_RBRACE,
      anon_sym_PIPE,
      anon_sym_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_AMP_CARET_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_case,
      anon_sym_default,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [25771] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(789), 1,
      aux_sym_source_file_token1,
    ACTIONS(791), 44,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_LBRACK,
      anon_sym_STAR,
      anon_sym_RBRACE,
      anon_sym_PIPE,
      anon_sym_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_AMP_CARET_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_case,
      anon_sym_default,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [25824] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(793), 1,
      aux_sym_source_file_token1,
    ACTIONS(795), 44,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_LBRACK,
      anon_sym_STAR,
      anon_sym_RBRACE,
      anon_sym_PIPE,
      anon_sym_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_AMP_CARET_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_case,
      anon_sym_default,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [25877] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(797), 1,
      aux_sym_source_file_token1,
    ACTIONS(799), 44,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_LBRACK,
      anon_sym_STAR,
      anon_sym_RBRACE,
      anon_sym_PIPE,
      anon_sym_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_AMP_CARET_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_case,
      anon_sym_default,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [25930] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(801), 1,
      aux_sym_source_file_token1,
    ACTIONS(803), 44,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_LBRACK,
      anon_sym_STAR,
      anon_sym_RBRACE,
      anon_sym_PIPE,
      anon_sym_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_AMP_CARET_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_case,
      anon_sym_default,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [25983] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(805), 1,
      aux_sym_source_file_token1,
    ACTIONS(807), 44,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_LBRACK,
      anon_sym_STAR,
      anon_sym_RBRACE,
      anon_sym_PIPE,
      anon_sym_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_AMP_CARET_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_case,
      anon_sym_default,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [26036] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(809), 1,
      aux_sym_source_file_token1,
    ACTIONS(811), 44,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_LBRACK,
      anon_sym_STAR,
      anon_sym_RBRACE,
      anon_sym_PIPE,
      anon_sym_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_AMP_CARET_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_case,
      anon_sym_default,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [26089] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(813), 1,
      aux_sym_source_file_token1,
    ACTIONS(815), 44,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_LBRACK,
      anon_sym_STAR,
      anon_sym_RBRACE,
      anon_sym_PIPE,
      anon_sym_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_AMP_CARET_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_case,
      anon_sym_default,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [26142] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(817), 1,
      aux_sym_source_file_token1,
    ACTIONS(819), 44,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_LBRACK,
      anon_sym_STAR,
      anon_sym_RBRACE,
      anon_sym_PIPE,
      anon_sym_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_AMP_CARET_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_case,
      anon_sym_default,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [26195] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(821), 1,
      aux_sym_source_file_token1,
    ACTIONS(823), 44,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_LBRACK,
      anon_sym_STAR,
      anon_sym_RBRACE,
      anon_sym_PIPE,
      anon_sym_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_AMP_CARET_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_case,
      anon_sym_default,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [26248] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(607), 1,
      anon_sym_SEMI,
    ACTIONS(617), 1,
      anon_sym_EQ,
    ACTIONS(675), 1,
      anon_sym_LPAREN,
    ACTIONS(677), 1,
      anon_sym_COMMA,
    ACTIONS(679), 1,
      anon_sym_LBRACK,
    ACTIONS(685), 1,
      anon_sym_LT_DASH,
    ACTIONS(689), 1,
      anon_sym_PLUS_PLUS,
    ACTIONS(691), 1,
      anon_sym_DASH_DASH,
    ACTIONS(697), 1,
      anon_sym_AMP_AMP,
    ACTIONS(699), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(825), 1,
      anon_sym_DOT,
    ACTIONS(827), 1,
      anon_sym_LBRACE,
    STATE(303), 1,
      sym_argument_list,
    STATE(790), 1,
      aux_sym_expression_list_repeat1,
    STATE(1259), 1,
      sym_type_arguments,
    ACTIONS(695), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(683), 4,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
    ACTIONS(693), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(681), 7,
      anon_sym_STAR,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
    ACTIONS(687), 12,
      anon_sym_COLON_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_AMP_CARET_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
  [26336] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(673), 1,
      anon_sym_DOT,
    ACTIONS(675), 1,
      anon_sym_LPAREN,
    ACTIONS(679), 1,
      anon_sym_LBRACK,
    STATE(303), 1,
      sym_argument_list,
    STATE(1259), 1,
      sym_type_arguments,
    ACTIONS(639), 3,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(683), 4,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
    ACTIONS(681), 7,
      anon_sym_STAR,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
    ACTIONS(637), 24,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACE,
      anon_sym_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_AMP_CARET_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [26401] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(607), 1,
      anon_sym_LBRACE,
    ACTIONS(617), 1,
      anon_sym_EQ,
    ACTIONS(673), 1,
      anon_sym_DOT,
    ACTIONS(675), 1,
      anon_sym_LPAREN,
    ACTIONS(677), 1,
      anon_sym_COMMA,
    ACTIONS(679), 1,
      anon_sym_LBRACK,
    ACTIONS(689), 1,
      anon_sym_PLUS_PLUS,
    ACTIONS(691), 1,
      anon_sym_DASH_DASH,
    ACTIONS(697), 1,
      anon_sym_AMP_AMP,
    ACTIONS(699), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(829), 1,
      anon_sym_LT_DASH,
    STATE(303), 1,
      sym_argument_list,
    STATE(790), 1,
      aux_sym_expression_list_repeat1,
    STATE(1259), 1,
      sym_type_arguments,
    ACTIONS(695), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(683), 4,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
    ACTIONS(693), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(681), 7,
      anon_sym_STAR,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
    ACTIONS(687), 12,
      anon_sym_COLON_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_AMP_CARET_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
  [26486] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(673), 1,
      anon_sym_DOT,
    ACTIONS(675), 1,
      anon_sym_LPAREN,
    ACTIONS(679), 1,
      anon_sym_LBRACK,
    STATE(303), 1,
      sym_argument_list,
    STATE(1259), 1,
      sym_type_arguments,
    ACTIONS(643), 14,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(641), 24,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACE,
      anon_sym_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_AMP_CARET_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [26547] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(673), 1,
      anon_sym_DOT,
    ACTIONS(675), 1,
      anon_sym_LPAREN,
    ACTIONS(679), 1,
      anon_sym_LBRACK,
    STATE(303), 1,
      sym_argument_list,
    STATE(1259), 1,
      sym_type_arguments,
    ACTIONS(639), 7,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(681), 7,
      anon_sym_STAR,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
    ACTIONS(637), 24,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACE,
      anon_sym_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_AMP_CARET_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [26610] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(639), 1,
      anon_sym_EQ,
    ACTIONS(673), 1,
      anon_sym_DOT,
    ACTIONS(675), 1,
      anon_sym_LPAREN,
    ACTIONS(679), 1,
      anon_sym_LBRACK,
    STATE(303), 1,
      sym_argument_list,
    STATE(1259), 1,
      sym_type_arguments,
    ACTIONS(695), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(683), 4,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
    ACTIONS(693), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(681), 7,
      anon_sym_STAR,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
    ACTIONS(637), 20,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACE,
      anon_sym_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_AMP_CARET_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [26679] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(639), 1,
      anon_sym_EQ,
    ACTIONS(673), 1,
      anon_sym_DOT,
    ACTIONS(675), 1,
      anon_sym_LPAREN,
    ACTIONS(679), 1,
      anon_sym_LBRACK,
    ACTIONS(697), 1,
      anon_sym_AMP_AMP,
    STATE(303), 1,
      sym_argument_list,
    STATE(1259), 1,
      sym_type_arguments,
    ACTIONS(695), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(683), 4,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
    ACTIONS(693), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(681), 7,
      anon_sym_STAR,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
    ACTIONS(637), 19,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACE,
      anon_sym_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_AMP_CARET_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_PIPE,
  [26750] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(563), 1,
      anon_sym_DOT,
    ACTIONS(831), 1,
      anon_sym_LPAREN,
    ACTIONS(834), 1,
      anon_sym_LBRACK,
    STATE(304), 1,
      sym_literal_value,
    STATE(854), 1,
      sym_type_arguments,
    ACTIONS(583), 14,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(578), 24,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACE,
      anon_sym_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_AMP_CARET_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [26811] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(673), 1,
      anon_sym_DOT,
    ACTIONS(675), 1,
      anon_sym_LPAREN,
    ACTIONS(679), 1,
      anon_sym_LBRACK,
    STATE(303), 1,
      sym_argument_list,
    STATE(1259), 1,
      sym_type_arguments,
    ACTIONS(639), 14,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(637), 24,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACE,
      anon_sym_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_AMP_CARET_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [26872] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(838), 1,
      anon_sym_LPAREN,
    STATE(303), 1,
      sym_special_argument_list,
    ACTIONS(583), 14,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(578), 26,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_AMP_CARET_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [26926] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(731), 14,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(729), 27,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_AMP_CARET_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [26975] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(653), 14,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(651), 27,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_AMP_CARET_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [27024] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(811), 14,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(809), 27,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_AMP_CARET_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [27073] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(815), 14,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(813), 27,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_AMP_CARET_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [27122] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(735), 14,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(733), 27,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_AMP_CARET_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [27171] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(667), 14,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(665), 27,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_AMP_CARET_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [27220] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(671), 14,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(669), 27,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_AMP_CARET_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [27269] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(583), 14,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(578), 27,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_AMP_CARET_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [27318] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(663), 14,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(661), 27,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_AMP_CARET_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [27367] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(787), 14,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(785), 27,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_AMP_CARET_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [27416] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(743), 14,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(741), 27,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_AMP_CARET_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [27465] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(649), 14,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(647), 27,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_AMP_CARET_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [27514] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(739), 14,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(737), 27,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_AMP_CARET_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [27563] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(823), 14,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(821), 27,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_AMP_CARET_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [27612] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(747), 14,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(745), 27,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_AMP_CARET_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [27661] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(799), 14,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(797), 27,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_AMP_CARET_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [27710] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(803), 14,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(801), 27,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_AMP_CARET_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [27759] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(819), 14,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(817), 27,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_AMP_CARET_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [27808] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(707), 14,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(705), 27,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_AMP_CARET_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [27857] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(703), 14,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(701), 27,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_AMP_CARET_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [27906] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(711), 14,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(709), 27,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_AMP_CARET_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [27955] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(715), 14,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(713), 27,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_AMP_CARET_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [28004] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(719), 14,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(717), 27,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_AMP_CARET_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [28053] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(723), 14,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(721), 27,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_AMP_CARET_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [28102] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(727), 14,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(725), 27,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_AMP_CARET_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [28151] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(657), 14,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(655), 27,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_AMP_CARET_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [28200] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(755), 14,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(753), 27,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_AMP_CARET_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [28249] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(759), 14,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(757), 27,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_AMP_CARET_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [28298] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(763), 14,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(761), 27,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_AMP_CARET_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [28347] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(767), 14,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(765), 27,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_AMP_CARET_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [28396] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(771), 14,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(769), 27,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_AMP_CARET_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [28445] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(775), 14,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(773), 27,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_AMP_CARET_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [28494] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(779), 14,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(777), 27,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_AMP_CARET_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [28543] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(783), 14,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(781), 27,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_AMP_CARET_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [28592] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(807), 14,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(805), 27,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_AMP_CARET_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [28641] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(791), 14,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(789), 27,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_AMP_CARET_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [28690] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(795), 14,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(793), 27,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_AMP_CARET_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [28739] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(751), 14,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(749), 27,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_AMP_CARET_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [28788] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(563), 1,
      anon_sym_DOT,
    ACTIONS(831), 1,
      anon_sym_LPAREN,
    ACTIONS(834), 1,
      anon_sym_LBRACK,
    ACTIONS(840), 1,
      anon_sym_LBRACE,
    STATE(383), 1,
      sym_literal_value,
    STATE(854), 1,
      sym_type_arguments,
    ACTIONS(583), 14,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(578), 19,
      anon_sym_COMMA,
      anon_sym_COLON_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_AMP_CARET_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [28847] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(842), 1,
      anon_sym_DOT,
    ACTIONS(844), 1,
      anon_sym_LPAREN,
    ACTIONS(846), 1,
      anon_sym_LBRACK,
    STATE(365), 1,
      sym_argument_list,
    STATE(1313), 1,
      sym_type_arguments,
    ACTIONS(639), 3,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(850), 4,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
    ACTIONS(848), 7,
      anon_sym_STAR,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
    ACTIONS(637), 19,
      anon_sym_COMMA,
      anon_sym_COLON_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_AMP_CARET_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [28907] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(842), 1,
      anon_sym_DOT,
    ACTIONS(844), 1,
      anon_sym_LPAREN,
    ACTIONS(846), 1,
      anon_sym_LBRACK,
    STATE(365), 1,
      sym_argument_list,
    STATE(1313), 1,
      sym_type_arguments,
    ACTIONS(639), 14,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(637), 19,
      anon_sym_COMMA,
      anon_sym_COLON_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_AMP_CARET_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [28963] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(842), 1,
      anon_sym_DOT,
    ACTIONS(844), 1,
      anon_sym_LPAREN,
    ACTIONS(846), 1,
      anon_sym_LBRACK,
    STATE(365), 1,
      sym_argument_list,
    STATE(1313), 1,
      sym_type_arguments,
    ACTIONS(639), 7,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(848), 7,
      anon_sym_STAR,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
    ACTIONS(637), 19,
      anon_sym_COMMA,
      anon_sym_COLON_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_AMP_CARET_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [29021] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(639), 1,
      anon_sym_EQ,
    ACTIONS(842), 1,
      anon_sym_DOT,
    ACTIONS(844), 1,
      anon_sym_LPAREN,
    ACTIONS(846), 1,
      anon_sym_LBRACK,
    STATE(365), 1,
      sym_argument_list,
    STATE(1313), 1,
      sym_type_arguments,
    ACTIONS(854), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(850), 4,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
    ACTIONS(852), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(848), 7,
      anon_sym_STAR,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
    ACTIONS(637), 15,
      anon_sym_COMMA,
      anon_sym_COLON_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_AMP_CARET_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [29085] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(639), 1,
      anon_sym_EQ,
    ACTIONS(842), 1,
      anon_sym_DOT,
    ACTIONS(844), 1,
      anon_sym_LPAREN,
    ACTIONS(846), 1,
      anon_sym_LBRACK,
    ACTIONS(856), 1,
      anon_sym_AMP_AMP,
    STATE(365), 1,
      sym_argument_list,
    STATE(1313), 1,
      sym_type_arguments,
    ACTIONS(854), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(850), 4,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
    ACTIONS(852), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(848), 7,
      anon_sym_STAR,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
    ACTIONS(637), 14,
      anon_sym_COMMA,
      anon_sym_COLON_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_AMP_CARET_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_PIPE,
  [29151] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(842), 1,
      anon_sym_DOT,
    ACTIONS(844), 1,
      anon_sym_LPAREN,
    ACTIONS(846), 1,
      anon_sym_LBRACK,
    STATE(365), 1,
      sym_argument_list,
    STATE(1313), 1,
      sym_type_arguments,
    ACTIONS(643), 14,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(641), 19,
      anon_sym_COMMA,
      anon_sym_COLON_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_AMP_CARET_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [29207] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(842), 1,
      anon_sym_DOT,
    ACTIONS(844), 1,
      anon_sym_LPAREN,
    ACTIONS(846), 1,
      anon_sym_LBRACK,
    ACTIONS(856), 1,
      anon_sym_AMP_AMP,
    ACTIONS(860), 1,
      anon_sym_EQ,
    ACTIONS(862), 1,
      anon_sym_PIPE_PIPE,
    STATE(365), 1,
      sym_argument_list,
    STATE(1313), 1,
      sym_type_arguments,
    ACTIONS(854), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(850), 4,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
    ACTIONS(852), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(848), 7,
      anon_sym_STAR,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
    ACTIONS(858), 13,
      anon_sym_COMMA,
      anon_sym_COLON_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_AMP_CARET_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
  [29275] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(864), 1,
      anon_sym_LPAREN,
    STATE(365), 1,
      sym_special_argument_list,
    ACTIONS(583), 14,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(578), 21,
      anon_sym_DOT,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_COLON_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_AMP_CARET_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [29324] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(723), 14,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(721), 22,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_COLON_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_AMP_CARET_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [29368] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(779), 14,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(777), 22,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_COLON_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_AMP_CARET_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [29412] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(783), 14,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(781), 22,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_COLON_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_AMP_CARET_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [29456] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(791), 14,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(789), 22,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_COLON_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_AMP_CARET_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [29500] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(795), 14,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(793), 22,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_COLON_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_AMP_CARET_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [29544] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(799), 14,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(797), 22,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_COLON_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_AMP_CARET_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [29588] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(803), 14,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(801), 22,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_COLON_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_AMP_CARET_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [29632] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(807), 14,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(805), 22,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_COLON_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_AMP_CARET_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [29676] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(811), 14,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(809), 22,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_COLON_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_AMP_CARET_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [29720] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(815), 14,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(813), 22,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_COLON_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_AMP_CARET_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [29764] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(663), 14,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(661), 22,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_COLON_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_AMP_CARET_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [29808] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(657), 14,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(655), 22,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_COLON_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_AMP_CARET_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [29852] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(731), 14,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(729), 22,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_COLON_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_AMP_CARET_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [29896] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(755), 14,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(753), 22,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_COLON_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_AMP_CARET_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [29940] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(759), 14,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(757), 22,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_COLON_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_AMP_CARET_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [29984] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(763), 14,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(761), 22,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_COLON_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_AMP_CARET_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [30028] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(583), 14,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(578), 22,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_COLON_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_AMP_CARET_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [30072] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(767), 14,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(765), 22,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_COLON_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_AMP_CARET_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [30116] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(653), 14,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(651), 22,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_COLON_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_AMP_CARET_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [30160] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(735), 14,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(733), 22,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_COLON_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_AMP_CARET_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [30204] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(727), 14,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(725), 22,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_COLON_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_AMP_CARET_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [30248] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(671), 14,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(669), 22,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_COLON_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_AMP_CARET_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [30292] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(787), 14,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(785), 22,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_COLON_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_AMP_CARET_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [30336] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(771), 14,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(769), 22,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_COLON_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_AMP_CARET_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [30380] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(743), 14,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(741), 22,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_COLON_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_AMP_CARET_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [30424] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(649), 14,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(647), 22,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_COLON_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_AMP_CARET_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [30468] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(739), 14,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(737), 22,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_COLON_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_AMP_CARET_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [30512] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(823), 14,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(821), 22,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_COLON_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_AMP_CARET_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [30556] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(747), 14,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(745), 22,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_COLON_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_AMP_CARET_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [30600] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(751), 14,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(749), 22,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_COLON_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_AMP_CARET_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [30644] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(775), 14,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(773), 22,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_COLON_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_AMP_CARET_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [30688] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(819), 14,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(817), 22,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_COLON_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_AMP_CARET_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [30732] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(707), 14,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(705), 22,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_COLON_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_AMP_CARET_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [30776] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(703), 14,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(701), 22,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_COLON_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_AMP_CARET_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [30820] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(711), 14,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(709), 22,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_COLON_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_AMP_CARET_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [30864] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(715), 14,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(713), 22,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_COLON_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_AMP_CARET_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [30908] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(719), 14,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(717), 22,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_COLON_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_AMP_CARET_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [30952] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(667), 14,
      anon_sym_EQ,
      anon_sym_STAR,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(665), 22,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_COLON_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_AMP_CARET_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [30996] = 17,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(866), 1,
      sym_identifier,
    ACTIONS(868), 1,
      aux_sym_source_file_token1,
    ACTIONS(872), 1,
      anon_sym_LPAREN,
    ACTIONS(874), 1,
      anon_sym_func,
    ACTIONS(876), 1,
      anon_sym_LBRACK,
    ACTIONS(878), 1,
      anon_sym_STAR,
    ACTIONS(880), 1,
      anon_sym_struct,
    ACTIONS(882), 1,
      anon_sym_TILDE,
    ACTIONS(884), 1,
      anon_sym_interface,
    ACTIONS(886), 1,
      anon_sym_map,
    ACTIONS(888), 1,
      anon_sym_chan,
    ACTIONS(890), 1,
      anon_sym_LT_DASH,
    STATE(796), 2,
      sym_negated_type,
      sym_qualified_type,
    STATE(830), 2,
      sym_parameter_list,
      sym__simple_type,
    STATE(807), 9,
      sym_generic_type,
      sym_pointer_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_interface_type,
      sym_map_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(870), 10,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_EQ,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_PIPE,
      anon_sym_case,
      anon_sym_default,
      sym_raw_string_literal,
      anon_sym_DQUOTE,
  [31067] = 24,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(880), 1,
      anon_sym_struct,
    ACTIONS(882), 1,
      anon_sym_TILDE,
    ACTIONS(884), 1,
      anon_sym_interface,
    ACTIONS(892), 1,
      sym_identifier,
    ACTIONS(894), 1,
      aux_sym_source_file_token1,
    ACTIONS(898), 1,
      anon_sym_DOT,
    ACTIONS(900), 1,
      anon_sym_LPAREN,
    ACTIONS(902), 1,
      anon_sym_COMMA,
    ACTIONS(904), 1,
      anon_sym_func,
    ACTIONS(906), 1,
      anon_sym_LBRACK,
    ACTIONS(908), 1,
      anon_sym_STAR,
    ACTIONS(910), 1,
      anon_sym_map,
    ACTIONS(912), 1,
      anon_sym_chan,
    ACTIONS(914), 1,
      anon_sym_LT_DASH,
    ACTIONS(916), 1,
      sym_raw_string_literal,
    ACTIONS(918), 1,
      anon_sym_DQUOTE,
    STATE(635), 1,
      aux_sym_field_declaration_repeat1,
    STATE(813), 1,
      sym_type_arguments,
    STATE(1079), 1,
      sym_interpreted_string_literal,
    STATE(799), 2,
      sym_negated_type,
      sym_qualified_type,
    STATE(906), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(896), 3,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_RBRACE,
    STATE(807), 9,
      sym_generic_type,
      sym_pointer_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_interface_type,
      sym_map_type,
      sym_channel_type,
      sym_function_type,
  [31152] = 17,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(868), 1,
      aux_sym_source_file_token1,
    ACTIONS(872), 1,
      anon_sym_LPAREN,
    ACTIONS(880), 1,
      anon_sym_struct,
    ACTIONS(882), 1,
      anon_sym_TILDE,
    ACTIONS(884), 1,
      anon_sym_interface,
    ACTIONS(892), 1,
      sym_identifier,
    ACTIONS(904), 1,
      anon_sym_func,
    ACTIONS(908), 1,
      anon_sym_STAR,
    ACTIONS(910), 1,
      anon_sym_map,
    ACTIONS(912), 1,
      anon_sym_chan,
    ACTIONS(914), 1,
      anon_sym_LT_DASH,
    ACTIONS(920), 1,
      anon_sym_LBRACK,
    STATE(799), 2,
      sym_negated_type,
      sym_qualified_type,
    STATE(830), 2,
      sym_parameter_list,
      sym__simple_type,
    STATE(807), 9,
      sym_generic_type,
      sym_pointer_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_interface_type,
      sym_map_type,
      sym_channel_type,
      sym_function_type,
    ACTIONS(870), 10,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_EQ,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_PIPE,
      anon_sym_case,
      anon_sym_default,
      sym_raw_string_literal,
      anon_sym_DQUOTE,
  [31223] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(922), 1,
      anon_sym_DOT,
    ACTIONS(924), 1,
      anon_sym_LPAREN,
    ACTIONS(926), 1,
      anon_sym_LBRACK,
    STATE(397), 1,
      sym_argument_list,
    STATE(1255), 1,
      sym_type_arguments,
    ACTIONS(643), 7,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_COLON,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(641), 22,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_DOT,
      anon_sym_STAR,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COLON_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [31275] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(922), 1,
      anon_sym_DOT,
    ACTIONS(924), 1,
      anon_sym_LPAREN,
    ACTIONS(926), 1,
      anon_sym_LBRACK,
    STATE(397), 1,
      sym_argument_list,
    STATE(1255), 1,
      sym_type_arguments,
    ACTIONS(639), 7,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_COLON,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(637), 22,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_DOT,
      anon_sym_STAR,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COLON_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [31327] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(928), 1,
      anon_sym_LPAREN,
    STATE(397), 1,
      sym_special_argument_list,
    ACTIONS(583), 8,
      anon_sym_DOT,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_COLON,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(578), 23,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_DOT,
      anon_sym_STAR,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COLON_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [31372] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(303), 1,
      anon_sym_LBRACE,
    ACTIONS(563), 1,
      anon_sym_DOT,
    ACTIONS(834), 1,
      anon_sym_LBRACK,
    STATE(398), 1,
      sym_literal_value,
    STATE(854), 1,
      sym_type_arguments,
    ACTIONS(831), 2,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
    ACTIONS(583), 7,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_COLON,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(578), 19,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_STAR,
      anon_sym_RBRACE,
      anon_sym_COLON_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [31425] = 20,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(279), 1,
      anon_sym_TILDE,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(561), 1,
      sym_identifier,
    ACTIONS(572), 1,
      anon_sym_func,
    ACTIONS(585), 1,
      anon_sym_map,
    ACTIONS(587), 1,
      anon_sym_chan,
    ACTIONS(930), 1,
      aux_sym_source_file_token1,
    ACTIONS(934), 1,
      anon_sym_LPAREN,
    ACTIONS(936), 1,
      anon_sym_COMMA,
    ACTIONS(938), 1,
      anon_sym_EQ,
    ACTIONS(940), 1,
      anon_sym_LBRACK,
    ACTIONS(942), 1,
      anon_sym_STAR,
    ACTIONS(944), 1,
      anon_sym_LT_DASH,
    STATE(392), 1,
      aux_sym_const_spec_repeat1,
    STATE(848), 2,
      sym_negated_type,
      sym_qualified_type,
    STATE(1323), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(932), 5,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
    STATE(858), 9,
      sym_generic_type,
      sym_pointer_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_interface_type,
      sym_map_type,
      sym_channel_type,
      sym_function_type,
  [31500] = 20,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(279), 1,
      anon_sym_TILDE,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(561), 1,
      sym_identifier,
    ACTIONS(572), 1,
      anon_sym_func,
    ACTIONS(585), 1,
      anon_sym_map,
    ACTIONS(587), 1,
      anon_sym_chan,
    ACTIONS(934), 1,
      anon_sym_LPAREN,
    ACTIONS(936), 1,
      anon_sym_COMMA,
    ACTIONS(940), 1,
      anon_sym_LBRACK,
    ACTIONS(942), 1,
      anon_sym_STAR,
    ACTIONS(944), 1,
      anon_sym_LT_DASH,
    ACTIONS(946), 1,
      aux_sym_source_file_token1,
    ACTIONS(950), 1,
      anon_sym_EQ,
    STATE(780), 1,
      aux_sym_const_spec_repeat1,
    STATE(848), 2,
      sym_negated_type,
      sym_qualified_type,
    STATE(1320), 2,
      sym_parenthesized_type,
      sym__simple_type,
    ACTIONS(948), 5,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
    STATE(858), 9,
      sym_generic_type,
      sym_pointer_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_interface_type,
      sym_map_type,
      sym_channel_type,
      sym_function_type,
  [31575] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(703), 8,
      anon_sym_DOT,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_COLON,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(701), 24,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_DOT,
      anon_sym_STAR,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COLON_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [31615] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(583), 8,
      anon_sym_DOT,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_COLON,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(578), 24,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_DOT,
      anon_sym_STAR,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COLON_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [31655] = 15,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(687), 1,
      aux_sym_source_file_token1,
    ACTIONS(952), 1,
      anon_sym_DOT,
    ACTIONS(954), 1,
      anon_sym_LPAREN,
    ACTIONS(956), 1,
      anon_sym_COMMA,
    ACTIONS(958), 1,
      anon_sym_LBRACK,
    ACTIONS(966), 1,
      anon_sym_AMP_AMP,
    ACTIONS(968), 1,
      anon_sym_PIPE_PIPE,
    STATE(504), 1,
      sym_argument_list,
    STATE(881), 1,
      aux_sym_expression_list_repeat1,
    STATE(1275), 1,
      sym_type_arguments,
    ACTIONS(962), 4,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
    ACTIONS(617), 5,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
    ACTIONS(964), 6,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_GT,
      anon_sym_GT_EQ,
    ACTIONS(960), 7,
      anon_sym_STAR,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
  [31719] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(653), 8,
      anon_sym_DOT,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_COLON,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(651), 24,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_DOT,
      anon_sym_STAR,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COLON_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [31759] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(735), 8,
      anon_sym_DOT,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_COLON,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(733), 24,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_DOT,
      anon_sym_STAR,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COLON_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [31799] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(667), 8,
      anon_sym_DOT,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_COLON,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(665), 24,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_DOT,
      anon_sym_STAR,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COLON_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [31839] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(671), 8,
      anon_sym_DOT,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_COLON,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(669), 24,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_DOT,
      anon_sym_STAR,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COLON_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [31879] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(787), 8,
      anon_sym_DOT,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_COLON,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(785), 24,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_DOT,
      anon_sym_STAR,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COLON_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [31919] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(743), 8,
      anon_sym_DOT,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_COLON,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(741), 24,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_DOT,
      anon_sym_STAR,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COLON_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [31959] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(649), 8,
      anon_sym_DOT,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_COLON,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(647), 24,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_DOT,
      anon_sym_STAR,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COLON_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [31999] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(739), 8,
      anon_sym_DOT,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_COLON,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(737), 24,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_DOT,
      anon_sym_STAR,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COLON_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [32039] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(823), 8,
      anon_sym_DOT,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_COLON,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(821), 24,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_DOT,
      anon_sym_STAR,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COLON_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [32079] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(747), 8,
      anon_sym_DOT,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_COLON,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(745), 24,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_DOT,
      anon_sym_STAR,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COLON_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [32119] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(751), 8,
      anon_sym_DOT,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_COLON,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(749), 24,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_DOT,
      anon_sym_STAR,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COLON_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [32159] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(819), 8,
      anon_sym_DOT,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_COLON,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(817), 24,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_DOT,
      anon_sym_STAR,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COLON_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [32199] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(707), 8,
      anon_sym_DOT,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_COLON,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(705), 24,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_DOT,
      anon_sym_STAR,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COLON_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [32239] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(657), 8,
      anon_sym_DOT,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_COLON,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(655), 24,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_DOT,
      anon_sym_STAR,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COLON_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [32279] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(711), 8,
      anon_sym_DOT,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_COLON,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(709), 24,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_DOT,
      anon_sym_STAR,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COLON_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [32319] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(715), 8,
      anon_sym_DOT,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_COLON,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(713), 24,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_DOT,
      anon_sym_STAR,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COLON_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [32359] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(719), 8,
      anon_sym_DOT,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_COLON,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(717), 24,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_DOT,
      anon_sym_STAR,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COLON_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [32399] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(723), 8,
      anon_sym_DOT,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_COLON,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(721), 24,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_DOT,
      anon_sym_STAR,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COLON_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [32439] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(727), 8,
      anon_sym_DOT,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_COLON,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(725), 24,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_DOT,
      anon_sym_STAR,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COLON_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [32479] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(731), 8,
      anon_sym_DOT,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_COLON,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(729), 24,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_DOT,
      anon_sym_STAR,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COLON_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [32519] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(755), 8,
      anon_sym_DOT,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_COLON,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(753), 24,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_DOT,
      anon_sym_STAR,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COLON_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [32559] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(759), 8,
      anon_sym_DOT,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_COLON,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(757), 24,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_DOT,
      anon_sym_STAR,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COLON_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [32599] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(763), 8,
      anon_sym_DOT,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_COLON,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(761), 24,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_DOT,
      anon_sym_STAR,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COLON_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [32639] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(767), 8,
      anon_sym_DOT,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_COLON,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(765), 24,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_DOT,
      anon_sym_STAR,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COLON_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [32679] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(771), 8,
      anon_sym_DOT,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_COLON,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(769), 24,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_DOT,
      anon_sym_STAR,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COLON_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [32719] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(775), 8,
      anon_sym_DOT,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_COLON,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(773), 24,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_DOT,
      anon_sym_STAR,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COLON_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [32759] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(779), 8,
      anon_sym_DOT,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_COLON,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(777), 24,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_DOT,
      anon_sym_STAR,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COLON_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [32799] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(783), 8,
      anon_sym_DOT,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_COLON,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(781), 24,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_DOT,
      anon_sym_STAR,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COLON_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [32839] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(791), 8,
      anon_sym_DOT,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_COLON,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(789), 24,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_DOT,
      anon_sym_STAR,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COLON_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [32879] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(795), 8,
      anon_sym_DOT,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_COLON,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(793), 24,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_DOT,
      anon_sym_STAR,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COLON_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [32919] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(799), 8,
      anon_sym_DOT,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_COLON,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(797), 24,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_DOT,
      anon_sym_STAR,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COLON_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [32959] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(803), 8,
      anon_sym_DOT,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_COLON,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(801), 24,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_DOT,
      anon_sym_STAR,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COLON_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [32999] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(807), 8,
      anon_sym_DOT,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_COLON,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(805), 24,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_DOT,
      anon_sym_STAR,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COLON_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [33039] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(811), 8,
      anon_sym_DOT,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_COLON,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(809), 24,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_DOT,
      anon_sym_STAR,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COLON_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [33079] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(815), 8,
      anon_sym_DOT,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_COLON,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(813), 24,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_DOT,
      anon_sym_STAR,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COLON_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [33119] = 9,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(578), 1,
      aux_sym_source_file_token1,
    ACTIONS(591), 1,
      anon_sym_DOT,
    ACTIONS(594), 1,
      anon_sym_LPAREN,
    ACTIONS(597), 1,
      anon_sym_LBRACK,
    ACTIONS(970), 1,
      anon_sym_LBRACE,
    STATE(505), 1,
      sym_literal_value,
    STATE(854), 1,
      sym_type_arguments,
    ACTIONS(583), 25,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_RBRACE,
      anon_sym_PIPE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [33171] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(663), 8,
      anon_sym_DOT,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_COLON,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(661), 24,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_DOT_DOT_DOT,
      anon_sym_STAR,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COLON_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [33211] = 8,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(641), 1,
      aux_sym_source_file_token1,
    ACTIONS(952), 1,
      anon_sym_DOT,
    ACTIONS(954), 1,
      anon_sym_LPAREN,
    ACTIONS(958), 1,
      anon_sym_LBRACK,
    STATE(504), 1,
      sym_argument_list,
    STATE(1275), 1,
      sym_type_arguments,
    ACTIONS(643), 25,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_RBRACE,
      anon_sym_PIPE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [33260] = 11,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(637), 1,
      aux_sym_source_file_token1,
    ACTIONS(952), 1,
      anon_sym_DOT,
    ACTIONS(954), 1,
      anon_sym_LPAREN,
    ACTIONS(958), 1,
      anon_sym_LBRACK,
    STATE(504), 1,
      sym_argument_list,
    STATE(1275), 1,
      sym_type_arguments,
    ACTIONS(962), 4,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
    ACTIONS(964), 6,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_GT,
      anon_sym_GT_EQ,
    ACTIONS(960), 7,
      anon_sym_STAR,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
    ACTIONS(639), 8,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [33315] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(561), 1,
      sym_identifier,
    ACTIONS(572), 1,
      anon_sym_func,
    ACTIONS(585), 1,
      anon_sym_map,
    ACTIONS(587), 1,
      anon_sym_chan,
    ACTIONS(589), 1,
      anon_sym_LT_DASH,
    ACTIONS(972), 1,
      anon_sym_LPAREN,
    ACTIONS(974), 1,
      anon_sym_LBRACK,
    ACTIONS(976), 1,
      anon_sym_STAR,
    STATE(848), 2,
      sym_negated_type,
      sym_qualified_type,
    STATE(853), 2,
      sym_parameter_list,
      sym__simple_type,
    ACTIONS(868), 7,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_RBRACK,
      anon_sym_LBRACE,
      anon_sym_PIPE,
      anon_sym_COLON,
    STATE(858), 9,
      sym_generic_type,
      sym_pointer_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_interface_type,
      sym_map_type,
      sym_channel_type,
      sym_function_type,
  [33380] = 8,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(637), 1,
      aux_sym_source_file_token1,
    ACTIONS(952), 1,
      anon_sym_DOT,
    ACTIONS(954), 1,
      anon_sym_LPAREN,
    ACTIONS(958), 1,
      anon_sym_LBRACK,
    STATE(504), 1,
      sym_argument_list,
    STATE(1275), 1,
      sym_type_arguments,
    ACTIONS(639), 25,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_RBRACE,
      anon_sym_PIPE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [33429] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(924), 1,
      anon_sym_LPAREN,
    ACTIONS(926), 1,
      anon_sym_LBRACK,
    ACTIONS(978), 1,
      anon_sym_DOT,
    STATE(397), 1,
      sym_argument_list,
    STATE(1255), 1,
      sym_type_arguments,
    ACTIONS(982), 2,
      anon_sym_AMP,
      anon_sym_SLASH,
    ACTIONS(639), 5,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(980), 5,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
    ACTIONS(637), 14,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [33482] = 10,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(637), 1,
      aux_sym_source_file_token1,
    ACTIONS(952), 1,
      anon_sym_DOT,
    ACTIONS(954), 1,
      anon_sym_LPAREN,
    ACTIONS(958), 1,
      anon_sym_LBRACK,
    STATE(504), 1,
      sym_argument_list,
    STATE(1275), 1,
      sym_type_arguments,
    ACTIONS(962), 4,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
    ACTIONS(960), 7,
      anon_sym_STAR,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
    ACTIONS(639), 14,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [33535] = 13,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(858), 1,
      aux_sym_source_file_token1,
    ACTIONS(952), 1,
      anon_sym_DOT,
    ACTIONS(954), 1,
      anon_sym_LPAREN,
    ACTIONS(958), 1,
      anon_sym_LBRACK,
    ACTIONS(966), 1,
      anon_sym_AMP_AMP,
    ACTIONS(968), 1,
      anon_sym_PIPE_PIPE,
    STATE(504), 1,
      sym_argument_list,
    STATE(1275), 1,
      sym_type_arguments,
    ACTIONS(962), 4,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
    ACTIONS(860), 6,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
    ACTIONS(964), 6,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_GT,
      anon_sym_GT_EQ,
    ACTIONS(960), 7,
      anon_sym_STAR,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
  [33594] = 9,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(637), 1,
      aux_sym_source_file_token1,
    ACTIONS(952), 1,
      anon_sym_DOT,
    ACTIONS(954), 1,
      anon_sym_LPAREN,
    ACTIONS(958), 1,
      anon_sym_LBRACK,
    STATE(504), 1,
      sym_argument_list,
    STATE(1275), 1,
      sym_type_arguments,
    ACTIONS(960), 7,
      anon_sym_STAR,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
    ACTIONS(639), 18,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_PIPE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [33645] = 12,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(637), 1,
      aux_sym_source_file_token1,
    ACTIONS(952), 1,
      anon_sym_DOT,
    ACTIONS(954), 1,
      anon_sym_LPAREN,
    ACTIONS(958), 1,
      anon_sym_LBRACK,
    ACTIONS(966), 1,
      anon_sym_AMP_AMP,
    STATE(504), 1,
      sym_argument_list,
    STATE(1275), 1,
      sym_type_arguments,
    ACTIONS(962), 4,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
    ACTIONS(964), 6,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_GT,
      anon_sym_GT_EQ,
    ACTIONS(639), 7,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_PIPE_PIPE,
    ACTIONS(960), 7,
      anon_sym_STAR,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
  [33702] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(924), 1,
      anon_sym_LPAREN,
    ACTIONS(926), 1,
      anon_sym_LBRACK,
    ACTIONS(978), 1,
      anon_sym_DOT,
    ACTIONS(984), 1,
      anon_sym_PIPE,
    STATE(397), 1,
      sym_argument_list,
    STATE(1255), 1,
      sym_type_arguments,
    ACTIONS(982), 2,
      anon_sym_AMP,
      anon_sym_SLASH,
    ACTIONS(986), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
    ACTIONS(639), 4,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(980), 5,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
    ACTIONS(637), 11,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [33759] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(924), 1,
      anon_sym_LPAREN,
    ACTIONS(926), 1,
      anon_sym_LBRACK,
    ACTIONS(978), 1,
      anon_sym_DOT,
    ACTIONS(984), 1,
      anon_sym_PIPE,
    ACTIONS(992), 1,
      anon_sym_AMP_AMP,
    STATE(397), 1,
      sym_argument_list,
    STATE(1255), 1,
      sym_type_arguments,
    ACTIONS(639), 2,
      anon_sym_EQ,
      anon_sym_COLON,
    ACTIONS(982), 2,
      anon_sym_AMP,
      anon_sym_SLASH,
    ACTIONS(990), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(986), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
    ACTIONS(988), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(980), 5,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
    ACTIONS(637), 6,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON_EQ,
      anon_sym_PIPE_PIPE,
  [33822] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(924), 1,
      anon_sym_LPAREN,
    ACTIONS(926), 1,
      anon_sym_LBRACK,
    ACTIONS(978), 1,
      anon_sym_DOT,
    ACTIONS(984), 1,
      anon_sym_PIPE,
    STATE(397), 1,
      sym_argument_list,
    STATE(1255), 1,
      sym_type_arguments,
    ACTIONS(639), 2,
      anon_sym_EQ,
      anon_sym_COLON,
    ACTIONS(982), 2,
      anon_sym_AMP,
      anon_sym_SLASH,
    ACTIONS(990), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(986), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
    ACTIONS(988), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(980), 5,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
    ACTIONS(637), 7,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [33883] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(972), 1,
      anon_sym_LPAREN,
    ACTIONS(994), 1,
      sym_identifier,
    ACTIONS(996), 1,
      anon_sym_func,
    ACTIONS(998), 1,
      anon_sym_LBRACK,
    ACTIONS(1000), 1,
      anon_sym_STAR,
    ACTIONS(1002), 1,
      anon_sym_LT_DASH,
    STATE(836), 2,
      sym_negated_type,
      sym_qualified_type,
    STATE(853), 2,
      sym_parameter_list,
      sym__simple_type,
    ACTIONS(868), 7,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_RBRACK,
      anon_sym_LBRACE,
      anon_sym_PIPE,
      anon_sym_COLON,
    STATE(858), 9,
      sym_generic_type,
      sym_pointer_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_interface_type,
      sym_map_type,
      sym_channel_type,
      sym_function_type,
  [33948] = 13,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(952), 1,
      anon_sym_DOT,
    ACTIONS(954), 1,
      anon_sym_LPAREN,
    ACTIONS(958), 1,
      anon_sym_LBRACK,
    ACTIONS(966), 1,
      anon_sym_AMP_AMP,
    ACTIONS(968), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1004), 1,
      aux_sym_source_file_token1,
    STATE(504), 1,
      sym_argument_list,
    STATE(1275), 1,
      sym_type_arguments,
    ACTIONS(962), 4,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
    ACTIONS(1006), 5,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
    ACTIONS(964), 6,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_GT,
      anon_sym_GT_EQ,
    ACTIONS(960), 7,
      anon_sym_STAR,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
  [34006] = 13,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(952), 1,
      anon_sym_DOT,
    ACTIONS(954), 1,
      anon_sym_LPAREN,
    ACTIONS(958), 1,
      anon_sym_LBRACK,
    ACTIONS(966), 1,
      anon_sym_AMP_AMP,
    ACTIONS(968), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1008), 1,
      aux_sym_source_file_token1,
    STATE(504), 1,
      sym_argument_list,
    STATE(1275), 1,
      sym_type_arguments,
    ACTIONS(962), 4,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
    ACTIONS(1010), 5,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
    ACTIONS(964), 6,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_GT,
      anon_sym_GT_EQ,
    ACTIONS(960), 7,
      anon_sym_STAR,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
  [34064] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(972), 1,
      anon_sym_LPAREN,
    ACTIONS(994), 1,
      sym_identifier,
    ACTIONS(996), 1,
      anon_sym_func,
    ACTIONS(998), 1,
      anon_sym_LBRACK,
    ACTIONS(1000), 1,
      anon_sym_STAR,
    ACTIONS(1002), 1,
      anon_sym_LT_DASH,
    ACTIONS(1012), 1,
      anon_sym_LBRACE,
    STATE(401), 1,
      sym_block,
    STATE(836), 2,
      sym_negated_type,
      sym_qualified_type,
    STATE(880), 2,
      sym_parameter_list,
      sym__simple_type,
    ACTIONS(868), 4,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_PIPE,
    STATE(858), 9,
      sym_generic_type,
      sym_pointer_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_interface_type,
      sym_map_type,
      sym_channel_type,
      sym_function_type,
  [34132] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(617), 1,
      anon_sym_EQ,
    ACTIONS(685), 1,
      anon_sym_LT_DASH,
    ACTIONS(687), 1,
      anon_sym_COLON_EQ,
    ACTIONS(1014), 1,
      anon_sym_DOT,
    ACTIONS(1016), 1,
      anon_sym_LPAREN,
    ACTIONS(1018), 1,
      anon_sym_COMMA,
    ACTIONS(1020), 1,
      anon_sym_LBRACK,
    ACTIONS(1024), 1,
      anon_sym_PIPE,
    ACTIONS(1026), 1,
      anon_sym_COLON,
    ACTIONS(1036), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1038), 1,
      anon_sym_PIPE_PIPE,
    STATE(538), 1,
      sym_argument_list,
    STATE(979), 1,
      aux_sym_expression_list_repeat1,
    STATE(1266), 1,
      sym_type_arguments,
    ACTIONS(1030), 2,
      anon_sym_AMP,
      anon_sym_SLASH,
    ACTIONS(1034), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1028), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
    ACTIONS(1032), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(1022), 5,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
  [34204] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(561), 1,
      sym_identifier,
    ACTIONS(572), 1,
      anon_sym_func,
    ACTIONS(585), 1,
      anon_sym_map,
    ACTIONS(587), 1,
      anon_sym_chan,
    ACTIONS(589), 1,
      anon_sym_LT_DASH,
    ACTIONS(976), 1,
      anon_sym_STAR,
    ACTIONS(1040), 1,
      anon_sym_DOT,
    ACTIONS(1042), 1,
      anon_sym_LPAREN,
    ACTIONS(1044), 1,
      anon_sym_RPAREN,
    ACTIONS(1046), 1,
      anon_sym_COMMA,
    ACTIONS(1049), 1,
      anon_sym_LBRACK,
    ACTIONS(1051), 1,
      anon_sym_DOT_DOT_DOT,
    STATE(595), 1,
      aux_sym_var_spec_repeat1,
    STATE(854), 1,
      sym_type_arguments,
    STATE(848), 2,
      sym_negated_type,
      sym_qualified_type,
    STATE(1286), 2,
      sym_parenthesized_type,
      sym__simple_type,
    STATE(858), 9,
      sym_generic_type,
      sym_pointer_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_interface_type,
      sym_map_type,
      sym_channel_type,
      sym_function_type,
  [34278] = 13,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(952), 1,
      anon_sym_DOT,
    ACTIONS(954), 1,
      anon_sym_LPAREN,
    ACTIONS(958), 1,
      anon_sym_LBRACK,
    ACTIONS(966), 1,
      anon_sym_AMP_AMP,
    ACTIONS(968), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1053), 1,
      aux_sym_source_file_token1,
    STATE(504), 1,
      sym_argument_list,
    STATE(1275), 1,
      sym_type_arguments,
    ACTIONS(962), 4,
      anon_sym_PIPE,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
    ACTIONS(1055), 5,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
    ACTIONS(964), 6,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_GT,
      anon_sym_GT_EQ,
    ACTIONS(960), 7,
      anon_sym_STAR,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
  [34336] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(563), 1,
      anon_sym_DOT,
    ACTIONS(831), 1,
      anon_sym_LPAREN,
    ACTIONS(834), 1,
      anon_sym_LBRACK,
    ACTIONS(1057), 1,
      anon_sym_LBRACE,
    STATE(539), 1,
      sym_literal_value,
    STATE(854), 1,
      sym_type_arguments,
    ACTIONS(583), 7,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_COLON,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(578), 17,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [34386] = 5,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(578), 1,
      aux_sym_source_file_token1,
    ACTIONS(1059), 1,
      anon_sym_LPAREN,
    STATE(504), 1,
      sym_special_argument_list,
    ACTIONS(583), 27,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_DOT,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_STAR,
      anon_sym_RBRACE,
      anon_sym_PIPE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [34428] = 19,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(1063), 1,
      sym_identifier,
    ACTIONS(1067), 1,
      anon_sym_LPAREN,
    ACTIONS(1069), 1,
      anon_sym_func,
    ACTIONS(1071), 1,
      anon_sym_LBRACK,
    ACTIONS(1073), 1,
      anon_sym_STAR,
    ACTIONS(1075), 1,
      anon_sym_struct,
    ACTIONS(1077), 1,
      anon_sym_TILDE,
    ACTIONS(1079), 1,
      anon_sym_LBRACE,
    ACTIONS(1081), 1,
      anon_sym_interface,
    ACTIONS(1083), 1,
      anon_sym_map,
    ACTIONS(1085), 1,
      anon_sym_chan,
    ACTIONS(1087), 1,
      anon_sym_LT_DASH,
    STATE(1065), 1,
      sym_block,
    ACTIONS(1061), 2,
      ts_builtin_sym_end,
      aux_sym_source_file_token1,
    ACTIONS(1065), 2,
      anon_sym_SEMI,
      anon_sym_NULL,
    STATE(910), 2,
      sym_negated_type,
      sym_qualified_type,
    STATE(915), 2,
      sym_parameter_list,
      sym__simple_type,
    STATE(950), 9,
      sym_generic_type,
      sym_pointer_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_interface_type,
      sym_map_type,
      sym_channel_type,
      sym_function_type,
  [34498] = 19,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(1063), 1,
      sym_identifier,
    ACTIONS(1067), 1,
      anon_sym_LPAREN,
    ACTIONS(1069), 1,
      anon_sym_func,
    ACTIONS(1071), 1,
      anon_sym_LBRACK,
    ACTIONS(1073), 1,
      anon_sym_STAR,
    ACTIONS(1075), 1,
      anon_sym_struct,
    ACTIONS(1077), 1,
      anon_sym_TILDE,
    ACTIONS(1079), 1,
      anon_sym_LBRACE,
    ACTIONS(1081), 1,
      anon_sym_interface,
    ACTIONS(1083), 1,
      anon_sym_map,
    ACTIONS(1085), 1,
      anon_sym_chan,
    ACTIONS(1087), 1,
      anon_sym_LT_DASH,
    STATE(1066), 1,
      sym_block,
    ACTIONS(1089), 2,
      ts_builtin_sym_end,
      aux_sym_source_file_token1,
    ACTIONS(1091), 2,
      anon_sym_SEMI,
      anon_sym_NULL,
    STATE(910), 2,
      sym_negated_type,
      sym_qualified_type,
    STATE(959), 2,
      sym_parameter_list,
      sym__simple_type,
    STATE(950), 9,
      sym_generic_type,
      sym_pointer_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_interface_type,
      sym_map_type,
      sym_channel_type,
      sym_function_type,
  [34568] = 19,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(1063), 1,
      sym_identifier,
    ACTIONS(1067), 1,
      anon_sym_LPAREN,
    ACTIONS(1069), 1,
      anon_sym_func,
    ACTIONS(1071), 1,
      anon_sym_LBRACK,
    ACTIONS(1073), 1,
      anon_sym_STAR,
    ACTIONS(1075), 1,
      anon_sym_struct,
    ACTIONS(1077), 1,
      anon_sym_TILDE,
    ACTIONS(1079), 1,
      anon_sym_LBRACE,
    ACTIONS(1081), 1,
      anon_sym_interface,
    ACTIONS(1083), 1,
      anon_sym_map,
    ACTIONS(1085), 1,
      anon_sym_chan,
    ACTIONS(1087), 1,
      anon_sym_LT_DASH,
    STATE(1081), 1,
      sym_block,
    ACTIONS(1093), 2,
      ts_builtin_sym_end,
      aux_sym_source_file_token1,
    ACTIONS(1095), 2,
      anon_sym_SEMI,
      anon_sym_NULL,
    STATE(910), 2,
      sym_negated_type,
      sym_qualified_type,
    STATE(914), 2,
      sym_parameter_list,
      sym__simple_type,
    STATE(950), 9,
      sym_generic_type,
      sym_pointer_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_interface_type,
      sym_map_type,
      sym_channel_type,
      sym_function_type,
  [34638] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(753), 1,
      aux_sym_source_file_token1,
    ACTIONS(755), 28,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_STAR,
      anon_sym_RBRACE,
      anon_sym_PIPE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [34675] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(745), 1,
      aux_sym_source_file_token1,
    ACTIONS(747), 28,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_STAR,
      anon_sym_RBRACE,
      anon_sym_PIPE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [34712] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(647), 1,
      aux_sym_source_file_token1,
    ACTIONS(649), 28,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_STAR,
      anon_sym_RBRACE,
      anon_sym_PIPE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [34749] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1014), 1,
      anon_sym_DOT,
    ACTIONS(1016), 1,
      anon_sym_LPAREN,
    ACTIONS(1020), 1,
      anon_sym_LBRACK,
    STATE(538), 1,
      sym_argument_list,
    STATE(1266), 1,
      sym_type_arguments,
    ACTIONS(1030), 2,
      anon_sym_AMP,
      anon_sym_SLASH,
    ACTIONS(639), 5,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1022), 5,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
    ACTIONS(637), 12,
      anon_sym_COMMA,
      anon_sym_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [34800] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1014), 1,
      anon_sym_DOT,
    ACTIONS(1016), 1,
      anon_sym_LPAREN,
    ACTIONS(1020), 1,
      anon_sym_LBRACK,
    ACTIONS(1024), 1,
      anon_sym_PIPE,
    STATE(538), 1,
      sym_argument_list,
    STATE(1266), 1,
      sym_type_arguments,
    ACTIONS(1030), 2,
      anon_sym_AMP,
      anon_sym_SLASH,
    ACTIONS(1028), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
    ACTIONS(639), 4,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1022), 5,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
    ACTIONS(637), 9,
      anon_sym_COMMA,
      anon_sym_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [34855] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1014), 1,
      anon_sym_DOT,
    ACTIONS(1016), 1,
      anon_sym_LPAREN,
    ACTIONS(1020), 1,
      anon_sym_LBRACK,
    ACTIONS(1024), 1,
      anon_sym_PIPE,
    STATE(538), 1,
      sym_argument_list,
    STATE(1266), 1,
      sym_type_arguments,
    ACTIONS(639), 2,
      anon_sym_EQ,
      anon_sym_COLON,
    ACTIONS(1030), 2,
      anon_sym_AMP,
      anon_sym_SLASH,
    ACTIONS(1034), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1028), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
    ACTIONS(1032), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(637), 5,
      anon_sym_COMMA,
      anon_sym_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(1022), 5,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
  [34914] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1014), 1,
      anon_sym_DOT,
    ACTIONS(1016), 1,
      anon_sym_LPAREN,
    ACTIONS(1020), 1,
      anon_sym_LBRACK,
    ACTIONS(1024), 1,
      anon_sym_PIPE,
    ACTIONS(1036), 1,
      anon_sym_AMP_AMP,
    STATE(538), 1,
      sym_argument_list,
    STATE(1266), 1,
      sym_type_arguments,
    ACTIONS(639), 2,
      anon_sym_EQ,
      anon_sym_COLON,
    ACTIONS(1030), 2,
      anon_sym_AMP,
      anon_sym_SLASH,
    ACTIONS(1034), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1028), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
    ACTIONS(637), 4,
      anon_sym_COMMA,
      anon_sym_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_PIPE_PIPE,
    ACTIONS(1032), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(1022), 5,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
  [34975] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(749), 1,
      aux_sym_source_file_token1,
    ACTIONS(751), 28,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_STAR,
      anon_sym_RBRACE,
      anon_sym_PIPE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [35012] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(817), 1,
      aux_sym_source_file_token1,
    ACTIONS(819), 28,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_STAR,
      anon_sym_RBRACE,
      anon_sym_PIPE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [35049] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(661), 1,
      aux_sym_source_file_token1,
    ACTIONS(663), 28,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_STAR,
      anon_sym_RBRACE,
      anon_sym_PIPE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [35086] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(572), 1,
      anon_sym_func,
    ACTIONS(585), 1,
      anon_sym_map,
    ACTIONS(587), 1,
      anon_sym_chan,
    ACTIONS(589), 1,
      anon_sym_LT_DASH,
    ACTIONS(974), 1,
      anon_sym_LBRACK,
    ACTIONS(976), 1,
      anon_sym_STAR,
    ACTIONS(1042), 1,
      anon_sym_LPAREN,
    ACTIONS(1097), 1,
      sym_identifier,
    ACTIONS(1099), 1,
      anon_sym_RPAREN,
    ACTIONS(1101), 1,
      anon_sym_COMMA,
    ACTIONS(1103), 1,
      anon_sym_DOT_DOT_DOT,
    STATE(848), 2,
      sym_negated_type,
      sym_qualified_type,
    STATE(1189), 2,
      sym_parameter_declaration,
      sym_variadic_parameter_declaration,
    STATE(1273), 2,
      sym_parenthesized_type,
      sym__simple_type,
    STATE(858), 9,
      sym_generic_type,
      sym_pointer_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_interface_type,
      sym_map_type,
      sym_channel_type,
      sym_function_type,
  [35155] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(705), 1,
      aux_sym_source_file_token1,
    ACTIONS(707), 28,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_STAR,
      anon_sym_RBRACE,
      anon_sym_PIPE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [35192] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(701), 1,
      aux_sym_source_file_token1,
    ACTIONS(703), 28,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_STAR,
      anon_sym_RBRACE,
      anon_sym_PIPE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [35229] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(709), 1,
      aux_sym_source_file_token1,
    ACTIONS(711), 28,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_STAR,
      anon_sym_RBRACE,
      anon_sym_PIPE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [35266] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(713), 1,
      aux_sym_source_file_token1,
    ACTIONS(715), 28,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_STAR,
      anon_sym_RBRACE,
      anon_sym_PIPE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [35303] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(717), 1,
      aux_sym_source_file_token1,
    ACTIONS(719), 28,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_STAR,
      anon_sym_RBRACE,
      anon_sym_PIPE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [35340] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(721), 1,
      aux_sym_source_file_token1,
    ACTIONS(723), 28,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_STAR,
      anon_sym_RBRACE,
      anon_sym_PIPE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [35377] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(725), 1,
      aux_sym_source_file_token1,
    ACTIONS(727), 28,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_STAR,
      anon_sym_RBRACE,
      anon_sym_PIPE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [35414] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(729), 1,
      aux_sym_source_file_token1,
    ACTIONS(731), 28,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_STAR,
      anon_sym_RBRACE,
      anon_sym_PIPE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [35451] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(757), 1,
      aux_sym_source_file_token1,
    ACTIONS(759), 28,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_STAR,
      anon_sym_RBRACE,
      anon_sym_PIPE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [35488] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(761), 1,
      aux_sym_source_file_token1,
    ACTIONS(763), 28,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_STAR,
      anon_sym_RBRACE,
      anon_sym_PIPE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [35525] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(572), 1,
      anon_sym_func,
    ACTIONS(585), 1,
      anon_sym_map,
    ACTIONS(587), 1,
      anon_sym_chan,
    ACTIONS(589), 1,
      anon_sym_LT_DASH,
    ACTIONS(974), 1,
      anon_sym_LBRACK,
    ACTIONS(976), 1,
      anon_sym_STAR,
    ACTIONS(1042), 1,
      anon_sym_LPAREN,
    ACTIONS(1097), 1,
      sym_identifier,
    ACTIONS(1103), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1105), 1,
      anon_sym_RPAREN,
    ACTIONS(1107), 1,
      anon_sym_COMMA,
    STATE(848), 2,
      sym_negated_type,
      sym_qualified_type,
    STATE(1213), 2,
      sym_parameter_declaration,
      sym_variadic_parameter_declaration,
    STATE(1273), 2,
      sym_parenthesized_type,
      sym__simple_type,
    STATE(858), 9,
      sym_generic_type,
      sym_pointer_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_interface_type,
      sym_map_type,
      sym_channel_type,
      sym_function_type,
  [35594] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(655), 1,
      aux_sym_source_file_token1,
    ACTIONS(657), 28,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_STAR,
      anon_sym_RBRACE,
      anon_sym_PIPE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [35631] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(765), 1,
      aux_sym_source_file_token1,
    ACTIONS(767), 28,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_STAR,
      anon_sym_RBRACE,
      anon_sym_PIPE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [35668] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(741), 1,
      aux_sym_source_file_token1,
    ACTIONS(743), 28,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_STAR,
      anon_sym_RBRACE,
      anon_sym_PIPE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [35705] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(924), 1,
      anon_sym_LPAREN,
    ACTIONS(926), 1,
      anon_sym_LBRACK,
    ACTIONS(978), 1,
      anon_sym_DOT,
    ACTIONS(984), 1,
      anon_sym_PIPE,
    ACTIONS(992), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1109), 1,
      anon_sym_PIPE_PIPE,
    STATE(397), 1,
      sym_argument_list,
    STATE(1255), 1,
      sym_type_arguments,
    ACTIONS(860), 2,
      anon_sym_EQ,
      anon_sym_COLON,
    ACTIONS(982), 2,
      anon_sym_AMP,
      anon_sym_SLASH,
    ACTIONS(990), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(858), 3,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_COLON_EQ,
    ACTIONS(986), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
    ACTIONS(988), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(980), 5,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
  [35768] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(773), 1,
      aux_sym_source_file_token1,
    ACTIONS(775), 28,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_STAR,
      anon_sym_RBRACE,
      anon_sym_PIPE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [35805] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(777), 1,
      aux_sym_source_file_token1,
    ACTIONS(779), 28,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_STAR,
      anon_sym_RBRACE,
      anon_sym_PIPE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [35842] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(781), 1,
      aux_sym_source_file_token1,
    ACTIONS(783), 28,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_STAR,
      anon_sym_RBRACE,
      anon_sym_PIPE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [35879] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(789), 1,
      aux_sym_source_file_token1,
    ACTIONS(791), 28,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_STAR,
      anon_sym_RBRACE,
      anon_sym_PIPE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [35916] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1014), 1,
      anon_sym_DOT,
    ACTIONS(1016), 1,
      anon_sym_LPAREN,
    ACTIONS(1020), 1,
      anon_sym_LBRACK,
    STATE(538), 1,
      sym_argument_list,
    STATE(1266), 1,
      sym_type_arguments,
    ACTIONS(643), 7,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_COLON,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(641), 17,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [35963] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(572), 1,
      anon_sym_func,
    ACTIONS(585), 1,
      anon_sym_map,
    ACTIONS(587), 1,
      anon_sym_chan,
    ACTIONS(589), 1,
      anon_sym_LT_DASH,
    ACTIONS(974), 1,
      anon_sym_LBRACK,
    ACTIONS(976), 1,
      anon_sym_STAR,
    ACTIONS(1042), 1,
      anon_sym_LPAREN,
    ACTIONS(1097), 1,
      sym_identifier,
    ACTIONS(1103), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1111), 1,
      anon_sym_RPAREN,
    ACTIONS(1113), 1,
      anon_sym_COMMA,
    STATE(848), 2,
      sym_negated_type,
      sym_qualified_type,
    STATE(1143), 2,
      sym_parameter_declaration,
      sym_variadic_parameter_declaration,
    STATE(1273), 2,
      sym_parenthesized_type,
      sym__simple_type,
    STATE(858), 9,
      sym_generic_type,
      sym_pointer_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_interface_type,
      sym_map_type,
      sym_channel_type,
      sym_function_type,
  [36032] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(793), 1,
      aux_sym_source_file_token1,
    ACTIONS(795), 28,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_STAR,
      anon_sym_RBRACE,
      anon_sym_PIPE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [36069] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(797), 1,
      aux_sym_source_file_token1,
    ACTIONS(799), 28,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_STAR,
      anon_sym_RBRACE,
      anon_sym_PIPE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [36106] = 17,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(1063), 1,
      sym_identifier,
    ACTIONS(1067), 1,
      anon_sym_LPAREN,
    ACTIONS(1069), 1,
      anon_sym_func,
    ACTIONS(1071), 1,
      anon_sym_LBRACK,
    ACTIONS(1073), 1,
      anon_sym_STAR,
    ACTIONS(1075), 1,
      anon_sym_struct,
    ACTIONS(1077), 1,
      anon_sym_TILDE,
    ACTIONS(1081), 1,
      anon_sym_interface,
    ACTIONS(1083), 1,
      anon_sym_map,
    ACTIONS(1085), 1,
      anon_sym_chan,
    ACTIONS(1087), 1,
      anon_sym_LT_DASH,
    ACTIONS(868), 2,
      ts_builtin_sym_end,
      aux_sym_source_file_token1,
    STATE(910), 2,
      sym_negated_type,
      sym_qualified_type,
    STATE(919), 2,
      sym_parameter_list,
      sym__simple_type,
    ACTIONS(870), 3,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_LBRACE,
    STATE(950), 9,
      sym_generic_type,
      sym_pointer_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_interface_type,
      sym_map_type,
      sym_channel_type,
      sym_function_type,
  [36171] = 17,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(1067), 1,
      anon_sym_LPAREN,
    ACTIONS(1075), 1,
      anon_sym_struct,
    ACTIONS(1077), 1,
      anon_sym_TILDE,
    ACTIONS(1081), 1,
      anon_sym_interface,
    ACTIONS(1115), 1,
      sym_identifier,
    ACTIONS(1117), 1,
      anon_sym_func,
    ACTIONS(1119), 1,
      anon_sym_LBRACK,
    ACTIONS(1121), 1,
      anon_sym_STAR,
    ACTIONS(1123), 1,
      anon_sym_map,
    ACTIONS(1125), 1,
      anon_sym_chan,
    ACTIONS(1127), 1,
      anon_sym_LT_DASH,
    ACTIONS(868), 2,
      ts_builtin_sym_end,
      aux_sym_source_file_token1,
    STATE(895), 2,
      sym_negated_type,
      sym_qualified_type,
    STATE(919), 2,
      sym_parameter_list,
      sym__simple_type,
    ACTIONS(870), 3,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_LBRACE,
    STATE(950), 9,
      sym_generic_type,
      sym_pointer_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_interface_type,
      sym_map_type,
      sym_channel_type,
      sym_function_type,
  [36236] = 19,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(872), 1,
      anon_sym_LPAREN,
    ACTIONS(880), 1,
      anon_sym_struct,
    ACTIONS(882), 1,
      anon_sym_TILDE,
    ACTIONS(884), 1,
      anon_sym_interface,
    ACTIONS(892), 1,
      sym_identifier,
    ACTIONS(904), 1,
      anon_sym_func,
    ACTIONS(908), 1,
      anon_sym_STAR,
    ACTIONS(910), 1,
      anon_sym_map,
    ACTIONS(912), 1,
      anon_sym_chan,
    ACTIONS(914), 1,
      anon_sym_LT_DASH,
    ACTIONS(920), 1,
      anon_sym_LBRACK,
    ACTIONS(1089), 1,
      aux_sym_source_file_token1,
    ACTIONS(1129), 1,
      anon_sym_LBRACE,
    STATE(1235), 1,
      sym_block,
    ACTIONS(1091), 2,
      anon_sym_SEMI,
      anon_sym_NULL,
    STATE(799), 2,
      sym_negated_type,
      sym_qualified_type,
    STATE(1044), 2,
      sym_parameter_list,
      sym__simple_type,
    STATE(807), 9,
      sym_generic_type,
      sym_pointer_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_interface_type,
      sym_map_type,
      sym_channel_type,
      sym_function_type,
  [36305] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(801), 1,
      aux_sym_source_file_token1,
    ACTIONS(803), 28,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_STAR,
      anon_sym_RBRACE,
      anon_sym_PIPE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [36342] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1014), 1,
      anon_sym_DOT,
    ACTIONS(1016), 1,
      anon_sym_LPAREN,
    ACTIONS(1020), 1,
      anon_sym_LBRACK,
    STATE(538), 1,
      sym_argument_list,
    STATE(1266), 1,
      sym_type_arguments,
    ACTIONS(639), 7,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_COLON,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(637), 17,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [36389] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(805), 1,
      aux_sym_source_file_token1,
    ACTIONS(807), 28,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_STAR,
      anon_sym_RBRACE,
      anon_sym_PIPE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [36426] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(809), 1,
      aux_sym_source_file_token1,
    ACTIONS(811), 28,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_STAR,
      anon_sym_RBRACE,
      anon_sym_PIPE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [36463] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(813), 1,
      aux_sym_source_file_token1,
    ACTIONS(815), 28,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_STAR,
      anon_sym_RBRACE,
      anon_sym_PIPE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [36500] = 19,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(872), 1,
      anon_sym_LPAREN,
    ACTIONS(880), 1,
      anon_sym_struct,
    ACTIONS(882), 1,
      anon_sym_TILDE,
    ACTIONS(884), 1,
      anon_sym_interface,
    ACTIONS(892), 1,
      sym_identifier,
    ACTIONS(904), 1,
      anon_sym_func,
    ACTIONS(908), 1,
      anon_sym_STAR,
    ACTIONS(910), 1,
      anon_sym_map,
    ACTIONS(912), 1,
      anon_sym_chan,
    ACTIONS(914), 1,
      anon_sym_LT_DASH,
    ACTIONS(920), 1,
      anon_sym_LBRACK,
    ACTIONS(1093), 1,
      aux_sym_source_file_token1,
    ACTIONS(1129), 1,
      anon_sym_LBRACE,
    STATE(1210), 1,
      sym_block,
    ACTIONS(1095), 2,
      anon_sym_SEMI,
      anon_sym_NULL,
    STATE(799), 2,
      sym_negated_type,
      sym_qualified_type,
    STATE(1049), 2,
      sym_parameter_list,
      sym__simple_type,
    STATE(807), 9,
      sym_generic_type,
      sym_pointer_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_interface_type,
      sym_map_type,
      sym_channel_type,
      sym_function_type,
  [36569] = 19,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(872), 1,
      anon_sym_LPAREN,
    ACTIONS(880), 1,
      anon_sym_struct,
    ACTIONS(882), 1,
      anon_sym_TILDE,
    ACTIONS(884), 1,
      anon_sym_interface,
    ACTIONS(892), 1,
      sym_identifier,
    ACTIONS(904), 1,
      anon_sym_func,
    ACTIONS(908), 1,
      anon_sym_STAR,
    ACTIONS(910), 1,
      anon_sym_map,
    ACTIONS(912), 1,
      anon_sym_chan,
    ACTIONS(914), 1,
      anon_sym_LT_DASH,
    ACTIONS(920), 1,
      anon_sym_LBRACK,
    ACTIONS(1061), 1,
      aux_sym_source_file_token1,
    ACTIONS(1129), 1,
      anon_sym_LBRACE,
    STATE(1241), 1,
      sym_block,
    ACTIONS(1065), 2,
      anon_sym_SEMI,
      anon_sym_NULL,
    STATE(799), 2,
      sym_negated_type,
      sym_qualified_type,
    STATE(1048), 2,
      sym_parameter_list,
      sym__simple_type,
    STATE(807), 9,
      sym_generic_type,
      sym_pointer_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_interface_type,
      sym_map_type,
      sym_channel_type,
      sym_function_type,
  [36638] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(785), 1,
      aux_sym_source_file_token1,
    ACTIONS(787), 28,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_STAR,
      anon_sym_RBRACE,
      anon_sym_PIPE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [36675] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(578), 1,
      aux_sym_source_file_token1,
    ACTIONS(583), 28,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_STAR,
      anon_sym_RBRACE,
      anon_sym_PIPE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [36712] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(737), 1,
      aux_sym_source_file_token1,
    ACTIONS(739), 28,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_STAR,
      anon_sym_RBRACE,
      anon_sym_PIPE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [36749] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(733), 1,
      aux_sym_source_file_token1,
    ACTIONS(735), 28,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_STAR,
      anon_sym_RBRACE,
      anon_sym_PIPE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [36786] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(665), 1,
      aux_sym_source_file_token1,
    ACTIONS(667), 28,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_STAR,
      anon_sym_RBRACE,
      anon_sym_PIPE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [36823] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(651), 1,
      aux_sym_source_file_token1,
    ACTIONS(653), 28,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_STAR,
      anon_sym_RBRACE,
      anon_sym_PIPE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [36860] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(669), 1,
      aux_sym_source_file_token1,
    ACTIONS(671), 28,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_STAR,
      anon_sym_RBRACE,
      anon_sym_PIPE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [36897] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(821), 1,
      aux_sym_source_file_token1,
    ACTIONS(823), 28,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_STAR,
      anon_sym_RBRACE,
      anon_sym_PIPE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [36934] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(769), 1,
      aux_sym_source_file_token1,
    ACTIONS(771), 28,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_STAR,
      anon_sym_RBRACE,
      anon_sym_PIPE,
      anon_sym_case,
      anon_sym_default,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [36971] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(572), 1,
      anon_sym_func,
    ACTIONS(585), 1,
      anon_sym_map,
    ACTIONS(587), 1,
      anon_sym_chan,
    ACTIONS(589), 1,
      anon_sym_LT_DASH,
    ACTIONS(974), 1,
      anon_sym_LBRACK,
    ACTIONS(976), 1,
      anon_sym_STAR,
    ACTIONS(1042), 1,
      anon_sym_LPAREN,
    ACTIONS(1097), 1,
      sym_identifier,
    ACTIONS(1103), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1131), 1,
      anon_sym_RPAREN,
    STATE(848), 2,
      sym_negated_type,
      sym_qualified_type,
    STATE(1273), 2,
      sym_parenthesized_type,
      sym__simple_type,
    STATE(1304), 2,
      sym_parameter_declaration,
      sym_variadic_parameter_declaration,
    STATE(858), 9,
      sym_generic_type,
      sym_pointer_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_interface_type,
      sym_map_type,
      sym_channel_type,
      sym_function_type,
  [37037] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(922), 1,
      anon_sym_DOT,
    ACTIONS(924), 1,
      anon_sym_LPAREN,
    ACTIONS(926), 1,
      anon_sym_LBRACK,
    ACTIONS(1133), 1,
      anon_sym_RPAREN,
    ACTIONS(1135), 1,
      anon_sym_COMMA,
    ACTIONS(1137), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1141), 1,
      anon_sym_PIPE,
    ACTIONS(1151), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1153), 1,
      anon_sym_PIPE_PIPE,
    STATE(397), 1,
      sym_argument_list,
    STATE(1185), 1,
      aux_sym_argument_list_repeat1,
    STATE(1255), 1,
      sym_type_arguments,
    ACTIONS(1145), 2,
      anon_sym_AMP,
      anon_sym_SLASH,
    ACTIONS(1149), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1143), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
    ACTIONS(1147), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(1139), 5,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
  [37103] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(922), 1,
      anon_sym_DOT,
    ACTIONS(924), 1,
      anon_sym_LPAREN,
    ACTIONS(926), 1,
      anon_sym_LBRACK,
    ACTIONS(1137), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1141), 1,
      anon_sym_PIPE,
    ACTIONS(1151), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1153), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1155), 1,
      anon_sym_RPAREN,
    ACTIONS(1157), 1,
      anon_sym_COMMA,
    STATE(397), 1,
      sym_argument_list,
    STATE(1145), 1,
      aux_sym_argument_list_repeat1,
    STATE(1255), 1,
      sym_type_arguments,
    ACTIONS(1145), 2,
      anon_sym_AMP,
      anon_sym_SLASH,
    ACTIONS(1149), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1143), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
    ACTIONS(1147), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(1139), 5,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
  [37169] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(687), 1,
      anon_sym_COLON_EQ,
    ACTIONS(924), 1,
      anon_sym_LPAREN,
    ACTIONS(926), 1,
      anon_sym_LBRACK,
    ACTIONS(1018), 1,
      anon_sym_COMMA,
    ACTIONS(1159), 1,
      anon_sym_DOT,
    ACTIONS(1163), 1,
      anon_sym_LBRACE,
    ACTIONS(1165), 1,
      anon_sym_PIPE,
    ACTIONS(1175), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1177), 1,
      anon_sym_PIPE_PIPE,
    STATE(397), 1,
      sym_argument_list,
    STATE(979), 1,
      aux_sym_expression_list_repeat1,
    STATE(1255), 1,
      sym_type_arguments,
    ACTIONS(1169), 2,
      anon_sym_AMP,
      anon_sym_SLASH,
    ACTIONS(1173), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1167), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
    ACTIONS(1171), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(1161), 5,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
  [37235] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(303), 1,
      anon_sym_LBRACE,
    ACTIONS(591), 1,
      anon_sym_DOT,
    ACTIONS(831), 1,
      anon_sym_LPAREN,
    ACTIONS(834), 1,
      anon_sym_LBRACK,
    STATE(398), 1,
      sym_literal_value,
    STATE(854), 1,
      sym_type_arguments,
    ACTIONS(583), 5,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(578), 17,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_DOT_DOT_DOT,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [37283] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1179), 1,
      anon_sym_LPAREN,
    STATE(538), 1,
      sym_special_argument_list,
    ACTIONS(583), 7,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_COLON,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(578), 19,
      anon_sym_DOT,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_STAR,
      anon_sym_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [37323] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(922), 1,
      anon_sym_DOT,
    ACTIONS(924), 1,
      anon_sym_LPAREN,
    ACTIONS(926), 1,
      anon_sym_LBRACK,
    ACTIONS(1137), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1141), 1,
      anon_sym_PIPE,
    ACTIONS(1151), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1153), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1181), 1,
      anon_sym_RPAREN,
    ACTIONS(1183), 1,
      anon_sym_COMMA,
    STATE(397), 1,
      sym_argument_list,
    STATE(1204), 1,
      aux_sym_argument_list_repeat1,
    STATE(1255), 1,
      sym_type_arguments,
    ACTIONS(1145), 2,
      anon_sym_AMP,
      anon_sym_SLASH,
    ACTIONS(1149), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1143), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
    ACTIONS(1147), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(1139), 5,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
  [37389] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(572), 1,
      anon_sym_func,
    ACTIONS(585), 1,
      anon_sym_map,
    ACTIONS(587), 1,
      anon_sym_chan,
    ACTIONS(589), 1,
      anon_sym_LT_DASH,
    ACTIONS(974), 1,
      anon_sym_LBRACK,
    ACTIONS(976), 1,
      anon_sym_STAR,
    ACTIONS(1042), 1,
      anon_sym_LPAREN,
    ACTIONS(1097), 1,
      sym_identifier,
    ACTIONS(1103), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1185), 1,
      anon_sym_RPAREN,
    STATE(848), 2,
      sym_negated_type,
      sym_qualified_type,
    STATE(1273), 2,
      sym_parenthesized_type,
      sym__simple_type,
    STATE(1304), 2,
      sym_parameter_declaration,
      sym_variadic_parameter_declaration,
    STATE(858), 9,
      sym_generic_type,
      sym_pointer_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_interface_type,
      sym_map_type,
      sym_channel_type,
      sym_function_type,
  [37455] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(572), 1,
      anon_sym_func,
    ACTIONS(585), 1,
      anon_sym_map,
    ACTIONS(587), 1,
      anon_sym_chan,
    ACTIONS(589), 1,
      anon_sym_LT_DASH,
    ACTIONS(974), 1,
      anon_sym_LBRACK,
    ACTIONS(976), 1,
      anon_sym_STAR,
    ACTIONS(1042), 1,
      anon_sym_LPAREN,
    ACTIONS(1097), 1,
      sym_identifier,
    ACTIONS(1103), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1187), 1,
      anon_sym_RPAREN,
    STATE(848), 2,
      sym_negated_type,
      sym_qualified_type,
    STATE(1273), 2,
      sym_parenthesized_type,
      sym__simple_type,
    STATE(1304), 2,
      sym_parameter_declaration,
      sym_variadic_parameter_declaration,
    STATE(858), 9,
      sym_generic_type,
      sym_pointer_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_interface_type,
      sym_map_type,
      sym_channel_type,
      sym_function_type,
  [37521] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(572), 1,
      anon_sym_func,
    ACTIONS(585), 1,
      anon_sym_map,
    ACTIONS(587), 1,
      anon_sym_chan,
    ACTIONS(589), 1,
      anon_sym_LT_DASH,
    ACTIONS(974), 1,
      anon_sym_LBRACK,
    ACTIONS(976), 1,
      anon_sym_STAR,
    ACTIONS(1042), 1,
      anon_sym_LPAREN,
    ACTIONS(1097), 1,
      sym_identifier,
    ACTIONS(1103), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1189), 1,
      anon_sym_RPAREN,
    STATE(848), 2,
      sym_negated_type,
      sym_qualified_type,
    STATE(1273), 2,
      sym_parenthesized_type,
      sym__simple_type,
    STATE(1304), 2,
      sym_parameter_declaration,
      sym_variadic_parameter_declaration,
    STATE(858), 9,
      sym_generic_type,
      sym_pointer_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_interface_type,
      sym_map_type,
      sym_channel_type,
      sym_function_type,
  [37587] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(303), 1,
      anon_sym_LBRACE,
    ACTIONS(563), 1,
      anon_sym_DOT,
    ACTIONS(594), 1,
      anon_sym_PIPE,
    ACTIONS(834), 1,
      anon_sym_LBRACK,
    ACTIONS(1044), 1,
      anon_sym_COMMA,
    STATE(398), 1,
      sym_literal_value,
    STATE(854), 1,
      sym_type_arguments,
    ACTIONS(831), 2,
      anon_sym_LPAREN,
      anon_sym_RBRACK,
    ACTIONS(583), 4,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(578), 15,
      anon_sym_STAR,
      anon_sym_COLON,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [37639] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(922), 1,
      anon_sym_DOT,
    ACTIONS(924), 1,
      anon_sym_LPAREN,
    ACTIONS(926), 1,
      anon_sym_LBRACK,
    ACTIONS(1137), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1141), 1,
      anon_sym_PIPE,
    ACTIONS(1151), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1153), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1191), 1,
      anon_sym_RPAREN,
    ACTIONS(1193), 1,
      anon_sym_COMMA,
    STATE(397), 1,
      sym_argument_list,
    STATE(1168), 1,
      aux_sym_argument_list_repeat1,
    STATE(1255), 1,
      sym_type_arguments,
    ACTIONS(1145), 2,
      anon_sym_AMP,
      anon_sym_SLASH,
    ACTIONS(1149), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1143), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
    ACTIONS(1147), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(1139), 5,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
  [37705] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(924), 1,
      anon_sym_LPAREN,
    ACTIONS(926), 1,
      anon_sym_LBRACK,
    ACTIONS(978), 1,
      anon_sym_DOT,
    ACTIONS(984), 1,
      anon_sym_PIPE,
    ACTIONS(992), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1018), 1,
      anon_sym_COMMA,
    ACTIONS(1109), 1,
      anon_sym_PIPE_PIPE,
    STATE(397), 1,
      sym_argument_list,
    STATE(979), 1,
      aux_sym_expression_list_repeat1,
    STATE(1255), 1,
      sym_type_arguments,
    ACTIONS(687), 2,
      anon_sym_SEMI,
      anon_sym_COLON,
    ACTIONS(982), 2,
      anon_sym_AMP,
      anon_sym_SLASH,
    ACTIONS(990), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(986), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
    ACTIONS(988), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(980), 5,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
  [37769] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(572), 1,
      anon_sym_func,
    ACTIONS(585), 1,
      anon_sym_map,
    ACTIONS(587), 1,
      anon_sym_chan,
    ACTIONS(589), 1,
      anon_sym_LT_DASH,
    ACTIONS(974), 1,
      anon_sym_LBRACK,
    ACTIONS(976), 1,
      anon_sym_STAR,
    ACTIONS(1042), 1,
      anon_sym_LPAREN,
    ACTIONS(1097), 1,
      sym_identifier,
    ACTIONS(1103), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1195), 1,
      anon_sym_RPAREN,
    STATE(848), 2,
      sym_negated_type,
      sym_qualified_type,
    STATE(1273), 2,
      sym_parenthesized_type,
      sym__simple_type,
    STATE(1304), 2,
      sym_parameter_declaration,
      sym_variadic_parameter_declaration,
    STATE(858), 9,
      sym_generic_type,
      sym_pointer_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_interface_type,
      sym_map_type,
      sym_channel_type,
      sym_function_type,
  [37835] = 17,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(872), 1,
      anon_sym_LPAREN,
    ACTIONS(880), 1,
      anon_sym_struct,
    ACTIONS(882), 1,
      anon_sym_TILDE,
    ACTIONS(884), 1,
      anon_sym_interface,
    ACTIONS(892), 1,
      sym_identifier,
    ACTIONS(904), 1,
      anon_sym_func,
    ACTIONS(908), 1,
      anon_sym_STAR,
    ACTIONS(910), 1,
      anon_sym_map,
    ACTIONS(912), 1,
      anon_sym_chan,
    ACTIONS(914), 1,
      anon_sym_LT_DASH,
    ACTIONS(920), 1,
      anon_sym_LBRACK,
    ACTIONS(1197), 1,
      aux_sym_source_file_token1,
    STATE(799), 2,
      sym_negated_type,
      sym_qualified_type,
    STATE(1130), 2,
      sym_parameter_list,
      sym__simple_type,
    ACTIONS(1199), 3,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_RBRACE,
    STATE(807), 9,
      sym_generic_type,
      sym_pointer_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_interface_type,
      sym_map_type,
      sym_channel_type,
      sym_function_type,
  [37899] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(922), 1,
      anon_sym_DOT,
    ACTIONS(924), 1,
      anon_sym_LPAREN,
    ACTIONS(926), 1,
      anon_sym_LBRACK,
    ACTIONS(1137), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1141), 1,
      anon_sym_PIPE,
    ACTIONS(1151), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1153), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1201), 1,
      anon_sym_RPAREN,
    ACTIONS(1203), 1,
      anon_sym_COMMA,
    STATE(397), 1,
      sym_argument_list,
    STATE(1146), 1,
      aux_sym_argument_list_repeat1,
    STATE(1255), 1,
      sym_type_arguments,
    ACTIONS(1145), 2,
      anon_sym_AMP,
      anon_sym_SLASH,
    ACTIONS(1149), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1143), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
    ACTIONS(1147), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(1139), 5,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
  [37965] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(572), 1,
      anon_sym_func,
    ACTIONS(585), 1,
      anon_sym_map,
    ACTIONS(587), 1,
      anon_sym_chan,
    ACTIONS(589), 1,
      anon_sym_LT_DASH,
    ACTIONS(974), 1,
      anon_sym_LBRACK,
    ACTIONS(976), 1,
      anon_sym_STAR,
    ACTIONS(1042), 1,
      anon_sym_LPAREN,
    ACTIONS(1097), 1,
      sym_identifier,
    ACTIONS(1103), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1205), 1,
      anon_sym_RPAREN,
    STATE(848), 2,
      sym_negated_type,
      sym_qualified_type,
    STATE(1273), 2,
      sym_parenthesized_type,
      sym__simple_type,
    STATE(1304), 2,
      sym_parameter_declaration,
      sym_variadic_parameter_declaration,
    STATE(858), 9,
      sym_generic_type,
      sym_pointer_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_interface_type,
      sym_map_type,
      sym_channel_type,
      sym_function_type,
  [38031] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(922), 1,
      anon_sym_DOT,
    ACTIONS(924), 1,
      anon_sym_LPAREN,
    ACTIONS(926), 1,
      anon_sym_LBRACK,
    ACTIONS(1137), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1141), 1,
      anon_sym_PIPE,
    ACTIONS(1151), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1153), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1207), 1,
      anon_sym_RPAREN,
    ACTIONS(1209), 1,
      anon_sym_COMMA,
    STATE(397), 1,
      sym_argument_list,
    STATE(1218), 1,
      aux_sym_argument_list_repeat1,
    STATE(1255), 1,
      sym_type_arguments,
    ACTIONS(1145), 2,
      anon_sym_AMP,
      anon_sym_SLASH,
    ACTIONS(1149), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1143), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
    ACTIONS(1147), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(1139), 5,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
  [38097] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(795), 7,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_COLON,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(793), 20,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_STAR,
      anon_sym_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [38132] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(657), 7,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_COLON,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(655), 20,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_STAR,
      anon_sym_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [38167] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(880), 1,
      anon_sym_struct,
    ACTIONS(884), 1,
      anon_sym_interface,
    ACTIONS(904), 1,
      anon_sym_func,
    ACTIONS(910), 1,
      anon_sym_map,
    ACTIONS(912), 1,
      anon_sym_chan,
    ACTIONS(1211), 1,
      sym_identifier,
    ACTIONS(1213), 1,
      anon_sym_LPAREN,
    ACTIONS(1215), 1,
      anon_sym_LBRACK,
    ACTIONS(1217), 1,
      anon_sym_STAR,
    ACTIONS(1219), 1,
      anon_sym_TILDE,
    ACTIONS(1221), 1,
      anon_sym_RBRACE,
    ACTIONS(1223), 1,
      anon_sym_LT_DASH,
    STATE(799), 2,
      sym_negated_type,
      sym_qualified_type,
    STATE(1007), 2,
      sym_parenthesized_type,
      sym__simple_type,
    STATE(1074), 2,
      sym_method_elem,
      sym_type_elem,
    STATE(807), 9,
      sym_generic_type,
      sym_pointer_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_interface_type,
      sym_map_type,
      sym_channel_type,
      sym_function_type,
  [38230] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(880), 1,
      anon_sym_struct,
    ACTIONS(884), 1,
      anon_sym_interface,
    ACTIONS(904), 1,
      anon_sym_func,
    ACTIONS(910), 1,
      anon_sym_map,
    ACTIONS(912), 1,
      anon_sym_chan,
    ACTIONS(1211), 1,
      sym_identifier,
    ACTIONS(1213), 1,
      anon_sym_LPAREN,
    ACTIONS(1215), 1,
      anon_sym_LBRACK,
    ACTIONS(1217), 1,
      anon_sym_STAR,
    ACTIONS(1219), 1,
      anon_sym_TILDE,
    ACTIONS(1223), 1,
      anon_sym_LT_DASH,
    ACTIONS(1225), 1,
      anon_sym_RBRACE,
    STATE(799), 2,
      sym_negated_type,
      sym_qualified_type,
    STATE(1007), 2,
      sym_parenthesized_type,
      sym__simple_type,
    STATE(1074), 2,
      sym_method_elem,
      sym_type_elem,
    STATE(807), 9,
      sym_generic_type,
      sym_pointer_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_interface_type,
      sym_map_type,
      sym_channel_type,
      sym_function_type,
  [38293] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(570), 1,
      anon_sym_COMMA,
    ACTIONS(880), 1,
      anon_sym_struct,
    ACTIONS(884), 1,
      anon_sym_interface,
    ACTIONS(892), 1,
      sym_identifier,
    ACTIONS(904), 1,
      anon_sym_func,
    ACTIONS(910), 1,
      anon_sym_map,
    ACTIONS(912), 1,
      anon_sym_chan,
    ACTIONS(1213), 1,
      anon_sym_LPAREN,
    ACTIONS(1215), 1,
      anon_sym_LBRACK,
    ACTIONS(1217), 1,
      anon_sym_STAR,
    ACTIONS(1219), 1,
      anon_sym_TILDE,
    ACTIONS(1223), 1,
      anon_sym_LT_DASH,
    ACTIONS(1227), 1,
      anon_sym_EQ,
    STATE(536), 1,
      aux_sym_var_spec_repeat1,
    STATE(799), 2,
      sym_negated_type,
      sym_qualified_type,
    STATE(900), 2,
      sym_parenthesized_type,
      sym__simple_type,
    STATE(807), 9,
      sym_generic_type,
      sym_pointer_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_interface_type,
      sym_map_type,
      sym_channel_type,
      sym_function_type,
  [38358] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(561), 1,
      sym_identifier,
    ACTIONS(570), 1,
      anon_sym_COMMA,
    ACTIONS(572), 1,
      anon_sym_func,
    ACTIONS(585), 1,
      anon_sym_map,
    ACTIONS(587), 1,
      anon_sym_chan,
    ACTIONS(589), 1,
      anon_sym_LT_DASH,
    ACTIONS(974), 1,
      anon_sym_LBRACK,
    ACTIONS(976), 1,
      anon_sym_STAR,
    ACTIONS(1042), 1,
      anon_sym_LPAREN,
    STATE(794), 1,
      aux_sym_var_spec_repeat1,
    STATE(1289), 1,
      sym_type_elem,
    STATE(848), 2,
      sym_negated_type,
      sym_qualified_type,
    STATE(1117), 2,
      sym_parenthesized_type,
      sym__simple_type,
    STATE(858), 9,
      sym_generic_type,
      sym_pointer_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_interface_type,
      sym_map_type,
      sym_channel_type,
      sym_function_type,
  [38423] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(583), 7,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_COLON,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(578), 20,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_STAR,
      anon_sym_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [38458] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(563), 1,
      anon_sym_DOT,
    ACTIONS(831), 1,
      anon_sym_LPAREN,
    ACTIONS(834), 1,
      anon_sym_LBRACK,
    STATE(398), 1,
      sym_literal_value,
    STATE(854), 1,
      sym_type_arguments,
    ACTIONS(583), 5,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(578), 17,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_LBRACE,
      anon_sym_COLON_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [38503] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(570), 1,
      anon_sym_COMMA,
    ACTIONS(880), 1,
      anon_sym_struct,
    ACTIONS(884), 1,
      anon_sym_interface,
    ACTIONS(892), 1,
      sym_identifier,
    ACTIONS(904), 1,
      anon_sym_func,
    ACTIONS(910), 1,
      anon_sym_map,
    ACTIONS(912), 1,
      anon_sym_chan,
    ACTIONS(1213), 1,
      anon_sym_LPAREN,
    ACTIONS(1215), 1,
      anon_sym_LBRACK,
    ACTIONS(1217), 1,
      anon_sym_STAR,
    ACTIONS(1219), 1,
      anon_sym_TILDE,
    ACTIONS(1223), 1,
      anon_sym_LT_DASH,
    ACTIONS(1229), 1,
      anon_sym_EQ,
    STATE(794), 1,
      aux_sym_var_spec_repeat1,
    STATE(896), 1,
      sym__simple_type,
    STATE(911), 1,
      sym_parenthesized_type,
    STATE(799), 2,
      sym_negated_type,
      sym_qualified_type,
    STATE(807), 9,
      sym_generic_type,
      sym_pointer_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_interface_type,
      sym_map_type,
      sym_channel_type,
      sym_function_type,
  [38570] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(653), 7,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_COLON,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(651), 20,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_STAR,
      anon_sym_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [38605] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(735), 7,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_COLON,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(733), 20,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_STAR,
      anon_sym_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [38640] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(667), 7,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_COLON,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(665), 20,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_STAR,
      anon_sym_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [38675] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(880), 1,
      anon_sym_struct,
    ACTIONS(884), 1,
      anon_sym_interface,
    ACTIONS(904), 1,
      anon_sym_func,
    ACTIONS(910), 1,
      anon_sym_map,
    ACTIONS(912), 1,
      anon_sym_chan,
    ACTIONS(1211), 1,
      sym_identifier,
    ACTIONS(1213), 1,
      anon_sym_LPAREN,
    ACTIONS(1215), 1,
      anon_sym_LBRACK,
    ACTIONS(1217), 1,
      anon_sym_STAR,
    ACTIONS(1219), 1,
      anon_sym_TILDE,
    ACTIONS(1223), 1,
      anon_sym_LT_DASH,
    ACTIONS(1231), 1,
      anon_sym_RBRACE,
    STATE(799), 2,
      sym_negated_type,
      sym_qualified_type,
    STATE(1007), 2,
      sym_parenthesized_type,
      sym__simple_type,
    STATE(1026), 2,
      sym_method_elem,
      sym_type_elem,
    STATE(807), 9,
      sym_generic_type,
      sym_pointer_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_interface_type,
      sym_map_type,
      sym_channel_type,
      sym_function_type,
  [38738] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(922), 1,
      anon_sym_DOT,
    ACTIONS(924), 1,
      anon_sym_LPAREN,
    ACTIONS(926), 1,
      anon_sym_LBRACK,
    ACTIONS(1137), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1141), 1,
      anon_sym_PIPE,
    ACTIONS(1151), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1153), 1,
      anon_sym_PIPE_PIPE,
    STATE(397), 1,
      sym_argument_list,
    STATE(1255), 1,
      sym_type_arguments,
    ACTIONS(1145), 2,
      anon_sym_AMP,
      anon_sym_SLASH,
    ACTIONS(1149), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1233), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
    ACTIONS(1143), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
    ACTIONS(1147), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(1139), 5,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
  [38799] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(687), 1,
      anon_sym_SEMI,
    ACTIONS(924), 1,
      anon_sym_LPAREN,
    ACTIONS(926), 1,
      anon_sym_LBRACK,
    ACTIONS(984), 1,
      anon_sym_PIPE,
    ACTIONS(992), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1018), 1,
      anon_sym_COMMA,
    ACTIONS(1109), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1235), 1,
      anon_sym_DOT,
    STATE(397), 1,
      sym_argument_list,
    STATE(979), 1,
      aux_sym_expression_list_repeat1,
    STATE(1255), 1,
      sym_type_arguments,
    ACTIONS(982), 2,
      anon_sym_AMP,
      anon_sym_SLASH,
    ACTIONS(990), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(986), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
    ACTIONS(988), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(980), 5,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
  [38862] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(671), 7,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_COLON,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(669), 20,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_STAR,
      anon_sym_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [38897] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(880), 1,
      anon_sym_struct,
    ACTIONS(884), 1,
      anon_sym_interface,
    ACTIONS(904), 1,
      anon_sym_func,
    ACTIONS(910), 1,
      anon_sym_map,
    ACTIONS(912), 1,
      anon_sym_chan,
    ACTIONS(1211), 1,
      sym_identifier,
    ACTIONS(1213), 1,
      anon_sym_LPAREN,
    ACTIONS(1215), 1,
      anon_sym_LBRACK,
    ACTIONS(1217), 1,
      anon_sym_STAR,
    ACTIONS(1219), 1,
      anon_sym_TILDE,
    ACTIONS(1223), 1,
      anon_sym_LT_DASH,
    ACTIONS(1237), 1,
      anon_sym_RBRACE,
    STATE(799), 2,
      sym_negated_type,
      sym_qualified_type,
    STATE(1007), 2,
      sym_parenthesized_type,
      sym__simple_type,
    STATE(1038), 2,
      sym_method_elem,
      sym_type_elem,
    STATE(807), 9,
      sym_generic_type,
      sym_pointer_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_interface_type,
      sym_map_type,
      sym_channel_type,
      sym_function_type,
  [38960] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(787), 7,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_COLON,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(785), 20,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_STAR,
      anon_sym_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [38995] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(924), 1,
      anon_sym_LPAREN,
    ACTIONS(926), 1,
      anon_sym_LBRACK,
    ACTIONS(978), 1,
      anon_sym_DOT,
    STATE(397), 1,
      sym_argument_list,
    STATE(1255), 1,
      sym_type_arguments,
    ACTIONS(1169), 2,
      anon_sym_AMP,
      anon_sym_SLASH,
    ACTIONS(639), 3,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1161), 5,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
    ACTIONS(637), 12,
      anon_sym_COMMA,
      anon_sym_LBRACE,
      anon_sym_COLON_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [39044] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(561), 1,
      sym_identifier,
    ACTIONS(570), 1,
      anon_sym_COMMA,
    ACTIONS(572), 1,
      anon_sym_func,
    ACTIONS(585), 1,
      anon_sym_map,
    ACTIONS(587), 1,
      anon_sym_chan,
    ACTIONS(589), 1,
      anon_sym_LT_DASH,
    ACTIONS(974), 1,
      anon_sym_LBRACK,
    ACTIONS(976), 1,
      anon_sym_STAR,
    ACTIONS(1042), 1,
      anon_sym_LPAREN,
    STATE(533), 1,
      aux_sym_var_spec_repeat1,
    STATE(1310), 1,
      sym_type_elem,
    STATE(848), 2,
      sym_negated_type,
      sym_qualified_type,
    STATE(1117), 2,
      sym_parenthesized_type,
      sym__simple_type,
    STATE(858), 9,
      sym_generic_type,
      sym_pointer_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_interface_type,
      sym_map_type,
      sym_channel_type,
      sym_function_type,
  [39109] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(743), 7,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_COLON,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(741), 20,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_STAR,
      anon_sym_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [39144] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(924), 1,
      anon_sym_LPAREN,
    ACTIONS(926), 1,
      anon_sym_LBRACK,
    ACTIONS(978), 1,
      anon_sym_DOT,
    ACTIONS(1165), 1,
      anon_sym_PIPE,
    STATE(397), 1,
      sym_argument_list,
    STATE(1255), 1,
      sym_type_arguments,
    ACTIONS(639), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1169), 2,
      anon_sym_AMP,
      anon_sym_SLASH,
    ACTIONS(1167), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
    ACTIONS(1161), 5,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
    ACTIONS(637), 9,
      anon_sym_COMMA,
      anon_sym_LBRACE,
      anon_sym_COLON_EQ,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [39197] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(924), 1,
      anon_sym_LPAREN,
    ACTIONS(926), 1,
      anon_sym_LBRACK,
    ACTIONS(978), 1,
      anon_sym_DOT,
    ACTIONS(1165), 1,
      anon_sym_PIPE,
    STATE(397), 1,
      sym_argument_list,
    STATE(1255), 1,
      sym_type_arguments,
    ACTIONS(1169), 2,
      anon_sym_AMP,
      anon_sym_SLASH,
    ACTIONS(1173), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1167), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
    ACTIONS(1171), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(637), 5,
      anon_sym_COMMA,
      anon_sym_LBRACE,
      anon_sym_COLON_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(1161), 5,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
  [39252] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(924), 1,
      anon_sym_LPAREN,
    ACTIONS(926), 1,
      anon_sym_LBRACK,
    ACTIONS(978), 1,
      anon_sym_DOT,
    ACTIONS(1165), 1,
      anon_sym_PIPE,
    ACTIONS(1175), 1,
      anon_sym_AMP_AMP,
    STATE(397), 1,
      sym_argument_list,
    STATE(1255), 1,
      sym_type_arguments,
    ACTIONS(1169), 2,
      anon_sym_AMP,
      anon_sym_SLASH,
    ACTIONS(1173), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1167), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
    ACTIONS(637), 4,
      anon_sym_COMMA,
      anon_sym_LBRACE,
      anon_sym_COLON_EQ,
      anon_sym_PIPE_PIPE,
    ACTIONS(1171), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(1161), 5,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
  [39309] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(649), 7,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_COLON,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(647), 20,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_STAR,
      anon_sym_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [39344] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(739), 7,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_COLON,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(737), 20,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_STAR,
      anon_sym_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [39379] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(823), 7,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_COLON,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(821), 20,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_STAR,
      anon_sym_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [39414] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(747), 7,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_COLON,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(745), 20,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_STAR,
      anon_sym_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [39449] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(880), 1,
      anon_sym_struct,
    ACTIONS(884), 1,
      anon_sym_interface,
    ACTIONS(904), 1,
      anon_sym_func,
    ACTIONS(910), 1,
      anon_sym_map,
    ACTIONS(912), 1,
      anon_sym_chan,
    ACTIONS(1211), 1,
      sym_identifier,
    ACTIONS(1213), 1,
      anon_sym_LPAREN,
    ACTIONS(1215), 1,
      anon_sym_LBRACK,
    ACTIONS(1217), 1,
      anon_sym_STAR,
    ACTIONS(1219), 1,
      anon_sym_TILDE,
    ACTIONS(1223), 1,
      anon_sym_LT_DASH,
    ACTIONS(1239), 1,
      anon_sym_RBRACE,
    STATE(799), 2,
      sym_negated_type,
      sym_qualified_type,
    STATE(1007), 2,
      sym_parenthesized_type,
      sym__simple_type,
    STATE(1074), 2,
      sym_method_elem,
      sym_type_elem,
    STATE(807), 9,
      sym_generic_type,
      sym_pointer_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_interface_type,
      sym_map_type,
      sym_channel_type,
      sym_function_type,
  [39512] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(572), 1,
      anon_sym_func,
    ACTIONS(585), 1,
      anon_sym_map,
    ACTIONS(587), 1,
      anon_sym_chan,
    ACTIONS(589), 1,
      anon_sym_LT_DASH,
    ACTIONS(974), 1,
      anon_sym_LBRACK,
    ACTIONS(976), 1,
      anon_sym_STAR,
    ACTIONS(1042), 1,
      anon_sym_LPAREN,
    ACTIONS(1097), 1,
      sym_identifier,
    ACTIONS(1103), 1,
      anon_sym_DOT_DOT_DOT,
    STATE(848), 2,
      sym_negated_type,
      sym_qualified_type,
    STATE(1273), 2,
      sym_parenthesized_type,
      sym__simple_type,
    STATE(1304), 2,
      sym_parameter_declaration,
      sym_variadic_parameter_declaration,
    STATE(858), 9,
      sym_generic_type,
      sym_pointer_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_interface_type,
      sym_map_type,
      sym_channel_type,
      sym_function_type,
  [39575] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(922), 1,
      anon_sym_DOT,
    ACTIONS(924), 1,
      anon_sym_LPAREN,
    ACTIONS(926), 1,
      anon_sym_LBRACK,
    STATE(397), 1,
      sym_argument_list,
    STATE(1255), 1,
      sym_type_arguments,
    ACTIONS(1145), 2,
      anon_sym_AMP,
      anon_sym_SLASH,
    ACTIONS(639), 3,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1139), 5,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
    ACTIONS(637), 12,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_DOT_DOT_DOT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [39624] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(922), 1,
      anon_sym_DOT,
    ACTIONS(924), 1,
      anon_sym_LPAREN,
    ACTIONS(926), 1,
      anon_sym_LBRACK,
    ACTIONS(1141), 1,
      anon_sym_PIPE,
    STATE(397), 1,
      sym_argument_list,
    STATE(1255), 1,
      sym_type_arguments,
    ACTIONS(639), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1145), 2,
      anon_sym_AMP,
      anon_sym_SLASH,
    ACTIONS(1143), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
    ACTIONS(1139), 5,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
    ACTIONS(637), 9,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_DOT_DOT_DOT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [39677] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(922), 1,
      anon_sym_DOT,
    ACTIONS(924), 1,
      anon_sym_LPAREN,
    ACTIONS(926), 1,
      anon_sym_LBRACK,
    ACTIONS(1141), 1,
      anon_sym_PIPE,
    STATE(397), 1,
      sym_argument_list,
    STATE(1255), 1,
      sym_type_arguments,
    ACTIONS(1145), 2,
      anon_sym_AMP,
      anon_sym_SLASH,
    ACTIONS(1149), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1143), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
    ACTIONS(1147), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(637), 5,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_DOT_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(1139), 5,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
  [39732] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(922), 1,
      anon_sym_DOT,
    ACTIONS(924), 1,
      anon_sym_LPAREN,
    ACTIONS(926), 1,
      anon_sym_LBRACK,
    ACTIONS(1141), 1,
      anon_sym_PIPE,
    ACTIONS(1151), 1,
      anon_sym_AMP_AMP,
    STATE(397), 1,
      sym_argument_list,
    STATE(1255), 1,
      sym_type_arguments,
    ACTIONS(1145), 2,
      anon_sym_AMP,
      anon_sym_SLASH,
    ACTIONS(1149), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1143), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
    ACTIONS(637), 4,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_DOT_DOT_DOT,
      anon_sym_PIPE_PIPE,
    ACTIONS(1147), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(1139), 5,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
  [39789] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(880), 1,
      anon_sym_struct,
    ACTIONS(884), 1,
      anon_sym_interface,
    ACTIONS(904), 1,
      anon_sym_func,
    ACTIONS(910), 1,
      anon_sym_map,
    ACTIONS(912), 1,
      anon_sym_chan,
    ACTIONS(1211), 1,
      sym_identifier,
    ACTIONS(1213), 1,
      anon_sym_LPAREN,
    ACTIONS(1215), 1,
      anon_sym_LBRACK,
    ACTIONS(1217), 1,
      anon_sym_STAR,
    ACTIONS(1219), 1,
      anon_sym_TILDE,
    ACTIONS(1223), 1,
      anon_sym_LT_DASH,
    ACTIONS(1241), 1,
      anon_sym_RBRACE,
    STATE(799), 2,
      sym_negated_type,
      sym_qualified_type,
    STATE(1007), 2,
      sym_parenthesized_type,
      sym__simple_type,
    STATE(1074), 2,
      sym_method_elem,
      sym_type_elem,
    STATE(807), 9,
      sym_generic_type,
      sym_pointer_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_interface_type,
      sym_map_type,
      sym_channel_type,
      sym_function_type,
  [39852] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(880), 1,
      anon_sym_struct,
    ACTIONS(884), 1,
      anon_sym_interface,
    ACTIONS(904), 1,
      anon_sym_func,
    ACTIONS(910), 1,
      anon_sym_map,
    ACTIONS(912), 1,
      anon_sym_chan,
    ACTIONS(1211), 1,
      sym_identifier,
    ACTIONS(1213), 1,
      anon_sym_LPAREN,
    ACTIONS(1215), 1,
      anon_sym_LBRACK,
    ACTIONS(1217), 1,
      anon_sym_STAR,
    ACTIONS(1219), 1,
      anon_sym_TILDE,
    ACTIONS(1223), 1,
      anon_sym_LT_DASH,
    ACTIONS(1243), 1,
      anon_sym_RBRACE,
    STATE(799), 2,
      sym_negated_type,
      sym_qualified_type,
    STATE(1007), 2,
      sym_parenthesized_type,
      sym__simple_type,
    STATE(1074), 2,
      sym_method_elem,
      sym_type_elem,
    STATE(807), 9,
      sym_generic_type,
      sym_pointer_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_interface_type,
      sym_map_type,
      sym_channel_type,
      sym_function_type,
  [39915] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(880), 1,
      anon_sym_struct,
    ACTIONS(884), 1,
      anon_sym_interface,
    ACTIONS(904), 1,
      anon_sym_func,
    ACTIONS(910), 1,
      anon_sym_map,
    ACTIONS(912), 1,
      anon_sym_chan,
    ACTIONS(1211), 1,
      sym_identifier,
    ACTIONS(1213), 1,
      anon_sym_LPAREN,
    ACTIONS(1215), 1,
      anon_sym_LBRACK,
    ACTIONS(1217), 1,
      anon_sym_STAR,
    ACTIONS(1219), 1,
      anon_sym_TILDE,
    ACTIONS(1223), 1,
      anon_sym_LT_DASH,
    ACTIONS(1245), 1,
      anon_sym_RBRACE,
    STATE(799), 2,
      sym_negated_type,
      sym_qualified_type,
    STATE(1007), 2,
      sym_parenthesized_type,
      sym__simple_type,
    STATE(1024), 2,
      sym_method_elem,
      sym_type_elem,
    STATE(807), 9,
      sym_generic_type,
      sym_pointer_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_interface_type,
      sym_map_type,
      sym_channel_type,
      sym_function_type,
  [39978] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(924), 1,
      anon_sym_LPAREN,
    ACTIONS(926), 1,
      anon_sym_LBRACK,
    ACTIONS(978), 1,
      anon_sym_DOT,
    ACTIONS(984), 1,
      anon_sym_PIPE,
    ACTIONS(992), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1109), 1,
      anon_sym_PIPE_PIPE,
    STATE(397), 1,
      sym_argument_list,
    STATE(1255), 1,
      sym_type_arguments,
    ACTIONS(982), 2,
      anon_sym_AMP,
      anon_sym_SLASH,
    ACTIONS(990), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(986), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
    ACTIONS(1247), 3,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_COLON,
    ACTIONS(988), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(980), 5,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
  [40037] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(819), 7,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_COLON,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(817), 20,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_STAR,
      anon_sym_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [40072] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(707), 7,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_COLON,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(705), 20,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_STAR,
      anon_sym_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [40107] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(703), 7,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_COLON,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(701), 20,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_STAR,
      anon_sym_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [40142] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(711), 7,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_COLON,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(709), 20,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_STAR,
      anon_sym_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [40177] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(715), 7,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_COLON,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(713), 20,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_STAR,
      anon_sym_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [40212] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(719), 7,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_COLON,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(717), 20,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_STAR,
      anon_sym_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [40247] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(723), 7,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_COLON,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(721), 20,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_STAR,
      anon_sym_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [40282] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(727), 7,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_COLON,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(725), 20,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_STAR,
      anon_sym_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [40317] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(731), 7,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_COLON,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(729), 20,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_STAR,
      anon_sym_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [40352] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(755), 7,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_COLON,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(753), 20,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_STAR,
      anon_sym_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [40387] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(759), 7,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_COLON,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(757), 20,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_STAR,
      anon_sym_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [40422] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(763), 7,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_COLON,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(761), 20,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_STAR,
      anon_sym_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [40457] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(767), 7,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_COLON,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(765), 20,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_STAR,
      anon_sym_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [40492] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(771), 7,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_COLON,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(769), 20,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_STAR,
      anon_sym_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [40527] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(775), 7,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_COLON,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(773), 20,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_STAR,
      anon_sym_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [40562] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(779), 7,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_COLON,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(777), 20,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_STAR,
      anon_sym_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [40597] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(783), 7,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_COLON,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(781), 20,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_STAR,
      anon_sym_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [40632] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(791), 7,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_COLON,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(789), 20,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_STAR,
      anon_sym_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [40667] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(799), 7,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_COLON,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(797), 20,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_STAR,
      anon_sym_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [40702] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(803), 7,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_COLON,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(801), 20,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_STAR,
      anon_sym_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [40737] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(807), 7,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_COLON,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(805), 20,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_STAR,
      anon_sym_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [40772] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(811), 7,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_COLON,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(809), 20,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_STAR,
      anon_sym_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [40807] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(815), 7,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_COLON,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(813), 20,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_STAR,
      anon_sym_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [40842] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(880), 1,
      anon_sym_struct,
    ACTIONS(884), 1,
      anon_sym_interface,
    ACTIONS(904), 1,
      anon_sym_func,
    ACTIONS(910), 1,
      anon_sym_map,
    ACTIONS(912), 1,
      anon_sym_chan,
    ACTIONS(1211), 1,
      sym_identifier,
    ACTIONS(1213), 1,
      anon_sym_LPAREN,
    ACTIONS(1215), 1,
      anon_sym_LBRACK,
    ACTIONS(1217), 1,
      anon_sym_STAR,
    ACTIONS(1219), 1,
      anon_sym_TILDE,
    ACTIONS(1223), 1,
      anon_sym_LT_DASH,
    ACTIONS(1249), 1,
      anon_sym_RBRACE,
    STATE(799), 2,
      sym_negated_type,
      sym_qualified_type,
    STATE(1007), 2,
      sym_parenthesized_type,
      sym__simple_type,
    STATE(1074), 2,
      sym_method_elem,
      sym_type_elem,
    STATE(807), 9,
      sym_generic_type,
      sym_pointer_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_interface_type,
      sym_map_type,
      sym_channel_type,
      sym_function_type,
  [40905] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(687), 1,
      anon_sym_LBRACE,
    ACTIONS(924), 1,
      anon_sym_LPAREN,
    ACTIONS(926), 1,
      anon_sym_LBRACK,
    ACTIONS(978), 1,
      anon_sym_DOT,
    ACTIONS(1165), 1,
      anon_sym_PIPE,
    ACTIONS(1175), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1177), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1251), 1,
      anon_sym_COMMA,
    STATE(397), 1,
      sym_argument_list,
    STATE(1188), 1,
      aux_sym_expression_list_repeat1,
    STATE(1255), 1,
      sym_type_arguments,
    ACTIONS(1169), 2,
      anon_sym_AMP,
      anon_sym_SLASH,
    ACTIONS(1173), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1167), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
    ACTIONS(1171), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(1161), 5,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
  [40968] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(663), 7,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_COLON,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(661), 20,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_STAR,
      anon_sym_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [41003] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(751), 7,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_COLON,
      anon_sym_AMP,
      anon_sym_SLASH,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(749), 20,
      anon_sym_DOT,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_STAR,
      anon_sym_LT_DASH,
      anon_sym_COLON_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
  [41038] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(33), 1,
      anon_sym_LBRACE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(972), 1,
      anon_sym_LPAREN,
    ACTIONS(996), 1,
      anon_sym_func,
    ACTIONS(998), 1,
      anon_sym_LBRACK,
    ACTIONS(1000), 1,
      anon_sym_STAR,
    ACTIONS(1002), 1,
      anon_sym_LT_DASH,
    ACTIONS(1253), 1,
      sym_identifier,
    STATE(268), 1,
      sym_block,
    STATE(836), 2,
      sym_negated_type,
      sym_qualified_type,
    STATE(1090), 2,
      sym_parameter_list,
      sym__simple_type,
    STATE(858), 9,
      sym_generic_type,
      sym_pointer_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_interface_type,
      sym_map_type,
      sym_channel_type,
      sym_function_type,
  [41100] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(924), 1,
      anon_sym_LPAREN,
    ACTIONS(926), 1,
      anon_sym_LBRACK,
    ACTIONS(978), 1,
      anon_sym_DOT,
    ACTIONS(984), 1,
      anon_sym_PIPE,
    ACTIONS(992), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1109), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1255), 1,
      anon_sym_RBRACK,
    ACTIONS(1257), 1,
      anon_sym_COLON,
    STATE(397), 1,
      sym_argument_list,
    STATE(1255), 1,
      sym_type_arguments,
    ACTIONS(982), 2,
      anon_sym_AMP,
      anon_sym_SLASH,
    ACTIONS(990), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(986), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
    ACTIONS(988), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(980), 5,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
  [41160] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(561), 1,
      sym_identifier,
    ACTIONS(570), 1,
      anon_sym_COMMA,
    ACTIONS(572), 1,
      anon_sym_func,
    ACTIONS(585), 1,
      anon_sym_map,
    ACTIONS(587), 1,
      anon_sym_chan,
    ACTIONS(589), 1,
      anon_sym_LT_DASH,
    ACTIONS(974), 1,
      anon_sym_LBRACK,
    ACTIONS(976), 1,
      anon_sym_STAR,
    ACTIONS(1042), 1,
      anon_sym_LPAREN,
    STATE(794), 1,
      aux_sym_var_spec_repeat1,
    STATE(1299), 1,
      sym_parenthesized_type,
    STATE(1301), 1,
      sym__simple_type,
    STATE(848), 2,
      sym_negated_type,
      sym_qualified_type,
    STATE(858), 9,
      sym_generic_type,
      sym_pointer_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_interface_type,
      sym_map_type,
      sym_channel_type,
      sym_function_type,
  [41224] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(561), 1,
      sym_identifier,
    ACTIONS(572), 1,
      anon_sym_func,
    ACTIONS(585), 1,
      anon_sym_map,
    ACTIONS(587), 1,
      anon_sym_chan,
    ACTIONS(589), 1,
      anon_sym_LT_DASH,
    ACTIONS(974), 1,
      anon_sym_LBRACK,
    ACTIONS(976), 1,
      anon_sym_STAR,
    ACTIONS(1042), 1,
      anon_sym_LPAREN,
    ACTIONS(1259), 1,
      anon_sym_RBRACK,
    STATE(1269), 1,
      sym_type_elem,
    STATE(848), 2,
      sym_negated_type,
      sym_qualified_type,
    STATE(1117), 2,
      sym_parenthesized_type,
      sym__simple_type,
    STATE(858), 9,
      sym_generic_type,
      sym_pointer_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_interface_type,
      sym_map_type,
      sym_channel_type,
      sym_function_type,
  [41286] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(924), 1,
      anon_sym_LPAREN,
    ACTIONS(926), 1,
      anon_sym_LBRACK,
    ACTIONS(978), 1,
      anon_sym_DOT,
    ACTIONS(1141), 1,
      anon_sym_PIPE,
    ACTIONS(1151), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1153), 1,
      anon_sym_PIPE_PIPE,
    STATE(397), 1,
      sym_argument_list,
    STATE(1255), 1,
      sym_type_arguments,
    ACTIONS(858), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
    ACTIONS(1145), 2,
      anon_sym_AMP,
      anon_sym_SLASH,
    ACTIONS(1149), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1143), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
    ACTIONS(1147), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(1139), 5,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
  [41344] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(924), 1,
      anon_sym_LPAREN,
    ACTIONS(926), 1,
      anon_sym_LBRACK,
    ACTIONS(978), 1,
      anon_sym_DOT,
    ACTIONS(984), 1,
      anon_sym_PIPE,
    ACTIONS(992), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1109), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1261), 1,
      anon_sym_RBRACK,
    ACTIONS(1263), 1,
      anon_sym_COLON,
    STATE(397), 1,
      sym_argument_list,
    STATE(1255), 1,
      sym_type_arguments,
    ACTIONS(982), 2,
      anon_sym_AMP,
      anon_sym_SLASH,
    ACTIONS(990), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(986), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
    ACTIONS(988), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(980), 5,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
  [41404] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(924), 1,
      anon_sym_LPAREN,
    ACTIONS(926), 1,
      anon_sym_LBRACK,
    ACTIONS(978), 1,
      anon_sym_DOT,
    ACTIONS(984), 1,
      anon_sym_PIPE,
    ACTIONS(992), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1109), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1265), 1,
      anon_sym_RBRACK,
    ACTIONS(1267), 1,
      anon_sym_COLON,
    STATE(397), 1,
      sym_argument_list,
    STATE(1255), 1,
      sym_type_arguments,
    ACTIONS(982), 2,
      anon_sym_AMP,
      anon_sym_SLASH,
    ACTIONS(990), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(986), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
    ACTIONS(988), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(980), 5,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
  [41464] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(561), 1,
      sym_identifier,
    ACTIONS(572), 1,
      anon_sym_func,
    ACTIONS(585), 1,
      anon_sym_map,
    ACTIONS(587), 1,
      anon_sym_chan,
    ACTIONS(589), 1,
      anon_sym_LT_DASH,
    ACTIONS(974), 1,
      anon_sym_LBRACK,
    ACTIONS(976), 1,
      anon_sym_STAR,
    ACTIONS(1042), 1,
      anon_sym_LPAREN,
    ACTIONS(1269), 1,
      anon_sym_RBRACK,
    STATE(1269), 1,
      sym_type_elem,
    STATE(848), 2,
      sym_negated_type,
      sym_qualified_type,
    STATE(1117), 2,
      sym_parenthesized_type,
      sym__simple_type,
    STATE(858), 9,
      sym_generic_type,
      sym_pointer_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_interface_type,
      sym_map_type,
      sym_channel_type,
      sym_function_type,
  [41526] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(972), 1,
      anon_sym_LPAREN,
    ACTIONS(994), 1,
      sym_identifier,
    ACTIONS(996), 1,
      anon_sym_func,
    ACTIONS(998), 1,
      anon_sym_LBRACK,
    ACTIONS(1000), 1,
      anon_sym_STAR,
    ACTIONS(1002), 1,
      anon_sym_LT_DASH,
    ACTIONS(1271), 1,
      anon_sym_LBRACE,
    STATE(309), 1,
      sym_block,
    STATE(836), 2,
      sym_negated_type,
      sym_qualified_type,
    STATE(1086), 2,
      sym_parameter_list,
      sym__simple_type,
    STATE(858), 9,
      sym_generic_type,
      sym_pointer_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_interface_type,
      sym_map_type,
      sym_channel_type,
      sym_function_type,
  [41588] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(924), 1,
      anon_sym_LPAREN,
    ACTIONS(926), 1,
      anon_sym_LBRACK,
    ACTIONS(978), 1,
      anon_sym_DOT,
    ACTIONS(1141), 1,
      anon_sym_PIPE,
    ACTIONS(1151), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1153), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1273), 1,
      anon_sym_RPAREN,
    ACTIONS(1275), 1,
      anon_sym_COMMA,
    STATE(397), 1,
      sym_argument_list,
    STATE(1255), 1,
      sym_type_arguments,
    ACTIONS(1145), 2,
      anon_sym_AMP,
      anon_sym_SLASH,
    ACTIONS(1149), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1143), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
    ACTIONS(1147), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(1139), 5,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
  [41648] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(924), 1,
      anon_sym_LPAREN,
    ACTIONS(926), 1,
      anon_sym_LBRACK,
    ACTIONS(978), 1,
      anon_sym_DOT,
    ACTIONS(984), 1,
      anon_sym_PIPE,
    ACTIONS(992), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1109), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1277), 1,
      anon_sym_RBRACK,
    ACTIONS(1279), 1,
      anon_sym_COLON,
    STATE(397), 1,
      sym_argument_list,
    STATE(1255), 1,
      sym_type_arguments,
    ACTIONS(982), 2,
      anon_sym_AMP,
      anon_sym_SLASH,
    ACTIONS(990), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(986), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
    ACTIONS(988), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(980), 5,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
  [41708] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(972), 1,
      anon_sym_LPAREN,
    ACTIONS(994), 1,
      sym_identifier,
    ACTIONS(996), 1,
      anon_sym_func,
    ACTIONS(998), 1,
      anon_sym_LBRACK,
    ACTIONS(1000), 1,
      anon_sym_STAR,
    ACTIONS(1002), 1,
      anon_sym_LT_DASH,
    ACTIONS(1281), 1,
      anon_sym_LBRACE,
    STATE(370), 1,
      sym_block,
    STATE(836), 2,
      sym_negated_type,
      sym_qualified_type,
    STATE(1099), 2,
      sym_parameter_list,
      sym__simple_type,
    STATE(858), 9,
      sym_generic_type,
      sym_pointer_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_interface_type,
      sym_map_type,
      sym_channel_type,
      sym_function_type,
  [41770] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(924), 1,
      anon_sym_LPAREN,
    ACTIONS(926), 1,
      anon_sym_LBRACK,
    ACTIONS(978), 1,
      anon_sym_DOT,
    ACTIONS(1141), 1,
      anon_sym_PIPE,
    ACTIONS(1151), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1153), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1283), 1,
      anon_sym_RPAREN,
    ACTIONS(1285), 1,
      anon_sym_COMMA,
    STATE(397), 1,
      sym_argument_list,
    STATE(1255), 1,
      sym_type_arguments,
    ACTIONS(1145), 2,
      anon_sym_AMP,
      anon_sym_SLASH,
    ACTIONS(1149), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1143), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
    ACTIONS(1147), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(1139), 5,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
  [41830] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(924), 1,
      anon_sym_LPAREN,
    ACTIONS(926), 1,
      anon_sym_LBRACK,
    ACTIONS(978), 1,
      anon_sym_DOT,
    ACTIONS(984), 1,
      anon_sym_PIPE,
    ACTIONS(992), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1109), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1287), 1,
      anon_sym_RBRACK,
    ACTIONS(1289), 1,
      anon_sym_COLON,
    STATE(397), 1,
      sym_argument_list,
    STATE(1255), 1,
      sym_type_arguments,
    ACTIONS(982), 2,
      anon_sym_AMP,
      anon_sym_SLASH,
    ACTIONS(990), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(986), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
    ACTIONS(988), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(980), 5,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
  [41890] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(924), 1,
      anon_sym_LPAREN,
    ACTIONS(926), 1,
      anon_sym_LBRACK,
    ACTIONS(978), 1,
      anon_sym_DOT,
    ACTIONS(1141), 1,
      anon_sym_PIPE,
    ACTIONS(1151), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1153), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1291), 1,
      anon_sym_RPAREN,
    ACTIONS(1293), 1,
      anon_sym_COMMA,
    STATE(397), 1,
      sym_argument_list,
    STATE(1255), 1,
      sym_type_arguments,
    ACTIONS(1145), 2,
      anon_sym_AMP,
      anon_sym_SLASH,
    ACTIONS(1149), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1143), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
    ACTIONS(1147), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(1139), 5,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
  [41950] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(924), 1,
      anon_sym_LPAREN,
    ACTIONS(926), 1,
      anon_sym_LBRACK,
    ACTIONS(978), 1,
      anon_sym_DOT,
    ACTIONS(984), 1,
      anon_sym_PIPE,
    ACTIONS(992), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1109), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1295), 1,
      anon_sym_RBRACK,
    ACTIONS(1297), 1,
      anon_sym_COLON,
    STATE(397), 1,
      sym_argument_list,
    STATE(1255), 1,
      sym_type_arguments,
    ACTIONS(982), 2,
      anon_sym_AMP,
      anon_sym_SLASH,
    ACTIONS(990), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(986), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
    ACTIONS(988), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(980), 5,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
  [42010] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(924), 1,
      anon_sym_LPAREN,
    ACTIONS(926), 1,
      anon_sym_LBRACK,
    ACTIONS(978), 1,
      anon_sym_DOT,
    ACTIONS(984), 1,
      anon_sym_PIPE,
    ACTIONS(992), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1109), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1299), 1,
      anon_sym_RBRACK,
    ACTIONS(1301), 1,
      anon_sym_COLON,
    STATE(397), 1,
      sym_argument_list,
    STATE(1255), 1,
      sym_type_arguments,
    ACTIONS(982), 2,
      anon_sym_AMP,
      anon_sym_SLASH,
    ACTIONS(990), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(986), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
    ACTIONS(988), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(980), 5,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
  [42070] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(561), 1,
      sym_identifier,
    ACTIONS(572), 1,
      anon_sym_func,
    ACTIONS(585), 1,
      anon_sym_map,
    ACTIONS(587), 1,
      anon_sym_chan,
    ACTIONS(589), 1,
      anon_sym_LT_DASH,
    ACTIONS(974), 1,
      anon_sym_LBRACK,
    ACTIONS(976), 1,
      anon_sym_STAR,
    ACTIONS(1042), 1,
      anon_sym_LPAREN,
    ACTIONS(1303), 1,
      anon_sym_RBRACK,
    STATE(1269), 1,
      sym_type_elem,
    STATE(848), 2,
      sym_negated_type,
      sym_qualified_type,
    STATE(1117), 2,
      sym_parenthesized_type,
      sym__simple_type,
    STATE(858), 9,
      sym_generic_type,
      sym_pointer_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_interface_type,
      sym_map_type,
      sym_channel_type,
      sym_function_type,
  [42132] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(924), 1,
      anon_sym_LPAREN,
    ACTIONS(926), 1,
      anon_sym_LBRACK,
    ACTIONS(978), 1,
      anon_sym_DOT,
    ACTIONS(1165), 1,
      anon_sym_PIPE,
    ACTIONS(1175), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1177), 1,
      anon_sym_PIPE_PIPE,
    STATE(397), 1,
      sym_argument_list,
    STATE(1255), 1,
      sym_type_arguments,
    ACTIONS(858), 2,
      anon_sym_COMMA,
      anon_sym_LBRACE,
    ACTIONS(1169), 2,
      anon_sym_AMP,
      anon_sym_SLASH,
    ACTIONS(1173), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1167), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
    ACTIONS(1171), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(1161), 5,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
  [42190] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(924), 1,
      anon_sym_LPAREN,
    ACTIONS(926), 1,
      anon_sym_LBRACK,
    ACTIONS(978), 1,
      anon_sym_DOT,
    ACTIONS(984), 1,
      anon_sym_PIPE,
    ACTIONS(992), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1109), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1305), 1,
      anon_sym_RBRACK,
    ACTIONS(1307), 1,
      anon_sym_COLON,
    STATE(397), 1,
      sym_argument_list,
    STATE(1255), 1,
      sym_type_arguments,
    ACTIONS(982), 2,
      anon_sym_AMP,
      anon_sym_SLASH,
    ACTIONS(990), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(986), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
    ACTIONS(988), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(980), 5,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
  [42250] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(33), 1,
      anon_sym_LBRACE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(972), 1,
      anon_sym_LPAREN,
    ACTIONS(994), 1,
      sym_identifier,
    ACTIONS(996), 1,
      anon_sym_func,
    ACTIONS(998), 1,
      anon_sym_LBRACK,
    ACTIONS(1000), 1,
      anon_sym_STAR,
    ACTIONS(1002), 1,
      anon_sym_LT_DASH,
    STATE(268), 1,
      sym_block,
    STATE(836), 2,
      sym_negated_type,
      sym_qualified_type,
    STATE(1090), 2,
      sym_parameter_list,
      sym__simple_type,
    STATE(858), 9,
      sym_generic_type,
      sym_pointer_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_interface_type,
      sym_map_type,
      sym_channel_type,
      sym_function_type,
  [42312] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(33), 1,
      anon_sym_LBRACE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(972), 1,
      anon_sym_LPAREN,
    ACTIONS(996), 1,
      anon_sym_func,
    ACTIONS(998), 1,
      anon_sym_LBRACK,
    ACTIONS(1000), 1,
      anon_sym_STAR,
    ACTIONS(1002), 1,
      anon_sym_LT_DASH,
    ACTIONS(1309), 1,
      sym_identifier,
    STATE(268), 1,
      sym_block,
    STATE(836), 2,
      sym_negated_type,
      sym_qualified_type,
    STATE(1090), 2,
      sym_parameter_list,
      sym__simple_type,
    STATE(858), 9,
      sym_generic_type,
      sym_pointer_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_interface_type,
      sym_map_type,
      sym_channel_type,
      sym_function_type,
  [42374] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(561), 1,
      sym_identifier,
    ACTIONS(572), 1,
      anon_sym_func,
    ACTIONS(585), 1,
      anon_sym_map,
    ACTIONS(587), 1,
      anon_sym_chan,
    ACTIONS(589), 1,
      anon_sym_LT_DASH,
    ACTIONS(974), 1,
      anon_sym_LBRACK,
    ACTIONS(976), 1,
      anon_sym_STAR,
    ACTIONS(1042), 1,
      anon_sym_LPAREN,
    ACTIONS(1311), 1,
      anon_sym_RBRACK,
    STATE(1269), 1,
      sym_type_elem,
    STATE(848), 2,
      sym_negated_type,
      sym_qualified_type,
    STATE(1117), 2,
      sym_parenthesized_type,
      sym__simple_type,
    STATE(858), 9,
      sym_generic_type,
      sym_pointer_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_interface_type,
      sym_map_type,
      sym_channel_type,
      sym_function_type,
  [42436] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(924), 1,
      anon_sym_LPAREN,
    ACTIONS(926), 1,
      anon_sym_LBRACK,
    ACTIONS(978), 1,
      anon_sym_DOT,
    ACTIONS(984), 1,
      anon_sym_PIPE,
    ACTIONS(992), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1109), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1313), 1,
      anon_sym_RBRACK,
    ACTIONS(1315), 1,
      anon_sym_COLON,
    STATE(397), 1,
      sym_argument_list,
    STATE(1255), 1,
      sym_type_arguments,
    ACTIONS(982), 2,
      anon_sym_AMP,
      anon_sym_SLASH,
    ACTIONS(990), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(986), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
    ACTIONS(988), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(980), 5,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
  [42496] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(924), 1,
      anon_sym_LPAREN,
    ACTIONS(926), 1,
      anon_sym_LBRACK,
    ACTIONS(978), 1,
      anon_sym_DOT,
    ACTIONS(984), 1,
      anon_sym_PIPE,
    ACTIONS(992), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1109), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1317), 1,
      anon_sym_RBRACK,
    ACTIONS(1319), 1,
      anon_sym_COLON,
    STATE(397), 1,
      sym_argument_list,
    STATE(1255), 1,
      sym_type_arguments,
    ACTIONS(982), 2,
      anon_sym_AMP,
      anon_sym_SLASH,
    ACTIONS(990), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(986), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
    ACTIONS(988), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(980), 5,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
  [42556] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(924), 1,
      anon_sym_LPAREN,
    ACTIONS(926), 1,
      anon_sym_LBRACK,
    ACTIONS(978), 1,
      anon_sym_DOT,
    ACTIONS(984), 1,
      anon_sym_PIPE,
    ACTIONS(992), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1109), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1321), 1,
      anon_sym_RBRACK,
    ACTIONS(1323), 1,
      anon_sym_COLON,
    STATE(397), 1,
      sym_argument_list,
    STATE(1255), 1,
      sym_type_arguments,
    ACTIONS(982), 2,
      anon_sym_AMP,
      anon_sym_SLASH,
    ACTIONS(990), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(986), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
    ACTIONS(988), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(980), 5,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
  [42616] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(561), 1,
      sym_identifier,
    ACTIONS(572), 1,
      anon_sym_func,
    ACTIONS(585), 1,
      anon_sym_map,
    ACTIONS(587), 1,
      anon_sym_chan,
    ACTIONS(589), 1,
      anon_sym_LT_DASH,
    ACTIONS(974), 1,
      anon_sym_LBRACK,
    ACTIONS(976), 1,
      anon_sym_STAR,
    ACTIONS(1042), 1,
      anon_sym_LPAREN,
    ACTIONS(1325), 1,
      anon_sym_RBRACK,
    STATE(1269), 1,
      sym_type_elem,
    STATE(848), 2,
      sym_negated_type,
      sym_qualified_type,
    STATE(1117), 2,
      sym_parenthesized_type,
      sym__simple_type,
    STATE(858), 9,
      sym_generic_type,
      sym_pointer_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_interface_type,
      sym_map_type,
      sym_channel_type,
      sym_function_type,
  [42678] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(880), 1,
      anon_sym_struct,
    ACTIONS(884), 1,
      anon_sym_interface,
    ACTIONS(904), 1,
      anon_sym_func,
    ACTIONS(910), 1,
      anon_sym_map,
    ACTIONS(912), 1,
      anon_sym_chan,
    ACTIONS(1211), 1,
      sym_identifier,
    ACTIONS(1213), 1,
      anon_sym_LPAREN,
    ACTIONS(1215), 1,
      anon_sym_LBRACK,
    ACTIONS(1217), 1,
      anon_sym_STAR,
    ACTIONS(1219), 1,
      anon_sym_TILDE,
    ACTIONS(1223), 1,
      anon_sym_LT_DASH,
    STATE(799), 2,
      sym_negated_type,
      sym_qualified_type,
    STATE(1007), 2,
      sym_parenthesized_type,
      sym__simple_type,
    STATE(1074), 2,
      sym_method_elem,
      sym_type_elem,
    STATE(807), 9,
      sym_generic_type,
      sym_pointer_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_interface_type,
      sym_map_type,
      sym_channel_type,
      sym_function_type,
  [42738] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(924), 1,
      anon_sym_LPAREN,
    ACTIONS(926), 1,
      anon_sym_LBRACK,
    ACTIONS(978), 1,
      anon_sym_DOT,
    ACTIONS(984), 1,
      anon_sym_PIPE,
    ACTIONS(992), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1109), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1327), 1,
      anon_sym_RBRACK,
    ACTIONS(1329), 1,
      anon_sym_COLON,
    STATE(397), 1,
      sym_argument_list,
    STATE(1255), 1,
      sym_type_arguments,
    ACTIONS(982), 2,
      anon_sym_AMP,
      anon_sym_SLASH,
    ACTIONS(990), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(986), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
    ACTIONS(988), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(980), 5,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
  [42798] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(924), 1,
      anon_sym_LPAREN,
    ACTIONS(926), 1,
      anon_sym_LBRACK,
    ACTIONS(978), 1,
      anon_sym_DOT,
    ACTIONS(984), 1,
      anon_sym_PIPE,
    ACTIONS(992), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1109), 1,
      anon_sym_PIPE_PIPE,
    STATE(397), 1,
      sym_argument_list,
    STATE(1255), 1,
      sym_type_arguments,
    ACTIONS(982), 2,
      anon_sym_AMP,
      anon_sym_SLASH,
    ACTIONS(990), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1008), 2,
      anon_sym_SEMI,
      anon_sym_COLON,
    ACTIONS(986), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
    ACTIONS(988), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(980), 5,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
  [42856] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(924), 1,
      anon_sym_LPAREN,
    ACTIONS(926), 1,
      anon_sym_LBRACK,
    ACTIONS(978), 1,
      anon_sym_DOT,
    ACTIONS(984), 1,
      anon_sym_PIPE,
    ACTIONS(992), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1109), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1331), 1,
      anon_sym_RBRACK,
    ACTIONS(1333), 1,
      anon_sym_COLON,
    STATE(397), 1,
      sym_argument_list,
    STATE(1255), 1,
      sym_type_arguments,
    ACTIONS(982), 2,
      anon_sym_AMP,
      anon_sym_SLASH,
    ACTIONS(990), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(986), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
    ACTIONS(988), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(980), 5,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
  [42916] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(880), 1,
      anon_sym_struct,
    ACTIONS(884), 1,
      anon_sym_interface,
    ACTIONS(892), 1,
      sym_identifier,
    ACTIONS(904), 1,
      anon_sym_func,
    ACTIONS(910), 1,
      anon_sym_map,
    ACTIONS(912), 1,
      anon_sym_chan,
    ACTIONS(1213), 1,
      anon_sym_LPAREN,
    ACTIONS(1217), 1,
      anon_sym_STAR,
    ACTIONS(1219), 1,
      anon_sym_TILDE,
    ACTIONS(1223), 1,
      anon_sym_LT_DASH,
    ACTIONS(1335), 1,
      anon_sym_EQ,
    ACTIONS(1337), 1,
      anon_sym_LBRACK,
    STATE(750), 1,
      sym_type_parameter_list,
    STATE(799), 2,
      sym_negated_type,
      sym_qualified_type,
    STATE(990), 2,
      sym_parenthesized_type,
      sym__simple_type,
    STATE(807), 9,
      sym_generic_type,
      sym_pointer_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_interface_type,
      sym_map_type,
      sym_channel_type,
      sym_function_type,
  [42978] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(561), 1,
      sym_identifier,
    ACTIONS(572), 1,
      anon_sym_func,
    ACTIONS(585), 1,
      anon_sym_map,
    ACTIONS(587), 1,
      anon_sym_chan,
    ACTIONS(589), 1,
      anon_sym_LT_DASH,
    ACTIONS(974), 1,
      anon_sym_LBRACK,
    ACTIONS(976), 1,
      anon_sym_STAR,
    ACTIONS(1042), 1,
      anon_sym_LPAREN,
    ACTIONS(1339), 1,
      anon_sym_RBRACK,
    STATE(1269), 1,
      sym_type_elem,
    STATE(848), 2,
      sym_negated_type,
      sym_qualified_type,
    STATE(1117), 2,
      sym_parenthesized_type,
      sym__simple_type,
    STATE(858), 9,
      sym_generic_type,
      sym_pointer_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_interface_type,
      sym_map_type,
      sym_channel_type,
      sym_function_type,
  [43040] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(924), 1,
      anon_sym_LPAREN,
    ACTIONS(926), 1,
      anon_sym_LBRACK,
    ACTIONS(978), 1,
      anon_sym_DOT,
    ACTIONS(984), 1,
      anon_sym_PIPE,
    ACTIONS(992), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1109), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1341), 1,
      anon_sym_RBRACK,
    ACTIONS(1343), 1,
      anon_sym_COLON,
    STATE(397), 1,
      sym_argument_list,
    STATE(1255), 1,
      sym_type_arguments,
    ACTIONS(982), 2,
      anon_sym_AMP,
      anon_sym_SLASH,
    ACTIONS(990), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(986), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
    ACTIONS(988), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(980), 5,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
  [43100] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(972), 1,
      anon_sym_LPAREN,
    ACTIONS(994), 1,
      sym_identifier,
    ACTIONS(996), 1,
      anon_sym_func,
    ACTIONS(998), 1,
      anon_sym_LBRACK,
    ACTIONS(1000), 1,
      anon_sym_STAR,
    ACTIONS(1002), 1,
      anon_sym_LT_DASH,
    ACTIONS(1345), 1,
      anon_sym_LBRACE,
    STATE(481), 1,
      sym_block,
    STATE(836), 2,
      sym_negated_type,
      sym_qualified_type,
    STATE(1072), 2,
      sym_parameter_list,
      sym__simple_type,
    STATE(858), 9,
      sym_generic_type,
      sym_pointer_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_interface_type,
      sym_map_type,
      sym_channel_type,
      sym_function_type,
  [43162] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(972), 1,
      anon_sym_LPAREN,
    ACTIONS(994), 1,
      sym_identifier,
    ACTIONS(996), 1,
      anon_sym_func,
    ACTIONS(998), 1,
      anon_sym_LBRACK,
    ACTIONS(1000), 1,
      anon_sym_STAR,
    ACTIONS(1002), 1,
      anon_sym_LT_DASH,
    ACTIONS(1347), 1,
      anon_sym_LBRACE,
    STATE(548), 1,
      sym_block,
    STATE(836), 2,
      sym_negated_type,
      sym_qualified_type,
    STATE(1113), 2,
      sym_parameter_list,
      sym__simple_type,
    STATE(858), 9,
      sym_generic_type,
      sym_pointer_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_interface_type,
      sym_map_type,
      sym_channel_type,
      sym_function_type,
  [43224] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(924), 1,
      anon_sym_LPAREN,
    ACTIONS(926), 1,
      anon_sym_LBRACK,
    ACTIONS(978), 1,
      anon_sym_DOT,
    ACTIONS(1141), 1,
      anon_sym_PIPE,
    ACTIONS(1151), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1153), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1349), 1,
      anon_sym_RPAREN,
    ACTIONS(1351), 1,
      anon_sym_COMMA,
    STATE(397), 1,
      sym_argument_list,
    STATE(1255), 1,
      sym_type_arguments,
    ACTIONS(1145), 2,
      anon_sym_AMP,
      anon_sym_SLASH,
    ACTIONS(1149), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1143), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
    ACTIONS(1147), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(1139), 5,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
  [43284] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(33), 1,
      anon_sym_LBRACE,
    ACTIONS(924), 1,
      anon_sym_LPAREN,
    ACTIONS(926), 1,
      anon_sym_LBRACK,
    ACTIONS(978), 1,
      anon_sym_DOT,
    ACTIONS(1165), 1,
      anon_sym_PIPE,
    ACTIONS(1175), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1177), 1,
      anon_sym_PIPE_PIPE,
    STATE(397), 1,
      sym_argument_list,
    STATE(904), 1,
      sym_block,
    STATE(1255), 1,
      sym_type_arguments,
    ACTIONS(1169), 2,
      anon_sym_AMP,
      anon_sym_SLASH,
    ACTIONS(1173), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1167), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
    ACTIONS(1171), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(1161), 5,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
  [43344] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(924), 1,
      anon_sym_LPAREN,
    ACTIONS(926), 1,
      anon_sym_LBRACK,
    ACTIONS(978), 1,
      anon_sym_DOT,
    ACTIONS(984), 1,
      anon_sym_PIPE,
    ACTIONS(992), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1109), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1353), 1,
      anon_sym_RBRACK,
    ACTIONS(1355), 1,
      anon_sym_COLON,
    STATE(397), 1,
      sym_argument_list,
    STATE(1255), 1,
      sym_type_arguments,
    ACTIONS(982), 2,
      anon_sym_AMP,
      anon_sym_SLASH,
    ACTIONS(990), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(986), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
    ACTIONS(988), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(980), 5,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
  [43404] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(924), 1,
      anon_sym_LPAREN,
    ACTIONS(926), 1,
      anon_sym_LBRACK,
    ACTIONS(978), 1,
      anon_sym_DOT,
    ACTIONS(984), 1,
      anon_sym_PIPE,
    ACTIONS(992), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1109), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1357), 1,
      anon_sym_RBRACK,
    ACTIONS(1359), 1,
      anon_sym_COLON,
    STATE(397), 1,
      sym_argument_list,
    STATE(1255), 1,
      sym_type_arguments,
    ACTIONS(982), 2,
      anon_sym_AMP,
      anon_sym_SLASH,
    ACTIONS(990), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(986), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
    ACTIONS(988), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(980), 5,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
  [43464] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(924), 1,
      anon_sym_LPAREN,
    ACTIONS(926), 1,
      anon_sym_LBRACK,
    ACTIONS(978), 1,
      anon_sym_DOT,
    ACTIONS(1141), 1,
      anon_sym_PIPE,
    ACTIONS(1151), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1153), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1361), 1,
      anon_sym_RPAREN,
    ACTIONS(1363), 1,
      anon_sym_COMMA,
    STATE(397), 1,
      sym_argument_list,
    STATE(1255), 1,
      sym_type_arguments,
    ACTIONS(1145), 2,
      anon_sym_AMP,
      anon_sym_SLASH,
    ACTIONS(1149), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1143), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
    ACTIONS(1147), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(1139), 5,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
  [43524] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(924), 1,
      anon_sym_LPAREN,
    ACTIONS(926), 1,
      anon_sym_LBRACK,
    ACTIONS(978), 1,
      anon_sym_DOT,
    ACTIONS(1141), 1,
      anon_sym_PIPE,
    ACTIONS(1151), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1153), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1365), 1,
      anon_sym_RPAREN,
    ACTIONS(1367), 1,
      anon_sym_COMMA,
    STATE(397), 1,
      sym_argument_list,
    STATE(1255), 1,
      sym_type_arguments,
    ACTIONS(1145), 2,
      anon_sym_AMP,
      anon_sym_SLASH,
    ACTIONS(1149), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1143), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
    ACTIONS(1147), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(1139), 5,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
  [43584] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(880), 1,
      anon_sym_struct,
    ACTIONS(884), 1,
      anon_sym_interface,
    ACTIONS(892), 1,
      sym_identifier,
    ACTIONS(904), 1,
      anon_sym_func,
    ACTIONS(910), 1,
      anon_sym_map,
    ACTIONS(912), 1,
      anon_sym_chan,
    ACTIONS(1213), 1,
      anon_sym_LPAREN,
    ACTIONS(1215), 1,
      anon_sym_LBRACK,
    ACTIONS(1217), 1,
      anon_sym_STAR,
    ACTIONS(1219), 1,
      anon_sym_TILDE,
    ACTIONS(1223), 1,
      anon_sym_LT_DASH,
    ACTIONS(1369), 1,
      anon_sym_COMMA,
    STATE(801), 1,
      aux_sym_field_declaration_repeat1,
    STATE(903), 1,
      sym__simple_type,
    STATE(905), 1,
      sym_parenthesized_type,
    STATE(799), 2,
      sym_negated_type,
      sym_qualified_type,
    STATE(807), 9,
      sym_generic_type,
      sym_pointer_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_interface_type,
      sym_map_type,
      sym_channel_type,
      sym_function_type,
  [43648] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(924), 1,
      anon_sym_LPAREN,
    ACTIONS(926), 1,
      anon_sym_LBRACK,
    ACTIONS(978), 1,
      anon_sym_DOT,
    ACTIONS(984), 1,
      anon_sym_PIPE,
    ACTIONS(992), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1109), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1371), 1,
      anon_sym_RBRACK,
    ACTIONS(1373), 1,
      anon_sym_COLON,
    STATE(397), 1,
      sym_argument_list,
    STATE(1255), 1,
      sym_type_arguments,
    ACTIONS(982), 2,
      anon_sym_AMP,
      anon_sym_SLASH,
    ACTIONS(990), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(986), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
    ACTIONS(988), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(980), 5,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
  [43708] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(924), 1,
      anon_sym_LPAREN,
    ACTIONS(926), 1,
      anon_sym_LBRACK,
    ACTIONS(978), 1,
      anon_sym_DOT,
    ACTIONS(984), 1,
      anon_sym_PIPE,
    ACTIONS(992), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1109), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1375), 1,
      anon_sym_RBRACK,
    ACTIONS(1377), 1,
      anon_sym_COLON,
    STATE(397), 1,
      sym_argument_list,
    STATE(1255), 1,
      sym_type_arguments,
    ACTIONS(982), 2,
      anon_sym_AMP,
      anon_sym_SLASH,
    ACTIONS(990), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(986), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
    ACTIONS(988), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(980), 5,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
  [43768] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(924), 1,
      anon_sym_LPAREN,
    ACTIONS(926), 1,
      anon_sym_LBRACK,
    ACTIONS(978), 1,
      anon_sym_DOT,
    ACTIONS(984), 1,
      anon_sym_PIPE,
    ACTIONS(992), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1109), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1379), 1,
      anon_sym_RBRACK,
    STATE(397), 1,
      sym_argument_list,
    STATE(1255), 1,
      sym_type_arguments,
    ACTIONS(982), 2,
      anon_sym_AMP,
      anon_sym_SLASH,
    ACTIONS(990), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(986), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
    ACTIONS(988), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(980), 5,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
  [43825] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(924), 1,
      anon_sym_LPAREN,
    ACTIONS(926), 1,
      anon_sym_LBRACK,
    ACTIONS(978), 1,
      anon_sym_DOT,
    ACTIONS(1008), 1,
      anon_sym_LBRACE,
    ACTIONS(1165), 1,
      anon_sym_PIPE,
    ACTIONS(1175), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1177), 1,
      anon_sym_PIPE_PIPE,
    STATE(397), 1,
      sym_argument_list,
    STATE(1255), 1,
      sym_type_arguments,
    ACTIONS(1169), 2,
      anon_sym_AMP,
      anon_sym_SLASH,
    ACTIONS(1173), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1167), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
    ACTIONS(1171), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(1161), 5,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
  [43882] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(561), 1,
      sym_identifier,
    ACTIONS(572), 1,
      anon_sym_func,
    ACTIONS(585), 1,
      anon_sym_map,
    ACTIONS(587), 1,
      anon_sym_chan,
    ACTIONS(589), 1,
      anon_sym_LT_DASH,
    ACTIONS(974), 1,
      anon_sym_LBRACK,
    ACTIONS(976), 1,
      anon_sym_STAR,
    ACTIONS(1042), 1,
      anon_sym_LPAREN,
    ACTIONS(1381), 1,
      anon_sym_RPAREN,
    STATE(848), 2,
      sym_negated_type,
      sym_qualified_type,
    STATE(1224), 2,
      sym_parenthesized_type,
      sym__simple_type,
    STATE(858), 9,
      sym_generic_type,
      sym_pointer_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_interface_type,
      sym_map_type,
      sym_channel_type,
      sym_function_type,
  [43941] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(924), 1,
      anon_sym_LPAREN,
    ACTIONS(926), 1,
      anon_sym_LBRACK,
    ACTIONS(978), 1,
      anon_sym_DOT,
    ACTIONS(984), 1,
      anon_sym_PIPE,
    ACTIONS(992), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1109), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1383), 1,
      anon_sym_SEMI,
    STATE(397), 1,
      sym_argument_list,
    STATE(1255), 1,
      sym_type_arguments,
    ACTIONS(982), 2,
      anon_sym_AMP,
      anon_sym_SLASH,
    ACTIONS(990), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(986), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
    ACTIONS(988), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(980), 5,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
  [43998] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(561), 1,
      sym_identifier,
    ACTIONS(572), 1,
      anon_sym_func,
    ACTIONS(585), 1,
      anon_sym_map,
    ACTIONS(587), 1,
      anon_sym_chan,
    ACTIONS(589), 1,
      anon_sym_LT_DASH,
    ACTIONS(974), 1,
      anon_sym_LBRACK,
    ACTIONS(976), 1,
      anon_sym_STAR,
    ACTIONS(1042), 1,
      anon_sym_LPAREN,
    STATE(1150), 1,
      sym_type_elem,
    STATE(848), 2,
      sym_negated_type,
      sym_qualified_type,
    STATE(1117), 2,
      sym_parenthesized_type,
      sym__simple_type,
    STATE(858), 9,
      sym_generic_type,
      sym_pointer_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_interface_type,
      sym_map_type,
      sym_channel_type,
      sym_function_type,
  [44057] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(561), 1,
      sym_identifier,
    ACTIONS(572), 1,
      anon_sym_func,
    ACTIONS(585), 1,
      anon_sym_map,
    ACTIONS(587), 1,
      anon_sym_chan,
    ACTIONS(589), 1,
      anon_sym_LT_DASH,
    ACTIONS(974), 1,
      anon_sym_LBRACK,
    ACTIONS(976), 1,
      anon_sym_STAR,
    ACTIONS(1042), 1,
      anon_sym_LPAREN,
    ACTIONS(1385), 1,
      anon_sym_type,
    STATE(848), 2,
      sym_negated_type,
      sym_qualified_type,
    STATE(1329), 2,
      sym_parenthesized_type,
      sym__simple_type,
    STATE(858), 9,
      sym_generic_type,
      sym_pointer_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_interface_type,
      sym_map_type,
      sym_channel_type,
      sym_function_type,
  [44116] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(561), 1,
      sym_identifier,
    ACTIONS(572), 1,
      anon_sym_func,
    ACTIONS(585), 1,
      anon_sym_map,
    ACTIONS(587), 1,
      anon_sym_chan,
    ACTIONS(589), 1,
      anon_sym_LT_DASH,
    ACTIONS(974), 1,
      anon_sym_LBRACK,
    ACTIONS(976), 1,
      anon_sym_STAR,
    ACTIONS(1042), 1,
      anon_sym_LPAREN,
    ACTIONS(1387), 1,
      anon_sym_RBRACK,
    STATE(848), 2,
      sym_negated_type,
      sym_qualified_type,
    STATE(1139), 2,
      sym_parenthesized_type,
      sym__simple_type,
    STATE(858), 9,
      sym_generic_type,
      sym_pointer_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_interface_type,
      sym_map_type,
      sym_channel_type,
      sym_function_type,
  [44175] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(924), 1,
      anon_sym_LPAREN,
    ACTIONS(926), 1,
      anon_sym_LBRACK,
    ACTIONS(978), 1,
      anon_sym_DOT,
    ACTIONS(1165), 1,
      anon_sym_PIPE,
    ACTIONS(1175), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1177), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1389), 1,
      anon_sym_LBRACE,
    STATE(397), 1,
      sym_argument_list,
    STATE(1255), 1,
      sym_type_arguments,
    ACTIONS(1169), 2,
      anon_sym_AMP,
      anon_sym_SLASH,
    ACTIONS(1173), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1167), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
    ACTIONS(1171), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(1161), 5,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
  [44232] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(924), 1,
      anon_sym_LPAREN,
    ACTIONS(926), 1,
      anon_sym_LBRACK,
    ACTIONS(978), 1,
      anon_sym_DOT,
    ACTIONS(1141), 1,
      anon_sym_PIPE,
    ACTIONS(1151), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1153), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1391), 1,
      anon_sym_RPAREN,
    STATE(397), 1,
      sym_argument_list,
    STATE(1255), 1,
      sym_type_arguments,
    ACTIONS(1145), 2,
      anon_sym_AMP,
      anon_sym_SLASH,
    ACTIONS(1149), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1143), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
    ACTIONS(1147), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(1139), 5,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
  [44289] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(924), 1,
      anon_sym_LPAREN,
    ACTIONS(926), 1,
      anon_sym_LBRACK,
    ACTIONS(978), 1,
      anon_sym_DOT,
    ACTIONS(1141), 1,
      anon_sym_PIPE,
    ACTIONS(1151), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1153), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1393), 1,
      anon_sym_RPAREN,
    STATE(397), 1,
      sym_argument_list,
    STATE(1255), 1,
      sym_type_arguments,
    ACTIONS(1145), 2,
      anon_sym_AMP,
      anon_sym_SLASH,
    ACTIONS(1149), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1143), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
    ACTIONS(1147), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(1139), 5,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
  [44346] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(561), 1,
      sym_identifier,
    ACTIONS(572), 1,
      anon_sym_func,
    ACTIONS(585), 1,
      anon_sym_map,
    ACTIONS(587), 1,
      anon_sym_chan,
    ACTIONS(589), 1,
      anon_sym_LT_DASH,
    ACTIONS(974), 1,
      anon_sym_LBRACK,
    ACTIONS(976), 1,
      anon_sym_STAR,
    ACTIONS(1042), 1,
      anon_sym_LPAREN,
    ACTIONS(1395), 1,
      anon_sym_RBRACK,
    STATE(848), 2,
      sym_negated_type,
      sym_qualified_type,
    STATE(1139), 2,
      sym_parenthesized_type,
      sym__simple_type,
    STATE(858), 9,
      sym_generic_type,
      sym_pointer_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_interface_type,
      sym_map_type,
      sym_channel_type,
      sym_function_type,
  [44405] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(924), 1,
      anon_sym_LPAREN,
    ACTIONS(926), 1,
      anon_sym_LBRACK,
    ACTIONS(978), 1,
      anon_sym_DOT,
    ACTIONS(984), 1,
      anon_sym_PIPE,
    ACTIONS(992), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1109), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1397), 1,
      anon_sym_RBRACK,
    STATE(397), 1,
      sym_argument_list,
    STATE(1255), 1,
      sym_type_arguments,
    ACTIONS(982), 2,
      anon_sym_AMP,
      anon_sym_SLASH,
    ACTIONS(990), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(986), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
    ACTIONS(988), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(980), 5,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
  [44462] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(561), 1,
      sym_identifier,
    ACTIONS(572), 1,
      anon_sym_func,
    ACTIONS(585), 1,
      anon_sym_map,
    ACTIONS(587), 1,
      anon_sym_chan,
    ACTIONS(589), 1,
      anon_sym_LT_DASH,
    ACTIONS(974), 1,
      anon_sym_LBRACK,
    ACTIONS(976), 1,
      anon_sym_STAR,
    ACTIONS(1042), 1,
      anon_sym_LPAREN,
    ACTIONS(1399), 1,
      anon_sym_RPAREN,
    STATE(848), 2,
      sym_negated_type,
      sym_qualified_type,
    STATE(1206), 2,
      sym_parenthesized_type,
      sym__simple_type,
    STATE(858), 9,
      sym_generic_type,
      sym_pointer_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_interface_type,
      sym_map_type,
      sym_channel_type,
      sym_function_type,
  [44521] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(561), 1,
      sym_identifier,
    ACTIONS(572), 1,
      anon_sym_func,
    ACTIONS(585), 1,
      anon_sym_map,
    ACTIONS(587), 1,
      anon_sym_chan,
    ACTIONS(589), 1,
      anon_sym_LT_DASH,
    ACTIONS(974), 1,
      anon_sym_LBRACK,
    ACTIONS(976), 1,
      anon_sym_STAR,
    ACTIONS(1042), 1,
      anon_sym_LPAREN,
    ACTIONS(1401), 1,
      anon_sym_RBRACK,
    STATE(848), 2,
      sym_negated_type,
      sym_qualified_type,
    STATE(1139), 2,
      sym_parenthesized_type,
      sym__simple_type,
    STATE(858), 9,
      sym_generic_type,
      sym_pointer_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_interface_type,
      sym_map_type,
      sym_channel_type,
      sym_function_type,
  [44580] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(561), 1,
      sym_identifier,
    ACTIONS(572), 1,
      anon_sym_func,
    ACTIONS(585), 1,
      anon_sym_map,
    ACTIONS(587), 1,
      anon_sym_chan,
    ACTIONS(589), 1,
      anon_sym_LT_DASH,
    ACTIONS(974), 1,
      anon_sym_LBRACK,
    ACTIONS(976), 1,
      anon_sym_STAR,
    ACTIONS(1042), 1,
      anon_sym_LPAREN,
    ACTIONS(1403), 1,
      anon_sym_RBRACK,
    STATE(848), 2,
      sym_negated_type,
      sym_qualified_type,
    STATE(1139), 2,
      sym_parenthesized_type,
      sym__simple_type,
    STATE(858), 9,
      sym_generic_type,
      sym_pointer_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_interface_type,
      sym_map_type,
      sym_channel_type,
      sym_function_type,
  [44639] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(924), 1,
      anon_sym_LPAREN,
    ACTIONS(926), 1,
      anon_sym_LBRACK,
    ACTIONS(978), 1,
      anon_sym_DOT,
    ACTIONS(984), 1,
      anon_sym_PIPE,
    ACTIONS(992), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1109), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1405), 1,
      anon_sym_RBRACK,
    STATE(397), 1,
      sym_argument_list,
    STATE(1255), 1,
      sym_type_arguments,
    ACTIONS(982), 2,
      anon_sym_AMP,
      anon_sym_SLASH,
    ACTIONS(990), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(986), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
    ACTIONS(988), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(980), 5,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
  [44696] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(924), 1,
      anon_sym_LPAREN,
    ACTIONS(926), 1,
      anon_sym_LBRACK,
    ACTIONS(978), 1,
      anon_sym_DOT,
    ACTIONS(984), 1,
      anon_sym_PIPE,
    ACTIONS(992), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1109), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1407), 1,
      anon_sym_RBRACK,
    STATE(397), 1,
      sym_argument_list,
    STATE(1255), 1,
      sym_type_arguments,
    ACTIONS(982), 2,
      anon_sym_AMP,
      anon_sym_SLASH,
    ACTIONS(990), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(986), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
    ACTIONS(988), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(980), 5,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
  [44753] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(561), 1,
      sym_identifier,
    ACTIONS(572), 1,
      anon_sym_func,
    ACTIONS(585), 1,
      anon_sym_map,
    ACTIONS(587), 1,
      anon_sym_chan,
    ACTIONS(589), 1,
      anon_sym_LT_DASH,
    ACTIONS(974), 1,
      anon_sym_LBRACK,
    ACTIONS(976), 1,
      anon_sym_STAR,
    ACTIONS(1042), 1,
      anon_sym_LPAREN,
    ACTIONS(1409), 1,
      anon_sym_type,
    STATE(848), 2,
      sym_negated_type,
      sym_qualified_type,
    STATE(1326), 2,
      sym_parenthesized_type,
      sym__simple_type,
    STATE(858), 9,
      sym_generic_type,
      sym_pointer_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_interface_type,
      sym_map_type,
      sym_channel_type,
      sym_function_type,
  [44812] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(561), 1,
      sym_identifier,
    ACTIONS(572), 1,
      anon_sym_func,
    ACTIONS(585), 1,
      anon_sym_map,
    ACTIONS(587), 1,
      anon_sym_chan,
    ACTIONS(589), 1,
      anon_sym_LT_DASH,
    ACTIONS(974), 1,
      anon_sym_LBRACK,
    ACTIONS(976), 1,
      anon_sym_STAR,
    ACTIONS(1042), 1,
      anon_sym_LPAREN,
    ACTIONS(1411), 1,
      anon_sym_type,
    STATE(848), 2,
      sym_negated_type,
      sym_qualified_type,
    STATE(1326), 2,
      sym_parenthesized_type,
      sym__simple_type,
    STATE(858), 9,
      sym_generic_type,
      sym_pointer_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_interface_type,
      sym_map_type,
      sym_channel_type,
      sym_function_type,
  [44871] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(924), 1,
      anon_sym_LPAREN,
    ACTIONS(926), 1,
      anon_sym_LBRACK,
    ACTIONS(978), 1,
      anon_sym_DOT,
    ACTIONS(1141), 1,
      anon_sym_PIPE,
    ACTIONS(1151), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1153), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1413), 1,
      anon_sym_RPAREN,
    STATE(397), 1,
      sym_argument_list,
    STATE(1255), 1,
      sym_type_arguments,
    ACTIONS(1145), 2,
      anon_sym_AMP,
      anon_sym_SLASH,
    ACTIONS(1149), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1143), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
    ACTIONS(1147), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(1139), 5,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
  [44928] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(924), 1,
      anon_sym_LPAREN,
    ACTIONS(926), 1,
      anon_sym_LBRACK,
    ACTIONS(978), 1,
      anon_sym_DOT,
    ACTIONS(984), 1,
      anon_sym_PIPE,
    ACTIONS(992), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1109), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1415), 1,
      anon_sym_RBRACK,
    STATE(397), 1,
      sym_argument_list,
    STATE(1255), 1,
      sym_type_arguments,
    ACTIONS(982), 2,
      anon_sym_AMP,
      anon_sym_SLASH,
    ACTIONS(990), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(986), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
    ACTIONS(988), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(980), 5,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
  [44985] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(561), 1,
      sym_identifier,
    ACTIONS(572), 1,
      anon_sym_func,
    ACTIONS(585), 1,
      anon_sym_map,
    ACTIONS(587), 1,
      anon_sym_chan,
    ACTIONS(589), 1,
      anon_sym_LT_DASH,
    ACTIONS(974), 1,
      anon_sym_LBRACK,
    ACTIONS(976), 1,
      anon_sym_STAR,
    ACTIONS(1042), 1,
      anon_sym_LPAREN,
    ACTIONS(1417), 1,
      anon_sym_RPAREN,
    STATE(848), 2,
      sym_negated_type,
      sym_qualified_type,
    STATE(1221), 2,
      sym_parenthesized_type,
      sym__simple_type,
    STATE(858), 9,
      sym_generic_type,
      sym_pointer_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_interface_type,
      sym_map_type,
      sym_channel_type,
      sym_function_type,
  [45044] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(924), 1,
      anon_sym_LPAREN,
    ACTIONS(926), 1,
      anon_sym_LBRACK,
    ACTIONS(978), 1,
      anon_sym_DOT,
    ACTIONS(984), 1,
      anon_sym_PIPE,
    ACTIONS(992), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1109), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1419), 1,
      anon_sym_COLON,
    STATE(397), 1,
      sym_argument_list,
    STATE(1255), 1,
      sym_type_arguments,
    ACTIONS(982), 2,
      anon_sym_AMP,
      anon_sym_SLASH,
    ACTIONS(990), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(986), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
    ACTIONS(988), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(980), 5,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
  [45101] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(561), 1,
      sym_identifier,
    ACTIONS(572), 1,
      anon_sym_func,
    ACTIONS(585), 1,
      anon_sym_map,
    ACTIONS(587), 1,
      anon_sym_chan,
    ACTIONS(589), 1,
      anon_sym_LT_DASH,
    ACTIONS(974), 1,
      anon_sym_LBRACK,
    ACTIONS(976), 1,
      anon_sym_STAR,
    ACTIONS(1042), 1,
      anon_sym_LPAREN,
    STATE(1269), 1,
      sym_type_elem,
    STATE(848), 2,
      sym_negated_type,
      sym_qualified_type,
    STATE(1117), 2,
      sym_parenthesized_type,
      sym__simple_type,
    STATE(858), 9,
      sym_generic_type,
      sym_pointer_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_interface_type,
      sym_map_type,
      sym_channel_type,
      sym_function_type,
  [45160] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(924), 1,
      anon_sym_LPAREN,
    ACTIONS(926), 1,
      anon_sym_LBRACK,
    ACTIONS(978), 1,
      anon_sym_DOT,
    ACTIONS(1165), 1,
      anon_sym_PIPE,
    ACTIONS(1175), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1177), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1421), 1,
      anon_sym_LBRACE,
    STATE(397), 1,
      sym_argument_list,
    STATE(1255), 1,
      sym_type_arguments,
    ACTIONS(1169), 2,
      anon_sym_AMP,
      anon_sym_SLASH,
    ACTIONS(1173), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1167), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
    ACTIONS(1171), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(1161), 5,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
  [45217] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(561), 1,
      sym_identifier,
    ACTIONS(572), 1,
      anon_sym_func,
    ACTIONS(585), 1,
      anon_sym_map,
    ACTIONS(587), 1,
      anon_sym_chan,
    ACTIONS(589), 1,
      anon_sym_LT_DASH,
    ACTIONS(974), 1,
      anon_sym_LBRACK,
    ACTIONS(976), 1,
      anon_sym_STAR,
    ACTIONS(1042), 1,
      anon_sym_LPAREN,
    ACTIONS(1423), 1,
      anon_sym_RBRACK,
    STATE(848), 2,
      sym_negated_type,
      sym_qualified_type,
    STATE(1139), 2,
      sym_parenthesized_type,
      sym__simple_type,
    STATE(858), 9,
      sym_generic_type,
      sym_pointer_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_interface_type,
      sym_map_type,
      sym_channel_type,
      sym_function_type,
  [45276] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(561), 1,
      sym_identifier,
    ACTIONS(572), 1,
      anon_sym_func,
    ACTIONS(585), 1,
      anon_sym_map,
    ACTIONS(587), 1,
      anon_sym_chan,
    ACTIONS(589), 1,
      anon_sym_LT_DASH,
    ACTIONS(974), 1,
      anon_sym_LBRACK,
    ACTIONS(976), 1,
      anon_sym_STAR,
    ACTIONS(1042), 1,
      anon_sym_LPAREN,
    ACTIONS(1425), 1,
      anon_sym_RBRACK,
    STATE(848), 2,
      sym_negated_type,
      sym_qualified_type,
    STATE(1139), 2,
      sym_parenthesized_type,
      sym__simple_type,
    STATE(858), 9,
      sym_generic_type,
      sym_pointer_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_interface_type,
      sym_map_type,
      sym_channel_type,
      sym_function_type,
  [45335] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(924), 1,
      anon_sym_LPAREN,
    ACTIONS(926), 1,
      anon_sym_LBRACK,
    ACTIONS(978), 1,
      anon_sym_DOT,
    ACTIONS(984), 1,
      anon_sym_PIPE,
    ACTIONS(992), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1109), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1427), 1,
      anon_sym_RBRACK,
    STATE(397), 1,
      sym_argument_list,
    STATE(1255), 1,
      sym_type_arguments,
    ACTIONS(982), 2,
      anon_sym_AMP,
      anon_sym_SLASH,
    ACTIONS(990), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(986), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
    ACTIONS(988), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(980), 5,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
  [45392] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(924), 1,
      anon_sym_LPAREN,
    ACTIONS(926), 1,
      anon_sym_LBRACK,
    ACTIONS(978), 1,
      anon_sym_DOT,
    ACTIONS(984), 1,
      anon_sym_PIPE,
    ACTIONS(992), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1109), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1429), 1,
      anon_sym_RBRACK,
    STATE(397), 1,
      sym_argument_list,
    STATE(1255), 1,
      sym_type_arguments,
    ACTIONS(982), 2,
      anon_sym_AMP,
      anon_sym_SLASH,
    ACTIONS(990), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(986), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
    ACTIONS(988), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(980), 5,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
  [45449] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(924), 1,
      anon_sym_LPAREN,
    ACTIONS(926), 1,
      anon_sym_LBRACK,
    ACTIONS(978), 1,
      anon_sym_DOT,
    ACTIONS(984), 1,
      anon_sym_PIPE,
    ACTIONS(992), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1109), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1431), 1,
      anon_sym_RBRACK,
    STATE(397), 1,
      sym_argument_list,
    STATE(1255), 1,
      sym_type_arguments,
    ACTIONS(982), 2,
      anon_sym_AMP,
      anon_sym_SLASH,
    ACTIONS(990), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(986), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
    ACTIONS(988), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(980), 5,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
  [45506] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(561), 1,
      sym_identifier,
    ACTIONS(572), 1,
      anon_sym_func,
    ACTIONS(585), 1,
      anon_sym_map,
    ACTIONS(587), 1,
      anon_sym_chan,
    ACTIONS(589), 1,
      anon_sym_LT_DASH,
    ACTIONS(974), 1,
      anon_sym_LBRACK,
    ACTIONS(976), 1,
      anon_sym_STAR,
    ACTIONS(1042), 1,
      anon_sym_LPAREN,
    ACTIONS(1433), 1,
      anon_sym_type,
    STATE(848), 2,
      sym_negated_type,
      sym_qualified_type,
    STATE(1326), 2,
      sym_parenthesized_type,
      sym__simple_type,
    STATE(858), 9,
      sym_generic_type,
      sym_pointer_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_interface_type,
      sym_map_type,
      sym_channel_type,
      sym_function_type,
  [45565] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(924), 1,
      anon_sym_LPAREN,
    ACTIONS(926), 1,
      anon_sym_LBRACK,
    ACTIONS(978), 1,
      anon_sym_DOT,
    ACTIONS(1141), 1,
      anon_sym_PIPE,
    ACTIONS(1151), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1153), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1435), 1,
      anon_sym_RPAREN,
    STATE(397), 1,
      sym_argument_list,
    STATE(1255), 1,
      sym_type_arguments,
    ACTIONS(1145), 2,
      anon_sym_AMP,
      anon_sym_SLASH,
    ACTIONS(1149), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1143), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
    ACTIONS(1147), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(1139), 5,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
  [45622] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(924), 1,
      anon_sym_LPAREN,
    ACTIONS(926), 1,
      anon_sym_LBRACK,
    ACTIONS(978), 1,
      anon_sym_DOT,
    ACTIONS(984), 1,
      anon_sym_PIPE,
    ACTIONS(992), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1109), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1437), 1,
      anon_sym_RBRACK,
    STATE(397), 1,
      sym_argument_list,
    STATE(1255), 1,
      sym_type_arguments,
    ACTIONS(982), 2,
      anon_sym_AMP,
      anon_sym_SLASH,
    ACTIONS(990), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(986), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
    ACTIONS(988), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(980), 5,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
  [45679] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(561), 1,
      sym_identifier,
    ACTIONS(572), 1,
      anon_sym_func,
    ACTIONS(585), 1,
      anon_sym_map,
    ACTIONS(587), 1,
      anon_sym_chan,
    ACTIONS(589), 1,
      anon_sym_LT_DASH,
    ACTIONS(974), 1,
      anon_sym_LBRACK,
    ACTIONS(976), 1,
      anon_sym_STAR,
    ACTIONS(1042), 1,
      anon_sym_LPAREN,
    ACTIONS(1439), 1,
      anon_sym_RPAREN,
    STATE(848), 2,
      sym_negated_type,
      sym_qualified_type,
    STATE(1160), 2,
      sym_parenthesized_type,
      sym__simple_type,
    STATE(858), 9,
      sym_generic_type,
      sym_pointer_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_interface_type,
      sym_map_type,
      sym_channel_type,
      sym_function_type,
  [45738] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(561), 1,
      sym_identifier,
    ACTIONS(572), 1,
      anon_sym_func,
    ACTIONS(585), 1,
      anon_sym_map,
    ACTIONS(587), 1,
      anon_sym_chan,
    ACTIONS(589), 1,
      anon_sym_LT_DASH,
    ACTIONS(974), 1,
      anon_sym_LBRACK,
    ACTIONS(976), 1,
      anon_sym_STAR,
    ACTIONS(1042), 1,
      anon_sym_LPAREN,
    ACTIONS(1441), 1,
      anon_sym_RBRACK,
    STATE(848), 2,
      sym_negated_type,
      sym_qualified_type,
    STATE(1139), 2,
      sym_parenthesized_type,
      sym__simple_type,
    STATE(858), 9,
      sym_generic_type,
      sym_pointer_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_interface_type,
      sym_map_type,
      sym_channel_type,
      sym_function_type,
  [45797] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(561), 1,
      sym_identifier,
    ACTIONS(572), 1,
      anon_sym_func,
    ACTIONS(585), 1,
      anon_sym_map,
    ACTIONS(587), 1,
      anon_sym_chan,
    ACTIONS(589), 1,
      anon_sym_LT_DASH,
    ACTIONS(974), 1,
      anon_sym_LBRACK,
    ACTIONS(976), 1,
      anon_sym_STAR,
    ACTIONS(1042), 1,
      anon_sym_LPAREN,
    ACTIONS(1443), 1,
      anon_sym_RBRACK,
    STATE(848), 2,
      sym_negated_type,
      sym_qualified_type,
    STATE(1139), 2,
      sym_parenthesized_type,
      sym__simple_type,
    STATE(858), 9,
      sym_generic_type,
      sym_pointer_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_interface_type,
      sym_map_type,
      sym_channel_type,
      sym_function_type,
  [45856] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(924), 1,
      anon_sym_LPAREN,
    ACTIONS(926), 1,
      anon_sym_LBRACK,
    ACTIONS(978), 1,
      anon_sym_DOT,
    ACTIONS(984), 1,
      anon_sym_PIPE,
    ACTIONS(992), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1109), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1445), 1,
      anon_sym_RBRACK,
    STATE(397), 1,
      sym_argument_list,
    STATE(1255), 1,
      sym_type_arguments,
    ACTIONS(982), 2,
      anon_sym_AMP,
      anon_sym_SLASH,
    ACTIONS(990), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(986), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
    ACTIONS(988), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(980), 5,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
  [45913] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(924), 1,
      anon_sym_LPAREN,
    ACTIONS(926), 1,
      anon_sym_LBRACK,
    ACTIONS(978), 1,
      anon_sym_DOT,
    ACTIONS(984), 1,
      anon_sym_PIPE,
    ACTIONS(992), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1109), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1447), 1,
      anon_sym_RBRACK,
    STATE(397), 1,
      sym_argument_list,
    STATE(1255), 1,
      sym_type_arguments,
    ACTIONS(982), 2,
      anon_sym_AMP,
      anon_sym_SLASH,
    ACTIONS(990), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(986), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
    ACTIONS(988), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(980), 5,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
  [45970] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(924), 1,
      anon_sym_LPAREN,
    ACTIONS(926), 1,
      anon_sym_LBRACK,
    ACTIONS(978), 1,
      anon_sym_DOT,
    ACTIONS(1141), 1,
      anon_sym_PIPE,
    ACTIONS(1151), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1153), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1449), 1,
      anon_sym_RPAREN,
    STATE(397), 1,
      sym_argument_list,
    STATE(1255), 1,
      sym_type_arguments,
    ACTIONS(1145), 2,
      anon_sym_AMP,
      anon_sym_SLASH,
    ACTIONS(1149), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1143), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
    ACTIONS(1147), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(1139), 5,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
  [46027] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(561), 1,
      sym_identifier,
    ACTIONS(572), 1,
      anon_sym_func,
    ACTIONS(585), 1,
      anon_sym_map,
    ACTIONS(587), 1,
      anon_sym_chan,
    ACTIONS(589), 1,
      anon_sym_LT_DASH,
    ACTIONS(974), 1,
      anon_sym_LBRACK,
    ACTIONS(976), 1,
      anon_sym_STAR,
    ACTIONS(1042), 1,
      anon_sym_LPAREN,
    ACTIONS(1451), 1,
      anon_sym_RPAREN,
    STATE(848), 2,
      sym_negated_type,
      sym_qualified_type,
    STATE(1177), 2,
      sym_parenthesized_type,
      sym__simple_type,
    STATE(858), 9,
      sym_generic_type,
      sym_pointer_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_interface_type,
      sym_map_type,
      sym_channel_type,
      sym_function_type,
  [46086] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(561), 1,
      sym_identifier,
    ACTIONS(572), 1,
      anon_sym_func,
    ACTIONS(585), 1,
      anon_sym_map,
    ACTIONS(587), 1,
      anon_sym_chan,
    ACTIONS(589), 1,
      anon_sym_LT_DASH,
    ACTIONS(974), 1,
      anon_sym_LBRACK,
    ACTIONS(976), 1,
      anon_sym_STAR,
    ACTIONS(1042), 1,
      anon_sym_LPAREN,
    ACTIONS(1453), 1,
      anon_sym_RBRACK,
    STATE(848), 2,
      sym_negated_type,
      sym_qualified_type,
    STATE(1139), 2,
      sym_parenthesized_type,
      sym__simple_type,
    STATE(858), 9,
      sym_generic_type,
      sym_pointer_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_interface_type,
      sym_map_type,
      sym_channel_type,
      sym_function_type,
  [46145] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(561), 1,
      sym_identifier,
    ACTIONS(572), 1,
      anon_sym_func,
    ACTIONS(585), 1,
      anon_sym_map,
    ACTIONS(587), 1,
      anon_sym_chan,
    ACTIONS(589), 1,
      anon_sym_LT_DASH,
    ACTIONS(974), 1,
      anon_sym_LBRACK,
    ACTIONS(976), 1,
      anon_sym_STAR,
    ACTIONS(1042), 1,
      anon_sym_LPAREN,
    ACTIONS(1455), 1,
      anon_sym_RBRACK,
    STATE(848), 2,
      sym_negated_type,
      sym_qualified_type,
    STATE(1139), 2,
      sym_parenthesized_type,
      sym__simple_type,
    STATE(858), 9,
      sym_generic_type,
      sym_pointer_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_interface_type,
      sym_map_type,
      sym_channel_type,
      sym_function_type,
  [46204] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(924), 1,
      anon_sym_LPAREN,
    ACTIONS(926), 1,
      anon_sym_LBRACK,
    ACTIONS(978), 1,
      anon_sym_DOT,
    ACTIONS(984), 1,
      anon_sym_PIPE,
    ACTIONS(992), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1109), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1457), 1,
      anon_sym_RBRACK,
    STATE(397), 1,
      sym_argument_list,
    STATE(1255), 1,
      sym_type_arguments,
    ACTIONS(982), 2,
      anon_sym_AMP,
      anon_sym_SLASH,
    ACTIONS(990), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(986), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
    ACTIONS(988), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(980), 5,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
  [46261] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(924), 1,
      anon_sym_LPAREN,
    ACTIONS(926), 1,
      anon_sym_LBRACK,
    ACTIONS(978), 1,
      anon_sym_DOT,
    ACTIONS(984), 1,
      anon_sym_PIPE,
    ACTIONS(992), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1109), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1459), 1,
      anon_sym_RBRACK,
    STATE(397), 1,
      sym_argument_list,
    STATE(1255), 1,
      sym_type_arguments,
    ACTIONS(982), 2,
      anon_sym_AMP,
      anon_sym_SLASH,
    ACTIONS(990), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(986), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
    ACTIONS(988), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(980), 5,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
  [46318] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(924), 1,
      anon_sym_LPAREN,
    ACTIONS(926), 1,
      anon_sym_LBRACK,
    ACTIONS(978), 1,
      anon_sym_DOT,
    ACTIONS(1141), 1,
      anon_sym_PIPE,
    ACTIONS(1151), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1153), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1461), 1,
      anon_sym_RPAREN,
    STATE(397), 1,
      sym_argument_list,
    STATE(1255), 1,
      sym_type_arguments,
    ACTIONS(1145), 2,
      anon_sym_AMP,
      anon_sym_SLASH,
    ACTIONS(1149), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1143), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
    ACTIONS(1147), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(1139), 5,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
  [46375] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(924), 1,
      anon_sym_LPAREN,
    ACTIONS(926), 1,
      anon_sym_LBRACK,
    ACTIONS(978), 1,
      anon_sym_DOT,
    ACTIONS(984), 1,
      anon_sym_PIPE,
    ACTIONS(992), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1109), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1463), 1,
      anon_sym_RBRACK,
    STATE(397), 1,
      sym_argument_list,
    STATE(1255), 1,
      sym_type_arguments,
    ACTIONS(982), 2,
      anon_sym_AMP,
      anon_sym_SLASH,
    ACTIONS(990), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(986), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
    ACTIONS(988), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(980), 5,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
  [46432] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(561), 1,
      sym_identifier,
    ACTIONS(572), 1,
      anon_sym_func,
    ACTIONS(585), 1,
      anon_sym_map,
    ACTIONS(587), 1,
      anon_sym_chan,
    ACTIONS(589), 1,
      anon_sym_LT_DASH,
    ACTIONS(974), 1,
      anon_sym_LBRACK,
    ACTIONS(976), 1,
      anon_sym_STAR,
    ACTIONS(1042), 1,
      anon_sym_LPAREN,
    ACTIONS(1465), 1,
      anon_sym_RPAREN,
    STATE(848), 2,
      sym_negated_type,
      sym_qualified_type,
    STATE(1193), 2,
      sym_parenthesized_type,
      sym__simple_type,
    STATE(858), 9,
      sym_generic_type,
      sym_pointer_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_interface_type,
      sym_map_type,
      sym_channel_type,
      sym_function_type,
  [46491] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(561), 1,
      sym_identifier,
    ACTIONS(572), 1,
      anon_sym_func,
    ACTIONS(585), 1,
      anon_sym_map,
    ACTIONS(587), 1,
      anon_sym_chan,
    ACTIONS(589), 1,
      anon_sym_LT_DASH,
    ACTIONS(974), 1,
      anon_sym_LBRACK,
    ACTIONS(976), 1,
      anon_sym_STAR,
    ACTIONS(1042), 1,
      anon_sym_LPAREN,
    ACTIONS(1467), 1,
      anon_sym_RBRACK,
    STATE(848), 2,
      sym_negated_type,
      sym_qualified_type,
    STATE(1139), 2,
      sym_parenthesized_type,
      sym__simple_type,
    STATE(858), 9,
      sym_generic_type,
      sym_pointer_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_interface_type,
      sym_map_type,
      sym_channel_type,
      sym_function_type,
  [46550] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(561), 1,
      sym_identifier,
    ACTIONS(572), 1,
      anon_sym_func,
    ACTIONS(585), 1,
      anon_sym_map,
    ACTIONS(587), 1,
      anon_sym_chan,
    ACTIONS(589), 1,
      anon_sym_LT_DASH,
    ACTIONS(974), 1,
      anon_sym_LBRACK,
    ACTIONS(976), 1,
      anon_sym_STAR,
    ACTIONS(1042), 1,
      anon_sym_LPAREN,
    ACTIONS(1469), 1,
      anon_sym_RBRACK,
    STATE(848), 2,
      sym_negated_type,
      sym_qualified_type,
    STATE(1139), 2,
      sym_parenthesized_type,
      sym__simple_type,
    STATE(858), 9,
      sym_generic_type,
      sym_pointer_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_interface_type,
      sym_map_type,
      sym_channel_type,
      sym_function_type,
  [46609] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(924), 1,
      anon_sym_LPAREN,
    ACTIONS(926), 1,
      anon_sym_LBRACK,
    ACTIONS(978), 1,
      anon_sym_DOT,
    ACTIONS(984), 1,
      anon_sym_PIPE,
    ACTIONS(992), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1109), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1471), 1,
      anon_sym_RBRACK,
    STATE(397), 1,
      sym_argument_list,
    STATE(1255), 1,
      sym_type_arguments,
    ACTIONS(982), 2,
      anon_sym_AMP,
      anon_sym_SLASH,
    ACTIONS(990), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(986), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
    ACTIONS(988), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(980), 5,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
  [46666] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(924), 1,
      anon_sym_LPAREN,
    ACTIONS(926), 1,
      anon_sym_LBRACK,
    ACTIONS(978), 1,
      anon_sym_DOT,
    ACTIONS(984), 1,
      anon_sym_PIPE,
    ACTIONS(992), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1109), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1473), 1,
      anon_sym_RBRACK,
    STATE(397), 1,
      sym_argument_list,
    STATE(1255), 1,
      sym_type_arguments,
    ACTIONS(982), 2,
      anon_sym_AMP,
      anon_sym_SLASH,
    ACTIONS(990), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(986), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
    ACTIONS(988), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(980), 5,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
  [46723] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(924), 1,
      anon_sym_LPAREN,
    ACTIONS(926), 1,
      anon_sym_LBRACK,
    ACTIONS(978), 1,
      anon_sym_DOT,
    ACTIONS(984), 1,
      anon_sym_PIPE,
    ACTIONS(992), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1109), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1475), 1,
      anon_sym_RBRACK,
    STATE(397), 1,
      sym_argument_list,
    STATE(1255), 1,
      sym_type_arguments,
    ACTIONS(982), 2,
      anon_sym_AMP,
      anon_sym_SLASH,
    ACTIONS(990), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(986), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
    ACTIONS(988), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(980), 5,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
  [46780] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(561), 1,
      sym_identifier,
    ACTIONS(572), 1,
      anon_sym_func,
    ACTIONS(585), 1,
      anon_sym_map,
    ACTIONS(587), 1,
      anon_sym_chan,
    ACTIONS(589), 1,
      anon_sym_LT_DASH,
    ACTIONS(974), 1,
      anon_sym_LBRACK,
    ACTIONS(976), 1,
      anon_sym_STAR,
    ACTIONS(1042), 1,
      anon_sym_LPAREN,
    STATE(1208), 1,
      sym_type_elem,
    STATE(848), 2,
      sym_negated_type,
      sym_qualified_type,
    STATE(1117), 2,
      sym_parenthesized_type,
      sym__simple_type,
    STATE(858), 9,
      sym_generic_type,
      sym_pointer_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_interface_type,
      sym_map_type,
      sym_channel_type,
      sym_function_type,
  [46839] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(561), 1,
      sym_identifier,
    ACTIONS(572), 1,
      anon_sym_func,
    ACTIONS(585), 1,
      anon_sym_map,
    ACTIONS(587), 1,
      anon_sym_chan,
    ACTIONS(589), 1,
      anon_sym_LT_DASH,
    ACTIONS(974), 1,
      anon_sym_LBRACK,
    ACTIONS(976), 1,
      anon_sym_STAR,
    ACTIONS(1042), 1,
      anon_sym_LPAREN,
    STATE(1222), 1,
      sym_type_elem,
    STATE(848), 2,
      sym_negated_type,
      sym_qualified_type,
    STATE(1117), 2,
      sym_parenthesized_type,
      sym__simple_type,
    STATE(858), 9,
      sym_generic_type,
      sym_pointer_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_interface_type,
      sym_map_type,
      sym_channel_type,
      sym_function_type,
  [46898] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(924), 1,
      anon_sym_LPAREN,
    ACTIONS(926), 1,
      anon_sym_LBRACK,
    ACTIONS(978), 1,
      anon_sym_DOT,
    ACTIONS(984), 1,
      anon_sym_PIPE,
    ACTIONS(992), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1109), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1477), 1,
      anon_sym_SEMI,
    STATE(397), 1,
      sym_argument_list,
    STATE(1255), 1,
      sym_type_arguments,
    ACTIONS(982), 2,
      anon_sym_AMP,
      anon_sym_SLASH,
    ACTIONS(990), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(986), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
    ACTIONS(988), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(980), 5,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
  [46955] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(924), 1,
      anon_sym_LPAREN,
    ACTIONS(926), 1,
      anon_sym_LBRACK,
    ACTIONS(978), 1,
      anon_sym_DOT,
    ACTIONS(984), 1,
      anon_sym_PIPE,
    ACTIONS(992), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1109), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1479), 1,
      anon_sym_RBRACK,
    STATE(397), 1,
      sym_argument_list,
    STATE(1255), 1,
      sym_type_arguments,
    ACTIONS(982), 2,
      anon_sym_AMP,
      anon_sym_SLASH,
    ACTIONS(990), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(986), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
    ACTIONS(988), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(980), 5,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
  [47012] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(994), 1,
      sym_identifier,
    ACTIONS(996), 1,
      anon_sym_func,
    ACTIONS(998), 1,
      anon_sym_LBRACK,
    ACTIONS(1000), 1,
      anon_sym_STAR,
    ACTIONS(1002), 1,
      anon_sym_LT_DASH,
    ACTIONS(1042), 1,
      anon_sym_LPAREN,
    STATE(836), 2,
      sym_negated_type,
      sym_qualified_type,
    STATE(846), 2,
      sym_parenthesized_type,
      sym__simple_type,
    STATE(858), 9,
      sym_generic_type,
      sym_pointer_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_interface_type,
      sym_map_type,
      sym_channel_type,
      sym_function_type,
  [47068] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(561), 1,
      sym_identifier,
    ACTIONS(572), 1,
      anon_sym_func,
    ACTIONS(585), 1,
      anon_sym_map,
    ACTIONS(587), 1,
      anon_sym_chan,
    ACTIONS(589), 1,
      anon_sym_LT_DASH,
    ACTIONS(974), 1,
      anon_sym_LBRACK,
    ACTIONS(976), 1,
      anon_sym_STAR,
    ACTIONS(1042), 1,
      anon_sym_LPAREN,
    STATE(848), 2,
      sym_negated_type,
      sym_qualified_type,
    STATE(1318), 2,
      sym_parenthesized_type,
      sym__simple_type,
    STATE(858), 9,
      sym_generic_type,
      sym_pointer_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_interface_type,
      sym_map_type,
      sym_channel_type,
      sym_function_type,
  [47124] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(866), 1,
      sym_identifier,
    ACTIONS(874), 1,
      anon_sym_func,
    ACTIONS(880), 1,
      anon_sym_struct,
    ACTIONS(884), 1,
      anon_sym_interface,
    ACTIONS(886), 1,
      anon_sym_map,
    ACTIONS(888), 1,
      anon_sym_chan,
    ACTIONS(1213), 1,
      anon_sym_LPAREN,
    ACTIONS(1219), 1,
      anon_sym_TILDE,
    ACTIONS(1481), 1,
      anon_sym_LBRACK,
    ACTIONS(1483), 1,
      anon_sym_STAR,
    ACTIONS(1485), 1,
      anon_sym_LT_DASH,
    STATE(796), 2,
      sym_negated_type,
      sym_qualified_type,
    STATE(810), 2,
      sym_parenthesized_type,
      sym__simple_type,
    STATE(807), 9,
      sym_generic_type,
      sym_pointer_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_interface_type,
      sym_map_type,
      sym_channel_type,
      sym_function_type,
  [47180] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(880), 1,
      anon_sym_struct,
    ACTIONS(884), 1,
      anon_sym_interface,
    ACTIONS(892), 1,
      sym_identifier,
    ACTIONS(904), 1,
      anon_sym_func,
    ACTIONS(910), 1,
      anon_sym_map,
    ACTIONS(912), 1,
      anon_sym_chan,
    ACTIONS(1213), 1,
      anon_sym_LPAREN,
    ACTIONS(1215), 1,
      anon_sym_LBRACK,
    ACTIONS(1217), 1,
      anon_sym_STAR,
    ACTIONS(1219), 1,
      anon_sym_TILDE,
    ACTIONS(1223), 1,
      anon_sym_LT_DASH,
    STATE(799), 2,
      sym_negated_type,
      sym_qualified_type,
    STATE(1045), 2,
      sym_parenthesized_type,
      sym__simple_type,
    STATE(807), 9,
      sym_generic_type,
      sym_pointer_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_interface_type,
      sym_map_type,
      sym_channel_type,
      sym_function_type,
  [47236] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(994), 1,
      sym_identifier,
    ACTIONS(996), 1,
      anon_sym_func,
    ACTIONS(998), 1,
      anon_sym_LBRACK,
    ACTIONS(1000), 1,
      anon_sym_STAR,
    ACTIONS(1002), 1,
      anon_sym_LT_DASH,
    ACTIONS(1042), 1,
      anon_sym_LPAREN,
    STATE(836), 2,
      sym_negated_type,
      sym_qualified_type,
    STATE(852), 2,
      sym_parenthesized_type,
      sym__simple_type,
    STATE(858), 9,
      sym_generic_type,
      sym_pointer_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_interface_type,
      sym_map_type,
      sym_channel_type,
      sym_function_type,
  [47292] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1063), 1,
      sym_identifier,
    ACTIONS(1069), 1,
      anon_sym_func,
    ACTIONS(1075), 1,
      anon_sym_struct,
    ACTIONS(1081), 1,
      anon_sym_interface,
    ACTIONS(1083), 1,
      anon_sym_map,
    ACTIONS(1487), 1,
      anon_sym_LPAREN,
    ACTIONS(1489), 1,
      anon_sym_LBRACK,
    ACTIONS(1491), 1,
      anon_sym_STAR,
    ACTIONS(1493), 1,
      anon_sym_TILDE,
    ACTIONS(1495), 1,
      anon_sym_chan,
    ACTIONS(1497), 1,
      anon_sym_LT_DASH,
    STATE(910), 2,
      sym_negated_type,
      sym_qualified_type,
    STATE(1000), 2,
      sym_parenthesized_type,
      sym__simple_type,
    STATE(950), 9,
      sym_generic_type,
      sym_pointer_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_interface_type,
      sym_map_type,
      sym_channel_type,
      sym_function_type,
  [47348] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1063), 1,
      sym_identifier,
    ACTIONS(1069), 1,
      anon_sym_func,
    ACTIONS(1075), 1,
      anon_sym_struct,
    ACTIONS(1081), 1,
      anon_sym_interface,
    ACTIONS(1083), 1,
      anon_sym_map,
    ACTIONS(1085), 1,
      anon_sym_chan,
    ACTIONS(1487), 1,
      anon_sym_LPAREN,
    ACTIONS(1489), 1,
      anon_sym_LBRACK,
    ACTIONS(1491), 1,
      anon_sym_STAR,
    ACTIONS(1493), 1,
      anon_sym_TILDE,
    ACTIONS(1499), 1,
      anon_sym_LT_DASH,
    STATE(910), 2,
      sym_negated_type,
      sym_qualified_type,
    STATE(1001), 2,
      sym_parenthesized_type,
      sym__simple_type,
    STATE(950), 9,
      sym_generic_type,
      sym_pointer_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_interface_type,
      sym_map_type,
      sym_channel_type,
      sym_function_type,
  [47404] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(561), 1,
      sym_identifier,
    ACTIONS(572), 1,
      anon_sym_func,
    ACTIONS(585), 1,
      anon_sym_map,
    ACTIONS(587), 1,
      anon_sym_chan,
    ACTIONS(589), 1,
      anon_sym_LT_DASH,
    ACTIONS(974), 1,
      anon_sym_LBRACK,
    ACTIONS(976), 1,
      anon_sym_STAR,
    ACTIONS(1042), 1,
      anon_sym_LPAREN,
    STATE(848), 2,
      sym_negated_type,
      sym_qualified_type,
    STATE(1134), 2,
      sym_parenthesized_type,
      sym__simple_type,
    STATE(858), 9,
      sym_generic_type,
      sym_pointer_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_interface_type,
      sym_map_type,
      sym_channel_type,
      sym_function_type,
  [47460] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1063), 1,
      sym_identifier,
    ACTIONS(1069), 1,
      anon_sym_func,
    ACTIONS(1075), 1,
      anon_sym_struct,
    ACTIONS(1081), 1,
      anon_sym_interface,
    ACTIONS(1083), 1,
      anon_sym_map,
    ACTIONS(1085), 1,
      anon_sym_chan,
    ACTIONS(1487), 1,
      anon_sym_LPAREN,
    ACTIONS(1489), 1,
      anon_sym_LBRACK,
    ACTIONS(1491), 1,
      anon_sym_STAR,
    ACTIONS(1493), 1,
      anon_sym_TILDE,
    ACTIONS(1497), 1,
      anon_sym_LT_DASH,
    STATE(910), 2,
      sym_negated_type,
      sym_qualified_type,
    STATE(917), 2,
      sym_parenthesized_type,
      sym__simple_type,
    STATE(950), 9,
      sym_generic_type,
      sym_pointer_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_interface_type,
      sym_map_type,
      sym_channel_type,
      sym_function_type,
  [47516] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1063), 1,
      sym_identifier,
    ACTIONS(1069), 1,
      anon_sym_func,
    ACTIONS(1075), 1,
      anon_sym_struct,
    ACTIONS(1081), 1,
      anon_sym_interface,
    ACTIONS(1083), 1,
      anon_sym_map,
    ACTIONS(1085), 1,
      anon_sym_chan,
    ACTIONS(1487), 1,
      anon_sym_LPAREN,
    ACTIONS(1489), 1,
      anon_sym_LBRACK,
    ACTIONS(1491), 1,
      anon_sym_STAR,
    ACTIONS(1493), 1,
      anon_sym_TILDE,
    ACTIONS(1497), 1,
      anon_sym_LT_DASH,
    STATE(910), 2,
      sym_negated_type,
      sym_qualified_type,
    STATE(920), 2,
      sym_parenthesized_type,
      sym__simple_type,
    STATE(950), 9,
      sym_generic_type,
      sym_pointer_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_interface_type,
      sym_map_type,
      sym_channel_type,
      sym_function_type,
  [47572] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(994), 1,
      sym_identifier,
    ACTIONS(996), 1,
      anon_sym_func,
    ACTIONS(998), 1,
      anon_sym_LBRACK,
    ACTIONS(1000), 1,
      anon_sym_STAR,
    ACTIONS(1042), 1,
      anon_sym_LPAREN,
    ACTIONS(1501), 1,
      anon_sym_LT_DASH,
    STATE(836), 2,
      sym_negated_type,
      sym_qualified_type,
    STATE(850), 2,
      sym_parenthesized_type,
      sym__simple_type,
    STATE(858), 9,
      sym_generic_type,
      sym_pointer_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_interface_type,
      sym_map_type,
      sym_channel_type,
      sym_function_type,
  [47628] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(561), 1,
      sym_identifier,
    ACTIONS(572), 1,
      anon_sym_func,
    ACTIONS(585), 1,
      anon_sym_map,
    ACTIONS(587), 1,
      anon_sym_chan,
    ACTIONS(589), 1,
      anon_sym_LT_DASH,
    ACTIONS(974), 1,
      anon_sym_LBRACK,
    ACTIONS(976), 1,
      anon_sym_STAR,
    ACTIONS(1042), 1,
      anon_sym_LPAREN,
    STATE(848), 2,
      sym_negated_type,
      sym_qualified_type,
    STATE(1152), 2,
      sym_parenthesized_type,
      sym__simple_type,
    STATE(858), 9,
      sym_generic_type,
      sym_pointer_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_interface_type,
      sym_map_type,
      sym_channel_type,
      sym_function_type,
  [47684] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1063), 1,
      sym_identifier,
    ACTIONS(1069), 1,
      anon_sym_func,
    ACTIONS(1075), 1,
      anon_sym_struct,
    ACTIONS(1081), 1,
      anon_sym_interface,
    ACTIONS(1083), 1,
      anon_sym_map,
    ACTIONS(1085), 1,
      anon_sym_chan,
    ACTIONS(1487), 1,
      anon_sym_LPAREN,
    ACTIONS(1489), 1,
      anon_sym_LBRACK,
    ACTIONS(1491), 1,
      anon_sym_STAR,
    ACTIONS(1493), 1,
      anon_sym_TILDE,
    ACTIONS(1497), 1,
      anon_sym_LT_DASH,
    STATE(910), 2,
      sym_negated_type,
      sym_qualified_type,
    STATE(938), 2,
      sym_parenthesized_type,
      sym__simple_type,
    STATE(950), 9,
      sym_generic_type,
      sym_pointer_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_interface_type,
      sym_map_type,
      sym_channel_type,
      sym_function_type,
  [47740] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1075), 1,
      anon_sym_struct,
    ACTIONS(1081), 1,
      anon_sym_interface,
    ACTIONS(1115), 1,
      sym_identifier,
    ACTIONS(1117), 1,
      anon_sym_func,
    ACTIONS(1123), 1,
      anon_sym_map,
    ACTIONS(1487), 1,
      anon_sym_LPAREN,
    ACTIONS(1493), 1,
      anon_sym_TILDE,
    ACTIONS(1503), 1,
      anon_sym_LBRACK,
    ACTIONS(1505), 1,
      anon_sym_STAR,
    ACTIONS(1507), 1,
      anon_sym_chan,
    ACTIONS(1509), 1,
      anon_sym_LT_DASH,
    STATE(895), 2,
      sym_negated_type,
      sym_qualified_type,
    STATE(1000), 2,
      sym_parenthesized_type,
      sym__simple_type,
    STATE(950), 9,
      sym_generic_type,
      sym_pointer_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_interface_type,
      sym_map_type,
      sym_channel_type,
      sym_function_type,
  [47796] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1075), 1,
      anon_sym_struct,
    ACTIONS(1081), 1,
      anon_sym_interface,
    ACTIONS(1115), 1,
      sym_identifier,
    ACTIONS(1117), 1,
      anon_sym_func,
    ACTIONS(1123), 1,
      anon_sym_map,
    ACTIONS(1125), 1,
      anon_sym_chan,
    ACTIONS(1487), 1,
      anon_sym_LPAREN,
    ACTIONS(1493), 1,
      anon_sym_TILDE,
    ACTIONS(1503), 1,
      anon_sym_LBRACK,
    ACTIONS(1505), 1,
      anon_sym_STAR,
    ACTIONS(1511), 1,
      anon_sym_LT_DASH,
    STATE(895), 2,
      sym_negated_type,
      sym_qualified_type,
    STATE(1001), 2,
      sym_parenthesized_type,
      sym__simple_type,
    STATE(950), 9,
      sym_generic_type,
      sym_pointer_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_interface_type,
      sym_map_type,
      sym_channel_type,
      sym_function_type,
  [47852] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1075), 1,
      anon_sym_struct,
    ACTIONS(1081), 1,
      anon_sym_interface,
    ACTIONS(1115), 1,
      sym_identifier,
    ACTIONS(1117), 1,
      anon_sym_func,
    ACTIONS(1123), 1,
      anon_sym_map,
    ACTIONS(1125), 1,
      anon_sym_chan,
    ACTIONS(1487), 1,
      anon_sym_LPAREN,
    ACTIONS(1493), 1,
      anon_sym_TILDE,
    ACTIONS(1503), 1,
      anon_sym_LBRACK,
    ACTIONS(1505), 1,
      anon_sym_STAR,
    ACTIONS(1509), 1,
      anon_sym_LT_DASH,
    STATE(895), 2,
      sym_negated_type,
      sym_qualified_type,
    STATE(917), 2,
      sym_parenthesized_type,
      sym__simple_type,
    STATE(950), 9,
      sym_generic_type,
      sym_pointer_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_interface_type,
      sym_map_type,
      sym_channel_type,
      sym_function_type,
  [47908] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1075), 1,
      anon_sym_struct,
    ACTIONS(1081), 1,
      anon_sym_interface,
    ACTIONS(1115), 1,
      sym_identifier,
    ACTIONS(1117), 1,
      anon_sym_func,
    ACTIONS(1123), 1,
      anon_sym_map,
    ACTIONS(1125), 1,
      anon_sym_chan,
    ACTIONS(1487), 1,
      anon_sym_LPAREN,
    ACTIONS(1493), 1,
      anon_sym_TILDE,
    ACTIONS(1503), 1,
      anon_sym_LBRACK,
    ACTIONS(1505), 1,
      anon_sym_STAR,
    ACTIONS(1509), 1,
      anon_sym_LT_DASH,
    STATE(895), 2,
      sym_negated_type,
      sym_qualified_type,
    STATE(920), 2,
      sym_parenthesized_type,
      sym__simple_type,
    STATE(950), 9,
      sym_generic_type,
      sym_pointer_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_interface_type,
      sym_map_type,
      sym_channel_type,
      sym_function_type,
  [47964] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1075), 1,
      anon_sym_struct,
    ACTIONS(1081), 1,
      anon_sym_interface,
    ACTIONS(1115), 1,
      sym_identifier,
    ACTIONS(1117), 1,
      anon_sym_func,
    ACTIONS(1123), 1,
      anon_sym_map,
    ACTIONS(1125), 1,
      anon_sym_chan,
    ACTIONS(1487), 1,
      anon_sym_LPAREN,
    ACTIONS(1493), 1,
      anon_sym_TILDE,
    ACTIONS(1503), 1,
      anon_sym_LBRACK,
    ACTIONS(1505), 1,
      anon_sym_STAR,
    ACTIONS(1509), 1,
      anon_sym_LT_DASH,
    STATE(895), 2,
      sym_negated_type,
      sym_qualified_type,
    STATE(938), 2,
      sym_parenthesized_type,
      sym__simple_type,
    STATE(950), 9,
      sym_generic_type,
      sym_pointer_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_interface_type,
      sym_map_type,
      sym_channel_type,
      sym_function_type,
  [48020] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(866), 1,
      sym_identifier,
    ACTIONS(874), 1,
      anon_sym_func,
    ACTIONS(880), 1,
      anon_sym_struct,
    ACTIONS(884), 1,
      anon_sym_interface,
    ACTIONS(886), 1,
      anon_sym_map,
    ACTIONS(888), 1,
      anon_sym_chan,
    ACTIONS(1213), 1,
      anon_sym_LPAREN,
    ACTIONS(1219), 1,
      anon_sym_TILDE,
    ACTIONS(1481), 1,
      anon_sym_LBRACK,
    ACTIONS(1483), 1,
      anon_sym_STAR,
    ACTIONS(1485), 1,
      anon_sym_LT_DASH,
    STATE(796), 2,
      sym_negated_type,
      sym_qualified_type,
    STATE(809), 2,
      sym_parenthesized_type,
      sym__simple_type,
    STATE(807), 9,
      sym_generic_type,
      sym_pointer_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_interface_type,
      sym_map_type,
      sym_channel_type,
      sym_function_type,
  [48076] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(561), 1,
      sym_identifier,
    ACTIONS(572), 1,
      anon_sym_func,
    ACTIONS(585), 1,
      anon_sym_map,
    ACTIONS(587), 1,
      anon_sym_chan,
    ACTIONS(974), 1,
      anon_sym_LBRACK,
    ACTIONS(976), 1,
      anon_sym_STAR,
    ACTIONS(1042), 1,
      anon_sym_LPAREN,
    ACTIONS(1513), 1,
      anon_sym_LT_DASH,
    STATE(848), 2,
      sym_negated_type,
      sym_qualified_type,
    STATE(850), 2,
      sym_parenthesized_type,
      sym__simple_type,
    STATE(858), 9,
      sym_generic_type,
      sym_pointer_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_interface_type,
      sym_map_type,
      sym_channel_type,
      sym_function_type,
  [48132] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(561), 1,
      sym_identifier,
    ACTIONS(572), 1,
      anon_sym_func,
    ACTIONS(585), 1,
      anon_sym_map,
    ACTIONS(587), 1,
      anon_sym_chan,
    ACTIONS(589), 1,
      anon_sym_LT_DASH,
    ACTIONS(974), 1,
      anon_sym_LBRACK,
    ACTIONS(976), 1,
      anon_sym_STAR,
    ACTIONS(1042), 1,
      anon_sym_LPAREN,
    STATE(848), 2,
      sym_negated_type,
      sym_qualified_type,
    STATE(1389), 2,
      sym_parenthesized_type,
      sym__simple_type,
    STATE(858), 9,
      sym_generic_type,
      sym_pointer_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_interface_type,
      sym_map_type,
      sym_channel_type,
      sym_function_type,
  [48188] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(561), 1,
      sym_identifier,
    ACTIONS(572), 1,
      anon_sym_func,
    ACTIONS(585), 1,
      anon_sym_map,
    ACTIONS(587), 1,
      anon_sym_chan,
    ACTIONS(589), 1,
      anon_sym_LT_DASH,
    ACTIONS(974), 1,
      anon_sym_LBRACK,
    ACTIONS(976), 1,
      anon_sym_STAR,
    ACTIONS(1042), 1,
      anon_sym_LPAREN,
    STATE(848), 2,
      sym_negated_type,
      sym_qualified_type,
    STATE(867), 2,
      sym_parenthesized_type,
      sym__simple_type,
    STATE(858), 9,
      sym_generic_type,
      sym_pointer_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_interface_type,
      sym_map_type,
      sym_channel_type,
      sym_function_type,
  [48244] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(561), 1,
      sym_identifier,
    ACTIONS(572), 1,
      anon_sym_func,
    ACTIONS(585), 1,
      anon_sym_map,
    ACTIONS(587), 1,
      anon_sym_chan,
    ACTIONS(589), 1,
      anon_sym_LT_DASH,
    ACTIONS(974), 1,
      anon_sym_LBRACK,
    ACTIONS(976), 1,
      anon_sym_STAR,
    ACTIONS(1042), 1,
      anon_sym_LPAREN,
    STATE(848), 2,
      sym_negated_type,
      sym_qualified_type,
    STATE(1322), 2,
      sym_parenthesized_type,
      sym__simple_type,
    STATE(858), 9,
      sym_generic_type,
      sym_pointer_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_interface_type,
      sym_map_type,
      sym_channel_type,
      sym_function_type,
  [48300] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(561), 1,
      sym_identifier,
    ACTIONS(572), 1,
      anon_sym_func,
    ACTIONS(585), 1,
      anon_sym_map,
    ACTIONS(587), 1,
      anon_sym_chan,
    ACTIONS(589), 1,
      anon_sym_LT_DASH,
    ACTIONS(974), 1,
      anon_sym_LBRACK,
    ACTIONS(976), 1,
      anon_sym_STAR,
    ACTIONS(1042), 1,
      anon_sym_LPAREN,
    STATE(846), 2,
      sym_parenthesized_type,
      sym__simple_type,
    STATE(848), 2,
      sym_negated_type,
      sym_qualified_type,
    STATE(858), 9,
      sym_generic_type,
      sym_pointer_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_interface_type,
      sym_map_type,
      sym_channel_type,
      sym_function_type,
  [48356] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(561), 1,
      sym_identifier,
    ACTIONS(572), 1,
      anon_sym_func,
    ACTIONS(585), 1,
      anon_sym_map,
    ACTIONS(587), 1,
      anon_sym_chan,
    ACTIONS(589), 1,
      anon_sym_LT_DASH,
    ACTIONS(974), 1,
      anon_sym_LBRACK,
    ACTIONS(976), 1,
      anon_sym_STAR,
    ACTIONS(1042), 1,
      anon_sym_LPAREN,
    STATE(848), 2,
      sym_negated_type,
      sym_qualified_type,
    STATE(1240), 2,
      sym_parenthesized_type,
      sym__simple_type,
    STATE(858), 9,
      sym_generic_type,
      sym_pointer_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_interface_type,
      sym_map_type,
      sym_channel_type,
      sym_function_type,
  [48412] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(561), 1,
      sym_identifier,
    ACTIONS(572), 1,
      anon_sym_func,
    ACTIONS(585), 1,
      anon_sym_map,
    ACTIONS(587), 1,
      anon_sym_chan,
    ACTIONS(589), 1,
      anon_sym_LT_DASH,
    ACTIONS(974), 1,
      anon_sym_LBRACK,
    ACTIONS(976), 1,
      anon_sym_STAR,
    ACTIONS(1042), 1,
      anon_sym_LPAREN,
    STATE(848), 2,
      sym_negated_type,
      sym_qualified_type,
    STATE(852), 2,
      sym_parenthesized_type,
      sym__simple_type,
    STATE(858), 9,
      sym_generic_type,
      sym_pointer_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_interface_type,
      sym_map_type,
      sym_channel_type,
      sym_function_type,
  [48468] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(924), 1,
      anon_sym_LPAREN,
    ACTIONS(926), 1,
      anon_sym_LBRACK,
    ACTIONS(984), 1,
      anon_sym_PIPE,
    ACTIONS(992), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1109), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1515), 1,
      anon_sym_DOT,
    STATE(397), 1,
      sym_argument_list,
    STATE(1255), 1,
      sym_type_arguments,
    ACTIONS(982), 2,
      anon_sym_AMP,
      anon_sym_SLASH,
    ACTIONS(990), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(986), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET,
    ACTIONS(988), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(980), 5,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_CARET,
  [48522] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1075), 1,
      anon_sym_struct,
    ACTIONS(1081), 1,
      anon_sym_interface,
    ACTIONS(1115), 1,
      sym_identifier,
    ACTIONS(1117), 1,
      anon_sym_func,
    ACTIONS(1123), 1,
      anon_sym_map,
    ACTIONS(1125), 1,
      anon_sym_chan,
    ACTIONS(1487), 1,
      anon_sym_LPAREN,
    ACTIONS(1493), 1,
      anon_sym_TILDE,
    ACTIONS(1503), 1,
      anon_sym_LBRACK,
    ACTIONS(1505), 1,
      anon_sym_STAR,
    ACTIONS(1509), 1,
      anon_sym_LT_DASH,
    STATE(895), 2,
      sym_negated_type,
      sym_qualified_type,
    STATE(954), 2,
      sym_parenthesized_type,
      sym__simple_type,
    STATE(950), 9,
      sym_generic_type,
      sym_pointer_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_interface_type,
      sym_map_type,
      sym_channel_type,
      sym_function_type,
  [48578] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(880), 1,
      anon_sym_struct,
    ACTIONS(884), 1,
      anon_sym_interface,
    ACTIONS(892), 1,
      sym_identifier,
    ACTIONS(904), 1,
      anon_sym_func,
    ACTIONS(910), 1,
      anon_sym_map,
    ACTIONS(912), 1,
      anon_sym_chan,
    ACTIONS(1213), 1,
      anon_sym_LPAREN,
    ACTIONS(1215), 1,
      anon_sym_LBRACK,
    ACTIONS(1217), 1,
      anon_sym_STAR,
    ACTIONS(1219), 1,
      anon_sym_TILDE,
    ACTIONS(1517), 1,
      anon_sym_LT_DASH,
    STATE(799), 2,
      sym_negated_type,
      sym_qualified_type,
    STATE(811), 2,
      sym_parenthesized_type,
      sym__simple_type,
    STATE(807), 9,
      sym_generic_type,
      sym_pointer_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_interface_type,
      sym_map_type,
      sym_channel_type,
      sym_function_type,
  [48634] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(561), 1,
      sym_identifier,
    ACTIONS(572), 1,
      anon_sym_func,
    ACTIONS(585), 1,
      anon_sym_map,
    ACTIONS(587), 1,
      anon_sym_chan,
    ACTIONS(589), 1,
      anon_sym_LT_DASH,
    ACTIONS(974), 1,
      anon_sym_LBRACK,
    ACTIONS(976), 1,
      anon_sym_STAR,
    ACTIONS(1042), 1,
      anon_sym_LPAREN,
    STATE(848), 2,
      sym_negated_type,
      sym_qualified_type,
    STATE(1139), 2,
      sym_parenthesized_type,
      sym__simple_type,
    STATE(858), 9,
      sym_generic_type,
      sym_pointer_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_interface_type,
      sym_map_type,
      sym_channel_type,
      sym_function_type,
  [48690] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(880), 1,
      anon_sym_struct,
    ACTIONS(884), 1,
      anon_sym_interface,
    ACTIONS(892), 1,
      sym_identifier,
    ACTIONS(904), 1,
      anon_sym_func,
    ACTIONS(910), 1,
      anon_sym_map,
    ACTIONS(912), 1,
      anon_sym_chan,
    ACTIONS(1213), 1,
      anon_sym_LPAREN,
    ACTIONS(1215), 1,
      anon_sym_LBRACK,
    ACTIONS(1217), 1,
      anon_sym_STAR,
    ACTIONS(1219), 1,
      anon_sym_TILDE,
    ACTIONS(1223), 1,
      anon_sym_LT_DASH,
    STATE(799), 2,
      sym_negated_type,
      sym_qualified_type,
    STATE(817), 2,
      sym_parenthesized_type,
      sym__simple_type,
    STATE(807), 9,
      sym_generic_type,
      sym_pointer_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_interface_type,
      sym_map_type,
      sym_channel_type,
      sym_function_type,
  [48746] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(880), 1,
      anon_sym_struct,
    ACTIONS(884), 1,
      anon_sym_interface,
    ACTIONS(892), 1,
      sym_identifier,
    ACTIONS(904), 1,
      anon_sym_func,
    ACTIONS(910), 1,
      anon_sym_map,
    ACTIONS(1213), 1,
      anon_sym_LPAREN,
    ACTIONS(1215), 1,
      anon_sym_LBRACK,
    ACTIONS(1217), 1,
      anon_sym_STAR,
    ACTIONS(1219), 1,
      anon_sym_TILDE,
    ACTIONS(1223), 1,
      anon_sym_LT_DASH,
    ACTIONS(1519), 1,
      anon_sym_chan,
    STATE(799), 2,
      sym_negated_type,
      sym_qualified_type,
    STATE(824), 2,
      sym_parenthesized_type,
      sym__simple_type,
    STATE(807), 9,
      sym_generic_type,
      sym_pointer_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_interface_type,
      sym_map_type,
      sym_channel_type,
      sym_function_type,
  [48802] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(561), 1,
      sym_identifier,
    ACTIONS(572), 1,
      anon_sym_func,
    ACTIONS(585), 1,
      anon_sym_map,
    ACTIONS(587), 1,
      anon_sym_chan,
    ACTIONS(589), 1,
      anon_sym_LT_DASH,
    ACTIONS(974), 1,
      anon_sym_LBRACK,
    ACTIONS(976), 1,
      anon_sym_STAR,
    ACTIONS(1042), 1,
      anon_sym_LPAREN,
    STATE(848), 2,
      sym_negated_type,
      sym_qualified_type,
    STATE(1366), 2,
      sym_parenthesized_type,
      sym__simple_type,
    STATE(858), 9,
      sym_generic_type,
      sym_pointer_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_interface_type,
      sym_map_type,
      sym_channel_type,
      sym_function_type,
  [48858] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(880), 1,
      anon_sym_struct,
    ACTIONS(884), 1,
      anon_sym_interface,
    ACTIONS(892), 1,
      sym_identifier,
    ACTIONS(904), 1,
      anon_sym_func,
    ACTIONS(910), 1,
      anon_sym_map,
    ACTIONS(912), 1,
      anon_sym_chan,
    ACTIONS(1213), 1,
      anon_sym_LPAREN,
    ACTIONS(1215), 1,
      anon_sym_LBRACK,
    ACTIONS(1217), 1,
      anon_sym_STAR,
    ACTIONS(1219), 1,
      anon_sym_TILDE,
    ACTIONS(1223), 1,
      anon_sym_LT_DASH,
    STATE(799), 2,
      sym_negated_type,
      sym_qualified_type,
    STATE(821), 2,
      sym_parenthesized_type,
      sym__simple_type,
    STATE(807), 9,
      sym_generic_type,
      sym_pointer_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_interface_type,
      sym_map_type,
      sym_channel_type,
      sym_function_type,
  [48914] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(880), 1,
      anon_sym_struct,
    ACTIONS(884), 1,
      anon_sym_interface,
    ACTIONS(892), 1,
      sym_identifier,
    ACTIONS(904), 1,
      anon_sym_func,
    ACTIONS(910), 1,
      anon_sym_map,
    ACTIONS(912), 1,
      anon_sym_chan,
    ACTIONS(1213), 1,
      anon_sym_LPAREN,
    ACTIONS(1215), 1,
      anon_sym_LBRACK,
    ACTIONS(1217), 1,
      anon_sym_STAR,
    ACTIONS(1219), 1,
      anon_sym_TILDE,
    ACTIONS(1517), 1,
      anon_sym_LT_DASH,
    STATE(799), 2,
      sym_negated_type,
      sym_qualified_type,
    STATE(825), 2,
      sym_parenthesized_type,
      sym__simple_type,
    STATE(807), 9,
      sym_generic_type,
      sym_pointer_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_interface_type,
      sym_map_type,
      sym_channel_type,
      sym_function_type,
  [48970] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(561), 1,
      sym_identifier,
    ACTIONS(572), 1,
      anon_sym_func,
    ACTIONS(585), 1,
      anon_sym_map,
    ACTIONS(587), 1,
      anon_sym_chan,
    ACTIONS(589), 1,
      anon_sym_LT_DASH,
    ACTIONS(974), 1,
      anon_sym_LBRACK,
    ACTIONS(976), 1,
      anon_sym_STAR,
    ACTIONS(1042), 1,
      anon_sym_LPAREN,
    STATE(848), 2,
      sym_negated_type,
      sym_qualified_type,
    STATE(1279), 2,
      sym_parenthesized_type,
      sym__simple_type,
    STATE(858), 9,
      sym_generic_type,
      sym_pointer_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_interface_type,
      sym_map_type,
      sym_channel_type,
      sym_function_type,
  [49026] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(561), 1,
      sym_identifier,
    ACTIONS(572), 1,
      anon_sym_func,
    ACTIONS(585), 1,
      anon_sym_map,
    ACTIONS(587), 1,
      anon_sym_chan,
    ACTIONS(589), 1,
      anon_sym_LT_DASH,
    ACTIONS(974), 1,
      anon_sym_LBRACK,
    ACTIONS(976), 1,
      anon_sym_STAR,
    ACTIONS(1042), 1,
      anon_sym_LPAREN,
    STATE(848), 2,
      sym_negated_type,
      sym_qualified_type,
    STATE(1338), 2,
      sym_parenthesized_type,
      sym__simple_type,
    STATE(858), 9,
      sym_generic_type,
      sym_pointer_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_interface_type,
      sym_map_type,
      sym_channel_type,
      sym_function_type,
  [49082] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(880), 1,
      anon_sym_struct,
    ACTIONS(884), 1,
      anon_sym_interface,
    ACTIONS(892), 1,
      sym_identifier,
    ACTIONS(904), 1,
      anon_sym_func,
    ACTIONS(910), 1,
      anon_sym_map,
    ACTIONS(912), 1,
      anon_sym_chan,
    ACTIONS(1213), 1,
      anon_sym_LPAREN,
    ACTIONS(1215), 1,
      anon_sym_LBRACK,
    ACTIONS(1217), 1,
      anon_sym_STAR,
    ACTIONS(1219), 1,
      anon_sym_TILDE,
    ACTIONS(1223), 1,
      anon_sym_LT_DASH,
    STATE(799), 2,
      sym_negated_type,
      sym_qualified_type,
    STATE(828), 2,
      sym_parenthesized_type,
      sym__simple_type,
    STATE(807), 9,
      sym_generic_type,
      sym_pointer_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_interface_type,
      sym_map_type,
      sym_channel_type,
      sym_function_type,
  [49138] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(880), 1,
      anon_sym_struct,
    ACTIONS(884), 1,
      anon_sym_interface,
    ACTIONS(892), 1,
      sym_identifier,
    ACTIONS(904), 1,
      anon_sym_func,
    ACTIONS(910), 1,
      anon_sym_map,
    ACTIONS(912), 1,
      anon_sym_chan,
    ACTIONS(1213), 1,
      anon_sym_LPAREN,
    ACTIONS(1215), 1,
      anon_sym_LBRACK,
    ACTIONS(1217), 1,
      anon_sym_STAR,
    ACTIONS(1219), 1,
      anon_sym_TILDE,
    ACTIONS(1223), 1,
      anon_sym_LT_DASH,
    STATE(799), 2,
      sym_negated_type,
      sym_qualified_type,
    STATE(831), 2,
      sym_parenthesized_type,
      sym__simple_type,
    STATE(807), 9,
      sym_generic_type,
      sym_pointer_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_interface_type,
      sym_map_type,
      sym_channel_type,
      sym_function_type,
  [49194] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(561), 1,
      sym_identifier,
    ACTIONS(572), 1,
      anon_sym_func,
    ACTIONS(585), 1,
      anon_sym_map,
    ACTIONS(587), 1,
      anon_sym_chan,
    ACTIONS(589), 1,
      anon_sym_LT_DASH,
    ACTIONS(974), 1,
      anon_sym_LBRACK,
    ACTIONS(976), 1,
      anon_sym_STAR,
    ACTIONS(1042), 1,
      anon_sym_LPAREN,
    STATE(848), 2,
      sym_negated_type,
      sym_qualified_type,
    STATE(1364), 2,
      sym_parenthesized_type,
      sym__simple_type,
    STATE(858), 9,
      sym_generic_type,
      sym_pointer_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_interface_type,
      sym_map_type,
      sym_channel_type,
      sym_function_type,
  [49250] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(866), 1,
      sym_identifier,
    ACTIONS(874), 1,
      anon_sym_func,
    ACTIONS(880), 1,
      anon_sym_struct,
    ACTIONS(884), 1,
      anon_sym_interface,
    ACTIONS(886), 1,
      anon_sym_map,
    ACTIONS(888), 1,
      anon_sym_chan,
    ACTIONS(1213), 1,
      anon_sym_LPAREN,
    ACTIONS(1219), 1,
      anon_sym_TILDE,
    ACTIONS(1481), 1,
      anon_sym_LBRACK,
    ACTIONS(1483), 1,
      anon_sym_STAR,
    ACTIONS(1485), 1,
      anon_sym_LT_DASH,
    STATE(796), 2,
      sym_negated_type,
      sym_qualified_type,
    STATE(831), 2,
      sym_parenthesized_type,
      sym__simple_type,
    STATE(807), 9,
      sym_generic_type,
      sym_pointer_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_interface_type,
      sym_map_type,
      sym_channel_type,
      sym_function_type,
  [49306] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(537), 1,
      anon_sym_chan,
    ACTIONS(994), 1,
      sym_identifier,
    ACTIONS(996), 1,
      anon_sym_func,
    ACTIONS(998), 1,
      anon_sym_LBRACK,
    ACTIONS(1000), 1,
      anon_sym_STAR,
    ACTIONS(1002), 1,
      anon_sym_LT_DASH,
    ACTIONS(1042), 1,
      anon_sym_LPAREN,
    STATE(836), 2,
      sym_negated_type,
      sym_qualified_type,
    STATE(865), 2,
      sym_parenthesized_type,
      sym__simple_type,
    STATE(858), 9,
      sym_generic_type,
      sym_pointer_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_interface_type,
      sym_map_type,
      sym_channel_type,
      sym_function_type,
  [49362] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(866), 1,
      sym_identifier,
    ACTIONS(874), 1,
      anon_sym_func,
    ACTIONS(880), 1,
      anon_sym_struct,
    ACTIONS(884), 1,
      anon_sym_interface,
    ACTIONS(886), 1,
      anon_sym_map,
    ACTIONS(888), 1,
      anon_sym_chan,
    ACTIONS(1213), 1,
      anon_sym_LPAREN,
    ACTIONS(1219), 1,
      anon_sym_TILDE,
    ACTIONS(1481), 1,
      anon_sym_LBRACK,
    ACTIONS(1483), 1,
      anon_sym_STAR,
    ACTIONS(1485), 1,
      anon_sym_LT_DASH,
    STATE(796), 2,
      sym_negated_type,
      sym_qualified_type,
    STATE(817), 2,
      sym_parenthesized_type,
      sym__simple_type,
    STATE(807), 9,
      sym_generic_type,
      sym_pointer_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_interface_type,
      sym_map_type,
      sym_channel_type,
      sym_function_type,
  [49418] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(994), 1,
      sym_identifier,
    ACTIONS(996), 1,
      anon_sym_func,
    ACTIONS(998), 1,
      anon_sym_LBRACK,
    ACTIONS(1000), 1,
      anon_sym_STAR,
    ACTIONS(1042), 1,
      anon_sym_LPAREN,
    ACTIONS(1501), 1,
      anon_sym_LT_DASH,
    STATE(836), 2,
      sym_negated_type,
      sym_qualified_type,
    STATE(866), 2,
      sym_parenthesized_type,
      sym__simple_type,
    STATE(858), 9,
      sym_generic_type,
      sym_pointer_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_interface_type,
      sym_map_type,
      sym_channel_type,
      sym_function_type,
  [49474] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(866), 1,
      sym_identifier,
    ACTIONS(874), 1,
      anon_sym_func,
    ACTIONS(880), 1,
      anon_sym_struct,
    ACTIONS(884), 1,
      anon_sym_interface,
    ACTIONS(886), 1,
      anon_sym_map,
    ACTIONS(888), 1,
      anon_sym_chan,
    ACTIONS(1213), 1,
      anon_sym_LPAREN,
    ACTIONS(1219), 1,
      anon_sym_TILDE,
    ACTIONS(1481), 1,
      anon_sym_LBRACK,
    ACTIONS(1483), 1,
      anon_sym_STAR,
    ACTIONS(1485), 1,
      anon_sym_LT_DASH,
    STATE(796), 2,
      sym_negated_type,
      sym_qualified_type,
    STATE(821), 2,
      sym_parenthesized_type,
      sym__simple_type,
    STATE(807), 9,
      sym_generic_type,
      sym_pointer_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_interface_type,
      sym_map_type,
      sym_channel_type,
      sym_function_type,
  [49530] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(866), 1,
      sym_identifier,
    ACTIONS(874), 1,
      anon_sym_func,
    ACTIONS(880), 1,
      anon_sym_struct,
    ACTIONS(884), 1,
      anon_sym_interface,
    ACTIONS(886), 1,
      anon_sym_map,
    ACTIONS(888), 1,
      anon_sym_chan,
    ACTIONS(1213), 1,
      anon_sym_LPAREN,
    ACTIONS(1219), 1,
      anon_sym_TILDE,
    ACTIONS(1481), 1,
      anon_sym_LBRACK,
    ACTIONS(1483), 1,
      anon_sym_STAR,
    ACTIONS(1485), 1,
      anon_sym_LT_DASH,
    STATE(796), 2,
      sym_negated_type,
      sym_qualified_type,
    STATE(828), 2,
      sym_parenthesized_type,
      sym__simple_type,
    STATE(807), 9,
      sym_generic_type,
      sym_pointer_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_interface_type,
      sym_map_type,
      sym_channel_type,
      sym_function_type,
  [49586] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(994), 1,
      sym_identifier,
    ACTIONS(996), 1,
      anon_sym_func,
    ACTIONS(998), 1,
      anon_sym_LBRACK,
    ACTIONS(1000), 1,
      anon_sym_STAR,
    ACTIONS(1002), 1,
      anon_sym_LT_DASH,
    ACTIONS(1042), 1,
      anon_sym_LPAREN,
    STATE(836), 2,
      sym_negated_type,
      sym_qualified_type,
    STATE(873), 2,
      sym_parenthesized_type,
      sym__simple_type,
    STATE(858), 9,
      sym_generic_type,
      sym_pointer_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_interface_type,
      sym_map_type,
      sym_channel_type,
      sym_function_type,
  [49642] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(561), 1,
      sym_identifier,
    ACTIONS(572), 1,
      anon_sym_func,
    ACTIONS(585), 1,
      anon_sym_map,
    ACTIONS(587), 1,
      anon_sym_chan,
    ACTIONS(589), 1,
      anon_sym_LT_DASH,
    ACTIONS(974), 1,
      anon_sym_LBRACK,
    ACTIONS(976), 1,
      anon_sym_STAR,
    ACTIONS(1042), 1,
      anon_sym_LPAREN,
    STATE(848), 2,
      sym_negated_type,
      sym_qualified_type,
    STATE(1345), 2,
      sym_parenthesized_type,
      sym__simple_type,
    STATE(858), 9,
      sym_generic_type,
      sym_pointer_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_interface_type,
      sym_map_type,
      sym_channel_type,
      sym_function_type,
  [49698] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1063), 1,
      sym_identifier,
    ACTIONS(1069), 1,
      anon_sym_func,
    ACTIONS(1075), 1,
      anon_sym_struct,
    ACTIONS(1081), 1,
      anon_sym_interface,
    ACTIONS(1083), 1,
      anon_sym_map,
    ACTIONS(1085), 1,
      anon_sym_chan,
    ACTIONS(1487), 1,
      anon_sym_LPAREN,
    ACTIONS(1489), 1,
      anon_sym_LBRACK,
    ACTIONS(1491), 1,
      anon_sym_STAR,
    ACTIONS(1493), 1,
      anon_sym_TILDE,
    ACTIONS(1499), 1,
      anon_sym_LT_DASH,
    STATE(910), 2,
      sym_negated_type,
      sym_qualified_type,
    STATE(961), 2,
      sym_parenthesized_type,
      sym__simple_type,
    STATE(950), 9,
      sym_generic_type,
      sym_pointer_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_interface_type,
      sym_map_type,
      sym_channel_type,
      sym_function_type,
  [49754] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(994), 1,
      sym_identifier,
    ACTIONS(996), 1,
      anon_sym_func,
    ACTIONS(998), 1,
      anon_sym_LBRACK,
    ACTIONS(1000), 1,
      anon_sym_STAR,
    ACTIONS(1002), 1,
      anon_sym_LT_DASH,
    ACTIONS(1042), 1,
      anon_sym_LPAREN,
    STATE(836), 2,
      sym_negated_type,
      sym_qualified_type,
    STATE(871), 2,
      sym_parenthesized_type,
      sym__simple_type,
    STATE(858), 9,
      sym_generic_type,
      sym_pointer_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_interface_type,
      sym_map_type,
      sym_channel_type,
      sym_function_type,
  [49810] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(880), 1,
      anon_sym_struct,
    ACTIONS(884), 1,
      anon_sym_interface,
    ACTIONS(892), 1,
      sym_identifier,
    ACTIONS(904), 1,
      anon_sym_func,
    ACTIONS(910), 1,
      anon_sym_map,
    ACTIONS(912), 1,
      anon_sym_chan,
    ACTIONS(1213), 1,
      anon_sym_LPAREN,
    ACTIONS(1215), 1,
      anon_sym_LBRACK,
    ACTIONS(1217), 1,
      anon_sym_STAR,
    ACTIONS(1219), 1,
      anon_sym_TILDE,
    ACTIONS(1223), 1,
      anon_sym_LT_DASH,
    STATE(799), 2,
      sym_negated_type,
      sym_qualified_type,
    STATE(810), 2,
      sym_parenthesized_type,
      sym__simple_type,
    STATE(807), 9,
      sym_generic_type,
      sym_pointer_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_interface_type,
      sym_map_type,
      sym_channel_type,
      sym_function_type,
  [49866] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1063), 1,
      sym_identifier,
    ACTIONS(1069), 1,
      anon_sym_func,
    ACTIONS(1075), 1,
      anon_sym_struct,
    ACTIONS(1081), 1,
      anon_sym_interface,
    ACTIONS(1083), 1,
      anon_sym_map,
    ACTIONS(1085), 1,
      anon_sym_chan,
    ACTIONS(1487), 1,
      anon_sym_LPAREN,
    ACTIONS(1489), 1,
      anon_sym_LBRACK,
    ACTIONS(1491), 1,
      anon_sym_STAR,
    ACTIONS(1493), 1,
      anon_sym_TILDE,
    ACTIONS(1497), 1,
      anon_sym_LT_DASH,
    STATE(910), 2,
      sym_negated_type,
      sym_qualified_type,
    STATE(983), 2,
      sym_parenthesized_type,
      sym__simple_type,
    STATE(950), 9,
      sym_generic_type,
      sym_pointer_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_interface_type,
      sym_map_type,
      sym_channel_type,
      sym_function_type,
  [49922] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(561), 1,
      sym_identifier,
    ACTIONS(572), 1,
      anon_sym_func,
    ACTIONS(585), 1,
      anon_sym_map,
    ACTIONS(589), 1,
      anon_sym_LT_DASH,
    ACTIONS(974), 1,
      anon_sym_LBRACK,
    ACTIONS(976), 1,
      anon_sym_STAR,
    ACTIONS(1042), 1,
      anon_sym_LPAREN,
    ACTIONS(1521), 1,
      anon_sym_chan,
    STATE(848), 2,
      sym_negated_type,
      sym_qualified_type,
    STATE(865), 2,
      sym_parenthesized_type,
      sym__simple_type,
    STATE(858), 9,
      sym_generic_type,
      sym_pointer_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_interface_type,
      sym_map_type,
      sym_channel_type,
      sym_function_type,
  [49978] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1063), 1,
      sym_identifier,
    ACTIONS(1069), 1,
      anon_sym_func,
    ACTIONS(1075), 1,
      anon_sym_struct,
    ACTIONS(1081), 1,
      anon_sym_interface,
    ACTIONS(1083), 1,
      anon_sym_map,
    ACTIONS(1085), 1,
      anon_sym_chan,
    ACTIONS(1487), 1,
      anon_sym_LPAREN,
    ACTIONS(1489), 1,
      anon_sym_LBRACK,
    ACTIONS(1491), 1,
      anon_sym_STAR,
    ACTIONS(1493), 1,
      anon_sym_TILDE,
    ACTIONS(1497), 1,
      anon_sym_LT_DASH,
    STATE(910), 2,
      sym_negated_type,
      sym_qualified_type,
    STATE(992), 2,
      sym_parenthesized_type,
      sym__simple_type,
    STATE(950), 9,
      sym_generic_type,
      sym_pointer_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_interface_type,
      sym_map_type,
      sym_channel_type,
      sym_function_type,
  [50034] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(561), 1,
      sym_identifier,
    ACTIONS(572), 1,
      anon_sym_func,
    ACTIONS(585), 1,
      anon_sym_map,
    ACTIONS(587), 1,
      anon_sym_chan,
    ACTIONS(974), 1,
      anon_sym_LBRACK,
    ACTIONS(976), 1,
      anon_sym_STAR,
    ACTIONS(1042), 1,
      anon_sym_LPAREN,
    ACTIONS(1513), 1,
      anon_sym_LT_DASH,
    STATE(848), 2,
      sym_negated_type,
      sym_qualified_type,
    STATE(866), 2,
      sym_parenthesized_type,
      sym__simple_type,
    STATE(858), 9,
      sym_generic_type,
      sym_pointer_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_interface_type,
      sym_map_type,
      sym_channel_type,
      sym_function_type,
  [50090] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(880), 1,
      anon_sym_struct,
    ACTIONS(884), 1,
      anon_sym_interface,
    ACTIONS(892), 1,
      sym_identifier,
    ACTIONS(904), 1,
      anon_sym_func,
    ACTIONS(910), 1,
      anon_sym_map,
    ACTIONS(912), 1,
      anon_sym_chan,
    ACTIONS(1213), 1,
      anon_sym_LPAREN,
    ACTIONS(1215), 1,
      anon_sym_LBRACK,
    ACTIONS(1217), 1,
      anon_sym_STAR,
    ACTIONS(1219), 1,
      anon_sym_TILDE,
    ACTIONS(1223), 1,
      anon_sym_LT_DASH,
    STATE(799), 2,
      sym_negated_type,
      sym_qualified_type,
    STATE(963), 2,
      sym_parenthesized_type,
      sym__simple_type,
    STATE(807), 9,
      sym_generic_type,
      sym_pointer_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_interface_type,
      sym_map_type,
      sym_channel_type,
      sym_function_type,
  [50146] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(880), 1,
      anon_sym_struct,
    ACTIONS(884), 1,
      anon_sym_interface,
    ACTIONS(892), 1,
      sym_identifier,
    ACTIONS(904), 1,
      anon_sym_func,
    ACTIONS(910), 1,
      anon_sym_map,
    ACTIONS(912), 1,
      anon_sym_chan,
    ACTIONS(1213), 1,
      anon_sym_LPAREN,
    ACTIONS(1215), 1,
      anon_sym_LBRACK,
    ACTIONS(1217), 1,
      anon_sym_STAR,
    ACTIONS(1219), 1,
      anon_sym_TILDE,
    ACTIONS(1223), 1,
      anon_sym_LT_DASH,
    STATE(799), 2,
      sym_negated_type,
      sym_qualified_type,
    STATE(965), 2,
      sym_parenthesized_type,
      sym__simple_type,
    STATE(807), 9,
      sym_generic_type,
      sym_pointer_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_interface_type,
      sym_map_type,
      sym_channel_type,
      sym_function_type,
  [50202] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1075), 1,
      anon_sym_struct,
    ACTIONS(1081), 1,
      anon_sym_interface,
    ACTIONS(1115), 1,
      sym_identifier,
    ACTIONS(1117), 1,
      anon_sym_func,
    ACTIONS(1123), 1,
      anon_sym_map,
    ACTIONS(1125), 1,
      anon_sym_chan,
    ACTIONS(1487), 1,
      anon_sym_LPAREN,
    ACTIONS(1493), 1,
      anon_sym_TILDE,
    ACTIONS(1503), 1,
      anon_sym_LBRACK,
    ACTIONS(1505), 1,
      anon_sym_STAR,
    ACTIONS(1511), 1,
      anon_sym_LT_DASH,
    STATE(895), 2,
      sym_negated_type,
      sym_qualified_type,
    STATE(961), 2,
      sym_parenthesized_type,
      sym__simple_type,
    STATE(950), 9,
      sym_generic_type,
      sym_pointer_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_interface_type,
      sym_map_type,
      sym_channel_type,
      sym_function_type,
  [50258] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1075), 1,
      anon_sym_struct,
    ACTIONS(1081), 1,
      anon_sym_interface,
    ACTIONS(1115), 1,
      sym_identifier,
    ACTIONS(1117), 1,
      anon_sym_func,
    ACTIONS(1123), 1,
      anon_sym_map,
    ACTIONS(1125), 1,
      anon_sym_chan,
    ACTIONS(1487), 1,
      anon_sym_LPAREN,
    ACTIONS(1493), 1,
      anon_sym_TILDE,
    ACTIONS(1503), 1,
      anon_sym_LBRACK,
    ACTIONS(1505), 1,
      anon_sym_STAR,
    ACTIONS(1509), 1,
      anon_sym_LT_DASH,
    STATE(895), 2,
      sym_negated_type,
      sym_qualified_type,
    STATE(983), 2,
      sym_parenthesized_type,
      sym__simple_type,
    STATE(950), 9,
      sym_generic_type,
      sym_pointer_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_interface_type,
      sym_map_type,
      sym_channel_type,
      sym_function_type,
  [50314] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1075), 1,
      anon_sym_struct,
    ACTIONS(1081), 1,
      anon_sym_interface,
    ACTIONS(1115), 1,
      sym_identifier,
    ACTIONS(1117), 1,
      anon_sym_func,
    ACTIONS(1123), 1,
      anon_sym_map,
    ACTIONS(1125), 1,
      anon_sym_chan,
    ACTIONS(1487), 1,
      anon_sym_LPAREN,
    ACTIONS(1493), 1,
      anon_sym_TILDE,
    ACTIONS(1503), 1,
      anon_sym_LBRACK,
    ACTIONS(1505), 1,
      anon_sym_STAR,
    ACTIONS(1509), 1,
      anon_sym_LT_DASH,
    STATE(895), 2,
      sym_negated_type,
      sym_qualified_type,
    STATE(992), 2,
      sym_parenthesized_type,
      sym__simple_type,
    STATE(950), 9,
      sym_generic_type,
      sym_pointer_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_interface_type,
      sym_map_type,
      sym_channel_type,
      sym_function_type,
  [50370] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(994), 1,
      sym_identifier,
    ACTIONS(996), 1,
      anon_sym_func,
    ACTIONS(998), 1,
      anon_sym_LBRACK,
    ACTIONS(1000), 1,
      anon_sym_STAR,
    ACTIONS(1002), 1,
      anon_sym_LT_DASH,
    ACTIONS(1042), 1,
      anon_sym_LPAREN,
    STATE(836), 2,
      sym_negated_type,
      sym_qualified_type,
    STATE(867), 2,
      sym_parenthesized_type,
      sym__simple_type,
    STATE(858), 9,
      sym_generic_type,
      sym_pointer_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_interface_type,
      sym_map_type,
      sym_channel_type,
      sym_function_type,
  [50426] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(561), 1,
      sym_identifier,
    ACTIONS(572), 1,
      anon_sym_func,
    ACTIONS(585), 1,
      anon_sym_map,
    ACTIONS(587), 1,
      anon_sym_chan,
    ACTIONS(589), 1,
      anon_sym_LT_DASH,
    ACTIONS(974), 1,
      anon_sym_LBRACK,
    ACTIONS(976), 1,
      anon_sym_STAR,
    ACTIONS(1042), 1,
      anon_sym_LPAREN,
    STATE(848), 2,
      sym_negated_type,
      sym_qualified_type,
    STATE(871), 2,
      sym_parenthesized_type,
      sym__simple_type,
    STATE(858), 9,
      sym_generic_type,
      sym_pointer_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_interface_type,
      sym_map_type,
      sym_channel_type,
      sym_function_type,
  [50482] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(561), 1,
      sym_identifier,
    ACTIONS(572), 1,
      anon_sym_func,
    ACTIONS(585), 1,
      anon_sym_map,
    ACTIONS(587), 1,
      anon_sym_chan,
    ACTIONS(589), 1,
      anon_sym_LT_DASH,
    ACTIONS(974), 1,
      anon_sym_LBRACK,
    ACTIONS(976), 1,
      anon_sym_STAR,
    ACTIONS(1042), 1,
      anon_sym_LPAREN,
    STATE(848), 2,
      sym_negated_type,
      sym_qualified_type,
    STATE(1298), 2,
      sym_parenthesized_type,
      sym__simple_type,
    STATE(858), 9,
      sym_generic_type,
      sym_pointer_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_interface_type,
      sym_map_type,
      sym_channel_type,
      sym_function_type,
  [50538] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(561), 1,
      sym_identifier,
    ACTIONS(572), 1,
      anon_sym_func,
    ACTIONS(585), 1,
      anon_sym_map,
    ACTIONS(587), 1,
      anon_sym_chan,
    ACTIONS(589), 1,
      anon_sym_LT_DASH,
    ACTIONS(974), 1,
      anon_sym_LBRACK,
    ACTIONS(976), 1,
      anon_sym_STAR,
    ACTIONS(1042), 1,
      anon_sym_LPAREN,
    STATE(848), 2,
      sym_negated_type,
      sym_qualified_type,
    STATE(876), 2,
      sym_parenthesized_type,
      sym__simple_type,
    STATE(858), 9,
      sym_generic_type,
      sym_pointer_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_interface_type,
      sym_map_type,
      sym_channel_type,
      sym_function_type,
  [50594] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(37), 1,
      anon_sym_map,
    ACTIONS(39), 1,
      anon_sym_chan,
    ACTIONS(994), 1,
      sym_identifier,
    ACTIONS(996), 1,
      anon_sym_func,
    ACTIONS(998), 1,
      anon_sym_LBRACK,
    ACTIONS(1000), 1,
      anon_sym_STAR,
    ACTIONS(1002), 1,
      anon_sym_LT_DASH,
    ACTIONS(1042), 1,
      anon_sym_LPAREN,
    STATE(836), 2,
      sym_negated_type,
      sym_qualified_type,
    STATE(876), 2,
      sym_parenthesized_type,
      sym__simple_type,
    STATE(858), 9,
      sym_generic_type,
      sym_pointer_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_interface_type,
      sym_map_type,
      sym_channel_type,
      sym_function_type,
  [50650] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(561), 1,
      sym_identifier,
    ACTIONS(572), 1,
      anon_sym_func,
    ACTIONS(585), 1,
      anon_sym_map,
    ACTIONS(587), 1,
      anon_sym_chan,
    ACTIONS(589), 1,
      anon_sym_LT_DASH,
    ACTIONS(974), 1,
      anon_sym_LBRACK,
    ACTIONS(976), 1,
      anon_sym_STAR,
    ACTIONS(1042), 1,
      anon_sym_LPAREN,
    STATE(848), 2,
      sym_negated_type,
      sym_qualified_type,
    STATE(1388), 2,
      sym_parenthesized_type,
      sym__simple_type,
    STATE(858), 9,
      sym_generic_type,
      sym_pointer_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_interface_type,
      sym_map_type,
      sym_channel_type,
      sym_function_type,
  [50706] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(866), 1,
      sym_identifier,
    ACTIONS(874), 1,
      anon_sym_func,
    ACTIONS(880), 1,
      anon_sym_struct,
    ACTIONS(884), 1,
      anon_sym_interface,
    ACTIONS(886), 1,
      anon_sym_map,
    ACTIONS(1213), 1,
      anon_sym_LPAREN,
    ACTIONS(1219), 1,
      anon_sym_TILDE,
    ACTIONS(1481), 1,
      anon_sym_LBRACK,
    ACTIONS(1483), 1,
      anon_sym_STAR,
    ACTIONS(1485), 1,
      anon_sym_LT_DASH,
    ACTIONS(1523), 1,
      anon_sym_chan,
    STATE(796), 2,
      sym_negated_type,
      sym_qualified_type,
    STATE(824), 2,
      sym_parenthesized_type,
      sym__simple_type,
    STATE(807), 9,
      sym_generic_type,
      sym_pointer_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_interface_type,
      sym_map_type,
      sym_channel_type,
      sym_function_type,
  [50762] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(561), 1,
      sym_identifier,
    ACTIONS(572), 1,
      anon_sym_func,
    ACTIONS(585), 1,
      anon_sym_map,
    ACTIONS(587), 1,
      anon_sym_chan,
    ACTIONS(589), 1,
      anon_sym_LT_DASH,
    ACTIONS(974), 1,
      anon_sym_LBRACK,
    ACTIONS(976), 1,
      anon_sym_STAR,
    ACTIONS(1042), 1,
      anon_sym_LPAREN,
    STATE(848), 2,
      sym_negated_type,
      sym_qualified_type,
    STATE(1223), 2,
      sym_parenthesized_type,
      sym__simple_type,
    STATE(858), 9,
      sym_generic_type,
      sym_pointer_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_interface_type,
      sym_map_type,
      sym_channel_type,
      sym_function_type,
  [50818] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(561), 1,
      sym_identifier,
    ACTIONS(572), 1,
      anon_sym_func,
    ACTIONS(585), 1,
      anon_sym_map,
    ACTIONS(587), 1,
      anon_sym_chan,
    ACTIONS(589), 1,
      anon_sym_LT_DASH,
    ACTIONS(974), 1,
      anon_sym_LBRACK,
    ACTIONS(976), 1,
      anon_sym_STAR,
    ACTIONS(1042), 1,
      anon_sym_LPAREN,
    STATE(848), 2,
      sym_negated_type,
      sym_qualified_type,
    STATE(1326), 2,
      sym_parenthesized_type,
      sym__simple_type,
    STATE(858), 9,
      sym_generic_type,
      sym_pointer_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_interface_type,
      sym_map_type,
      sym_channel_type,
      sym_function_type,
  [50874] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(561), 1,
      sym_identifier,
    ACTIONS(572), 1,
      anon_sym_func,
    ACTIONS(585), 1,
      anon_sym_map,
    ACTIONS(587), 1,
      anon_sym_chan,
    ACTIONS(589), 1,
      anon_sym_LT_DASH,
    ACTIONS(974), 1,
      anon_sym_LBRACK,
    ACTIONS(976), 1,
      anon_sym_STAR,
    ACTIONS(1042), 1,
      anon_sym_LPAREN,
    STATE(848), 2,
      sym_negated_type,
      sym_qualified_type,
    STATE(1352), 2,
      sym_parenthesized_type,
      sym__simple_type,
    STATE(858), 9,
      sym_generic_type,
      sym_pointer_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_interface_type,
      sym_map_type,
      sym_channel_type,
      sym_function_type,
  [50930] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(866), 1,
      sym_identifier,
    ACTIONS(874), 1,
      anon_sym_func,
    ACTIONS(880), 1,
      anon_sym_struct,
    ACTIONS(884), 1,
      anon_sym_interface,
    ACTIONS(886), 1,
      anon_sym_map,
    ACTIONS(888), 1,
      anon_sym_chan,
    ACTIONS(1213), 1,
      anon_sym_LPAREN,
    ACTIONS(1219), 1,
      anon_sym_TILDE,
    ACTIONS(1481), 1,
      anon_sym_LBRACK,
    ACTIONS(1483), 1,
      anon_sym_STAR,
    ACTIONS(1525), 1,
      anon_sym_LT_DASH,
    STATE(796), 2,
      sym_negated_type,
      sym_qualified_type,
    STATE(825), 2,
      sym_parenthesized_type,
      sym__simple_type,
    STATE(807), 9,
      sym_generic_type,
      sym_pointer_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_interface_type,
      sym_map_type,
      sym_channel_type,
      sym_function_type,
  [50986] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(561), 1,
      sym_identifier,
    ACTIONS(572), 1,
      anon_sym_func,
    ACTIONS(585), 1,
      anon_sym_map,
    ACTIONS(587), 1,
      anon_sym_chan,
    ACTIONS(589), 1,
      anon_sym_LT_DASH,
    ACTIONS(974), 1,
      anon_sym_LBRACK,
    ACTIONS(976), 1,
      anon_sym_STAR,
    ACTIONS(1042), 1,
      anon_sym_LPAREN,
    STATE(848), 2,
      sym_negated_type,
      sym_qualified_type,
    STATE(1238), 2,
      sym_parenthesized_type,
      sym__simple_type,
    STATE(858), 9,
      sym_generic_type,
      sym_pointer_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_interface_type,
      sym_map_type,
      sym_channel_type,
      sym_function_type,
  [51042] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(561), 1,
      sym_identifier,
    ACTIONS(572), 1,
      anon_sym_func,
    ACTIONS(585), 1,
      anon_sym_map,
    ACTIONS(587), 1,
      anon_sym_chan,
    ACTIONS(589), 1,
      anon_sym_LT_DASH,
    ACTIONS(974), 1,
      anon_sym_LBRACK,
    ACTIONS(976), 1,
      anon_sym_STAR,
    ACTIONS(1042), 1,
      anon_sym_LPAREN,
    STATE(848), 2,
      sym_negated_type,
      sym_qualified_type,
    STATE(1335), 2,
      sym_parenthesized_type,
      sym__simple_type,
    STATE(858), 9,
      sym_generic_type,
      sym_pointer_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_interface_type,
      sym_map_type,
      sym_channel_type,
      sym_function_type,
  [51098] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(561), 1,
      sym_identifier,
    ACTIONS(572), 1,
      anon_sym_func,
    ACTIONS(585), 1,
      anon_sym_map,
    ACTIONS(587), 1,
      anon_sym_chan,
    ACTIONS(589), 1,
      anon_sym_LT_DASH,
    ACTIONS(974), 1,
      anon_sym_LBRACK,
    ACTIONS(976), 1,
      anon_sym_STAR,
    ACTIONS(1042), 1,
      anon_sym_LPAREN,
    STATE(848), 2,
      sym_negated_type,
      sym_qualified_type,
    STATE(1371), 2,
      sym_parenthesized_type,
      sym__simple_type,
    STATE(858), 9,
      sym_generic_type,
      sym_pointer_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_interface_type,
      sym_map_type,
      sym_channel_type,
      sym_function_type,
  [51154] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(561), 1,
      sym_identifier,
    ACTIONS(572), 1,
      anon_sym_func,
    ACTIONS(585), 1,
      anon_sym_map,
    ACTIONS(587), 1,
      anon_sym_chan,
    ACTIONS(589), 1,
      anon_sym_LT_DASH,
    ACTIONS(974), 1,
      anon_sym_LBRACK,
    ACTIONS(976), 1,
      anon_sym_STAR,
    ACTIONS(1042), 1,
      anon_sym_LPAREN,
    STATE(848), 2,
      sym_negated_type,
      sym_qualified_type,
    STATE(1162), 2,
      sym_parenthesized_type,
      sym__simple_type,
    STATE(858), 9,
      sym_generic_type,
      sym_pointer_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_interface_type,
      sym_map_type,
      sym_channel_type,
      sym_function_type,
  [51210] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(561), 1,
      sym_identifier,
    ACTIONS(572), 1,
      anon_sym_func,
    ACTIONS(585), 1,
      anon_sym_map,
    ACTIONS(587), 1,
      anon_sym_chan,
    ACTIONS(589), 1,
      anon_sym_LT_DASH,
    ACTIONS(974), 1,
      anon_sym_LBRACK,
    ACTIONS(976), 1,
      anon_sym_STAR,
    ACTIONS(1042), 1,
      anon_sym_LPAREN,
    STATE(848), 2,
      sym_negated_type,
      sym_qualified_type,
    STATE(1329), 2,
      sym_parenthesized_type,
      sym__simple_type,
    STATE(858), 9,
      sym_generic_type,
      sym_pointer_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_interface_type,
      sym_map_type,
      sym_channel_type,
      sym_function_type,
  [51266] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(561), 1,
      sym_identifier,
    ACTIONS(572), 1,
      anon_sym_func,
    ACTIONS(585), 1,
      anon_sym_map,
    ACTIONS(587), 1,
      anon_sym_chan,
    ACTIONS(589), 1,
      anon_sym_LT_DASH,
    ACTIONS(974), 1,
      anon_sym_LBRACK,
    ACTIONS(976), 1,
      anon_sym_STAR,
    ACTIONS(1042), 1,
      anon_sym_LPAREN,
    STATE(848), 2,
      sym_negated_type,
      sym_qualified_type,
    STATE(1379), 2,
      sym_parenthesized_type,
      sym__simple_type,
    STATE(858), 9,
      sym_generic_type,
      sym_pointer_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_interface_type,
      sym_map_type,
      sym_channel_type,
      sym_function_type,
  [51322] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(561), 1,
      sym_identifier,
    ACTIONS(572), 1,
      anon_sym_func,
    ACTIONS(585), 1,
      anon_sym_map,
    ACTIONS(587), 1,
      anon_sym_chan,
    ACTIONS(589), 1,
      anon_sym_LT_DASH,
    ACTIONS(974), 1,
      anon_sym_LBRACK,
    ACTIONS(976), 1,
      anon_sym_STAR,
    ACTIONS(1042), 1,
      anon_sym_LPAREN,
    STATE(848), 2,
      sym_negated_type,
      sym_qualified_type,
    STATE(1179), 2,
      sym_parenthesized_type,
      sym__simple_type,
    STATE(858), 9,
      sym_generic_type,
      sym_pointer_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_interface_type,
      sym_map_type,
      sym_channel_type,
      sym_function_type,
  [51378] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(561), 1,
      sym_identifier,
    ACTIONS(572), 1,
      anon_sym_func,
    ACTIONS(585), 1,
      anon_sym_map,
    ACTIONS(587), 1,
      anon_sym_chan,
    ACTIONS(589), 1,
      anon_sym_LT_DASH,
    ACTIONS(974), 1,
      anon_sym_LBRACK,
    ACTIONS(976), 1,
      anon_sym_STAR,
    ACTIONS(1042), 1,
      anon_sym_LPAREN,
    STATE(848), 2,
      sym_negated_type,
      sym_qualified_type,
    STATE(1353), 2,
      sym_parenthesized_type,
      sym__simple_type,
    STATE(858), 9,
      sym_generic_type,
      sym_pointer_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_interface_type,
      sym_map_type,
      sym_channel_type,
      sym_function_type,
  [51434] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(561), 1,
      sym_identifier,
    ACTIONS(572), 1,
      anon_sym_func,
    ACTIONS(585), 1,
      anon_sym_map,
    ACTIONS(587), 1,
      anon_sym_chan,
    ACTIONS(589), 1,
      anon_sym_LT_DASH,
    ACTIONS(974), 1,
      anon_sym_LBRACK,
    ACTIONS(976), 1,
      anon_sym_STAR,
    ACTIONS(1042), 1,
      anon_sym_LPAREN,
    STATE(848), 2,
      sym_negated_type,
      sym_qualified_type,
    STATE(1375), 2,
      sym_parenthesized_type,
      sym__simple_type,
    STATE(858), 9,
      sym_generic_type,
      sym_pointer_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_interface_type,
      sym_map_type,
      sym_channel_type,
      sym_function_type,
  [51490] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(29), 1,
      anon_sym_struct,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(35), 1,
      anon_sym_interface,
    ACTIONS(561), 1,
      sym_identifier,
    ACTIONS(572), 1,
      anon_sym_func,
    ACTIONS(585), 1,
      anon_sym_map,
    ACTIONS(587), 1,
      anon_sym_chan,
    ACTIONS(589), 1,
      anon_sym_LT_DASH,
    ACTIONS(974), 1,
      anon_sym_LBRACK,
    ACTIONS(976), 1,
      anon_sym_STAR,
    ACTIONS(1042), 1,
      anon_sym_LPAREN,
    STATE(848), 2,
      sym_negated_type,
      sym_qualified_type,
    STATE(1196), 2,
      sym_parenthesized_type,
      sym__simple_type,
    STATE(858), 9,
      sym_generic_type,
      sym_pointer_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_interface_type,
      sym_map_type,
      sym_channel_type,
      sym_function_type,
  [51546] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(866), 1,
      sym_identifier,
    ACTIONS(874), 1,
      anon_sym_func,
    ACTIONS(880), 1,
      anon_sym_struct,
    ACTIONS(884), 1,
      anon_sym_interface,
    ACTIONS(886), 1,
      anon_sym_map,
    ACTIONS(888), 1,
      anon_sym_chan,
    ACTIONS(1213), 1,
      anon_sym_LPAREN,
    ACTIONS(1219), 1,
      anon_sym_TILDE,
    ACTIONS(1481), 1,
      anon_sym_LBRACK,
    ACTIONS(1483), 1,
      anon_sym_STAR,
    ACTIONS(1525), 1,
      anon_sym_LT_DASH,
    STATE(796), 2,
      sym_negated_type,
      sym_qualified_type,
    STATE(811), 2,
      sym_parenthesized_type,
      sym__simple_type,
    STATE(807), 9,
      sym_generic_type,
      sym_pointer_type,
      sym_array_type,
      sym_slice_type,
      sym_struct_type,
      sym_interface_type,
      sym_map_type,
      sym_channel_type,
      sym_function_type,
  [51602] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(1529), 1,
      aux_sym_source_file_token1,
    ACTIONS(1527), 21,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_LPAREN,
      anon_sym_EQ,
      anon_sym_func,
      anon_sym_LBRACK,
      anon_sym_STAR,
      anon_sym_struct,
      anon_sym_TILDE,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_interface,
      anon_sym_PIPE,
      anon_sym_map,
      anon_sym_chan,
      anon_sym_LT_DASH,
      anon_sym_case,
      anon_sym_default,
      sym_identifier,
      sym_raw_string_literal,
      anon_sym_DQUOTE,
  [51632] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(1533), 1,
      aux_sym_source_file_token1,
    ACTIONS(1531), 21,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_LPAREN,
      anon_sym_EQ,
      anon_sym_func,
      anon_sym_LBRACK,
      anon_sym_STAR,
      anon_sym_struct,
      anon_sym_TILDE,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_interface,
      anon_sym_PIPE,
      anon_sym_map,
      anon_sym_chan,
      anon_sym_LT_DASH,
      anon_sym_case,
      anon_sym_default,
      sym_identifier,
      sym_raw_string_literal,
      anon_sym_DQUOTE,
  [51662] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(1537), 1,
      aux_sym_source_file_token1,
    ACTIONS(1535), 21,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_LPAREN,
      anon_sym_EQ,
      anon_sym_func,
      anon_sym_LBRACK,
      anon_sym_STAR,
      anon_sym_struct,
      anon_sym_TILDE,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_interface,
      anon_sym_PIPE,
      anon_sym_map,
      anon_sym_chan,
      anon_sym_LT_DASH,
      anon_sym_case,
      anon_sym_default,
      sym_identifier,
      sym_raw_string_literal,
      anon_sym_DQUOTE,
  [51692] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(1541), 1,
      aux_sym_source_file_token1,
    ACTIONS(1539), 21,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_LPAREN,
      anon_sym_EQ,
      anon_sym_func,
      anon_sym_LBRACK,
      anon_sym_STAR,
      anon_sym_struct,
      anon_sym_TILDE,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_interface,
      anon_sym_PIPE,
      anon_sym_map,
      anon_sym_chan,
      anon_sym_LT_DASH,
      anon_sym_case,
      anon_sym_default,
      sym_identifier,
      sym_raw_string_literal,
      anon_sym_DQUOTE,
  [51722] = 5,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(1545), 1,
      aux_sym_source_file_token1,
    ACTIONS(1547), 1,
      anon_sym_COMMA,
    STATE(780), 1,
      aux_sym_const_spec_repeat1,
    ACTIONS(1543), 17,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_LPAREN,
      anon_sym_EQ,
      anon_sym_func,
      anon_sym_LBRACK,
      anon_sym_STAR,
      anon_sym_struct,
      anon_sym_TILDE,
      anon_sym_RBRACE,
      anon_sym_interface,
      anon_sym_map,
      anon_sym_chan,
      anon_sym_LT_DASH,
      anon_sym_case,
      anon_sym_default,
      sym_identifier,
  [51754] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(1545), 1,
      aux_sym_source_file_token1,
    ACTIONS(1543), 18,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_func,
      anon_sym_LBRACK,
      anon_sym_STAR,
      anon_sym_struct,
      anon_sym_TILDE,
      anon_sym_RBRACE,
      anon_sym_interface,
      anon_sym_map,
      anon_sym_chan,
      anon_sym_LT_DASH,
      anon_sym_case,
      anon_sym_default,
      sym_identifier,
  [51781] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1527), 6,
      anon_sym_func,
      anon_sym_struct,
      anon_sym_interface,
      anon_sym_map,
      anon_sym_chan,
      sym_identifier,
    ACTIONS(1529), 12,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR,
      anon_sym_TILDE,
      anon_sym_LBRACE,
      anon_sym_PIPE,
      anon_sym_LT_DASH,
      anon_sym_COLON,
  [51807] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1539), 6,
      anon_sym_func,
      anon_sym_struct,
      anon_sym_interface,
      anon_sym_map,
      anon_sym_chan,
      sym_identifier,
    ACTIONS(1541), 12,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR,
      anon_sym_TILDE,
      anon_sym_LBRACE,
      anon_sym_PIPE,
      anon_sym_LT_DASH,
      anon_sym_COLON,
  [51833] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1535), 6,
      anon_sym_func,
      anon_sym_struct,
      anon_sym_interface,
      anon_sym_map,
      anon_sym_chan,
      sym_identifier,
    ACTIONS(1537), 12,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR,
      anon_sym_TILDE,
      anon_sym_LBRACE,
      anon_sym_PIPE,
      anon_sym_LT_DASH,
      anon_sym_COLON,
  [51859] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1531), 6,
      anon_sym_func,
      anon_sym_struct,
      anon_sym_interface,
      anon_sym_map,
      anon_sym_chan,
      sym_identifier,
    ACTIONS(1533), 12,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR,
      anon_sym_TILDE,
      anon_sym_LBRACE,
      anon_sym_PIPE,
      anon_sym_LT_DASH,
      anon_sym_COLON,
  [51885] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(1537), 2,
      ts_builtin_sym_end,
      aux_sym_source_file_token1,
    ACTIONS(1535), 14,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_LPAREN,
      anon_sym_func,
      anon_sym_LBRACK,
      anon_sym_STAR,
      anon_sym_struct,
      anon_sym_TILDE,
      anon_sym_LBRACE,
      anon_sym_interface,
      anon_sym_map,
      anon_sym_chan,
      anon_sym_LT_DASH,
      sym_identifier,
  [51909] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(1541), 2,
      ts_builtin_sym_end,
      aux_sym_source_file_token1,
    ACTIONS(1539), 14,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_LPAREN,
      anon_sym_func,
      anon_sym_LBRACK,
      anon_sym_STAR,
      anon_sym_struct,
      anon_sym_TILDE,
      anon_sym_LBRACE,
      anon_sym_interface,
      anon_sym_map,
      anon_sym_chan,
      anon_sym_LT_DASH,
      sym_identifier,
  [51933] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(1529), 2,
      ts_builtin_sym_end,
      aux_sym_source_file_token1,
    ACTIONS(1527), 14,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_LPAREN,
      anon_sym_func,
      anon_sym_LBRACK,
      anon_sym_STAR,
      anon_sym_struct,
      anon_sym_TILDE,
      anon_sym_LBRACE,
      anon_sym_interface,
      anon_sym_map,
      anon_sym_chan,
      anon_sym_LT_DASH,
      sym_identifier,
  [51957] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(1533), 2,
      ts_builtin_sym_end,
      aux_sym_source_file_token1,
    ACTIONS(1531), 14,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_LPAREN,
      anon_sym_func,
      anon_sym_LBRACK,
      anon_sym_STAR,
      anon_sym_struct,
      anon_sym_TILDE,
      anon_sym_LBRACE,
      anon_sym_interface,
      anon_sym_map,
      anon_sym_chan,
      anon_sym_LT_DASH,
      sym_identifier,
  [51981] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(677), 1,
      anon_sym_COMMA,
    STATE(791), 1,
      aux_sym_expression_list_repeat1,
    ACTIONS(1550), 13,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_AMP_CARET_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
  [52006] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1552), 1,
      anon_sym_COMMA,
    STATE(791), 1,
      aux_sym_expression_list_repeat1,
    ACTIONS(858), 13,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_AMP_CARET_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
  [52031] = 6,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(898), 1,
      anon_sym_DOT,
    ACTIONS(1044), 1,
      aux_sym_source_file_token1,
    ACTIONS(1557), 1,
      anon_sym_LBRACK,
    STATE(813), 1,
      sym_type_arguments,
    ACTIONS(1555), 10,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_EQ,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_PIPE,
      anon_sym_case,
      anon_sym_default,
      sym_raw_string_literal,
      anon_sym_DQUOTE,
  [52059] = 6,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(898), 1,
      anon_sym_DOT,
    ACTIONS(1044), 1,
      aux_sym_source_file_token1,
    ACTIONS(1560), 1,
      anon_sym_LBRACK,
    STATE(813), 1,
      sym_type_arguments,
    ACTIONS(1555), 10,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_EQ,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_PIPE,
      anon_sym_case,
      anon_sym_default,
      sym_raw_string_literal,
      anon_sym_DQUOTE,
  [52087] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1566), 1,
      anon_sym_COMMA,
    STATE(794), 1,
      aux_sym_var_spec_repeat1,
    ACTIONS(1562), 6,
      anon_sym_func,
      anon_sym_struct,
      anon_sym_interface,
      anon_sym_map,
      anon_sym_chan,
      sym_identifier,
    ACTIONS(1564), 6,
      anon_sym_LPAREN,
      anon_sym_EQ,
      anon_sym_LBRACK,
      anon_sym_STAR,
      anon_sym_TILDE,
      anon_sym_LT_DASH,
  [52113] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1571), 1,
      anon_sym_COLON_EQ,
    ACTIONS(1569), 12,
      anon_sym_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_AMP_CARET_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
  [52134] = 5,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(1573), 1,
      aux_sym_source_file_token1,
    ACTIONS(1577), 1,
      anon_sym_LBRACK,
    STATE(814), 1,
      sym_type_arguments,
    ACTIONS(1575), 10,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_EQ,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_PIPE,
      anon_sym_case,
      anon_sym_default,
      sym_raw_string_literal,
      anon_sym_DQUOTE,
  [52159] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1580), 1,
      anon_sym_EQ,
    ACTIONS(1582), 1,
      anon_sym_COLON_EQ,
    ACTIONS(1584), 11,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_AMP_CARET_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
  [52182] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1586), 1,
      anon_sym_COLON_EQ,
    ACTIONS(1584), 12,
      anon_sym_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_AMP_CARET_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
  [52203] = 5,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(1560), 1,
      anon_sym_LBRACK,
    ACTIONS(1573), 1,
      aux_sym_source_file_token1,
    STATE(814), 1,
      sym_type_arguments,
    ACTIONS(1575), 10,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_EQ,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_PIPE,
      anon_sym_case,
      anon_sym_default,
      sym_raw_string_literal,
      anon_sym_DQUOTE,
  [52228] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1588), 1,
      anon_sym_COLON_EQ,
    ACTIONS(1584), 12,
      anon_sym_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_AMP_CARET_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
  [52249] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1594), 1,
      anon_sym_COMMA,
    STATE(801), 1,
      aux_sym_field_declaration_repeat1,
    ACTIONS(1592), 5,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_STAR,
      anon_sym_TILDE,
      anon_sym_LT_DASH,
    ACTIONS(1590), 6,
      anon_sym_func,
      anon_sym_struct,
      anon_sym_interface,
      anon_sym_map,
      anon_sym_chan,
      sym_identifier,
  [52274] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1597), 6,
      anon_sym_func,
      anon_sym_struct,
      anon_sym_interface,
      anon_sym_map,
      anon_sym_chan,
      sym_identifier,
    ACTIONS(1599), 7,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_LBRACK,
      anon_sym_STAR,
      anon_sym_TILDE,
      anon_sym_LT_DASH,
  [52295] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1603), 1,
      anon_sym_COLON_EQ,
    ACTIONS(1601), 12,
      anon_sym_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_AMP_CARET_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
  [52316] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(1605), 1,
      aux_sym_source_file_token1,
    ACTIONS(1607), 11,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_EQ,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_PIPE,
      anon_sym_case,
      anon_sym_default,
      sym_raw_string_literal,
      anon_sym_DQUOTE,
  [52336] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1609), 6,
      anon_sym_func,
      anon_sym_struct,
      anon_sym_interface,
      anon_sym_map,
      anon_sym_chan,
      sym_identifier,
    ACTIONS(1611), 6,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_STAR,
      anon_sym_TILDE,
      anon_sym_LT_DASH,
  [52356] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(1613), 1,
      aux_sym_source_file_token1,
    ACTIONS(1615), 11,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_EQ,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_PIPE,
      anon_sym_case,
      anon_sym_default,
      sym_raw_string_literal,
      anon_sym_DQUOTE,
  [52376] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(1573), 1,
      aux_sym_source_file_token1,
    ACTIONS(1575), 11,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_EQ,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_PIPE,
      anon_sym_case,
      anon_sym_default,
      sym_raw_string_literal,
      anon_sym_DQUOTE,
  [52396] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(1617), 1,
      aux_sym_source_file_token1,
    ACTIONS(1619), 11,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_EQ,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_PIPE,
      anon_sym_case,
      anon_sym_default,
      sym_raw_string_literal,
      anon_sym_DQUOTE,
  [52416] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(1621), 1,
      aux_sym_source_file_token1,
    ACTIONS(1623), 11,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_EQ,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_PIPE,
      anon_sym_case,
      anon_sym_default,
      sym_raw_string_literal,
      anon_sym_DQUOTE,
  [52436] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(1625), 1,
      aux_sym_source_file_token1,
    ACTIONS(1627), 11,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_EQ,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_PIPE,
      anon_sym_case,
      anon_sym_default,
      sym_raw_string_literal,
      anon_sym_DQUOTE,
  [52456] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(1629), 1,
      aux_sym_source_file_token1,
    ACTIONS(1631), 11,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_EQ,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_PIPE,
      anon_sym_case,
      anon_sym_default,
      sym_raw_string_literal,
      anon_sym_DQUOTE,
  [52476] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(1633), 1,
      aux_sym_source_file_token1,
    ACTIONS(1635), 11,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_EQ,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_PIPE,
      anon_sym_case,
      anon_sym_default,
      sym_raw_string_literal,
      anon_sym_DQUOTE,
  [52496] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(1637), 1,
      aux_sym_source_file_token1,
    ACTIONS(1639), 11,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_EQ,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_PIPE,
      anon_sym_case,
      anon_sym_default,
      sym_raw_string_literal,
      anon_sym_DQUOTE,
  [52516] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(1641), 1,
      aux_sym_source_file_token1,
    ACTIONS(1643), 11,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_EQ,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_PIPE,
      anon_sym_case,
      anon_sym_default,
      sym_raw_string_literal,
      anon_sym_DQUOTE,
  [52536] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(1645), 1,
      aux_sym_source_file_token1,
    ACTIONS(1647), 11,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_EQ,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_PIPE,
      anon_sym_case,
      anon_sym_default,
      sym_raw_string_literal,
      anon_sym_DQUOTE,
  [52556] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(1649), 1,
      aux_sym_source_file_token1,
    ACTIONS(1651), 11,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_EQ,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_PIPE,
      anon_sym_case,
      anon_sym_default,
      sym_raw_string_literal,
      anon_sym_DQUOTE,
  [52576] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(1653), 1,
      aux_sym_source_file_token1,
    ACTIONS(1655), 11,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_EQ,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_PIPE,
      anon_sym_case,
      anon_sym_default,
      sym_raw_string_literal,
      anon_sym_DQUOTE,
  [52596] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(1657), 1,
      aux_sym_source_file_token1,
    ACTIONS(1659), 11,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_EQ,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_PIPE,
      anon_sym_case,
      anon_sym_default,
      sym_raw_string_literal,
      anon_sym_DQUOTE,
  [52616] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(1661), 1,
      aux_sym_source_file_token1,
    ACTIONS(1663), 11,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_EQ,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_PIPE,
      anon_sym_case,
      anon_sym_default,
      sym_raw_string_literal,
      anon_sym_DQUOTE,
  [52636] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(1665), 1,
      aux_sym_source_file_token1,
    ACTIONS(1667), 11,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_EQ,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_PIPE,
      anon_sym_case,
      anon_sym_default,
      sym_raw_string_literal,
      anon_sym_DQUOTE,
  [52656] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(1669), 1,
      aux_sym_source_file_token1,
    ACTIONS(1671), 11,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_EQ,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_PIPE,
      anon_sym_case,
      anon_sym_default,
      sym_raw_string_literal,
      anon_sym_DQUOTE,
  [52676] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(1673), 1,
      aux_sym_source_file_token1,
    ACTIONS(1675), 11,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_EQ,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_PIPE,
      anon_sym_case,
      anon_sym_default,
      sym_raw_string_literal,
      anon_sym_DQUOTE,
  [52696] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(1677), 1,
      aux_sym_source_file_token1,
    ACTIONS(1679), 11,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_EQ,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_PIPE,
      anon_sym_case,
      anon_sym_default,
      sym_raw_string_literal,
      anon_sym_DQUOTE,
  [52716] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(1681), 1,
      aux_sym_source_file_token1,
    ACTIONS(1683), 11,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_EQ,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_PIPE,
      anon_sym_case,
      anon_sym_default,
      sym_raw_string_literal,
      anon_sym_DQUOTE,
  [52736] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(1681), 1,
      aux_sym_source_file_token1,
    ACTIONS(1683), 11,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_EQ,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_PIPE,
      anon_sym_case,
      anon_sym_default,
      sym_raw_string_literal,
      anon_sym_DQUOTE,
  [52756] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(1685), 1,
      aux_sym_source_file_token1,
    ACTIONS(1687), 11,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_EQ,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_PIPE,
      anon_sym_case,
      anon_sym_default,
      sym_raw_string_literal,
      anon_sym_DQUOTE,
  [52776] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(1689), 1,
      aux_sym_source_file_token1,
    ACTIONS(1691), 11,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_EQ,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_PIPE,
      anon_sym_case,
      anon_sym_default,
      sym_raw_string_literal,
      anon_sym_DQUOTE,
  [52796] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(1693), 1,
      aux_sym_source_file_token1,
    ACTIONS(1695), 11,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_EQ,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_PIPE,
      anon_sym_case,
      anon_sym_default,
      sym_raw_string_literal,
      anon_sym_DQUOTE,
  [52816] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(1697), 1,
      aux_sym_source_file_token1,
    ACTIONS(1699), 11,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_EQ,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_PIPE,
      anon_sym_case,
      anon_sym_default,
      sym_raw_string_literal,
      anon_sym_DQUOTE,
  [52836] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(1701), 1,
      aux_sym_source_file_token1,
    ACTIONS(1703), 11,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_EQ,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_PIPE,
      anon_sym_case,
      anon_sym_default,
      sym_raw_string_literal,
      anon_sym_DQUOTE,
  [52856] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(1681), 1,
      aux_sym_source_file_token1,
    ACTIONS(1683), 11,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_EQ,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_PIPE,
      anon_sym_case,
      anon_sym_default,
      sym_raw_string_literal,
      anon_sym_DQUOTE,
  [52876] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1705), 1,
      anon_sym_DOT,
    ACTIONS(1707), 1,
      anon_sym_LBRACK,
    STATE(854), 1,
      sym_type_arguments,
    ACTIONS(1044), 8,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_RBRACK,
      anon_sym_LBRACE,
      anon_sym_PIPE,
      anon_sym_COLON,
  [52899] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1712), 5,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_STAR,
      anon_sym_TILDE,
      anon_sym_LT_DASH,
    ACTIONS(1710), 6,
      anon_sym_func,
      anon_sym_struct,
      anon_sym_interface,
      anon_sym_map,
      anon_sym_chan,
      sym_identifier,
  [52918] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1716), 5,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_STAR,
      anon_sym_TILDE,
      anon_sym_LT_DASH,
    ACTIONS(1714), 6,
      anon_sym_func,
      anon_sym_struct,
      anon_sym_interface,
      anon_sym_map,
      anon_sym_chan,
      sym_identifier,
  [52937] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1720), 5,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_STAR,
      anon_sym_TILDE,
      anon_sym_LT_DASH,
    ACTIONS(1718), 6,
      anon_sym_func,
      anon_sym_struct,
      anon_sym_interface,
      anon_sym_map,
      anon_sym_chan,
      sym_identifier,
  [52956] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1722), 1,
      anon_sym_LBRACK,
    STATE(862), 1,
      sym_type_arguments,
    ACTIONS(1573), 8,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_RBRACK,
      anon_sym_LBRACE,
      anon_sym_PIPE,
      anon_sym_COLON,
  [52976] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1725), 1,
      sym_identifier,
    ACTIONS(1727), 1,
      anon_sym_DOT,
    ACTIONS(1729), 1,
      sym_blank_identifier,
    ACTIONS(1731), 1,
      anon_sym_LPAREN,
    ACTIONS(1733), 1,
      sym_raw_string_literal,
    ACTIONS(1735), 1,
      anon_sym_DQUOTE,
    STATE(1129), 1,
      sym_interpreted_string_literal,
    STATE(1227), 1,
      sym_dot,
    STATE(1076), 2,
      sym_import_spec,
      sym_import_spec_list,
  [53008] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(71), 1,
      anon_sym_DQUOTE,
    ACTIONS(1727), 1,
      anon_sym_DOT,
    ACTIONS(1737), 1,
      sym_identifier,
    ACTIONS(1739), 1,
      sym_blank_identifier,
    ACTIONS(1741), 1,
      anon_sym_LPAREN,
    ACTIONS(1743), 1,
      sym_raw_string_literal,
    STATE(1091), 1,
      sym_interpreted_string_literal,
    STATE(1149), 1,
      sym_dot,
    STATE(1171), 2,
      sym_import_spec,
      sym_import_spec_list,
  [53040] = 8,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(872), 1,
      anon_sym_LPAREN,
    ACTIONS(898), 1,
      anon_sym_DOT,
    ACTIONS(1044), 1,
      aux_sym_source_file_token1,
    ACTIONS(1560), 1,
      anon_sym_LBRACK,
    STATE(524), 1,
      sym_parameter_list,
    STATE(813), 1,
      sym_type_arguments,
    ACTIONS(1555), 4,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_RBRACE,
      anon_sym_PIPE,
  [53068] = 9,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(898), 1,
      anon_sym_DOT,
    ACTIONS(918), 1,
      anon_sym_DQUOTE,
    ACTIONS(1560), 1,
      anon_sym_LBRACK,
    ACTIONS(1745), 1,
      aux_sym_source_file_token1,
    ACTIONS(1749), 1,
      sym_raw_string_literal,
    STATE(813), 1,
      sym_type_arguments,
    STATE(1077), 1,
      sym_interpreted_string_literal,
    ACTIONS(1747), 3,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_RBRACE,
  [53098] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1705), 1,
      anon_sym_DOT,
    ACTIONS(1751), 1,
      anon_sym_LBRACK,
    STATE(854), 1,
      sym_type_arguments,
    ACTIONS(1044), 7,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_RBRACK,
      anon_sym_LBRACE,
      anon_sym_PIPE,
      anon_sym_COLON,
  [53120] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1689), 9,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LBRACE,
      anon_sym_PIPE,
      anon_sym_COLON,
  [53135] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1649), 9,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LBRACE,
      anon_sym_PIPE,
      anon_sym_COLON,
  [53150] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1613), 9,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LBRACE,
      anon_sym_PIPE,
      anon_sym_COLON,
  [53165] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(71), 1,
      anon_sym_DQUOTE,
    ACTIONS(1727), 1,
      anon_sym_DOT,
    ACTIONS(1737), 1,
      sym_identifier,
    ACTIONS(1739), 1,
      sym_blank_identifier,
    ACTIONS(1743), 1,
      sym_raw_string_literal,
    ACTIONS(1753), 1,
      anon_sym_RPAREN,
    STATE(1091), 1,
      sym_interpreted_string_literal,
    STATE(1125), 1,
      sym_import_spec,
    STATE(1149), 1,
      sym_dot,
  [53196] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1669), 9,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LBRACE,
      anon_sym_PIPE,
      anon_sym_COLON,
  [53211] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1605), 9,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LBRACE,
      anon_sym_PIPE,
      anon_sym_COLON,
  [53226] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1751), 1,
      anon_sym_LBRACK,
    STATE(862), 1,
      sym_type_arguments,
    ACTIONS(1573), 7,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_RBRACK,
      anon_sym_LBRACE,
      anon_sym_PIPE,
      anon_sym_COLON,
  [53245] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(71), 1,
      anon_sym_DQUOTE,
    ACTIONS(1727), 1,
      anon_sym_DOT,
    ACTIONS(1737), 1,
      sym_identifier,
    ACTIONS(1739), 1,
      sym_blank_identifier,
    ACTIONS(1743), 1,
      sym_raw_string_literal,
    ACTIONS(1755), 1,
      anon_sym_RPAREN,
    STATE(1091), 1,
      sym_interpreted_string_literal,
    STATE(1125), 1,
      sym_import_spec,
    STATE(1149), 1,
      sym_dot,
  [53276] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1629), 9,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LBRACE,
      anon_sym_PIPE,
      anon_sym_COLON,
  [53291] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1657), 9,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LBRACE,
      anon_sym_PIPE,
      anon_sym_COLON,
  [53306] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1625), 9,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LBRACE,
      anon_sym_PIPE,
      anon_sym_COLON,
  [53321] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1701), 9,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LBRACE,
      anon_sym_PIPE,
      anon_sym_COLON,
  [53336] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1637), 9,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LBRACE,
      anon_sym_PIPE,
      anon_sym_COLON,
  [53351] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(303), 1,
      anon_sym_LBRACE,
    ACTIONS(1722), 1,
      anon_sym_LBRACK,
    STATE(399), 1,
      sym_literal_value,
    STATE(862), 1,
      sym_type_arguments,
    ACTIONS(1573), 5,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_PIPE,
  [53374] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1685), 9,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LBRACE,
      anon_sym_PIPE,
      anon_sym_COLON,
  [53389] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1645), 9,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LBRACE,
      anon_sym_PIPE,
      anon_sym_COLON,
  [53404] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1573), 9,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LBRACE,
      anon_sym_PIPE,
      anon_sym_COLON,
  [53419] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1633), 9,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LBRACE,
      anon_sym_PIPE,
      anon_sym_COLON,
  [53434] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1677), 9,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LBRACE,
      anon_sym_PIPE,
      anon_sym_COLON,
  [53449] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(71), 1,
      anon_sym_DQUOTE,
    ACTIONS(1727), 1,
      anon_sym_DOT,
    ACTIONS(1737), 1,
      sym_identifier,
    ACTIONS(1739), 1,
      sym_blank_identifier,
    ACTIONS(1743), 1,
      sym_raw_string_literal,
    ACTIONS(1757), 1,
      anon_sym_RPAREN,
    STATE(1091), 1,
      sym_interpreted_string_literal,
    STATE(1125), 1,
      sym_import_spec,
    STATE(1149), 1,
      sym_dot,
  [53480] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1641), 9,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LBRACE,
      anon_sym_PIPE,
      anon_sym_COLON,
  [53495] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(71), 1,
      anon_sym_DQUOTE,
    ACTIONS(1727), 1,
      anon_sym_DOT,
    ACTIONS(1737), 1,
      sym_identifier,
    ACTIONS(1739), 1,
      sym_blank_identifier,
    ACTIONS(1743), 1,
      sym_raw_string_literal,
    ACTIONS(1759), 1,
      anon_sym_RPAREN,
    STATE(1091), 1,
      sym_interpreted_string_literal,
    STATE(1125), 1,
      sym_import_spec,
    STATE(1149), 1,
      sym_dot,
  [53526] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(71), 1,
      anon_sym_DQUOTE,
    ACTIONS(1727), 1,
      anon_sym_DOT,
    ACTIONS(1737), 1,
      sym_identifier,
    ACTIONS(1739), 1,
      sym_blank_identifier,
    ACTIONS(1743), 1,
      sym_raw_string_literal,
    ACTIONS(1761), 1,
      anon_sym_RPAREN,
    STATE(1039), 1,
      sym_import_spec,
    STATE(1091), 1,
      sym_interpreted_string_literal,
    STATE(1149), 1,
      sym_dot,
  [53557] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1681), 9,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LBRACE,
      anon_sym_PIPE,
      anon_sym_COLON,
  [53572] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1681), 9,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LBRACE,
      anon_sym_PIPE,
      anon_sym_COLON,
  [53587] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1653), 9,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LBRACE,
      anon_sym_PIPE,
      anon_sym_COLON,
  [53602] = 8,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(918), 1,
      anon_sym_DQUOTE,
    ACTIONS(1560), 1,
      anon_sym_LBRACK,
    ACTIONS(1763), 1,
      aux_sym_source_file_token1,
    ACTIONS(1767), 1,
      sym_raw_string_literal,
    STATE(814), 1,
      sym_type_arguments,
    STATE(1082), 1,
      sym_interpreted_string_literal,
    ACTIONS(1765), 3,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_RBRACE,
  [53629] = 8,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(918), 1,
      anon_sym_DQUOTE,
    ACTIONS(1560), 1,
      anon_sym_LBRACK,
    ACTIONS(1769), 1,
      aux_sym_source_file_token1,
    ACTIONS(1773), 1,
      sym_raw_string_literal,
    STATE(814), 1,
      sym_type_arguments,
    STATE(1115), 1,
      sym_interpreted_string_literal,
    ACTIONS(1771), 3,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_RBRACE,
  [53656] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1617), 9,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LBRACE,
      anon_sym_PIPE,
      anon_sym_COLON,
  [53671] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1693), 9,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LBRACE,
      anon_sym_PIPE,
      anon_sym_COLON,
  [53686] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(71), 1,
      anon_sym_DQUOTE,
    ACTIONS(1727), 1,
      anon_sym_DOT,
    ACTIONS(1737), 1,
      sym_identifier,
    ACTIONS(1739), 1,
      sym_blank_identifier,
    ACTIONS(1743), 1,
      sym_raw_string_literal,
    ACTIONS(1775), 1,
      anon_sym_RPAREN,
    STATE(1043), 1,
      sym_import_spec,
    STATE(1091), 1,
      sym_interpreted_string_literal,
    STATE(1149), 1,
      sym_dot,
  [53717] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1621), 9,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LBRACE,
      anon_sym_PIPE,
      anon_sym_COLON,
  [53732] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1697), 9,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LBRACE,
      anon_sym_PIPE,
      anon_sym_COLON,
  [53747] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1673), 9,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LBRACE,
      anon_sym_PIPE,
      anon_sym_COLON,
  [53762] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1681), 9,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LBRACE,
      anon_sym_PIPE,
      anon_sym_COLON,
  [53777] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1665), 9,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LBRACE,
      anon_sym_PIPE,
      anon_sym_COLON,
  [53792] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1661), 9,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_LBRACE,
      anon_sym_PIPE,
      anon_sym_COLON,
  [53807] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(1777), 1,
      sym_identifier,
    ACTIONS(1779), 1,
      anon_sym_STAR,
    ACTIONS(1781), 1,
      anon_sym_RBRACE,
    STATE(868), 1,
      sym_qualified_type,
    STATE(909), 1,
      sym_generic_type,
    STATE(1085), 1,
      sym_field_declaration,
    STATE(1257), 1,
      sym_negated_type,
  [53835] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1012), 1,
      anon_sym_LBRACE,
    STATE(408), 1,
      sym_block,
    ACTIONS(1701), 6,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_PIPE,
  [53853] = 5,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(956), 1,
      anon_sym_COMMA,
    ACTIONS(1550), 1,
      aux_sym_source_file_token1,
    STATE(888), 1,
      aux_sym_expression_list_repeat1,
    ACTIONS(1783), 5,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
  [53873] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(71), 1,
      anon_sym_DQUOTE,
    ACTIONS(1727), 1,
      anon_sym_DOT,
    ACTIONS(1737), 1,
      sym_identifier,
    ACTIONS(1739), 1,
      sym_blank_identifier,
    ACTIONS(1743), 1,
      sym_raw_string_literal,
    STATE(1091), 1,
      sym_interpreted_string_literal,
    STATE(1125), 1,
      sym_import_spec,
    STATE(1149), 1,
      sym_dot,
  [53901] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(1777), 1,
      sym_identifier,
    ACTIONS(1779), 1,
      anon_sym_STAR,
    ACTIONS(1785), 1,
      anon_sym_RBRACE,
    STATE(868), 1,
      sym_qualified_type,
    STATE(909), 1,
      sym_generic_type,
    STATE(1085), 1,
      sym_field_declaration,
    STATE(1257), 1,
      sym_negated_type,
  [53929] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(1777), 1,
      sym_identifier,
    ACTIONS(1779), 1,
      anon_sym_STAR,
    ACTIONS(1787), 1,
      anon_sym_RBRACE,
    STATE(868), 1,
      sym_qualified_type,
    STATE(909), 1,
      sym_generic_type,
    STATE(1085), 1,
      sym_field_declaration,
    STATE(1257), 1,
      sym_negated_type,
  [53957] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(1777), 1,
      sym_identifier,
    ACTIONS(1779), 1,
      anon_sym_STAR,
    ACTIONS(1789), 1,
      anon_sym_RBRACE,
    STATE(868), 1,
      sym_qualified_type,
    STATE(909), 1,
      sym_generic_type,
    STATE(1021), 1,
      sym_field_declaration,
    STATE(1257), 1,
      sym_negated_type,
  [53985] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(1777), 1,
      sym_identifier,
    ACTIONS(1779), 1,
      anon_sym_STAR,
    ACTIONS(1791), 1,
      anon_sym_RBRACE,
    STATE(868), 1,
      sym_qualified_type,
    STATE(909), 1,
      sym_generic_type,
    STATE(1085), 1,
      sym_field_declaration,
    STATE(1257), 1,
      sym_negated_type,
  [54013] = 6,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(1793), 1,
      anon_sym_DOT,
    ACTIONS(1795), 1,
      anon_sym_LBRACK,
    STATE(968), 1,
      sym_type_arguments,
    ACTIONS(1044), 2,
      ts_builtin_sym_end,
      aux_sym_source_file_token1,
    ACTIONS(1555), 3,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_LBRACE,
  [54035] = 5,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(858), 1,
      aux_sym_source_file_token1,
    ACTIONS(1798), 1,
      anon_sym_COMMA,
    STATE(888), 1,
      aux_sym_expression_list_repeat1,
    ACTIONS(860), 5,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
  [54055] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(1777), 1,
      sym_identifier,
    ACTIONS(1779), 1,
      anon_sym_STAR,
    ACTIONS(1801), 1,
      anon_sym_RBRACE,
    STATE(868), 1,
      sym_qualified_type,
    STATE(909), 1,
      sym_generic_type,
    STATE(1023), 1,
      sym_field_declaration,
    STATE(1257), 1,
      sym_negated_type,
  [54083] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(1777), 1,
      sym_identifier,
    ACTIONS(1779), 1,
      anon_sym_STAR,
    ACTIONS(1803), 1,
      anon_sym_RBRACE,
    STATE(868), 1,
      sym_qualified_type,
    STATE(909), 1,
      sym_generic_type,
    STATE(1025), 1,
      sym_field_declaration,
    STATE(1257), 1,
      sym_negated_type,
  [54111] = 6,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(1793), 1,
      anon_sym_DOT,
    ACTIONS(1805), 1,
      anon_sym_LBRACK,
    STATE(968), 1,
      sym_type_arguments,
    ACTIONS(1044), 2,
      ts_builtin_sym_end,
      aux_sym_source_file_token1,
    ACTIONS(1555), 3,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_LBRACE,
  [54133] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(1777), 1,
      sym_identifier,
    ACTIONS(1779), 1,
      anon_sym_STAR,
    ACTIONS(1807), 1,
      anon_sym_RBRACE,
    STATE(868), 1,
      sym_qualified_type,
    STATE(909), 1,
      sym_generic_type,
    STATE(1085), 1,
      sym_field_declaration,
    STATE(1257), 1,
      sym_negated_type,
  [54161] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(1777), 1,
      sym_identifier,
    ACTIONS(1779), 1,
      anon_sym_STAR,
    ACTIONS(1809), 1,
      anon_sym_RBRACE,
    STATE(868), 1,
      sym_qualified_type,
    STATE(909), 1,
      sym_generic_type,
    STATE(1085), 1,
      sym_field_declaration,
    STATE(1257), 1,
      sym_negated_type,
  [54189] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(303), 1,
      anon_sym_LBRACE,
    STATE(399), 1,
      sym_literal_value,
    ACTIONS(1573), 6,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_PIPE,
  [54207] = 5,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(1811), 1,
      anon_sym_LBRACK,
    STATE(973), 1,
      sym_type_arguments,
    ACTIONS(1573), 2,
      ts_builtin_sym_end,
      aux_sym_source_file_token1,
    ACTIONS(1575), 3,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_LBRACE,
  [54226] = 4,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(1814), 1,
      aux_sym_source_file_token1,
    ACTIONS(1818), 1,
      anon_sym_EQ,
    ACTIONS(1816), 5,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
  [54243] = 4,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(1820), 1,
      sym_identifier,
    ACTIONS(1822), 1,
      aux_sym_source_file_token1,
    ACTIONS(1824), 5,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
  [54260] = 5,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(1826), 1,
      aux_sym_source_file_token1,
    STATE(908), 1,
      aux_sym__statement_list_repeat1,
    ACTIONS(1828), 2,
      anon_sym_SEMI,
      anon_sym_NULL,
    ACTIONS(1830), 3,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
  [54279] = 5,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(1832), 1,
      aux_sym_source_file_token1,
    STATE(899), 1,
      aux_sym__statement_list_repeat1,
    ACTIONS(1835), 2,
      anon_sym_SEMI,
      anon_sym_NULL,
    ACTIONS(1838), 3,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
  [54298] = 4,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(1840), 1,
      aux_sym_source_file_token1,
    ACTIONS(1844), 1,
      anon_sym_EQ,
    ACTIONS(1842), 5,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
  [54315] = 4,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(1846), 1,
      aux_sym_source_file_token1,
    ACTIONS(1850), 1,
      anon_sym_else,
    ACTIONS(1848), 5,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
  [54332] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(1777), 1,
      sym_identifier,
    ACTIONS(1779), 1,
      anon_sym_STAR,
    STATE(868), 1,
      sym_qualified_type,
    STATE(909), 1,
      sym_generic_type,
    STATE(1085), 1,
      sym_field_declaration,
    STATE(1257), 1,
      sym_negated_type,
  [54357] = 6,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(918), 1,
      anon_sym_DQUOTE,
    ACTIONS(1852), 1,
      aux_sym_source_file_token1,
    ACTIONS(1856), 1,
      sym_raw_string_literal,
    STATE(1058), 1,
      sym_interpreted_string_literal,
    ACTIONS(1854), 3,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_RBRACE,
  [54378] = 4,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(1858), 1,
      aux_sym_source_file_token1,
    ACTIONS(1862), 1,
      anon_sym_else,
    ACTIONS(1860), 5,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
  [54395] = 6,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(918), 1,
      anon_sym_DQUOTE,
    ACTIONS(1852), 1,
      aux_sym_source_file_token1,
    ACTIONS(1864), 1,
      sym_raw_string_literal,
    STATE(1056), 1,
      sym_interpreted_string_literal,
    ACTIONS(1854), 3,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_RBRACE,
  [54416] = 6,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(918), 1,
      anon_sym_DQUOTE,
    ACTIONS(1866), 1,
      aux_sym_source_file_token1,
    ACTIONS(1870), 1,
      sym_raw_string_literal,
    STATE(1059), 1,
      sym_interpreted_string_literal,
    ACTIONS(1868), 3,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_RBRACE,
  [54437] = 6,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(918), 1,
      anon_sym_DQUOTE,
    ACTIONS(1769), 1,
      aux_sym_source_file_token1,
    ACTIONS(1773), 1,
      sym_raw_string_literal,
    STATE(1115), 1,
      sym_interpreted_string_literal,
    ACTIONS(1771), 3,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_RBRACE,
  [54458] = 5,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(1872), 1,
      aux_sym_source_file_token1,
    STATE(899), 1,
      aux_sym__statement_list_repeat1,
    ACTIONS(1874), 2,
      anon_sym_SEMI,
      anon_sym_NULL,
    ACTIONS(207), 3,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
  [54477] = 6,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(918), 1,
      anon_sym_DQUOTE,
    ACTIONS(1763), 1,
      aux_sym_source_file_token1,
    ACTIONS(1767), 1,
      sym_raw_string_literal,
    STATE(1082), 1,
      sym_interpreted_string_literal,
    ACTIONS(1765), 3,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_RBRACE,
  [54498] = 5,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(1805), 1,
      anon_sym_LBRACK,
    STATE(973), 1,
      sym_type_arguments,
    ACTIONS(1573), 2,
      ts_builtin_sym_end,
      aux_sym_source_file_token1,
    ACTIONS(1575), 3,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_LBRACE,
  [54517] = 4,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(1814), 1,
      aux_sym_source_file_token1,
    ACTIONS(1876), 1,
      anon_sym_EQ,
    ACTIONS(1816), 5,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
  [54534] = 4,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(1878), 1,
      sym_identifier,
    ACTIONS(1880), 1,
      aux_sym_source_file_token1,
    ACTIONS(1882), 5,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
  [54551] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(1884), 1,
      aux_sym_source_file_token1,
    ACTIONS(1886), 5,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
  [54565] = 5,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(1079), 1,
      anon_sym_LBRACE,
    STATE(1053), 1,
      sym_block,
    ACTIONS(1888), 2,
      ts_builtin_sym_end,
      aux_sym_source_file_token1,
    ACTIONS(1890), 2,
      anon_sym_SEMI,
      anon_sym_NULL,
  [54583] = 5,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(1079), 1,
      anon_sym_LBRACE,
    STATE(1054), 1,
      sym_block,
    ACTIONS(1892), 2,
      ts_builtin_sym_end,
      aux_sym_source_file_token1,
    ACTIONS(1894), 2,
      anon_sym_SEMI,
      anon_sym_NULL,
  [54601] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1896), 1,
      anon_sym_RBRACE,
    ACTIONS(1898), 1,
      anon_sym_case,
    ACTIONS(1900), 1,
      anon_sym_default,
    STATE(998), 3,
      sym_default_case,
      sym_communication_case,
      aux_sym_select_statement_repeat1,
  [54619] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(1693), 2,
      ts_builtin_sym_end,
      aux_sym_source_file_token1,
    ACTIONS(1695), 4,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
  [54633] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(1697), 2,
      ts_builtin_sym_end,
      aux_sym_source_file_token1,
    ACTIONS(1699), 4,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
  [54647] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(1701), 2,
      ts_builtin_sym_end,
      aux_sym_source_file_token1,
    ACTIONS(1703), 4,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
  [54661] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(1681), 2,
      ts_builtin_sym_end,
      aux_sym_source_file_token1,
    ACTIONS(1683), 4,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
  [54675] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(1689), 2,
      ts_builtin_sym_end,
      aux_sym_source_file_token1,
    ACTIONS(1691), 4,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
  [54689] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(1902), 1,
      aux_sym_source_file_token1,
    ACTIONS(1904), 5,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
  [54703] = 5,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(1906), 1,
      aux_sym_source_file_token1,
    ACTIONS(1910), 1,
      anon_sym_PIPE,
    STATE(923), 1,
      aux_sym_type_elem_repeat1,
    ACTIONS(1908), 3,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_RBRACE,
  [54721] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(1605), 2,
      ts_builtin_sym_end,
      aux_sym_source_file_token1,
    ACTIONS(1607), 4,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
  [54735] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(1913), 1,
      aux_sym_source_file_token1,
    ACTIONS(1915), 5,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
  [54749] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(1917), 1,
      aux_sym_source_file_token1,
    ACTIONS(1919), 5,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
  [54763] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(1921), 1,
      aux_sym_source_file_token1,
    ACTIONS(1923), 5,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
  [54777] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1900), 1,
      anon_sym_default,
    ACTIONS(1925), 1,
      anon_sym_RBRACE,
    ACTIONS(1927), 1,
      anon_sym_case,
    STATE(985), 3,
      sym_expression_case,
      sym_default_case,
      aux_sym_expression_switch_statement_repeat1,
  [54795] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1900), 1,
      anon_sym_default,
    ACTIONS(1927), 1,
      anon_sym_case,
    ACTIONS(1929), 1,
      anon_sym_RBRACE,
    STATE(958), 3,
      sym_expression_case,
      sym_default_case,
      aux_sym_expression_switch_statement_repeat1,
  [54813] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(1931), 1,
      aux_sym_source_file_token1,
    ACTIONS(1933), 5,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
  [54827] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1935), 1,
      anon_sym_RBRACE,
    ACTIONS(1937), 1,
      anon_sym_case,
    ACTIONS(1940), 1,
      anon_sym_default,
    STATE(931), 3,
      sym_default_case,
      sym_type_case,
      aux_sym_type_switch_statement_repeat1,
  [54845] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(1943), 1,
      aux_sym_source_file_token1,
    ACTIONS(1945), 5,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
  [54859] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(1947), 1,
      aux_sym_source_file_token1,
    ACTIONS(1949), 5,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
  [54873] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(1951), 1,
      aux_sym_source_file_token1,
    ACTIONS(1953), 5,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
  [54887] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(1955), 1,
      aux_sym_source_file_token1,
    ACTIONS(1957), 5,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
  [54901] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(1657), 2,
      ts_builtin_sym_end,
      aux_sym_source_file_token1,
    ACTIONS(1659), 4,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
  [54915] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(1613), 2,
      ts_builtin_sym_end,
      aux_sym_source_file_token1,
    ACTIONS(1615), 4,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
  [54929] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(1625), 2,
      ts_builtin_sym_end,
      aux_sym_source_file_token1,
    ACTIONS(1627), 4,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
  [54943] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(1633), 2,
      ts_builtin_sym_end,
      aux_sym_source_file_token1,
    ACTIONS(1635), 4,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
  [54957] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(1959), 1,
      aux_sym_source_file_token1,
    ACTIONS(1961), 5,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
  [54971] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(1963), 1,
      aux_sym_source_file_token1,
    ACTIONS(1965), 5,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
  [54985] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(1645), 2,
      ts_builtin_sym_end,
      aux_sym_source_file_token1,
    ACTIONS(1647), 4,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
  [54999] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(1967), 1,
      aux_sym_source_file_token1,
    ACTIONS(1969), 5,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
  [55013] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(1661), 2,
      ts_builtin_sym_end,
      aux_sym_source_file_token1,
    ACTIONS(1663), 4,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
  [55027] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1044), 1,
      anon_sym_LBRACE,
    ACTIONS(1705), 1,
      anon_sym_DOT,
    ACTIONS(1707), 1,
      anon_sym_LBRACK,
    ACTIONS(1971), 1,
      anon_sym_LPAREN,
    STATE(500), 1,
      sym_parameter_list,
    STATE(854), 1,
      sym_type_arguments,
  [55049] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(1673), 2,
      ts_builtin_sym_end,
      aux_sym_source_file_token1,
    ACTIONS(1675), 4,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
  [55063] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(1973), 1,
      aux_sym_source_file_token1,
    ACTIONS(1975), 5,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
  [55077] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(1977), 1,
      aux_sym_source_file_token1,
    ACTIONS(1979), 5,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
  [55091] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(1981), 1,
      aux_sym_source_file_token1,
    ACTIONS(1983), 5,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
  [55105] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(1573), 2,
      ts_builtin_sym_end,
      aux_sym_source_file_token1,
    ACTIONS(1575), 4,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
  [55119] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(1981), 1,
      aux_sym_source_file_token1,
    ACTIONS(1983), 5,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
  [55133] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1669), 6,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_PIPE,
  [55145] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(1617), 2,
      ts_builtin_sym_end,
      aux_sym_source_file_token1,
    ACTIONS(1619), 4,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
  [55159] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(1621), 2,
      ts_builtin_sym_end,
      aux_sym_source_file_token1,
    ACTIONS(1623), 4,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
  [55173] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(1985), 1,
      aux_sym_source_file_token1,
    ACTIONS(1987), 5,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
  [55187] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(1989), 1,
      aux_sym_source_file_token1,
    ACTIONS(1991), 5,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
  [55201] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(1993), 1,
      aux_sym_source_file_token1,
    ACTIONS(1995), 5,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
  [55215] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1900), 1,
      anon_sym_default,
    ACTIONS(1927), 1,
      anon_sym_case,
    ACTIONS(1997), 1,
      anon_sym_RBRACE,
    STATE(985), 3,
      sym_expression_case,
      sym_default_case,
      aux_sym_expression_switch_statement_repeat1,
  [55233] = 5,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(1079), 1,
      anon_sym_LBRACE,
    STATE(1128), 1,
      sym_block,
    ACTIONS(1999), 2,
      ts_builtin_sym_end,
      aux_sym_source_file_token1,
    ACTIONS(2001), 2,
      anon_sym_SEMI,
      anon_sym_NULL,
  [55251] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(2003), 1,
      aux_sym_source_file_token1,
    ACTIONS(2005), 5,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
  [55265] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(1629), 2,
      ts_builtin_sym_end,
      aux_sym_source_file_token1,
    ACTIONS(1631), 4,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
  [55279] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(2007), 1,
      aux_sym_source_file_token1,
    ACTIONS(2009), 5,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
  [55293] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(2011), 1,
      aux_sym_source_file_token1,
    ACTIONS(2013), 5,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
  [55307] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1900), 1,
      anon_sym_default,
    ACTIONS(1927), 1,
      anon_sym_case,
    ACTIONS(2015), 1,
      anon_sym_RBRACE,
    STATE(967), 3,
      sym_expression_case,
      sym_default_case,
      aux_sym_expression_switch_statement_repeat1,
  [55325] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(2017), 1,
      aux_sym_source_file_token1,
    ACTIONS(2019), 5,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
  [55339] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(2021), 1,
      aux_sym_source_file_token1,
    ACTIONS(2023), 5,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
  [55353] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1900), 1,
      anon_sym_default,
    ACTIONS(1927), 1,
      anon_sym_case,
    ACTIONS(2025), 1,
      anon_sym_RBRACE,
    STATE(985), 3,
      sym_expression_case,
      sym_default_case,
      aux_sym_expression_switch_statement_repeat1,
  [55371] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(1637), 2,
      ts_builtin_sym_end,
      aux_sym_source_file_token1,
    ACTIONS(1639), 4,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
  [55385] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(2027), 1,
      aux_sym_source_file_token1,
    ACTIONS(2029), 5,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
  [55399] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(2031), 1,
      aux_sym_source_file_token1,
    ACTIONS(2033), 5,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
  [55413] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(2035), 1,
      aux_sym_source_file_token1,
    ACTIONS(2037), 5,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
  [55427] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(860), 1,
      anon_sym_COLON,
    ACTIONS(2039), 1,
      anon_sym_COMMA,
    STATE(972), 1,
      aux_sym_expression_list_repeat1,
    ACTIONS(858), 3,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
  [55445] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(1641), 2,
      ts_builtin_sym_end,
      aux_sym_source_file_token1,
    ACTIONS(1643), 4,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
  [55459] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(2042), 1,
      aux_sym_source_file_token1,
    ACTIONS(1838), 5,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
  [55473] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(2044), 1,
      aux_sym_source_file_token1,
    ACTIONS(2046), 5,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
  [55487] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1044), 1,
      anon_sym_LBRACE,
    ACTIONS(1705), 1,
      anon_sym_DOT,
    ACTIONS(1707), 1,
      anon_sym_LBRACK,
    ACTIONS(2048), 1,
      anon_sym_LPAREN,
    STATE(454), 1,
      sym_parameter_list,
    STATE(854), 1,
      sym_type_arguments,
  [55509] = 5,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(2050), 1,
      aux_sym_source_file_token1,
    ACTIONS(2054), 1,
      anon_sym_PIPE,
    STATE(923), 1,
      aux_sym_type_elem_repeat1,
    ACTIONS(2052), 3,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_RBRACE,
  [55527] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(2056), 1,
      aux_sym_source_file_token1,
    ACTIONS(2058), 5,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
  [55541] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1018), 1,
      anon_sym_COMMA,
    ACTIONS(1783), 1,
      anon_sym_COLON,
    STATE(972), 1,
      aux_sym_expression_list_repeat1,
    ACTIONS(1550), 3,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
  [55559] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(1649), 2,
      ts_builtin_sym_end,
      aux_sym_source_file_token1,
    ACTIONS(1651), 4,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
  [55573] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1898), 1,
      anon_sym_case,
    ACTIONS(1900), 1,
      anon_sym_default,
    ACTIONS(2060), 1,
      anon_sym_RBRACE,
    STATE(916), 3,
      sym_default_case,
      sym_communication_case,
      aux_sym_select_statement_repeat1,
  [55591] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1900), 1,
      anon_sym_default,
    ACTIONS(2062), 1,
      anon_sym_RBRACE,
    ACTIONS(2064), 1,
      anon_sym_case,
    STATE(993), 3,
      sym_default_case,
      sym_type_case,
      aux_sym_type_switch_statement_repeat1,
  [55609] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(1653), 2,
      ts_builtin_sym_end,
      aux_sym_source_file_token1,
    ACTIONS(1655), 4,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
  [55623] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(2066), 1,
      aux_sym_source_file_token1,
    ACTIONS(2068), 5,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
  [55637] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2070), 1,
      anon_sym_RBRACE,
    ACTIONS(2072), 1,
      anon_sym_case,
    ACTIONS(2075), 1,
      anon_sym_default,
    STATE(985), 3,
      sym_expression_case,
      sym_default_case,
      aux_sym_expression_switch_statement_repeat1,
  [55655] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1900), 1,
      anon_sym_default,
    ACTIONS(1927), 1,
      anon_sym_case,
    ACTIONS(2078), 1,
      anon_sym_RBRACE,
    STATE(996), 3,
      sym_expression_case,
      sym_default_case,
      aux_sym_expression_switch_statement_repeat1,
  [55673] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(2080), 1,
      aux_sym_source_file_token1,
    ACTIONS(2082), 5,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
  [55687] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1900), 1,
      anon_sym_default,
    ACTIONS(1927), 1,
      anon_sym_case,
    ACTIONS(2084), 1,
      anon_sym_RBRACE,
    STATE(928), 3,
      sym_expression_case,
      sym_default_case,
      aux_sym_expression_switch_statement_repeat1,
  [55705] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(1665), 2,
      ts_builtin_sym_end,
      aux_sym_source_file_token1,
    ACTIONS(1667), 4,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
  [55719] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(2086), 1,
      aux_sym_source_file_token1,
    ACTIONS(2088), 5,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
  [55733] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(2090), 1,
      aux_sym_source_file_token1,
    ACTIONS(2092), 5,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
  [55747] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(1669), 2,
      ts_builtin_sym_end,
      aux_sym_source_file_token1,
    ACTIONS(1671), 4,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
  [55761] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1900), 1,
      anon_sym_default,
    ACTIONS(2064), 1,
      anon_sym_case,
    ACTIONS(2094), 1,
      anon_sym_RBRACE,
    STATE(931), 3,
      sym_default_case,
      sym_type_case,
      aux_sym_type_switch_statement_repeat1,
  [55779] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(2096), 1,
      aux_sym_source_file_token1,
    ACTIONS(2098), 5,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
  [55793] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(2100), 1,
      aux_sym_source_file_token1,
    ACTIONS(2102), 5,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
  [55807] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1900), 1,
      anon_sym_default,
    ACTIONS(1927), 1,
      anon_sym_case,
    ACTIONS(2104), 1,
      anon_sym_RBRACE,
    STATE(985), 3,
      sym_expression_case,
      sym_default_case,
      aux_sym_expression_switch_statement_repeat1,
  [55825] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(2106), 1,
      aux_sym_source_file_token1,
    ACTIONS(2108), 5,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
  [55839] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2110), 1,
      anon_sym_RBRACE,
    ACTIONS(2112), 1,
      anon_sym_case,
    ACTIONS(2115), 1,
      anon_sym_default,
    STATE(998), 3,
      sym_default_case,
      sym_communication_case,
      aux_sym_select_statement_repeat1,
  [55857] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(1677), 2,
      ts_builtin_sym_end,
      aux_sym_source_file_token1,
    ACTIONS(1679), 4,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
  [55871] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(1681), 2,
      ts_builtin_sym_end,
      aux_sym_source_file_token1,
    ACTIONS(1683), 4,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
  [55885] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(1681), 2,
      ts_builtin_sym_end,
      aux_sym_source_file_token1,
    ACTIONS(1683), 4,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
  [55899] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(1685), 2,
      ts_builtin_sym_end,
      aux_sym_source_file_token1,
    ACTIONS(1687), 4,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
  [55913] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(2118), 1,
      aux_sym_source_file_token1,
    ACTIONS(2120), 5,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
  [55927] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2122), 1,
      anon_sym_LPAREN,
    ACTIONS(2126), 1,
      anon_sym_LBRACK,
    ACTIONS(2128), 1,
      anon_sym_PIPE,
    STATE(1132), 1,
      aux_sym_type_elem_repeat1,
    ACTIONS(2124), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
  [55947] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(2130), 1,
      aux_sym_source_file_token1,
    ACTIONS(2132), 5,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
  [55961] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(2134), 1,
      aux_sym_source_file_token1,
    ACTIONS(2136), 5,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
  [55975] = 5,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(2054), 1,
      anon_sym_PIPE,
    ACTIONS(2124), 1,
      aux_sym_source_file_token1,
    STATE(977), 1,
      aux_sym_type_elem_repeat1,
    ACTIONS(2138), 3,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_RBRACE,
  [55993] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(2140), 1,
      aux_sym_source_file_token1,
    ACTIONS(2142), 5,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
  [56007] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(2144), 1,
      aux_sym_source_file_token1,
    ACTIONS(2146), 5,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
  [56021] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(2148), 1,
      aux_sym_source_file_token1,
    ACTIONS(2150), 5,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
  [56035] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(2152), 1,
      aux_sym_source_file_token1,
    ACTIONS(2154), 5,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
  [56049] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(2156), 1,
      aux_sym_source_file_token1,
    ACTIONS(2158), 5,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
  [56063] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(2160), 1,
      aux_sym_source_file_token1,
    ACTIONS(2162), 5,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
  [56077] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(2164), 1,
      aux_sym_source_file_token1,
    ACTIONS(2166), 5,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
  [56091] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(2168), 1,
      aux_sym_source_file_token1,
    ACTIONS(2170), 5,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
  [56105] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(2172), 1,
      aux_sym_source_file_token1,
    ACTIONS(2174), 5,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
  [56119] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(2176), 1,
      aux_sym_source_file_token1,
    ACTIONS(2178), 5,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
  [56133] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1573), 1,
      anon_sym_LPAREN,
    ACTIONS(1722), 1,
      anon_sym_LBRACK,
    ACTIONS(2180), 1,
      anon_sym_LBRACE,
    STATE(305), 1,
      sym_literal_value,
    STATE(862), 1,
      sym_type_arguments,
  [56152] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2182), 1,
      sym_identifier,
    ACTIONS(2185), 1,
      anon_sym_RPAREN,
    STATE(1019), 1,
      aux_sym_type_declaration_repeat1,
    STATE(1176), 2,
      sym_type_alias,
      sym_type_spec,
  [56169] = 5,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(2187), 1,
      aux_sym_source_file_token1,
    ACTIONS(2191), 1,
      anon_sym_RBRACE,
    STATE(1028), 1,
      aux_sym_interface_type_repeat1,
    ACTIONS(2189), 2,
      anon_sym_SEMI,
      anon_sym_NULL,
  [56186] = 5,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(2193), 1,
      aux_sym_source_file_token1,
    ACTIONS(2197), 1,
      anon_sym_RBRACE,
    STATE(1047), 1,
      aux_sym_field_declaration_list_repeat1,
    ACTIONS(2195), 2,
      anon_sym_SEMI,
      anon_sym_NULL,
  [56203] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1057), 1,
      anon_sym_LBRACE,
    ACTIONS(1573), 1,
      anon_sym_LPAREN,
    ACTIONS(1722), 1,
      anon_sym_LBRACK,
    STATE(543), 1,
      sym_literal_value,
    STATE(862), 1,
      sym_type_arguments,
  [56222] = 5,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(2199), 1,
      aux_sym_source_file_token1,
    ACTIONS(2203), 1,
      anon_sym_RBRACE,
    STATE(1030), 1,
      aux_sym_field_declaration_list_repeat1,
    ACTIONS(2201), 2,
      anon_sym_SEMI,
      anon_sym_NULL,
  [56239] = 5,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(2205), 1,
      aux_sym_source_file_token1,
    ACTIONS(2209), 1,
      anon_sym_RBRACE,
    STATE(1035), 1,
      aux_sym_interface_type_repeat1,
    ACTIONS(2207), 2,
      anon_sym_SEMI,
      anon_sym_NULL,
  [56256] = 5,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(2211), 1,
      aux_sym_source_file_token1,
    ACTIONS(2215), 1,
      anon_sym_RBRACE,
    STATE(1040), 1,
      aux_sym_field_declaration_list_repeat1,
    ACTIONS(2213), 2,
      anon_sym_SEMI,
      anon_sym_NULL,
  [56273] = 5,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(2217), 1,
      aux_sym_source_file_token1,
    ACTIONS(2221), 1,
      anon_sym_RBRACE,
    STATE(1020), 1,
      aux_sym_interface_type_repeat1,
    ACTIONS(2219), 2,
      anon_sym_SEMI,
      anon_sym_NULL,
  [56290] = 5,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(2223), 1,
      aux_sym_source_file_token1,
    ACTIONS(2227), 1,
      anon_sym_RBRACE,
    STATE(1028), 1,
      aux_sym_interface_type_repeat1,
    ACTIONS(2225), 2,
      anon_sym_SEMI,
      anon_sym_NULL,
  [56307] = 5,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(2229), 1,
      aux_sym_source_file_token1,
    ACTIONS(2235), 1,
      anon_sym_RBRACE,
    STATE(1028), 1,
      aux_sym_interface_type_repeat1,
    ACTIONS(2232), 2,
      anon_sym_SEMI,
      anon_sym_NULL,
  [56324] = 5,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(2237), 1,
      aux_sym_source_file_token1,
    ACTIONS(2241), 1,
      anon_sym_RPAREN,
    STATE(1037), 1,
      aux_sym_import_spec_list_repeat1,
    ACTIONS(2239), 2,
      anon_sym_SEMI,
      anon_sym_NULL,
  [56341] = 5,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(2243), 1,
      aux_sym_source_file_token1,
    ACTIONS(2247), 1,
      anon_sym_RBRACE,
    STATE(1036), 1,
      aux_sym_field_declaration_list_repeat1,
    ACTIONS(2245), 2,
      anon_sym_SEMI,
      anon_sym_NULL,
  [56358] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(840), 1,
      anon_sym_LBRACE,
    ACTIONS(1573), 1,
      anon_sym_LPAREN,
    ACTIONS(1722), 1,
      anon_sym_LBRACK,
    STATE(367), 1,
      sym_literal_value,
    STATE(862), 1,
      sym_type_arguments,
  [56377] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1573), 1,
      anon_sym_LPAREN,
    ACTIONS(1722), 1,
      anon_sym_LBRACK,
    ACTIONS(2249), 1,
      anon_sym_LBRACE,
    STATE(254), 1,
      sym_literal_value,
    STATE(862), 1,
      sym_type_arguments,
  [56396] = 5,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(2251), 1,
      aux_sym_source_file_token1,
    ACTIONS(2255), 1,
      anon_sym_RPAREN,
    STATE(1037), 1,
      aux_sym_import_spec_list_repeat1,
    ACTIONS(2253), 2,
      anon_sym_SEMI,
      anon_sym_NULL,
  [56413] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2257), 1,
      sym_identifier,
    ACTIONS(2259), 1,
      anon_sym_RPAREN,
    STATE(1042), 1,
      aux_sym_type_declaration_repeat1,
    STATE(1176), 2,
      sym_type_alias,
      sym_type_spec,
  [56430] = 5,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(2261), 1,
      aux_sym_source_file_token1,
    ACTIONS(2265), 1,
      anon_sym_RBRACE,
    STATE(1028), 1,
      aux_sym_interface_type_repeat1,
    ACTIONS(2263), 2,
      anon_sym_SEMI,
      anon_sym_NULL,
  [56447] = 5,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(2267), 1,
      aux_sym_source_file_token1,
    ACTIONS(2273), 1,
      anon_sym_RBRACE,
    STATE(1036), 1,
      aux_sym_field_declaration_list_repeat1,
    ACTIONS(2270), 2,
      anon_sym_SEMI,
      anon_sym_NULL,
  [56464] = 5,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(2275), 1,
      aux_sym_source_file_token1,
    ACTIONS(2281), 1,
      anon_sym_RPAREN,
    STATE(1037), 1,
      aux_sym_import_spec_list_repeat1,
    ACTIONS(2278), 2,
      anon_sym_SEMI,
      anon_sym_NULL,
  [56481] = 5,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(2283), 1,
      aux_sym_source_file_token1,
    ACTIONS(2287), 1,
      anon_sym_RBRACE,
    STATE(1027), 1,
      aux_sym_interface_type_repeat1,
    ACTIONS(2285), 2,
      anon_sym_SEMI,
      anon_sym_NULL,
  [56498] = 5,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(2289), 1,
      aux_sym_source_file_token1,
    ACTIONS(2293), 1,
      anon_sym_RPAREN,
    STATE(1029), 1,
      aux_sym_import_spec_list_repeat1,
    ACTIONS(2291), 2,
      anon_sym_SEMI,
      anon_sym_NULL,
  [56515] = 5,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(2295), 1,
      aux_sym_source_file_token1,
    ACTIONS(2299), 1,
      anon_sym_RBRACE,
    STATE(1036), 1,
      aux_sym_field_declaration_list_repeat1,
    ACTIONS(2297), 2,
      anon_sym_SEMI,
      anon_sym_NULL,
  [56532] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1573), 1,
      anon_sym_LPAREN,
    ACTIONS(1722), 1,
      anon_sym_LBRACK,
    ACTIONS(2301), 1,
      anon_sym_LBRACE,
    STATE(507), 1,
      sym_literal_value,
    STATE(862), 1,
      sym_type_arguments,
  [56551] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2257), 1,
      sym_identifier,
    ACTIONS(2303), 1,
      anon_sym_RPAREN,
    STATE(1019), 1,
      aux_sym_type_declaration_repeat1,
    STATE(1176), 2,
      sym_type_alias,
      sym_type_spec,
  [56568] = 5,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(2305), 1,
      aux_sym_source_file_token1,
    ACTIONS(2309), 1,
      anon_sym_RPAREN,
    STATE(1033), 1,
      aux_sym_import_spec_list_repeat1,
    ACTIONS(2307), 2,
      anon_sym_SEMI,
      anon_sym_NULL,
  [56585] = 5,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(1129), 1,
      anon_sym_LBRACE,
    ACTIONS(1999), 1,
      aux_sym_source_file_token1,
    STATE(1234), 1,
      sym_block,
    ACTIONS(2001), 2,
      anon_sym_SEMI,
      anon_sym_NULL,
  [56602] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(1906), 1,
      aux_sym_source_file_token1,
    ACTIONS(1908), 4,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_RBRACE,
      anon_sym_PIPE,
  [56615] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(31), 1,
      anon_sym_TILDE,
    ACTIONS(2311), 1,
      sym_identifier,
    STATE(869), 1,
      sym_qualified_type,
    STATE(907), 1,
      sym_generic_type,
    STATE(1257), 1,
      sym_negated_type,
  [56634] = 5,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(2313), 1,
      aux_sym_source_file_token1,
    ACTIONS(2317), 1,
      anon_sym_RBRACE,
    STATE(1036), 1,
      aux_sym_field_declaration_list_repeat1,
    ACTIONS(2315), 2,
      anon_sym_SEMI,
      anon_sym_NULL,
  [56651] = 5,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(1129), 1,
      anon_sym_LBRACE,
    ACTIONS(1892), 1,
      aux_sym_source_file_token1,
    STATE(1212), 1,
      sym_block,
    ACTIONS(1894), 2,
      anon_sym_SEMI,
      anon_sym_NULL,
  [56668] = 5,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(1129), 1,
      anon_sym_LBRACE,
    ACTIONS(1888), 1,
      aux_sym_source_file_token1,
    STATE(1211), 1,
      sym_block,
    ACTIONS(1890), 2,
      anon_sym_SEMI,
      anon_sym_NULL,
  [56685] = 4,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(2319), 1,
      anon_sym_DQUOTE2,
    STATE(1080), 1,
      aux_sym_interpreted_string_literal_repeat1,
    ACTIONS(2321), 2,
      sym__interpreted_string_literal_basic_content,
      sym_escape_sequence,
  [56699] = 4,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(2323), 1,
      anon_sym_DQUOTE2,
    STATE(1116), 1,
      aux_sym_interpreted_string_literal_repeat1,
    ACTIONS(2325), 2,
      sym__interpreted_string_literal_basic_content,
      sym_escape_sequence,
  [56713] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2327), 1,
      anon_sym_COMMA,
    ACTIONS(2329), 1,
      anon_sym_RBRACE,
    ACTIONS(2331), 1,
      anon_sym_COLON,
    STATE(1209), 1,
      aux_sym_literal_value_repeat1,
  [56729] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(2333), 2,
      ts_builtin_sym_end,
      aux_sym_source_file_token1,
    ACTIONS(2335), 2,
      anon_sym_SEMI,
      anon_sym_NULL,
  [56741] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(2337), 2,
      ts_builtin_sym_end,
      aux_sym_source_file_token1,
    ACTIONS(2339), 2,
      anon_sym_SEMI,
      anon_sym_NULL,
  [56753] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(2341), 1,
      aux_sym_source_file_token1,
    ACTIONS(2343), 3,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_RBRACE,
  [56765] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(2341), 1,
      aux_sym_source_file_token1,
    ACTIONS(2343), 3,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_RBRACE,
  [56777] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(2341), 1,
      aux_sym_source_file_token1,
    ACTIONS(2343), 3,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_RBRACE,
  [56789] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(2341), 1,
      aux_sym_source_file_token1,
    ACTIONS(2343), 3,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_RBRACE,
  [56801] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(2345), 1,
      aux_sym_source_file_token1,
    ACTIONS(2347), 3,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_RBRACE,
  [56813] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(2349), 2,
      ts_builtin_sym_end,
      aux_sym_source_file_token1,
    ACTIONS(2351), 2,
      anon_sym_SEMI,
      anon_sym_NULL,
  [56825] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2353), 1,
      sym_identifier,
    ACTIONS(2355), 1,
      anon_sym_RPAREN,
    STATE(1089), 1,
      aux_sym_var_spec_list_repeat1,
    STATE(1154), 1,
      sym_var_spec,
  [56841] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(33), 1,
      anon_sym_LBRACE,
    ACTIONS(2357), 1,
      anon_sym_if,
    STATE(969), 2,
      sym_block,
      sym_if_statement,
  [56855] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(651), 2,
      ts_builtin_sym_end,
      aux_sym_source_file_token1,
    ACTIONS(653), 2,
      anon_sym_SEMI,
      anon_sym_NULL,
  [56867] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(2359), 2,
      ts_builtin_sym_end,
      aux_sym_source_file_token1,
    ACTIONS(2361), 2,
      anon_sym_SEMI,
      anon_sym_NULL,
  [56879] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(2363), 2,
      ts_builtin_sym_end,
      aux_sym_source_file_token1,
    ACTIONS(2365), 2,
      anon_sym_SEMI,
      anon_sym_NULL,
  [56891] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(2367), 2,
      ts_builtin_sym_end,
      aux_sym_source_file_token1,
    ACTIONS(2369), 2,
      anon_sym_SEMI,
      anon_sym_NULL,
  [56903] = 4,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(2371), 1,
      anon_sym_DQUOTE2,
    STATE(1071), 1,
      aux_sym_interpreted_string_literal_repeat1,
    ACTIONS(2373), 2,
      sym__interpreted_string_literal_basic_content,
      sym_escape_sequence,
  [56917] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2301), 1,
      anon_sym_LBRACE,
    STATE(507), 1,
      sym_literal_value,
    ACTIONS(1573), 2,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
  [56931] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(2375), 2,
      ts_builtin_sym_end,
      aux_sym_source_file_token1,
    ACTIONS(2377), 2,
      anon_sym_SEMI,
      anon_sym_NULL,
  [56943] = 4,
    ACTIONS(75), 1,
      ts_builtin_sym_end,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(2379), 1,
      aux_sym_source_file_token1,
    ACTIONS(2381), 2,
      anon_sym_SEMI,
      anon_sym_NULL,
  [56957] = 4,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(2383), 1,
      anon_sym_DQUOTE2,
    STATE(1080), 1,
      aux_sym_interpreted_string_literal_repeat1,
    ACTIONS(2321), 2,
      sym__interpreted_string_literal_basic_content,
      sym_escape_sequence,
  [56971] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1345), 1,
      anon_sym_LBRACE,
    STATE(468), 1,
      sym_block,
    ACTIONS(1701), 2,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
  [56985] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2331), 1,
      anon_sym_COLON,
    ACTIONS(2385), 1,
      anon_sym_COMMA,
    ACTIONS(2387), 1,
      anon_sym_RBRACE,
    STATE(1144), 1,
      aux_sym_literal_value_repeat1,
  [57001] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(2389), 1,
      aux_sym_source_file_token1,
    ACTIONS(2235), 3,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_RBRACE,
  [57013] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2353), 1,
      sym_identifier,
    ACTIONS(2391), 1,
      anon_sym_RPAREN,
    STATE(1061), 1,
      aux_sym_var_spec_list_repeat1,
    STATE(1154), 1,
      sym_var_spec,
  [57029] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(2393), 2,
      ts_builtin_sym_end,
      aux_sym_source_file_token1,
    ACTIONS(2395), 2,
      anon_sym_SEMI,
      anon_sym_NULL,
  [57041] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(2397), 1,
      aux_sym_source_file_token1,
    ACTIONS(2399), 3,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_RBRACE,
  [57053] = 4,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(2401), 1,
      anon_sym_DQUOTE2,
    STATE(1098), 1,
      aux_sym_interpreted_string_literal_repeat1,
    ACTIONS(2403), 2,
      sym__interpreted_string_literal_basic_content,
      sym_escape_sequence,
  [57067] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(2405), 1,
      aux_sym_source_file_token1,
    ACTIONS(2407), 3,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_RBRACE,
  [57079] = 4,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(2409), 1,
      anon_sym_DQUOTE2,
    STATE(1080), 1,
      aux_sym_interpreted_string_literal_repeat1,
    ACTIONS(2411), 2,
      sym__interpreted_string_literal_basic_content,
      sym_escape_sequence,
  [57093] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(2414), 2,
      ts_builtin_sym_end,
      aux_sym_source_file_token1,
    ACTIONS(2416), 2,
      anon_sym_SEMI,
      anon_sym_NULL,
  [57105] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(2418), 1,
      aux_sym_source_file_token1,
    ACTIONS(2420), 3,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_RBRACE,
  [57117] = 4,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(2422), 1,
      anon_sym_DQUOTE2,
    STATE(1050), 1,
      aux_sym_interpreted_string_literal_repeat1,
    ACTIONS(2424), 2,
      sym__interpreted_string_literal_basic_content,
      sym_escape_sequence,
  [57131] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2180), 1,
      anon_sym_LBRACE,
    STATE(305), 1,
      sym_literal_value,
    ACTIONS(1573), 2,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
  [57145] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(2426), 1,
      aux_sym_source_file_token1,
    ACTIONS(2273), 3,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_RBRACE,
  [57157] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1271), 1,
      anon_sym_LBRACE,
    STATE(317), 1,
      sym_block,
    ACTIONS(1701), 2,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
  [57171] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2331), 1,
      anon_sym_COLON,
    ACTIONS(2428), 1,
      anon_sym_COMMA,
    ACTIONS(2430), 1,
      anon_sym_RBRACE,
    STATE(1166), 1,
      aux_sym_literal_value_repeat1,
  [57187] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1971), 1,
      anon_sym_LPAREN,
    ACTIONS(2432), 1,
      anon_sym_LBRACK,
    STATE(493), 1,
      sym_parameter_list,
    STATE(1260), 1,
      sym_type_parameter_list,
  [57203] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2434), 1,
      sym_identifier,
    ACTIONS(2437), 1,
      anon_sym_RPAREN,
    STATE(1089), 1,
      aux_sym_var_spec_list_repeat1,
    STATE(1154), 1,
      sym_var_spec,
  [57219] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(33), 1,
      anon_sym_LBRACE,
    STATE(257), 1,
      sym_block,
    ACTIONS(1701), 2,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
  [57233] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(2439), 1,
      aux_sym_source_file_token1,
    ACTIONS(2441), 3,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_RPAREN,
  [57245] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2443), 1,
      anon_sym_COMMA,
    STATE(1092), 1,
      aux_sym_type_case_repeat1,
    ACTIONS(2446), 2,
      anon_sym_RBRACK,
      anon_sym_COLON,
  [57259] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2448), 1,
      sym_identifier,
    ACTIONS(2451), 1,
      anon_sym_RPAREN,
    STATE(1093), 1,
      aux_sym_const_declaration_repeat1,
    STATE(1175), 1,
      sym_const_spec,
  [57275] = 4,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(2379), 1,
      aux_sym_source_file_token1,
    ACTIONS(2453), 1,
      ts_builtin_sym_end,
    ACTIONS(2381), 2,
      anon_sym_SEMI,
      anon_sym_NULL,
  [57289] = 4,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(2455), 1,
      anon_sym_DQUOTE2,
    STATE(1097), 1,
      aux_sym_interpreted_string_literal_repeat1,
    ACTIONS(2457), 2,
      sym__interpreted_string_literal_basic_content,
      sym_escape_sequence,
  [57303] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(840), 1,
      anon_sym_LBRACE,
    STATE(367), 1,
      sym_literal_value,
    ACTIONS(1573), 2,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
  [57317] = 4,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(2459), 1,
      anon_sym_DQUOTE2,
    STATE(1080), 1,
      aux_sym_interpreted_string_literal_repeat1,
    ACTIONS(2321), 2,
      sym__interpreted_string_literal_basic_content,
      sym_escape_sequence,
  [57331] = 4,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(2461), 1,
      anon_sym_DQUOTE2,
    STATE(1080), 1,
      aux_sym_interpreted_string_literal_repeat1,
    ACTIONS(2321), 2,
      sym__interpreted_string_literal_basic_content,
      sym_escape_sequence,
  [57345] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1281), 1,
      anon_sym_LBRACE,
    STATE(378), 1,
      sym_block,
    ACTIONS(1701), 2,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
  [57359] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2331), 1,
      anon_sym_COLON,
    ACTIONS(2463), 1,
      anon_sym_COMMA,
    ACTIONS(2465), 1,
      anon_sym_RBRACE,
    STATE(1182), 1,
      aux_sym_literal_value_repeat1,
  [57375] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2467), 1,
      sym_identifier,
    ACTIONS(2469), 1,
      anon_sym_RPAREN,
    STATE(1093), 1,
      aux_sym_const_declaration_repeat1,
    STATE(1175), 1,
      sym_const_spec,
  [57391] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(661), 2,
      ts_builtin_sym_end,
      aux_sym_source_file_token1,
    ACTIONS(663), 2,
      anon_sym_SEMI,
      anon_sym_NULL,
  [57403] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2048), 1,
      anon_sym_LPAREN,
    ACTIONS(2432), 1,
      anon_sym_LBRACK,
    STATE(455), 1,
      sym_parameter_list,
    STATE(1252), 1,
      sym_type_parameter_list,
  [57419] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2249), 1,
      anon_sym_LBRACE,
    STATE(254), 1,
      sym_literal_value,
    ACTIONS(1573), 2,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
  [57433] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2353), 1,
      sym_identifier,
    ACTIONS(2471), 1,
      anon_sym_LPAREN,
    STATE(975), 2,
      sym_var_spec,
      sym_var_spec_list,
  [57447] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2467), 1,
      sym_identifier,
    ACTIONS(2473), 1,
      anon_sym_RPAREN,
    STATE(1101), 1,
      aux_sym_const_declaration_repeat1,
    STATE(1175), 1,
      sym_const_spec,
  [57463] = 4,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(2475), 1,
      anon_sym_DQUOTE2,
    STATE(1111), 1,
      aux_sym_interpreted_string_literal_repeat1,
    ACTIONS(2477), 2,
      sym__interpreted_string_literal_basic_content,
      sym_escape_sequence,
  [57477] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1057), 1,
      anon_sym_LBRACE,
    STATE(543), 1,
      sym_literal_value,
    ACTIONS(1573), 2,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
  [57491] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(647), 2,
      ts_builtin_sym_end,
      aux_sym_source_file_token1,
    ACTIONS(649), 2,
      anon_sym_SEMI,
      anon_sym_NULL,
  [57503] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(2349), 1,
      aux_sym_source_file_token1,
    ACTIONS(2351), 3,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_RPAREN,
  [57515] = 4,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(2479), 1,
      anon_sym_DQUOTE2,
    STATE(1080), 1,
      aux_sym_interpreted_string_literal_repeat1,
    ACTIONS(2321), 2,
      sym__interpreted_string_literal_basic_content,
      sym_escape_sequence,
  [57529] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(2375), 1,
      aux_sym_source_file_token1,
    ACTIONS(2377), 3,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_RPAREN,
  [57541] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1347), 1,
      anon_sym_LBRACE,
    STATE(567), 1,
      sym_block,
    ACTIONS(1701), 2,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
  [57555] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2331), 1,
      anon_sym_COLON,
    ACTIONS(2481), 1,
      anon_sym_COMMA,
    ACTIONS(2483), 1,
      anon_sym_RBRACE,
    STATE(1201), 1,
      aux_sym_literal_value_repeat1,
  [57571] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(2485), 1,
      aux_sym_source_file_token1,
    ACTIONS(2487), 3,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_RBRACE,
  [57583] = 4,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(2489), 1,
      anon_sym_DQUOTE2,
    STATE(1080), 1,
      aux_sym_interpreted_string_literal_repeat1,
    ACTIONS(2321), 2,
      sym__interpreted_string_literal_basic_content,
      sym_escape_sequence,
  [57597] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2128), 1,
      anon_sym_PIPE,
    STATE(1132), 1,
      aux_sym_type_elem_repeat1,
    ACTIONS(2124), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
  [57611] = 4,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(2491), 1,
      anon_sym_DQUOTE2,
    STATE(1119), 1,
      aux_sym_interpreted_string_literal_repeat1,
    ACTIONS(2493), 2,
      sym__interpreted_string_literal_basic_content,
      sym_escape_sequence,
  [57625] = 4,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(2495), 1,
      anon_sym_DQUOTE2,
    STATE(1080), 1,
      aux_sym_interpreted_string_literal_repeat1,
    ACTIONS(2321), 2,
      sym__interpreted_string_literal_basic_content,
      sym_escape_sequence,
  [57639] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2331), 1,
      anon_sym_COLON,
    ACTIONS(2497), 1,
      anon_sym_COMMA,
    ACTIONS(2499), 1,
      anon_sym_RBRACE,
    STATE(1173), 1,
      aux_sym_literal_value_repeat1,
  [57655] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(655), 2,
      ts_builtin_sym_end,
      aux_sym_source_file_token1,
    ACTIONS(657), 2,
      anon_sym_SEMI,
      anon_sym_NULL,
  [57667] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(2501), 2,
      ts_builtin_sym_end,
      aux_sym_source_file_token1,
    ACTIONS(2503), 2,
      anon_sym_SEMI,
      anon_sym_NULL,
  [57679] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(2505), 2,
      ts_builtin_sym_end,
      aux_sym_source_file_token1,
    ACTIONS(2507), 2,
      anon_sym_SEMI,
      anon_sym_NULL,
  [57691] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(2509), 2,
      ts_builtin_sym_end,
      aux_sym_source_file_token1,
    ACTIONS(2511), 2,
      anon_sym_SEMI,
      anon_sym_NULL,
  [57703] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(2513), 1,
      aux_sym_source_file_token1,
    ACTIONS(2281), 3,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_RPAREN,
  [57715] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(2515), 2,
      ts_builtin_sym_end,
      aux_sym_source_file_token1,
    ACTIONS(2517), 2,
      anon_sym_SEMI,
      anon_sym_NULL,
  [57727] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2519), 1,
      anon_sym_PIPE,
    STATE(1127), 1,
      aux_sym_type_elem_repeat1,
    ACTIONS(1906), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
  [57741] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(2522), 2,
      ts_builtin_sym_end,
      aux_sym_source_file_token1,
    ACTIONS(2524), 2,
      anon_sym_SEMI,
      anon_sym_NULL,
  [57753] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(2439), 2,
      ts_builtin_sym_end,
      aux_sym_source_file_token1,
    ACTIONS(2441), 2,
      anon_sym_SEMI,
      anon_sym_NULL,
  [57765] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(2526), 1,
      aux_sym_source_file_token1,
    ACTIONS(2528), 3,
      anon_sym_SEMI,
      anon_sym_NULL,
      anon_sym_RBRACE,
  [57777] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2257), 1,
      sym_identifier,
    ACTIONS(2530), 1,
      anon_sym_LPAREN,
    STATE(1014), 2,
      sym_type_alias,
      sym_type_spec,
  [57791] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2128), 1,
      anon_sym_PIPE,
    STATE(1127), 1,
      aux_sym_type_elem_repeat1,
    ACTIONS(2050), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
  [57805] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(33), 1,
      anon_sym_LBRACE,
    ACTIONS(2357), 1,
      anon_sym_if,
    STATE(926), 2,
      sym_block,
      sym_if_statement,
  [57819] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2532), 1,
      anon_sym_COMMA,
    ACTIONS(2534), 1,
      anon_sym_COLON,
    STATE(1183), 1,
      aux_sym_type_case_repeat1,
  [57832] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1201), 1,
      anon_sym_RPAREN,
    ACTIONS(1203), 1,
      anon_sym_COMMA,
    STATE(1146), 1,
      aux_sym_argument_list_repeat1,
  [57845] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1131), 1,
      anon_sym_RPAREN,
    ACTIONS(2536), 1,
      anon_sym_COMMA,
    STATE(1239), 1,
      aux_sym_parameter_list_repeat1,
  [57858] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(2509), 1,
      aux_sym_source_file_token1,
    ACTIONS(2511), 2,
      anon_sym_SEMI,
      anon_sym_NULL,
  [57869] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1205), 1,
      anon_sym_RPAREN,
    ACTIONS(2538), 1,
      anon_sym_COMMA,
    STATE(1239), 1,
      aux_sym_parameter_list_repeat1,
  [57882] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2446), 3,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_COLON,
  [57891] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(503), 1,
      anon_sym_RPAREN,
    ACTIONS(2540), 1,
      anon_sym_COMMA,
    STATE(1226), 1,
      aux_sym_expression_list_repeat1,
  [57904] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(531), 1,
      anon_sym_RPAREN,
    ACTIONS(2542), 1,
      anon_sym_COMMA,
    STATE(1226), 1,
      aux_sym_expression_list_repeat1,
  [57917] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1303), 1,
      anon_sym_RBRACK,
    ACTIONS(2544), 1,
      anon_sym_COMMA,
    STATE(1170), 1,
      aux_sym_type_arguments_repeat1,
  [57930] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2546), 1,
      anon_sym_RPAREN,
    ACTIONS(2548), 1,
      anon_sym_COMMA,
    STATE(1138), 1,
      aux_sym_parameter_list_repeat1,
  [57943] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(343), 1,
      anon_sym_RBRACE,
    ACTIONS(2550), 1,
      anon_sym_COMMA,
    STATE(1215), 1,
      aux_sym_literal_value_repeat1,
  [57956] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(419), 1,
      anon_sym_RPAREN,
    ACTIONS(2552), 1,
      anon_sym_COMMA,
    STATE(1186), 1,
      aux_sym_argument_list_repeat1,
  [57969] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(427), 1,
      anon_sym_RPAREN,
    ACTIONS(2554), 1,
      anon_sym_COMMA,
    STATE(1186), 1,
      aux_sym_argument_list_repeat1,
  [57982] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2556), 3,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
  [57991] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2558), 3,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
  [58000] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(71), 1,
      anon_sym_DQUOTE,
    ACTIONS(2560), 1,
      sym_raw_string_literal,
    STATE(1110), 1,
      sym_interpreted_string_literal,
  [58013] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2562), 1,
      anon_sym_COMMA,
    ACTIONS(2564), 1,
      anon_sym_RBRACK,
    STATE(1205), 1,
      aux_sym_type_arguments_repeat1,
  [58026] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(71), 1,
      anon_sym_DQUOTE,
    ACTIONS(2566), 1,
      sym_raw_string_literal,
    STATE(1112), 1,
      sym_interpreted_string_literal,
  [58039] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2568), 1,
      anon_sym_COMMA,
    ACTIONS(2570), 1,
      anon_sym_RBRACK,
    STATE(1214), 1,
      aux_sym_type_case_repeat1,
  [58052] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2572), 1,
      sym_identifier,
    ACTIONS(2574), 1,
      anon_sym_RBRACK,
    STATE(1278), 1,
      sym_type_parameter_declaration,
  [58065] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(2576), 1,
      aux_sym_source_file_token1,
    ACTIONS(2578), 2,
      anon_sym_SEMI,
      anon_sym_NULL,
  [58076] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2580), 1,
      anon_sym_COMMA,
    ACTIONS(2582), 1,
      anon_sym_RBRACK,
    STATE(1164), 1,
      aux_sym_type_parameter_list_repeat1,
  [58089] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(209), 3,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
  [58098] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2584), 3,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
  [58107] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2572), 1,
      sym_identifier,
    ACTIONS(2582), 1,
      anon_sym_RBRACK,
    STATE(1278), 1,
      sym_type_parameter_declaration,
  [58120] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2586), 1,
      anon_sym_COMMA,
    ACTIONS(2588), 1,
      anon_sym_RBRACK,
    STATE(1155), 1,
      aux_sym_type_parameter_list_repeat1,
  [58133] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2590), 1,
      anon_sym_RPAREN,
    ACTIONS(2592), 1,
      anon_sym_COMMA,
    STATE(1165), 1,
      aux_sym_expression_list_repeat1,
  [58146] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2428), 1,
      anon_sym_COMMA,
    ACTIONS(2430), 1,
      anon_sym_RBRACE,
    STATE(1166), 1,
      aux_sym_literal_value_repeat1,
  [58159] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2594), 1,
      anon_sym_COMMA,
    ACTIONS(2596), 1,
      anon_sym_RBRACK,
    STATE(1167), 1,
      aux_sym_type_case_repeat1,
  [58172] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1191), 1,
      anon_sym_RPAREN,
    ACTIONS(1193), 1,
      anon_sym_COMMA,
    STATE(1168), 1,
      aux_sym_argument_list_repeat1,
  [58185] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2598), 1,
      anon_sym_COMMA,
    ACTIONS(2601), 1,
      anon_sym_RBRACK,
    STATE(1164), 1,
      aux_sym_type_parameter_list_repeat1,
  [58198] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(491), 1,
      anon_sym_RPAREN,
    ACTIONS(2603), 1,
      anon_sym_COMMA,
    STATE(1226), 1,
      aux_sym_expression_list_repeat1,
  [58211] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(347), 1,
      anon_sym_RBRACE,
    ACTIONS(2605), 1,
      anon_sym_COMMA,
    STATE(1215), 1,
      aux_sym_literal_value_repeat1,
  [58224] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1441), 1,
      anon_sym_RBRACK,
    ACTIONS(2607), 1,
      anon_sym_COMMA,
    STATE(1092), 1,
      aux_sym_type_case_repeat1,
  [58237] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(435), 1,
      anon_sym_RPAREN,
    ACTIONS(2609), 1,
      anon_sym_COMMA,
    STATE(1186), 1,
      aux_sym_argument_list_repeat1,
  [58250] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(2505), 1,
      aux_sym_source_file_token1,
    ACTIONS(2507), 2,
      anon_sym_SEMI,
      anon_sym_NULL,
  [58261] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2611), 1,
      anon_sym_COMMA,
    ACTIONS(2614), 1,
      anon_sym_RBRACK,
    STATE(1170), 1,
      aux_sym_type_arguments_repeat1,
  [58274] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(2393), 1,
      aux_sym_source_file_token1,
    ACTIONS(2395), 2,
      anon_sym_SEMI,
      anon_sym_NULL,
  [58285] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1325), 1,
      anon_sym_RBRACK,
    ACTIONS(2616), 1,
      anon_sym_COMMA,
    STATE(1170), 1,
      aux_sym_type_arguments_repeat1,
  [58298] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(341), 1,
      anon_sym_RBRACE,
    ACTIONS(2618), 1,
      anon_sym_COMMA,
    STATE(1215), 1,
      aux_sym_literal_value_repeat1,
  [58311] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1207), 1,
      anon_sym_RPAREN,
    ACTIONS(1209), 1,
      anon_sym_COMMA,
    STATE(1218), 1,
      aux_sym_argument_list_repeat1,
  [58324] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(2620), 1,
      aux_sym_source_file_token1,
    ACTIONS(2622), 2,
      anon_sym_SEMI,
      anon_sym_NULL,
  [58335] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(2624), 1,
      aux_sym_source_file_token1,
    ACTIONS(2626), 2,
      anon_sym_SEMI,
      anon_sym_NULL,
  [58346] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2628), 1,
      anon_sym_RPAREN,
    ACTIONS(2630), 1,
      anon_sym_COMMA,
    STATE(1181), 1,
      aux_sym_expression_list_repeat1,
  [58359] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2463), 1,
      anon_sym_COMMA,
    ACTIONS(2465), 1,
      anon_sym_RBRACE,
    STATE(1182), 1,
      aux_sym_literal_value_repeat1,
  [58372] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2632), 1,
      anon_sym_COMMA,
    ACTIONS(2634), 1,
      anon_sym_RBRACK,
    STATE(1184), 1,
      aux_sym_type_case_repeat1,
  [58385] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1133), 1,
      anon_sym_RPAREN,
    ACTIONS(1135), 1,
      anon_sym_COMMA,
    STATE(1185), 1,
      aux_sym_argument_list_repeat1,
  [58398] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(533), 1,
      anon_sym_RPAREN,
    ACTIONS(2636), 1,
      anon_sym_COMMA,
    STATE(1226), 1,
      aux_sym_expression_list_repeat1,
  [58411] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(355), 1,
      anon_sym_RBRACE,
    ACTIONS(2638), 1,
      anon_sym_COMMA,
    STATE(1215), 1,
      aux_sym_literal_value_repeat1,
  [58424] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2532), 1,
      anon_sym_COMMA,
    ACTIONS(2640), 1,
      anon_sym_COLON,
    STATE(1092), 1,
      aux_sym_type_case_repeat1,
  [58437] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1453), 1,
      anon_sym_RBRACK,
    ACTIONS(2642), 1,
      anon_sym_COMMA,
    STATE(1092), 1,
      aux_sym_type_case_repeat1,
  [58450] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(445), 1,
      anon_sym_RPAREN,
    ACTIONS(2644), 1,
      anon_sym_COMMA,
    STATE(1186), 1,
      aux_sym_argument_list_repeat1,
  [58463] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1233), 1,
      anon_sym_RPAREN,
    ACTIONS(2646), 1,
      anon_sym_COMMA,
    STATE(1186), 1,
      aux_sym_argument_list_repeat1,
  [58476] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2331), 1,
      anon_sym_COLON,
    ACTIONS(2649), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
  [58487] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1251), 1,
      anon_sym_COMMA,
    ACTIONS(1550), 1,
      anon_sym_LBRACE,
    STATE(1220), 1,
      aux_sym_expression_list_repeat1,
  [58500] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2651), 1,
      anon_sym_RPAREN,
    ACTIONS(2653), 1,
      anon_sym_COMMA,
    STATE(1236), 1,
      aux_sym_parameter_list_repeat1,
  [58513] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2655), 3,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
  [58522] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(2359), 1,
      aux_sym_source_file_token1,
    ACTIONS(2361), 2,
      anon_sym_SEMI,
      anon_sym_NULL,
  [58533] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2327), 1,
      anon_sym_COMMA,
    ACTIONS(2329), 1,
      anon_sym_RBRACE,
    STATE(1209), 1,
      aux_sym_literal_value_repeat1,
  [58546] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2657), 1,
      anon_sym_RPAREN,
    ACTIONS(2659), 1,
      anon_sym_COMMA,
    STATE(1199), 1,
      aux_sym_expression_list_repeat1,
  [58559] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2661), 3,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
  [58568] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2481), 1,
      anon_sym_COMMA,
    ACTIONS(2483), 1,
      anon_sym_RBRACE,
    STATE(1201), 1,
      aux_sym_literal_value_repeat1,
  [58581] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2663), 1,
      anon_sym_COMMA,
    ACTIONS(2665), 1,
      anon_sym_RBRACK,
    STATE(1202), 1,
      aux_sym_type_case_repeat1,
  [58594] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2122), 1,
      anon_sym_LPAREN,
    ACTIONS(2126), 1,
      anon_sym_LBRACK,
    ACTIONS(2667), 1,
      anon_sym_RPAREN,
  [58607] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1181), 1,
      anon_sym_RPAREN,
    ACTIONS(1183), 1,
      anon_sym_COMMA,
    STATE(1204), 1,
      aux_sym_argument_list_repeat1,
  [58620] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(523), 1,
      anon_sym_RPAREN,
    ACTIONS(2669), 1,
      anon_sym_COMMA,
    STATE(1226), 1,
      aux_sym_expression_list_repeat1,
  [58633] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(497), 1,
      anon_sym_RPAREN,
    ACTIONS(2671), 1,
      anon_sym_COMMA,
    STATE(1226), 1,
      aux_sym_expression_list_repeat1,
  [58646] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(357), 1,
      anon_sym_RBRACE,
    ACTIONS(2673), 1,
      anon_sym_COMMA,
    STATE(1215), 1,
      aux_sym_literal_value_repeat1,
  [58659] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1467), 1,
      anon_sym_RBRACK,
    ACTIONS(2675), 1,
      anon_sym_COMMA,
    STATE(1092), 1,
      aux_sym_type_case_repeat1,
  [58672] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(2515), 1,
      aux_sym_source_file_token1,
    ACTIONS(2517), 2,
      anon_sym_SEMI,
      anon_sym_NULL,
  [58683] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(451), 1,
      anon_sym_RPAREN,
    ACTIONS(2677), 1,
      anon_sym_COMMA,
    STATE(1186), 1,
      aux_sym_argument_list_repeat1,
  [58696] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1311), 1,
      anon_sym_RBRACK,
    ACTIONS(2679), 1,
      anon_sym_COMMA,
    STATE(1170), 1,
      aux_sym_type_arguments_repeat1,
  [58709] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2681), 1,
      anon_sym_RPAREN,
    ACTIONS(2683), 1,
      anon_sym_COMMA,
    STATE(1140), 1,
      aux_sym_expression_list_repeat1,
  [58722] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(2379), 1,
      aux_sym_source_file_token1,
    ACTIONS(2381), 2,
      anon_sym_SEMI,
      anon_sym_NULL,
  [58733] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2685), 1,
      anon_sym_COMMA,
    ACTIONS(2687), 1,
      anon_sym_RBRACK,
    STATE(1172), 1,
      aux_sym_type_arguments_repeat1,
  [58746] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(353), 1,
      anon_sym_RBRACE,
    ACTIONS(2689), 1,
      anon_sym_COMMA,
    STATE(1215), 1,
      aux_sym_literal_value_repeat1,
  [58759] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(2414), 1,
      aux_sym_source_file_token1,
    ACTIONS(2416), 2,
      anon_sym_SEMI,
      anon_sym_NULL,
  [58770] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(2333), 1,
      aux_sym_source_file_token1,
    ACTIONS(2335), 2,
      anon_sym_SEMI,
      anon_sym_NULL,
  [58781] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(2337), 1,
      aux_sym_source_file_token1,
    ACTIONS(2339), 2,
      anon_sym_SEMI,
      anon_sym_NULL,
  [58792] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2691), 1,
      anon_sym_RPAREN,
    ACTIONS(2693), 1,
      anon_sym_COMMA,
    STATE(1136), 1,
      aux_sym_parameter_list_repeat1,
  [58805] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1387), 1,
      anon_sym_RBRACK,
    ACTIONS(2695), 1,
      anon_sym_COMMA,
    STATE(1092), 1,
      aux_sym_type_case_repeat1,
  [58818] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2649), 1,
      anon_sym_RBRACE,
    ACTIONS(2697), 1,
      anon_sym_COMMA,
    STATE(1215), 1,
      aux_sym_literal_value_repeat1,
  [58831] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(972), 1,
      anon_sym_LPAREN,
    ACTIONS(2700), 1,
      sym_identifier,
    STATE(593), 1,
      sym_parameter_list,
  [58844] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2497), 1,
      anon_sym_COMMA,
    ACTIONS(2499), 1,
      anon_sym_RBRACE,
    STATE(1173), 1,
      aux_sym_literal_value_repeat1,
  [58857] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(441), 1,
      anon_sym_RPAREN,
    ACTIONS(2702), 1,
      anon_sym_COMMA,
    STATE(1186), 1,
      aux_sym_argument_list_repeat1,
  [58870] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2467), 1,
      sym_identifier,
    ACTIONS(2704), 1,
      anon_sym_LPAREN,
    STATE(962), 1,
      sym_const_spec,
  [58883] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(858), 1,
      anon_sym_LBRACE,
    ACTIONS(2706), 1,
      anon_sym_COMMA,
    STATE(1220), 1,
      aux_sym_expression_list_repeat1,
  [58896] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2709), 1,
      anon_sym_RPAREN,
    ACTIONS(2711), 1,
      anon_sym_COMMA,
    STATE(1141), 1,
      aux_sym_expression_list_repeat1,
  [58909] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2713), 1,
      anon_sym_COMMA,
    ACTIONS(2715), 1,
      anon_sym_RBRACK,
    STATE(1142), 1,
      aux_sym_type_arguments_repeat1,
  [58922] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2717), 1,
      anon_sym_COMMA,
    ACTIONS(2719), 1,
      anon_sym_RBRACK,
    STATE(1228), 1,
      aux_sym_type_case_repeat1,
  [58935] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2721), 1,
      anon_sym_RPAREN,
    ACTIONS(2723), 1,
      anon_sym_COMMA,
    STATE(1200), 1,
      aux_sym_expression_list_repeat1,
  [58948] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1155), 1,
      anon_sym_RPAREN,
    ACTIONS(1157), 1,
      anon_sym_COMMA,
    STATE(1145), 1,
      aux_sym_argument_list_repeat1,
  [58961] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(858), 1,
      anon_sym_RPAREN,
    ACTIONS(2725), 1,
      anon_sym_COMMA,
    STATE(1226), 1,
      aux_sym_expression_list_repeat1,
  [58974] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1735), 1,
      anon_sym_DQUOTE,
    ACTIONS(2728), 1,
      sym_raw_string_literal,
    STATE(1060), 1,
      sym_interpreted_string_literal,
  [58987] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1401), 1,
      anon_sym_RBRACK,
    ACTIONS(2730), 1,
      anon_sym_COMMA,
    STATE(1092), 1,
      aux_sym_type_case_repeat1,
  [59000] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(972), 1,
      anon_sym_LPAREN,
    ACTIONS(2732), 1,
      sym_identifier,
    STATE(614), 1,
      sym_parameter_list,
  [59013] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2734), 3,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
  [59022] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1735), 1,
      anon_sym_DQUOTE,
    ACTIONS(2736), 1,
      sym_raw_string_literal,
    STATE(1069), 1,
      sym_interpreted_string_literal,
  [59035] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(2501), 1,
      aux_sym_source_file_token1,
    ACTIONS(2503), 2,
      anon_sym_SEMI,
      anon_sym_NULL,
  [59046] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2385), 1,
      anon_sym_COMMA,
    ACTIONS(2387), 1,
      anon_sym_RBRACE,
    STATE(1144), 1,
      aux_sym_literal_value_repeat1,
  [59059] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(2522), 1,
      aux_sym_source_file_token1,
    ACTIONS(2524), 2,
      anon_sym_SEMI,
      anon_sym_NULL,
  [59070] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(2367), 1,
      aux_sym_source_file_token1,
    ACTIONS(2369), 2,
      anon_sym_SEMI,
      anon_sym_NULL,
  [59081] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1195), 1,
      anon_sym_RPAREN,
    ACTIONS(2738), 1,
      anon_sym_COMMA,
    STATE(1239), 1,
      aux_sym_parameter_list_repeat1,
  [59094] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1247), 3,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [59103] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2740), 1,
      anon_sym_COMMA,
    ACTIONS(2742), 1,
      anon_sym_RBRACK,
    STATE(1242), 1,
      aux_sym_type_case_repeat1,
  [59116] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2744), 1,
      anon_sym_RPAREN,
    ACTIONS(2746), 1,
      anon_sym_COMMA,
    STATE(1239), 1,
      aux_sym_parameter_list_repeat1,
  [59129] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1906), 3,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_PIPE,
  [59138] = 3,
    ACTIONS(291), 1,
      sym_comment,
    ACTIONS(2363), 1,
      aux_sym_source_file_token1,
    ACTIONS(2365), 2,
      anon_sym_SEMI,
      anon_sym_NULL,
  [59149] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1423), 1,
      anon_sym_RBRACK,
    ACTIONS(2749), 1,
      anon_sym_COMMA,
    STATE(1092), 1,
      aux_sym_type_case_repeat1,
  [59162] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2751), 1,
      anon_sym_LBRACE,
    STATE(808), 1,
      sym_field_declaration_list,
  [59172] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1971), 1,
      anon_sym_LPAREN,
    STATE(384), 1,
      sym_parameter_list,
  [59182] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1233), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
  [59190] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2185), 2,
      anon_sym_RPAREN,
      sym_identifier,
  [59198] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1971), 1,
      anon_sym_LPAREN,
    STATE(386), 1,
      sym_parameter_list,
  [59208] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2753), 1,
      sym_identifier,
    ACTIONS(2755), 1,
      anon_sym_LPAREN,
  [59218] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2757), 1,
      anon_sym_LBRACE,
    STATE(870), 1,
      sym_field_declaration_list,
  [59228] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2753), 1,
      sym_identifier,
    ACTIONS(2759), 1,
      anon_sym_LPAREN,
  [59238] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2761), 1,
      sym_identifier,
    ACTIONS(2763), 1,
      anon_sym_LPAREN,
  [59248] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2048), 1,
      anon_sym_LPAREN,
    STATE(456), 1,
      sym_parameter_list,
  [59258] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2168), 2,
      anon_sym_SEMI,
      anon_sym_LBRACE,
  [59266] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2172), 2,
      anon_sym_SEMI,
      anon_sym_LBRACE,
  [59274] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(924), 1,
      anon_sym_LPAREN,
    STATE(407), 1,
      sym_argument_list,
  [59284] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2765), 1,
      anon_sym_LPAREN,
    STATE(287), 1,
      sym_argument_list,
  [59294] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2767), 1,
      anon_sym_LBRACK,
    STATE(814), 1,
      sym_type_arguments,
  [59304] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1057), 1,
      anon_sym_LBRACE,
    STATE(543), 1,
      sym_literal_value,
  [59314] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(675), 1,
      anon_sym_LPAREN,
    STATE(316), 1,
      sym_argument_list,
  [59324] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1971), 1,
      anon_sym_LPAREN,
    STATE(499), 1,
      sym_parameter_list,
  [59334] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2769), 2,
      anon_sym_EQ,
      anon_sym_COLON_EQ,
  [59342] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2048), 1,
      anon_sym_LPAREN,
    STATE(492), 1,
      sym_parameter_list,
  [59352] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2649), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
  [59360] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2771), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
  [59368] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2773), 1,
      sym_identifier,
    ACTIONS(2775), 1,
      anon_sym_LPAREN,
  [59378] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1016), 1,
      anon_sym_LPAREN,
    STATE(566), 1,
      sym_argument_list,
  [59388] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2777), 1,
      sym_identifier,
    ACTIONS(2779), 1,
      anon_sym_LPAREN,
  [59398] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(303), 1,
      anon_sym_LBRACE,
    STATE(399), 1,
      sym_literal_value,
  [59408] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2614), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
  [59416] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2753), 1,
      sym_identifier,
    ACTIONS(2781), 1,
      anon_sym_LPAREN,
  [59426] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2783), 1,
      anon_sym_LBRACE,
    STATE(953), 1,
      sym_field_declaration_list,
  [59436] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2249), 1,
      anon_sym_LBRACE,
    STATE(254), 1,
      sym_literal_value,
  [59446] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2785), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
  [59454] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2572), 1,
      sym_identifier,
    STATE(1159), 1,
      sym_type_parameter_declaration,
  [59464] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2787), 1,
      anon_sym_LPAREN,
    STATE(465), 1,
      sym_argument_list,
  [59474] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2118), 2,
      anon_sym_SEMI,
      anon_sym_LBRACE,
  [59482] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2451), 2,
      anon_sym_RPAREN,
      sym_identifier,
  [59490] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2601), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
  [59498] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2789), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
  [59506] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(972), 1,
      anon_sym_LPAREN,
    STATE(613), 1,
      sym_parameter_list,
  [59516] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2031), 2,
      anon_sym_SEMI,
      anon_sym_LBRACE,
  [59524] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2791), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
  [59532] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2793), 1,
      anon_sym_LPAREN,
    ACTIONS(2795), 1,
      anon_sym_LBRACK,
  [59542] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2176), 2,
      anon_sym_SEMI,
      anon_sym_LBRACE,
  [59550] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2797), 1,
      sym_identifier,
    ACTIONS(2799), 1,
      anon_sym_LPAREN,
  [59560] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2801), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
  [59568] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2803), 2,
      sym_raw_string_literal,
      anon_sym_DQUOTE,
  [59576] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2572), 1,
      sym_identifier,
    STATE(1278), 1,
      sym_type_parameter_declaration,
  [59586] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2805), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
  [59594] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(972), 1,
      anon_sym_LPAREN,
    STATE(627), 1,
      sym_parameter_list,
  [59604] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2761), 1,
      sym_identifier,
    ACTIONS(2807), 1,
      anon_sym_LPAREN,
  [59614] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2301), 1,
      anon_sym_LBRACE,
    STATE(507), 1,
      sym_literal_value,
  [59624] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2180), 1,
      anon_sym_LBRACE,
    STATE(305), 1,
      sym_literal_value,
  [59634] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(972), 1,
      anon_sym_LPAREN,
    STATE(601), 1,
      sym_parameter_list,
  [59644] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(840), 1,
      anon_sym_LBRACE,
    STATE(367), 1,
      sym_literal_value,
  [59654] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2753), 1,
      sym_identifier,
    ACTIONS(2809), 1,
      anon_sym_LPAREN,
  [59664] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2437), 2,
      anon_sym_RPAREN,
      sym_identifier,
  [59672] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2811), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
  [59680] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2813), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
  [59688] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(972), 1,
      anon_sym_LPAREN,
    STATE(604), 1,
      sym_parameter_list,
  [59698] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2813), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
  [59706] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2048), 1,
      anon_sym_LPAREN,
    STATE(491), 1,
      sym_parameter_list,
  [59716] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(972), 1,
      anon_sym_LPAREN,
    STATE(448), 1,
      sym_parameter_list,
  [59726] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2744), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
  [59734] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(972), 1,
      anon_sym_LPAREN,
    STATE(628), 1,
      sym_parameter_list,
  [59744] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2815), 1,
      anon_sym_LPAREN,
    ACTIONS(2817), 1,
      anon_sym_LBRACK,
  [59754] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(972), 1,
      anon_sym_LPAREN,
    STATE(445), 1,
      sym_parameter_list,
  [59764] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(33), 1,
      anon_sym_LBRACE,
    STATE(913), 1,
      sym_block,
  [59774] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2819), 1,
      sym_identifier,
    ACTIONS(2821), 1,
      anon_sym_LPAREN,
  [59784] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2823), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
  [59792] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2122), 1,
      anon_sym_LPAREN,
    ACTIONS(2126), 1,
      anon_sym_LBRACK,
  [59802] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2825), 1,
      anon_sym_LPAREN,
    ACTIONS(2827), 1,
      anon_sym_LBRACK,
  [59812] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(844), 1,
      anon_sym_LPAREN,
    STATE(377), 1,
      sym_argument_list,
  [59822] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2829), 1,
      anon_sym_LPAREN,
    ACTIONS(2831), 1,
      anon_sym_LBRACK,
  [59832] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2833), 1,
      anon_sym_LPAREN,
    ACTIONS(2835), 1,
      anon_sym_LBRACK,
  [59842] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(972), 1,
      anon_sym_LPAREN,
    STATE(435), 1,
      sym_parameter_list,
  [59852] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2837), 1,
      anon_sym_LBRACK,
  [59859] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2839), 1,
      anon_sym_RPAREN,
  [59866] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2841), 1,
      anon_sym_RBRACE,
  [59873] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2843), 1,
      anon_sym_EQ,
  [59880] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2845), 1,
      anon_sym_chan,
  [59887] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2847), 1,
      anon_sym_RPAREN,
  [59894] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2849), 1,
      anon_sym_EQ,
  [59901] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2851), 1,
      anon_sym_RPAREN,
  [59908] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2329), 1,
      anon_sym_RBRACE,
  [59915] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2853), 1,
      anon_sym_RPAREN,
  [59922] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2499), 1,
      anon_sym_RBRACE,
  [59929] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2855), 1,
      anon_sym_RPAREN,
  [59936] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2857), 1,
      anon_sym_RPAREN,
  [59943] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2859), 1,
      sym_identifier,
  [59950] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2861), 1,
      sym_identifier,
  [59957] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2863), 1,
      anon_sym_LBRACE,
  [59964] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2691), 1,
      anon_sym_RPAREN,
  [59971] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2865), 1,
      anon_sym_RBRACE,
  [59978] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2867), 1,
      anon_sym_RPAREN,
  [59985] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2651), 1,
      anon_sym_RPAREN,
  [59992] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2869), 1,
      anon_sym_RBRACK,
  [59999] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2871), 1,
      anon_sym_RPAREN,
  [60006] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2873), 1,
      anon_sym_RBRACE,
  [60013] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2546), 1,
      anon_sym_RPAREN,
  [60020] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2875), 1,
      anon_sym_LBRACE,
  [60027] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2877), 1,
      anon_sym_LBRACE,
  [60034] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2879), 1,
      anon_sym_chan,
  [60041] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2881), 1,
      anon_sym_LBRACE,
  [60048] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2883), 1,
      anon_sym_LBRACE,
  [60055] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2885), 1,
      anon_sym_RBRACE,
  [60062] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2887), 1,
      anon_sym_RPAREN,
  [60069] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2889), 1,
      anon_sym_RPAREN,
  [60076] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2891), 1,
      anon_sym_COLON,
  [60083] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2893), 1,
      sym_identifier,
  [60090] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2895), 1,
      anon_sym_LBRACE,
  [60097] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2897), 1,
      anon_sym_RBRACK,
  [60104] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2899), 1,
      anon_sym_RPAREN,
  [60111] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2901), 1,
      anon_sym_LBRACE,
  [60118] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2903), 1,
      anon_sym_chan,
  [60125] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2905), 1,
      anon_sym_LBRACE,
  [60132] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2907), 1,
      anon_sym_RBRACE,
  [60139] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2909), 1,
      anon_sym_LBRACE,
  [60146] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2911), 1,
      anon_sym_chan,
  [60153] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2913), 1,
      anon_sym_SEMI,
  [60160] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2915), 1,
      anon_sym_LBRACE,
  [60167] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2387), 1,
      anon_sym_RBRACE,
  [60174] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2917), 1,
      anon_sym_LBRACK,
  [60181] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2919), 1,
      anon_sym_RBRACK,
  [60188] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2921), 1,
      sym_identifier,
  [60195] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2923), 1,
      anon_sym_RPAREN,
  [60202] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2925), 1,
      anon_sym_COLON,
  [60209] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2927), 1,
      anon_sym_RPAREN,
  [60216] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2929), 1,
      anon_sym_RBRACE,
  [60223] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2931), 1,
      sym_identifier,
  [60230] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2933), 1,
      anon_sym_RBRACK,
  [60237] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2935), 1,
      anon_sym_COLON,
  [60244] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2937), 1,
      anon_sym_LBRACE,
  [60251] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2939), 1,
      anon_sym_LBRACE,
  [60258] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2941), 1,
      anon_sym_RBRACK,
  [60265] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2943), 1,
      anon_sym_LBRACE,
  [60272] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2483), 1,
      anon_sym_RBRACE,
  [60279] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2430), 1,
      anon_sym_RBRACE,
  [60286] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2945), 1,
      anon_sym_RBRACK,
  [60293] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2947), 1,
      sym_identifier,
  [60300] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2949), 1,
      anon_sym_chan,
  [60307] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2951), 1,
      anon_sym_RBRACE,
  [60314] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2953), 1,
      anon_sym_chan,
  [60321] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2955), 1,
      ts_builtin_sym_end,
  [60328] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2957), 1,
      sym_identifier,
  [60335] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2959), 1,
      anon_sym_SEMI,
  [60342] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2961), 1,
      anon_sym_RPAREN,
  [60349] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2963), 1,
      anon_sym_RBRACK,
  [60356] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2667), 1,
      anon_sym_RPAREN,
  [60363] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2965), 1,
      anon_sym_RPAREN,
  [60370] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2967), 1,
      anon_sym_RPAREN,
  [60377] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2969), 1,
      sym_identifier,
  [60384] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2971), 1,
      anon_sym_LBRACK,
  [60391] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2973), 1,
      anon_sym_SEMI,
  [60398] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2975), 1,
      anon_sym_LBRACK,
  [60405] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2977), 1,
      anon_sym_COLON_EQ,
  [60412] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2979), 1,
      anon_sym_RPAREN,
  [60419] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2981), 1,
      anon_sym_RPAREN,
  [60426] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2983), 1,
      anon_sym_LBRACK,
  [60433] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2465), 1,
      anon_sym_RBRACE,
  [60440] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2985), 1,
      anon_sym_LBRACK,
  [60447] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2987), 1,
      anon_sym_LBRACE,
  [60454] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2989), 1,
      sym_identifier,
};

static const uint32_t ts_small_parse_table_map[] = {
  [SMALL_STATE(28)] = 0,
  [SMALL_STATE(29)] = 119,
  [SMALL_STATE(30)] = 245,
  [SMALL_STATE(31)] = 371,
  [SMALL_STATE(32)] = 497,
  [SMALL_STATE(33)] = 623,
  [SMALL_STATE(34)] = 749,
  [SMALL_STATE(35)] = 875,
  [SMALL_STATE(36)] = 998,
  [SMALL_STATE(37)] = 1121,
  [SMALL_STATE(38)] = 1244,
  [SMALL_STATE(39)] = 1367,
  [SMALL_STATE(40)] = 1490,
  [SMALL_STATE(41)] = 1613,
  [SMALL_STATE(42)] = 1736,
  [SMALL_STATE(43)] = 1859,
  [SMALL_STATE(44)] = 1982,
  [SMALL_STATE(45)] = 2105,
  [SMALL_STATE(46)] = 2228,
  [SMALL_STATE(47)] = 2351,
  [SMALL_STATE(48)] = 2471,
  [SMALL_STATE(49)] = 2588,
  [SMALL_STATE(50)] = 2703,
  [SMALL_STATE(51)] = 2817,
  [SMALL_STATE(52)] = 2931,
  [SMALL_STATE(53)] = 3045,
  [SMALL_STATE(54)] = 3159,
  [SMALL_STATE(55)] = 3273,
  [SMALL_STATE(56)] = 3387,
  [SMALL_STATE(57)] = 3501,
  [SMALL_STATE(58)] = 3615,
  [SMALL_STATE(59)] = 3729,
  [SMALL_STATE(60)] = 3843,
  [SMALL_STATE(61)] = 3957,
  [SMALL_STATE(62)] = 4071,
  [SMALL_STATE(63)] = 4185,
  [SMALL_STATE(64)] = 4299,
  [SMALL_STATE(65)] = 4413,
  [SMALL_STATE(66)] = 4527,
  [SMALL_STATE(67)] = 4641,
  [SMALL_STATE(68)] = 4755,
  [SMALL_STATE(69)] = 4869,
  [SMALL_STATE(70)] = 4983,
  [SMALL_STATE(71)] = 5097,
  [SMALL_STATE(72)] = 5211,
  [SMALL_STATE(73)] = 5325,
  [SMALL_STATE(74)] = 5439,
  [SMALL_STATE(75)] = 5553,
  [SMALL_STATE(76)] = 5667,
  [SMALL_STATE(77)] = 5781,
  [SMALL_STATE(78)] = 5895,
  [SMALL_STATE(79)] = 6009,
  [SMALL_STATE(80)] = 6123,
  [SMALL_STATE(81)] = 6237,
  [SMALL_STATE(82)] = 6348,
  [SMALL_STATE(83)] = 6459,
  [SMALL_STATE(84)] = 6570,
  [SMALL_STATE(85)] = 6681,
  [SMALL_STATE(86)] = 6792,
  [SMALL_STATE(87)] = 6903,
  [SMALL_STATE(88)] = 7014,
  [SMALL_STATE(89)] = 7125,
  [SMALL_STATE(90)] = 7236,
  [SMALL_STATE(91)] = 7347,
  [SMALL_STATE(92)] = 7458,
  [SMALL_STATE(93)] = 7569,
  [SMALL_STATE(94)] = 7680,
  [SMALL_STATE(95)] = 7791,
  [SMALL_STATE(96)] = 7902,
  [SMALL_STATE(97)] = 8013,
  [SMALL_STATE(98)] = 8124,
  [SMALL_STATE(99)] = 8235,
  [SMALL_STATE(100)] = 8346,
  [SMALL_STATE(101)] = 8457,
  [SMALL_STATE(102)] = 8568,
  [SMALL_STATE(103)] = 8679,
  [SMALL_STATE(104)] = 8790,
  [SMALL_STATE(105)] = 8901,
  [SMALL_STATE(106)] = 9012,
  [SMALL_STATE(107)] = 9123,
  [SMALL_STATE(108)] = 9234,
  [SMALL_STATE(109)] = 9345,
  [SMALL_STATE(110)] = 9456,
  [SMALL_STATE(111)] = 9567,
  [SMALL_STATE(112)] = 9678,
  [SMALL_STATE(113)] = 9789,
  [SMALL_STATE(114)] = 9900,
  [SMALL_STATE(115)] = 10011,
  [SMALL_STATE(116)] = 10122,
  [SMALL_STATE(117)] = 10233,
  [SMALL_STATE(118)] = 10344,
  [SMALL_STATE(119)] = 10455,
  [SMALL_STATE(120)] = 10566,
  [SMALL_STATE(121)] = 10677,
  [SMALL_STATE(122)] = 10788,
  [SMALL_STATE(123)] = 10899,
  [SMALL_STATE(124)] = 11010,
  [SMALL_STATE(125)] = 11121,
  [SMALL_STATE(126)] = 11232,
  [SMALL_STATE(127)] = 11343,
  [SMALL_STATE(128)] = 11454,
  [SMALL_STATE(129)] = 11565,
  [SMALL_STATE(130)] = 11676,
  [SMALL_STATE(131)] = 11787,
  [SMALL_STATE(132)] = 11895,
  [SMALL_STATE(133)] = 12003,
  [SMALL_STATE(134)] = 12111,
  [SMALL_STATE(135)] = 12219,
  [SMALL_STATE(136)] = 12327,
  [SMALL_STATE(137)] = 12435,
  [SMALL_STATE(138)] = 12543,
  [SMALL_STATE(139)] = 12651,
  [SMALL_STATE(140)] = 12759,
  [SMALL_STATE(141)] = 12867,
  [SMALL_STATE(142)] = 12975,
  [SMALL_STATE(143)] = 13083,
  [SMALL_STATE(144)] = 13191,
  [SMALL_STATE(145)] = 13299,
  [SMALL_STATE(146)] = 13407,
  [SMALL_STATE(147)] = 13515,
  [SMALL_STATE(148)] = 13623,
  [SMALL_STATE(149)] = 13731,
  [SMALL_STATE(150)] = 13839,
  [SMALL_STATE(151)] = 13947,
  [SMALL_STATE(152)] = 14055,
  [SMALL_STATE(153)] = 14163,
  [SMALL_STATE(154)] = 14271,
  [SMALL_STATE(155)] = 14379,
  [SMALL_STATE(156)] = 14487,
  [SMALL_STATE(157)] = 14595,
  [SMALL_STATE(158)] = 14703,
  [SMALL_STATE(159)] = 14811,
  [SMALL_STATE(160)] = 14919,
  [SMALL_STATE(161)] = 15027,
  [SMALL_STATE(162)] = 15135,
  [SMALL_STATE(163)] = 15243,
  [SMALL_STATE(164)] = 15351,
  [SMALL_STATE(165)] = 15459,
  [SMALL_STATE(166)] = 15567,
  [SMALL_STATE(167)] = 15675,
  [SMALL_STATE(168)] = 15783,
  [SMALL_STATE(169)] = 15891,
  [SMALL_STATE(170)] = 15999,
  [SMALL_STATE(171)] = 16107,
  [SMALL_STATE(172)] = 16215,
  [SMALL_STATE(173)] = 16323,
  [SMALL_STATE(174)] = 16431,
  [SMALL_STATE(175)] = 16539,
  [SMALL_STATE(176)] = 16647,
  [SMALL_STATE(177)] = 16755,
  [SMALL_STATE(178)] = 16863,
  [SMALL_STATE(179)] = 16971,
  [SMALL_STATE(180)] = 17079,
  [SMALL_STATE(181)] = 17187,
  [SMALL_STATE(182)] = 17295,
  [SMALL_STATE(183)] = 17403,
  [SMALL_STATE(184)] = 17511,
  [SMALL_STATE(185)] = 17619,
  [SMALL_STATE(186)] = 17727,
  [SMALL_STATE(187)] = 17835,
  [SMALL_STATE(188)] = 17943,
  [SMALL_STATE(189)] = 18051,
  [SMALL_STATE(190)] = 18159,
  [SMALL_STATE(191)] = 18267,
  [SMALL_STATE(192)] = 18375,
  [SMALL_STATE(193)] = 18483,
  [SMALL_STATE(194)] = 18591,
  [SMALL_STATE(195)] = 18699,
  [SMALL_STATE(196)] = 18807,
  [SMALL_STATE(197)] = 18915,
  [SMALL_STATE(198)] = 19023,
  [SMALL_STATE(199)] = 19131,
  [SMALL_STATE(200)] = 19239,
  [SMALL_STATE(201)] = 19347,
  [SMALL_STATE(202)] = 19455,
  [SMALL_STATE(203)] = 19563,
  [SMALL_STATE(204)] = 19671,
  [SMALL_STATE(205)] = 19779,
  [SMALL_STATE(206)] = 19887,
  [SMALL_STATE(207)] = 19995,
  [SMALL_STATE(208)] = 20103,
  [SMALL_STATE(209)] = 20211,
  [SMALL_STATE(210)] = 20319,
  [SMALL_STATE(211)] = 20427,
  [SMALL_STATE(212)] = 20535,
  [SMALL_STATE(213)] = 20643,
  [SMALL_STATE(214)] = 20751,
  [SMALL_STATE(215)] = 20859,
  [SMALL_STATE(216)] = 20967,
  [SMALL_STATE(217)] = 21075,
  [SMALL_STATE(218)] = 21183,
  [SMALL_STATE(219)] = 21291,
  [SMALL_STATE(220)] = 21399,
  [SMALL_STATE(221)] = 21507,
  [SMALL_STATE(222)] = 21615,
  [SMALL_STATE(223)] = 21723,
  [SMALL_STATE(224)] = 21831,
  [SMALL_STATE(225)] = 21939,
  [SMALL_STATE(226)] = 22047,
  [SMALL_STATE(227)] = 22155,
  [SMALL_STATE(228)] = 22263,
  [SMALL_STATE(229)] = 22371,
  [SMALL_STATE(230)] = 22479,
  [SMALL_STATE(231)] = 22587,
  [SMALL_STATE(232)] = 22695,
  [SMALL_STATE(233)] = 22803,
  [SMALL_STATE(234)] = 22911,
  [SMALL_STATE(235)] = 23019,
  [SMALL_STATE(236)] = 23127,
  [SMALL_STATE(237)] = 23227,
  [SMALL_STATE(238)] = 23298,
  [SMALL_STATE(239)] = 23369,
  [SMALL_STATE(240)] = 23457,
  [SMALL_STATE(241)] = 23525,
  [SMALL_STATE(242)] = 23596,
  [SMALL_STATE(243)] = 23661,
  [SMALL_STATE(244)] = 23730,
  [SMALL_STATE(245)] = 23803,
  [SMALL_STATE(246)] = 23858,
  [SMALL_STATE(247)] = 23923,
  [SMALL_STATE(248)] = 23990,
  [SMALL_STATE(249)] = 24044,
  [SMALL_STATE(250)] = 24098,
  [SMALL_STATE(251)] = 24152,
  [SMALL_STATE(252)] = 24210,
  [SMALL_STATE(253)] = 24264,
  [SMALL_STATE(254)] = 24317,
  [SMALL_STATE(255)] = 24370,
  [SMALL_STATE(256)] = 24461,
  [SMALL_STATE(257)] = 24514,
  [SMALL_STATE(258)] = 24567,
  [SMALL_STATE(259)] = 24620,
  [SMALL_STATE(260)] = 24711,
  [SMALL_STATE(261)] = 24764,
  [SMALL_STATE(262)] = 24817,
  [SMALL_STATE(263)] = 24870,
  [SMALL_STATE(264)] = 24923,
  [SMALL_STATE(265)] = 24976,
  [SMALL_STATE(266)] = 25029,
  [SMALL_STATE(267)] = 25082,
  [SMALL_STATE(268)] = 25135,
  [SMALL_STATE(269)] = 25188,
  [SMALL_STATE(270)] = 25241,
  [SMALL_STATE(271)] = 25294,
  [SMALL_STATE(272)] = 25347,
  [SMALL_STATE(273)] = 25400,
  [SMALL_STATE(274)] = 25453,
  [SMALL_STATE(275)] = 25506,
  [SMALL_STATE(276)] = 25559,
  [SMALL_STATE(277)] = 25612,
  [SMALL_STATE(278)] = 25665,
  [SMALL_STATE(279)] = 25718,
  [SMALL_STATE(280)] = 25771,
  [SMALL_STATE(281)] = 25824,
  [SMALL_STATE(282)] = 25877,
  [SMALL_STATE(283)] = 25930,
  [SMALL_STATE(284)] = 25983,
  [SMALL_STATE(285)] = 26036,
  [SMALL_STATE(286)] = 26089,
  [SMALL_STATE(287)] = 26142,
  [SMALL_STATE(288)] = 26195,
  [SMALL_STATE(289)] = 26248,
  [SMALL_STATE(290)] = 26336,
  [SMALL_STATE(291)] = 26401,
  [SMALL_STATE(292)] = 26486,
  [SMALL_STATE(293)] = 26547,
  [SMALL_STATE(294)] = 26610,
  [SMALL_STATE(295)] = 26679,
  [SMALL_STATE(296)] = 26750,
  [SMALL_STATE(297)] = 26811,
  [SMALL_STATE(298)] = 26872,
  [SMALL_STATE(299)] = 26926,
  [SMALL_STATE(300)] = 26975,
  [SMALL_STATE(301)] = 27024,
  [SMALL_STATE(302)] = 27073,
  [SMALL_STATE(303)] = 27122,
  [SMALL_STATE(304)] = 27171,
  [SMALL_STATE(305)] = 27220,
  [SMALL_STATE(306)] = 27269,
  [SMALL_STATE(307)] = 27318,
  [SMALL_STATE(308)] = 27367,
  [SMALL_STATE(309)] = 27416,
  [SMALL_STATE(310)] = 27465,
  [SMALL_STATE(311)] = 27514,
  [SMALL_STATE(312)] = 27563,
  [SMALL_STATE(313)] = 27612,
  [SMALL_STATE(314)] = 27661,
  [SMALL_STATE(315)] = 27710,
  [SMALL_STATE(316)] = 27759,
  [SMALL_STATE(317)] = 27808,
  [SMALL_STATE(318)] = 27857,
  [SMALL_STATE(319)] = 27906,
  [SMALL_STATE(320)] = 27955,
  [SMALL_STATE(321)] = 28004,
  [SMALL_STATE(322)] = 28053,
  [SMALL_STATE(323)] = 28102,
  [SMALL_STATE(324)] = 28151,
  [SMALL_STATE(325)] = 28200,
  [SMALL_STATE(326)] = 28249,
  [SMALL_STATE(327)] = 28298,
  [SMALL_STATE(328)] = 28347,
  [SMALL_STATE(329)] = 28396,
  [SMALL_STATE(330)] = 28445,
  [SMALL_STATE(331)] = 28494,
  [SMALL_STATE(332)] = 28543,
  [SMALL_STATE(333)] = 28592,
  [SMALL_STATE(334)] = 28641,
  [SMALL_STATE(335)] = 28690,
  [SMALL_STATE(336)] = 28739,
  [SMALL_STATE(337)] = 28788,
  [SMALL_STATE(338)] = 28847,
  [SMALL_STATE(339)] = 28907,
  [SMALL_STATE(340)] = 28963,
  [SMALL_STATE(341)] = 29021,
  [SMALL_STATE(342)] = 29085,
  [SMALL_STATE(343)] = 29151,
  [SMALL_STATE(344)] = 29207,
  [SMALL_STATE(345)] = 29275,
  [SMALL_STATE(346)] = 29324,
  [SMALL_STATE(347)] = 29368,
  [SMALL_STATE(348)] = 29412,
  [SMALL_STATE(349)] = 29456,
  [SMALL_STATE(350)] = 29500,
  [SMALL_STATE(351)] = 29544,
  [SMALL_STATE(352)] = 29588,
  [SMALL_STATE(353)] = 29632,
  [SMALL_STATE(354)] = 29676,
  [SMALL_STATE(355)] = 29720,
  [SMALL_STATE(356)] = 29764,
  [SMALL_STATE(357)] = 29808,
  [SMALL_STATE(358)] = 29852,
  [SMALL_STATE(359)] = 29896,
  [SMALL_STATE(360)] = 29940,
  [SMALL_STATE(361)] = 29984,
  [SMALL_STATE(362)] = 30028,
  [SMALL_STATE(363)] = 30072,
  [SMALL_STATE(364)] = 30116,
  [SMALL_STATE(365)] = 30160,
  [SMALL_STATE(366)] = 30204,
  [SMALL_STATE(367)] = 30248,
  [SMALL_STATE(368)] = 30292,
  [SMALL_STATE(369)] = 30336,
  [SMALL_STATE(370)] = 30380,
  [SMALL_STATE(371)] = 30424,
  [SMALL_STATE(372)] = 30468,
  [SMALL_STATE(373)] = 30512,
  [SMALL_STATE(374)] = 30556,
  [SMALL_STATE(375)] = 30600,
  [SMALL_STATE(376)] = 30644,
  [SMALL_STATE(377)] = 30688,
  [SMALL_STATE(378)] = 30732,
  [SMALL_STATE(379)] = 30776,
  [SMALL_STATE(380)] = 30820,
  [SMALL_STATE(381)] = 30864,
  [SMALL_STATE(382)] = 30908,
  [SMALL_STATE(383)] = 30952,
  [SMALL_STATE(384)] = 30996,
  [SMALL_STATE(385)] = 31067,
  [SMALL_STATE(386)] = 31152,
  [SMALL_STATE(387)] = 31223,
  [SMALL_STATE(388)] = 31275,
  [SMALL_STATE(389)] = 31327,
  [SMALL_STATE(390)] = 31372,
  [SMALL_STATE(391)] = 31425,
  [SMALL_STATE(392)] = 31500,
  [SMALL_STATE(393)] = 31575,
  [SMALL_STATE(394)] = 31615,
  [SMALL_STATE(395)] = 31655,
  [SMALL_STATE(396)] = 31719,
  [SMALL_STATE(397)] = 31759,
  [SMALL_STATE(398)] = 31799,
  [SMALL_STATE(399)] = 31839,
  [SMALL_STATE(400)] = 31879,
  [SMALL_STATE(401)] = 31919,
  [SMALL_STATE(402)] = 31959,
  [SMALL_STATE(403)] = 31999,
  [SMALL_STATE(404)] = 32039,
  [SMALL_STATE(405)] = 32079,
  [SMALL_STATE(406)] = 32119,
  [SMALL_STATE(407)] = 32159,
  [SMALL_STATE(408)] = 32199,
  [SMALL_STATE(409)] = 32239,
  [SMALL_STATE(410)] = 32279,
  [SMALL_STATE(411)] = 32319,
  [SMALL_STATE(412)] = 32359,
  [SMALL_STATE(413)] = 32399,
  [SMALL_STATE(414)] = 32439,
  [SMALL_STATE(415)] = 32479,
  [SMALL_STATE(416)] = 32519,
  [SMALL_STATE(417)] = 32559,
  [SMALL_STATE(418)] = 32599,
  [SMALL_STATE(419)] = 32639,
  [SMALL_STATE(420)] = 32679,
  [SMALL_STATE(421)] = 32719,
  [SMALL_STATE(422)] = 32759,
  [SMALL_STATE(423)] = 32799,
  [SMALL_STATE(424)] = 32839,
  [SMALL_STATE(425)] = 32879,
  [SMALL_STATE(426)] = 32919,
  [SMALL_STATE(427)] = 32959,
  [SMALL_STATE(428)] = 32999,
  [SMALL_STATE(429)] = 33039,
  [SMALL_STATE(430)] = 33079,
  [SMALL_STATE(431)] = 33119,
  [SMALL_STATE(432)] = 33171,
  [SMALL_STATE(433)] = 33211,
  [SMALL_STATE(434)] = 33260,
  [SMALL_STATE(435)] = 33315,
  [SMALL_STATE(436)] = 33380,
  [SMALL_STATE(437)] = 33429,
  [SMALL_STATE(438)] = 33482,
  [SMALL_STATE(439)] = 33535,
  [SMALL_STATE(440)] = 33594,
  [SMALL_STATE(441)] = 33645,
  [SMALL_STATE(442)] = 33702,
  [SMALL_STATE(443)] = 33759,
  [SMALL_STATE(444)] = 33822,
  [SMALL_STATE(445)] = 33883,
  [SMALL_STATE(446)] = 33948,
  [SMALL_STATE(447)] = 34006,
  [SMALL_STATE(448)] = 34064,
  [SMALL_STATE(449)] = 34132,
  [SMALL_STATE(450)] = 34204,
  [SMALL_STATE(451)] = 34278,
  [SMALL_STATE(452)] = 34336,
  [SMALL_STATE(453)] = 34386,
  [SMALL_STATE(454)] = 34428,
  [SMALL_STATE(455)] = 34498,
  [SMALL_STATE(456)] = 34568,
  [SMALL_STATE(457)] = 34638,
  [SMALL_STATE(458)] = 34675,
  [SMALL_STATE(459)] = 34712,
  [SMALL_STATE(460)] = 34749,
  [SMALL_STATE(461)] = 34800,
  [SMALL_STATE(462)] = 34855,
  [SMALL_STATE(463)] = 34914,
  [SMALL_STATE(464)] = 34975,
  [SMALL_STATE(465)] = 35012,
  [SMALL_STATE(466)] = 35049,
  [SMALL_STATE(467)] = 35086,
  [SMALL_STATE(468)] = 35155,
  [SMALL_STATE(469)] = 35192,
  [SMALL_STATE(470)] = 35229,
  [SMALL_STATE(471)] = 35266,
  [SMALL_STATE(472)] = 35303,
  [SMALL_STATE(473)] = 35340,
  [SMALL_STATE(474)] = 35377,
  [SMALL_STATE(475)] = 35414,
  [SMALL_STATE(476)] = 35451,
  [SMALL_STATE(477)] = 35488,
  [SMALL_STATE(478)] = 35525,
  [SMALL_STATE(479)] = 35594,
  [SMALL_STATE(480)] = 35631,
  [SMALL_STATE(481)] = 35668,
  [SMALL_STATE(482)] = 35705,
  [SMALL_STATE(483)] = 35768,
  [SMALL_STATE(484)] = 35805,
  [SMALL_STATE(485)] = 35842,
  [SMALL_STATE(486)] = 35879,
  [SMALL_STATE(487)] = 35916,
  [SMALL_STATE(488)] = 35963,
  [SMALL_STATE(489)] = 36032,
  [SMALL_STATE(490)] = 36069,
  [SMALL_STATE(491)] = 36106,
  [SMALL_STATE(492)] = 36171,
  [SMALL_STATE(493)] = 36236,
  [SMALL_STATE(494)] = 36305,
  [SMALL_STATE(495)] = 36342,
  [SMALL_STATE(496)] = 36389,
  [SMALL_STATE(497)] = 36426,
  [SMALL_STATE(498)] = 36463,
  [SMALL_STATE(499)] = 36500,
  [SMALL_STATE(500)] = 36569,
  [SMALL_STATE(501)] = 36638,
  [SMALL_STATE(502)] = 36675,
  [SMALL_STATE(503)] = 36712,
  [SMALL_STATE(504)] = 36749,
  [SMALL_STATE(505)] = 36786,
  [SMALL_STATE(506)] = 36823,
  [SMALL_STATE(507)] = 36860,
  [SMALL_STATE(508)] = 36897,
  [SMALL_STATE(509)] = 36934,
  [SMALL_STATE(510)] = 36971,
  [SMALL_STATE(511)] = 37037,
  [SMALL_STATE(512)] = 37103,
  [SMALL_STATE(513)] = 37169,
  [SMALL_STATE(514)] = 37235,
  [SMALL_STATE(515)] = 37283,
  [SMALL_STATE(516)] = 37323,
  [SMALL_STATE(517)] = 37389,
  [SMALL_STATE(518)] = 37455,
  [SMALL_STATE(519)] = 37521,
  [SMALL_STATE(520)] = 37587,
  [SMALL_STATE(521)] = 37639,
  [SMALL_STATE(522)] = 37705,
  [SMALL_STATE(523)] = 37769,
  [SMALL_STATE(524)] = 37835,
  [SMALL_STATE(525)] = 37899,
  [SMALL_STATE(526)] = 37965,
  [SMALL_STATE(527)] = 38031,
  [SMALL_STATE(528)] = 38097,
  [SMALL_STATE(529)] = 38132,
  [SMALL_STATE(530)] = 38167,
  [SMALL_STATE(531)] = 38230,
  [SMALL_STATE(532)] = 38293,
  [SMALL_STATE(533)] = 38358,
  [SMALL_STATE(534)] = 38423,
  [SMALL_STATE(535)] = 38458,
  [SMALL_STATE(536)] = 38503,
  [SMALL_STATE(537)] = 38570,
  [SMALL_STATE(538)] = 38605,
  [SMALL_STATE(539)] = 38640,
  [SMALL_STATE(540)] = 38675,
  [SMALL_STATE(541)] = 38738,
  [SMALL_STATE(542)] = 38799,
  [SMALL_STATE(543)] = 38862,
  [SMALL_STATE(544)] = 38897,
  [SMALL_STATE(545)] = 38960,
  [SMALL_STATE(546)] = 38995,
  [SMALL_STATE(547)] = 39044,
  [SMALL_STATE(548)] = 39109,
  [SMALL_STATE(549)] = 39144,
  [SMALL_STATE(550)] = 39197,
  [SMALL_STATE(551)] = 39252,
  [SMALL_STATE(552)] = 39309,
  [SMALL_STATE(553)] = 39344,
  [SMALL_STATE(554)] = 39379,
  [SMALL_STATE(555)] = 39414,
  [SMALL_STATE(556)] = 39449,
  [SMALL_STATE(557)] = 39512,
  [SMALL_STATE(558)] = 39575,
  [SMALL_STATE(559)] = 39624,
  [SMALL_STATE(560)] = 39677,
  [SMALL_STATE(561)] = 39732,
  [SMALL_STATE(562)] = 39789,
  [SMALL_STATE(563)] = 39852,
  [SMALL_STATE(564)] = 39915,
  [SMALL_STATE(565)] = 39978,
  [SMALL_STATE(566)] = 40037,
  [SMALL_STATE(567)] = 40072,
  [SMALL_STATE(568)] = 40107,
  [SMALL_STATE(569)] = 40142,
  [SMALL_STATE(570)] = 40177,
  [SMALL_STATE(571)] = 40212,
  [SMALL_STATE(572)] = 40247,
  [SMALL_STATE(573)] = 40282,
  [SMALL_STATE(574)] = 40317,
  [SMALL_STATE(575)] = 40352,
  [SMALL_STATE(576)] = 40387,
  [SMALL_STATE(577)] = 40422,
  [SMALL_STATE(578)] = 40457,
  [SMALL_STATE(579)] = 40492,
  [SMALL_STATE(580)] = 40527,
  [SMALL_STATE(581)] = 40562,
  [SMALL_STATE(582)] = 40597,
  [SMALL_STATE(583)] = 40632,
  [SMALL_STATE(584)] = 40667,
  [SMALL_STATE(585)] = 40702,
  [SMALL_STATE(586)] = 40737,
  [SMALL_STATE(587)] = 40772,
  [SMALL_STATE(588)] = 40807,
  [SMALL_STATE(589)] = 40842,
  [SMALL_STATE(590)] = 40905,
  [SMALL_STATE(591)] = 40968,
  [SMALL_STATE(592)] = 41003,
  [SMALL_STATE(593)] = 41038,
  [SMALL_STATE(594)] = 41100,
  [SMALL_STATE(595)] = 41160,
  [SMALL_STATE(596)] = 41224,
  [SMALL_STATE(597)] = 41286,
  [SMALL_STATE(598)] = 41344,
  [SMALL_STATE(599)] = 41404,
  [SMALL_STATE(600)] = 41464,
  [SMALL_STATE(601)] = 41526,
  [SMALL_STATE(602)] = 41588,
  [SMALL_STATE(603)] = 41648,
  [SMALL_STATE(604)] = 41708,
  [SMALL_STATE(605)] = 41770,
  [SMALL_STATE(606)] = 41830,
  [SMALL_STATE(607)] = 41890,
  [SMALL_STATE(608)] = 41950,
  [SMALL_STATE(609)] = 42010,
  [SMALL_STATE(610)] = 42070,
  [SMALL_STATE(611)] = 42132,
  [SMALL_STATE(612)] = 42190,
  [SMALL_STATE(613)] = 42250,
  [SMALL_STATE(614)] = 42312,
  [SMALL_STATE(615)] = 42374,
  [SMALL_STATE(616)] = 42436,
  [SMALL_STATE(617)] = 42496,
  [SMALL_STATE(618)] = 42556,
  [SMALL_STATE(619)] = 42616,
  [SMALL_STATE(620)] = 42678,
  [SMALL_STATE(621)] = 42738,
  [SMALL_STATE(622)] = 42798,
  [SMALL_STATE(623)] = 42856,
  [SMALL_STATE(624)] = 42916,
  [SMALL_STATE(625)] = 42978,
  [SMALL_STATE(626)] = 43040,
  [SMALL_STATE(627)] = 43100,
  [SMALL_STATE(628)] = 43162,
  [SMALL_STATE(629)] = 43224,
  [SMALL_STATE(630)] = 43284,
  [SMALL_STATE(631)] = 43344,
  [SMALL_STATE(632)] = 43404,
  [SMALL_STATE(633)] = 43464,
  [SMALL_STATE(634)] = 43524,
  [SMALL_STATE(635)] = 43584,
  [SMALL_STATE(636)] = 43648,
  [SMALL_STATE(637)] = 43708,
  [SMALL_STATE(638)] = 43768,
  [SMALL_STATE(639)] = 43825,
  [SMALL_STATE(640)] = 43882,
  [SMALL_STATE(641)] = 43941,
  [SMALL_STATE(642)] = 43998,
  [SMALL_STATE(643)] = 44057,
  [SMALL_STATE(644)] = 44116,
  [SMALL_STATE(645)] = 44175,
  [SMALL_STATE(646)] = 44232,
  [SMALL_STATE(647)] = 44289,
  [SMALL_STATE(648)] = 44346,
  [SMALL_STATE(649)] = 44405,
  [SMALL_STATE(650)] = 44462,
  [SMALL_STATE(651)] = 44521,
  [SMALL_STATE(652)] = 44580,
  [SMALL_STATE(653)] = 44639,
  [SMALL_STATE(654)] = 44696,
  [SMALL_STATE(655)] = 44753,
  [SMALL_STATE(656)] = 44812,
  [SMALL_STATE(657)] = 44871,
  [SMALL_STATE(658)] = 44928,
  [SMALL_STATE(659)] = 44985,
  [SMALL_STATE(660)] = 45044,
  [SMALL_STATE(661)] = 45101,
  [SMALL_STATE(662)] = 45160,
  [SMALL_STATE(663)] = 45217,
  [SMALL_STATE(664)] = 45276,
  [SMALL_STATE(665)] = 45335,
  [SMALL_STATE(666)] = 45392,
  [SMALL_STATE(667)] = 45449,
  [SMALL_STATE(668)] = 45506,
  [SMALL_STATE(669)] = 45565,
  [SMALL_STATE(670)] = 45622,
  [SMALL_STATE(671)] = 45679,
  [SMALL_STATE(672)] = 45738,
  [SMALL_STATE(673)] = 45797,
  [SMALL_STATE(674)] = 45856,
  [SMALL_STATE(675)] = 45913,
  [SMALL_STATE(676)] = 45970,
  [SMALL_STATE(677)] = 46027,
  [SMALL_STATE(678)] = 46086,
  [SMALL_STATE(679)] = 46145,
  [SMALL_STATE(680)] = 46204,
  [SMALL_STATE(681)] = 46261,
  [SMALL_STATE(682)] = 46318,
  [SMALL_STATE(683)] = 46375,
  [SMALL_STATE(684)] = 46432,
  [SMALL_STATE(685)] = 46491,
  [SMALL_STATE(686)] = 46550,
  [SMALL_STATE(687)] = 46609,
  [SMALL_STATE(688)] = 46666,
  [SMALL_STATE(689)] = 46723,
  [SMALL_STATE(690)] = 46780,
  [SMALL_STATE(691)] = 46839,
  [SMALL_STATE(692)] = 46898,
  [SMALL_STATE(693)] = 46955,
  [SMALL_STATE(694)] = 47012,
  [SMALL_STATE(695)] = 47068,
  [SMALL_STATE(696)] = 47124,
  [SMALL_STATE(697)] = 47180,
  [SMALL_STATE(698)] = 47236,
  [SMALL_STATE(699)] = 47292,
  [SMALL_STATE(700)] = 47348,
  [SMALL_STATE(701)] = 47404,
  [SMALL_STATE(702)] = 47460,
  [SMALL_STATE(703)] = 47516,
  [SMALL_STATE(704)] = 47572,
  [SMALL_STATE(705)] = 47628,
  [SMALL_STATE(706)] = 47684,
  [SMALL_STATE(707)] = 47740,
  [SMALL_STATE(708)] = 47796,
  [SMALL_STATE(709)] = 47852,
  [SMALL_STATE(710)] = 47908,
  [SMALL_STATE(711)] = 47964,
  [SMALL_STATE(712)] = 48020,
  [SMALL_STATE(713)] = 48076,
  [SMALL_STATE(714)] = 48132,
  [SMALL_STATE(715)] = 48188,
  [SMALL_STATE(716)] = 48244,
  [SMALL_STATE(717)] = 48300,
  [SMALL_STATE(718)] = 48356,
  [SMALL_STATE(719)] = 48412,
  [SMALL_STATE(720)] = 48468,
  [SMALL_STATE(721)] = 48522,
  [SMALL_STATE(722)] = 48578,
  [SMALL_STATE(723)] = 48634,
  [SMALL_STATE(724)] = 48690,
  [SMALL_STATE(725)] = 48746,
  [SMALL_STATE(726)] = 48802,
  [SMALL_STATE(727)] = 48858,
  [SMALL_STATE(728)] = 48914,
  [SMALL_STATE(729)] = 48970,
  [SMALL_STATE(730)] = 49026,
  [SMALL_STATE(731)] = 49082,
  [SMALL_STATE(732)] = 49138,
  [SMALL_STATE(733)] = 49194,
  [SMALL_STATE(734)] = 49250,
  [SMALL_STATE(735)] = 49306,
  [SMALL_STATE(736)] = 49362,
  [SMALL_STATE(737)] = 49418,
  [SMALL_STATE(738)] = 49474,
  [SMALL_STATE(739)] = 49530,
  [SMALL_STATE(740)] = 49586,
  [SMALL_STATE(741)] = 49642,
  [SMALL_STATE(742)] = 49698,
  [SMALL_STATE(743)] = 49754,
  [SMALL_STATE(744)] = 49810,
  [SMALL_STATE(745)] = 49866,
  [SMALL_STATE(746)] = 49922,
  [SMALL_STATE(747)] = 49978,
  [SMALL_STATE(748)] = 50034,
  [SMALL_STATE(749)] = 50090,
  [SMALL_STATE(750)] = 50146,
  [SMALL_STATE(751)] = 50202,
  [SMALL_STATE(752)] = 50258,
  [SMALL_STATE(753)] = 50314,
  [SMALL_STATE(754)] = 50370,
  [SMALL_STATE(755)] = 50426,
  [SMALL_STATE(756)] = 50482,
  [SMALL_STATE(757)] = 50538,
  [SMALL_STATE(758)] = 50594,
  [SMALL_STATE(759)] = 50650,
  [SMALL_STATE(760)] = 50706,
  [SMALL_STATE(761)] = 50762,
  [SMALL_STATE(762)] = 50818,
  [SMALL_STATE(763)] = 50874,
  [SMALL_STATE(764)] = 50930,
  [SMALL_STATE(765)] = 50986,
  [SMALL_STATE(766)] = 51042,
  [SMALL_STATE(767)] = 51098,
  [SMALL_STATE(768)] = 51154,
  [SMALL_STATE(769)] = 51210,
  [SMALL_STATE(770)] = 51266,
  [SMALL_STATE(771)] = 51322,
  [SMALL_STATE(772)] = 51378,
  [SMALL_STATE(773)] = 51434,
  [SMALL_STATE(774)] = 51490,
  [SMALL_STATE(775)] = 51546,
  [SMALL_STATE(776)] = 51602,
  [SMALL_STATE(777)] = 51632,
  [SMALL_STATE(778)] = 51662,
  [SMALL_STATE(779)] = 51692,
  [SMALL_STATE(780)] = 51722,
  [SMALL_STATE(781)] = 51754,
  [SMALL_STATE(782)] = 51781,
  [SMALL_STATE(783)] = 51807,
  [SMALL_STATE(784)] = 51833,
  [SMALL_STATE(785)] = 51859,
  [SMALL_STATE(786)] = 51885,
  [SMALL_STATE(787)] = 51909,
  [SMALL_STATE(788)] = 51933,
  [SMALL_STATE(789)] = 51957,
  [SMALL_STATE(790)] = 51981,
  [SMALL_STATE(791)] = 52006,
  [SMALL_STATE(792)] = 52031,
  [SMALL_STATE(793)] = 52059,
  [SMALL_STATE(794)] = 52087,
  [SMALL_STATE(795)] = 52113,
  [SMALL_STATE(796)] = 52134,
  [SMALL_STATE(797)] = 52159,
  [SMALL_STATE(798)] = 52182,
  [SMALL_STATE(799)] = 52203,
  [SMALL_STATE(800)] = 52228,
  [SMALL_STATE(801)] = 52249,
  [SMALL_STATE(802)] = 52274,
  [SMALL_STATE(803)] = 52295,
  [SMALL_STATE(804)] = 52316,
  [SMALL_STATE(805)] = 52336,
  [SMALL_STATE(806)] = 52356,
  [SMALL_STATE(807)] = 52376,
  [SMALL_STATE(808)] = 52396,
  [SMALL_STATE(809)] = 52416,
  [SMALL_STATE(810)] = 52436,
  [SMALL_STATE(811)] = 52456,
  [SMALL_STATE(812)] = 52476,
  [SMALL_STATE(813)] = 52496,
  [SMALL_STATE(814)] = 52516,
  [SMALL_STATE(815)] = 52536,
  [SMALL_STATE(816)] = 52556,
  [SMALL_STATE(817)] = 52576,
  [SMALL_STATE(818)] = 52596,
  [SMALL_STATE(819)] = 52616,
  [SMALL_STATE(820)] = 52636,
  [SMALL_STATE(821)] = 52656,
  [SMALL_STATE(822)] = 52676,
  [SMALL_STATE(823)] = 52696,
  [SMALL_STATE(824)] = 52716,
  [SMALL_STATE(825)] = 52736,
  [SMALL_STATE(826)] = 52756,
  [SMALL_STATE(827)] = 52776,
  [SMALL_STATE(828)] = 52796,
  [SMALL_STATE(829)] = 52816,
  [SMALL_STATE(830)] = 52836,
  [SMALL_STATE(831)] = 52856,
  [SMALL_STATE(832)] = 52876,
  [SMALL_STATE(833)] = 52899,
  [SMALL_STATE(834)] = 52918,
  [SMALL_STATE(835)] = 52937,
  [SMALL_STATE(836)] = 52956,
  [SMALL_STATE(837)] = 52976,
  [SMALL_STATE(838)] = 53008,
  [SMALL_STATE(839)] = 53040,
  [SMALL_STATE(840)] = 53068,
  [SMALL_STATE(841)] = 53098,
  [SMALL_STATE(842)] = 53120,
  [SMALL_STATE(843)] = 53135,
  [SMALL_STATE(844)] = 53150,
  [SMALL_STATE(845)] = 53165,
  [SMALL_STATE(846)] = 53196,
  [SMALL_STATE(847)] = 53211,
  [SMALL_STATE(848)] = 53226,
  [SMALL_STATE(849)] = 53245,
  [SMALL_STATE(850)] = 53276,
  [SMALL_STATE(851)] = 53291,
  [SMALL_STATE(852)] = 53306,
  [SMALL_STATE(853)] = 53321,
  [SMALL_STATE(854)] = 53336,
  [SMALL_STATE(855)] = 53351,
  [SMALL_STATE(856)] = 53374,
  [SMALL_STATE(857)] = 53389,
  [SMALL_STATE(858)] = 53404,
  [SMALL_STATE(859)] = 53419,
  [SMALL_STATE(860)] = 53434,
  [SMALL_STATE(861)] = 53449,
  [SMALL_STATE(862)] = 53480,
  [SMALL_STATE(863)] = 53495,
  [SMALL_STATE(864)] = 53526,
  [SMALL_STATE(865)] = 53557,
  [SMALL_STATE(866)] = 53572,
  [SMALL_STATE(867)] = 53587,
  [SMALL_STATE(868)] = 53602,
  [SMALL_STATE(869)] = 53629,
  [SMALL_STATE(870)] = 53656,
  [SMALL_STATE(871)] = 53671,
  [SMALL_STATE(872)] = 53686,
  [SMALL_STATE(873)] = 53717,
  [SMALL_STATE(874)] = 53732,
  [SMALL_STATE(875)] = 53747,
  [SMALL_STATE(876)] = 53762,
  [SMALL_STATE(877)] = 53777,
  [SMALL_STATE(878)] = 53792,
  [SMALL_STATE(879)] = 53807,
  [SMALL_STATE(880)] = 53835,
  [SMALL_STATE(881)] = 53853,
  [SMALL_STATE(882)] = 53873,
  [SMALL_STATE(883)] = 53901,
  [SMALL_STATE(884)] = 53929,
  [SMALL_STATE(885)] = 53957,
  [SMALL_STATE(886)] = 53985,
  [SMALL_STATE(887)] = 54013,
  [SMALL_STATE(888)] = 54035,
  [SMALL_STATE(889)] = 54055,
  [SMALL_STATE(890)] = 54083,
  [SMALL_STATE(891)] = 54111,
  [SMALL_STATE(892)] = 54133,
  [SMALL_STATE(893)] = 54161,
  [SMALL_STATE(894)] = 54189,
  [SMALL_STATE(895)] = 54207,
  [SMALL_STATE(896)] = 54226,
  [SMALL_STATE(897)] = 54243,
  [SMALL_STATE(898)] = 54260,
  [SMALL_STATE(899)] = 54279,
  [SMALL_STATE(900)] = 54298,
  [SMALL_STATE(901)] = 54315,
  [SMALL_STATE(902)] = 54332,
  [SMALL_STATE(903)] = 54357,
  [SMALL_STATE(904)] = 54378,
  [SMALL_STATE(905)] = 54395,
  [SMALL_STATE(906)] = 54416,
  [SMALL_STATE(907)] = 54437,
  [SMALL_STATE(908)] = 54458,
  [SMALL_STATE(909)] = 54477,
  [SMALL_STATE(910)] = 54498,
  [SMALL_STATE(911)] = 54517,
  [SMALL_STATE(912)] = 54534,
  [SMALL_STATE(913)] = 54551,
  [SMALL_STATE(914)] = 54565,
  [SMALL_STATE(915)] = 54583,
  [SMALL_STATE(916)] = 54601,
  [SMALL_STATE(917)] = 54619,
  [SMALL_STATE(918)] = 54633,
  [SMALL_STATE(919)] = 54647,
  [SMALL_STATE(920)] = 54661,
  [SMALL_STATE(921)] = 54675,
  [SMALL_STATE(922)] = 54689,
  [SMALL_STATE(923)] = 54703,
  [SMALL_STATE(924)] = 54721,
  [SMALL_STATE(925)] = 54735,
  [SMALL_STATE(926)] = 54749,
  [SMALL_STATE(927)] = 54763,
  [SMALL_STATE(928)] = 54777,
  [SMALL_STATE(929)] = 54795,
  [SMALL_STATE(930)] = 54813,
  [SMALL_STATE(931)] = 54827,
  [SMALL_STATE(932)] = 54845,
  [SMALL_STATE(933)] = 54859,
  [SMALL_STATE(934)] = 54873,
  [SMALL_STATE(935)] = 54887,
  [SMALL_STATE(936)] = 54901,
  [SMALL_STATE(937)] = 54915,
  [SMALL_STATE(938)] = 54929,
  [SMALL_STATE(939)] = 54943,
  [SMALL_STATE(940)] = 54957,
  [SMALL_STATE(941)] = 54971,
  [SMALL_STATE(942)] = 54985,
  [SMALL_STATE(943)] = 54999,
  [SMALL_STATE(944)] = 55013,
  [SMALL_STATE(945)] = 55027,
  [SMALL_STATE(946)] = 55049,
  [SMALL_STATE(947)] = 55063,
  [SMALL_STATE(948)] = 55077,
  [SMALL_STATE(949)] = 55091,
  [SMALL_STATE(950)] = 55105,
  [SMALL_STATE(951)] = 55119,
  [SMALL_STATE(952)] = 55133,
  [SMALL_STATE(953)] = 55145,
  [SMALL_STATE(954)] = 55159,
  [SMALL_STATE(955)] = 55173,
  [SMALL_STATE(956)] = 55187,
  [SMALL_STATE(957)] = 55201,
  [SMALL_STATE(958)] = 55215,
  [SMALL_STATE(959)] = 55233,
  [SMALL_STATE(960)] = 55251,
  [SMALL_STATE(961)] = 55265,
  [SMALL_STATE(962)] = 55279,
  [SMALL_STATE(963)] = 55293,
  [SMALL_STATE(964)] = 55307,
  [SMALL_STATE(965)] = 55325,
  [SMALL_STATE(966)] = 55339,
  [SMALL_STATE(967)] = 55353,
  [SMALL_STATE(968)] = 55371,
  [SMALL_STATE(969)] = 55385,
  [SMALL_STATE(970)] = 55399,
  [SMALL_STATE(971)] = 55413,
  [SMALL_STATE(972)] = 55427,
  [SMALL_STATE(973)] = 55445,
  [SMALL_STATE(974)] = 55459,
  [SMALL_STATE(975)] = 55473,
  [SMALL_STATE(976)] = 55487,
  [SMALL_STATE(977)] = 55509,
  [SMALL_STATE(978)] = 55527,
  [SMALL_STATE(979)] = 55541,
  [SMALL_STATE(980)] = 55559,
  [SMALL_STATE(981)] = 55573,
  [SMALL_STATE(982)] = 55591,
  [SMALL_STATE(983)] = 55609,
  [SMALL_STATE(984)] = 55623,
  [SMALL_STATE(985)] = 55637,
  [SMALL_STATE(986)] = 55655,
  [SMALL_STATE(987)] = 55673,
  [SMALL_STATE(988)] = 55687,
  [SMALL_STATE(989)] = 55705,
  [SMALL_STATE(990)] = 55719,
  [SMALL_STATE(991)] = 55733,
  [SMALL_STATE(992)] = 55747,
  [SMALL_STATE(993)] = 55761,
  [SMALL_STATE(994)] = 55779,
  [SMALL_STATE(995)] = 55793,
  [SMALL_STATE(996)] = 55807,
  [SMALL_STATE(997)] = 55825,
  [SMALL_STATE(998)] = 55839,
  [SMALL_STATE(999)] = 55857,
  [SMALL_STATE(1000)] = 55871,
  [SMALL_STATE(1001)] = 55885,
  [SMALL_STATE(1002)] = 55899,
  [SMALL_STATE(1003)] = 55913,
  [SMALL_STATE(1004)] = 55927,
  [SMALL_STATE(1005)] = 55947,
  [SMALL_STATE(1006)] = 55961,
  [SMALL_STATE(1007)] = 55975,
  [SMALL_STATE(1008)] = 55993,
  [SMALL_STATE(1009)] = 56007,
  [SMALL_STATE(1010)] = 56021,
  [SMALL_STATE(1011)] = 56035,
  [SMALL_STATE(1012)] = 56049,
  [SMALL_STATE(1013)] = 56063,
  [SMALL_STATE(1014)] = 56077,
  [SMALL_STATE(1015)] = 56091,
  [SMALL_STATE(1016)] = 56105,
  [SMALL_STATE(1017)] = 56119,
  [SMALL_STATE(1018)] = 56133,
  [SMALL_STATE(1019)] = 56152,
  [SMALL_STATE(1020)] = 56169,
  [SMALL_STATE(1021)] = 56186,
  [SMALL_STATE(1022)] = 56203,
  [SMALL_STATE(1023)] = 56222,
  [SMALL_STATE(1024)] = 56239,
  [SMALL_STATE(1025)] = 56256,
  [SMALL_STATE(1026)] = 56273,
  [SMALL_STATE(1027)] = 56290,
  [SMALL_STATE(1028)] = 56307,
  [SMALL_STATE(1029)] = 56324,
  [SMALL_STATE(1030)] = 56341,
  [SMALL_STATE(1031)] = 56358,
  [SMALL_STATE(1032)] = 56377,
  [SMALL_STATE(1033)] = 56396,
  [SMALL_STATE(1034)] = 56413,
  [SMALL_STATE(1035)] = 56430,
  [SMALL_STATE(1036)] = 56447,
  [SMALL_STATE(1037)] = 56464,
  [SMALL_STATE(1038)] = 56481,
  [SMALL_STATE(1039)] = 56498,
  [SMALL_STATE(1040)] = 56515,
  [SMALL_STATE(1041)] = 56532,
  [SMALL_STATE(1042)] = 56551,
  [SMALL_STATE(1043)] = 56568,
  [SMALL_STATE(1044)] = 56585,
  [SMALL_STATE(1045)] = 56602,
  [SMALL_STATE(1046)] = 56615,
  [SMALL_STATE(1047)] = 56634,
  [SMALL_STATE(1048)] = 56651,
  [SMALL_STATE(1049)] = 56668,
  [SMALL_STATE(1050)] = 56685,
  [SMALL_STATE(1051)] = 56699,
  [SMALL_STATE(1052)] = 56713,
  [SMALL_STATE(1053)] = 56729,
  [SMALL_STATE(1054)] = 56741,
  [SMALL_STATE(1055)] = 56753,
  [SMALL_STATE(1056)] = 56765,
  [SMALL_STATE(1057)] = 56777,
  [SMALL_STATE(1058)] = 56789,
  [SMALL_STATE(1059)] = 56801,
  [SMALL_STATE(1060)] = 56813,
  [SMALL_STATE(1061)] = 56825,
  [SMALL_STATE(1062)] = 56841,
  [SMALL_STATE(1063)] = 56855,
  [SMALL_STATE(1064)] = 56867,
  [SMALL_STATE(1065)] = 56879,
  [SMALL_STATE(1066)] = 56891,
  [SMALL_STATE(1067)] = 56903,
  [SMALL_STATE(1068)] = 56917,
  [SMALL_STATE(1069)] = 56931,
  [SMALL_STATE(1070)] = 56943,
  [SMALL_STATE(1071)] = 56957,
  [SMALL_STATE(1072)] = 56971,
  [SMALL_STATE(1073)] = 56985,
  [SMALL_STATE(1074)] = 57001,
  [SMALL_STATE(1075)] = 57013,
  [SMALL_STATE(1076)] = 57029,
  [SMALL_STATE(1077)] = 57041,
  [SMALL_STATE(1078)] = 57053,
  [SMALL_STATE(1079)] = 57067,
  [SMALL_STATE(1080)] = 57079,
  [SMALL_STATE(1081)] = 57093,
  [SMALL_STATE(1082)] = 57105,
  [SMALL_STATE(1083)] = 57117,
  [SMALL_STATE(1084)] = 57131,
  [SMALL_STATE(1085)] = 57145,
  [SMALL_STATE(1086)] = 57157,
  [SMALL_STATE(1087)] = 57171,
  [SMALL_STATE(1088)] = 57187,
  [SMALL_STATE(1089)] = 57203,
  [SMALL_STATE(1090)] = 57219,
  [SMALL_STATE(1091)] = 57233,
  [SMALL_STATE(1092)] = 57245,
  [SMALL_STATE(1093)] = 57259,
  [SMALL_STATE(1094)] = 57275,
  [SMALL_STATE(1095)] = 57289,
  [SMALL_STATE(1096)] = 57303,
  [SMALL_STATE(1097)] = 57317,
  [SMALL_STATE(1098)] = 57331,
  [SMALL_STATE(1099)] = 57345,
  [SMALL_STATE(1100)] = 57359,
  [SMALL_STATE(1101)] = 57375,
  [SMALL_STATE(1102)] = 57391,
  [SMALL_STATE(1103)] = 57403,
  [SMALL_STATE(1104)] = 57419,
  [SMALL_STATE(1105)] = 57433,
  [SMALL_STATE(1106)] = 57447,
  [SMALL_STATE(1107)] = 57463,
  [SMALL_STATE(1108)] = 57477,
  [SMALL_STATE(1109)] = 57491,
  [SMALL_STATE(1110)] = 57503,
  [SMALL_STATE(1111)] = 57515,
  [SMALL_STATE(1112)] = 57529,
  [SMALL_STATE(1113)] = 57541,
  [SMALL_STATE(1114)] = 57555,
  [SMALL_STATE(1115)] = 57571,
  [SMALL_STATE(1116)] = 57583,
  [SMALL_STATE(1117)] = 57597,
  [SMALL_STATE(1118)] = 57611,
  [SMALL_STATE(1119)] = 57625,
  [SMALL_STATE(1120)] = 57639,
  [SMALL_STATE(1121)] = 57655,
  [SMALL_STATE(1122)] = 57667,
  [SMALL_STATE(1123)] = 57679,
  [SMALL_STATE(1124)] = 57691,
  [SMALL_STATE(1125)] = 57703,
  [SMALL_STATE(1126)] = 57715,
  [SMALL_STATE(1127)] = 57727,
  [SMALL_STATE(1128)] = 57741,
  [SMALL_STATE(1129)] = 57753,
  [SMALL_STATE(1130)] = 57765,
  [SMALL_STATE(1131)] = 57777,
  [SMALL_STATE(1132)] = 57791,
  [SMALL_STATE(1133)] = 57805,
  [SMALL_STATE(1134)] = 57819,
  [SMALL_STATE(1135)] = 57832,
  [SMALL_STATE(1136)] = 57845,
  [SMALL_STATE(1137)] = 57858,
  [SMALL_STATE(1138)] = 57869,
  [SMALL_STATE(1139)] = 57882,
  [SMALL_STATE(1140)] = 57891,
  [SMALL_STATE(1141)] = 57904,
  [SMALL_STATE(1142)] = 57917,
  [SMALL_STATE(1143)] = 57930,
  [SMALL_STATE(1144)] = 57943,
  [SMALL_STATE(1145)] = 57956,
  [SMALL_STATE(1146)] = 57969,
  [SMALL_STATE(1147)] = 57982,
  [SMALL_STATE(1148)] = 57991,
  [SMALL_STATE(1149)] = 58000,
  [SMALL_STATE(1150)] = 58013,
  [SMALL_STATE(1151)] = 58026,
  [SMALL_STATE(1152)] = 58039,
  [SMALL_STATE(1153)] = 58052,
  [SMALL_STATE(1154)] = 58065,
  [SMALL_STATE(1155)] = 58076,
  [SMALL_STATE(1156)] = 58089,
  [SMALL_STATE(1157)] = 58098,
  [SMALL_STATE(1158)] = 58107,
  [SMALL_STATE(1159)] = 58120,
  [SMALL_STATE(1160)] = 58133,
  [SMALL_STATE(1161)] = 58146,
  [SMALL_STATE(1162)] = 58159,
  [SMALL_STATE(1163)] = 58172,
  [SMALL_STATE(1164)] = 58185,
  [SMALL_STATE(1165)] = 58198,
  [SMALL_STATE(1166)] = 58211,
  [SMALL_STATE(1167)] = 58224,
  [SMALL_STATE(1168)] = 58237,
  [SMALL_STATE(1169)] = 58250,
  [SMALL_STATE(1170)] = 58261,
  [SMALL_STATE(1171)] = 58274,
  [SMALL_STATE(1172)] = 58285,
  [SMALL_STATE(1173)] = 58298,
  [SMALL_STATE(1174)] = 58311,
  [SMALL_STATE(1175)] = 58324,
  [SMALL_STATE(1176)] = 58335,
  [SMALL_STATE(1177)] = 58346,
  [SMALL_STATE(1178)] = 58359,
  [SMALL_STATE(1179)] = 58372,
  [SMALL_STATE(1180)] = 58385,
  [SMALL_STATE(1181)] = 58398,
  [SMALL_STATE(1182)] = 58411,
  [SMALL_STATE(1183)] = 58424,
  [SMALL_STATE(1184)] = 58437,
  [SMALL_STATE(1185)] = 58450,
  [SMALL_STATE(1186)] = 58463,
  [SMALL_STATE(1187)] = 58476,
  [SMALL_STATE(1188)] = 58487,
  [SMALL_STATE(1189)] = 58500,
  [SMALL_STATE(1190)] = 58513,
  [SMALL_STATE(1191)] = 58522,
  [SMALL_STATE(1192)] = 58533,
  [SMALL_STATE(1193)] = 58546,
  [SMALL_STATE(1194)] = 58559,
  [SMALL_STATE(1195)] = 58568,
  [SMALL_STATE(1196)] = 58581,
  [SMALL_STATE(1197)] = 58594,
  [SMALL_STATE(1198)] = 58607,
  [SMALL_STATE(1199)] = 58620,
  [SMALL_STATE(1200)] = 58633,
  [SMALL_STATE(1201)] = 58646,
  [SMALL_STATE(1202)] = 58659,
  [SMALL_STATE(1203)] = 58672,
  [SMALL_STATE(1204)] = 58683,
  [SMALL_STATE(1205)] = 58696,
  [SMALL_STATE(1206)] = 58709,
  [SMALL_STATE(1207)] = 58722,
  [SMALL_STATE(1208)] = 58733,
  [SMALL_STATE(1209)] = 58746,
  [SMALL_STATE(1210)] = 58759,
  [SMALL_STATE(1211)] = 58770,
  [SMALL_STATE(1212)] = 58781,
  [SMALL_STATE(1213)] = 58792,
  [SMALL_STATE(1214)] = 58805,
  [SMALL_STATE(1215)] = 58818,
  [SMALL_STATE(1216)] = 58831,
  [SMALL_STATE(1217)] = 58844,
  [SMALL_STATE(1218)] = 58857,
  [SMALL_STATE(1219)] = 58870,
  [SMALL_STATE(1220)] = 58883,
  [SMALL_STATE(1221)] = 58896,
  [SMALL_STATE(1222)] = 58909,
  [SMALL_STATE(1223)] = 58922,
  [SMALL_STATE(1224)] = 58935,
  [SMALL_STATE(1225)] = 58948,
  [SMALL_STATE(1226)] = 58961,
  [SMALL_STATE(1227)] = 58974,
  [SMALL_STATE(1228)] = 58987,
  [SMALL_STATE(1229)] = 59000,
  [SMALL_STATE(1230)] = 59013,
  [SMALL_STATE(1231)] = 59022,
  [SMALL_STATE(1232)] = 59035,
  [SMALL_STATE(1233)] = 59046,
  [SMALL_STATE(1234)] = 59059,
  [SMALL_STATE(1235)] = 59070,
  [SMALL_STATE(1236)] = 59081,
  [SMALL_STATE(1237)] = 59094,
  [SMALL_STATE(1238)] = 59103,
  [SMALL_STATE(1239)] = 59116,
  [SMALL_STATE(1240)] = 59129,
  [SMALL_STATE(1241)] = 59138,
  [SMALL_STATE(1242)] = 59149,
  [SMALL_STATE(1243)] = 59162,
  [SMALL_STATE(1244)] = 59172,
  [SMALL_STATE(1245)] = 59182,
  [SMALL_STATE(1246)] = 59190,
  [SMALL_STATE(1247)] = 59198,
  [SMALL_STATE(1248)] = 59208,
  [SMALL_STATE(1249)] = 59218,
  [SMALL_STATE(1250)] = 59228,
  [SMALL_STATE(1251)] = 59238,
  [SMALL_STATE(1252)] = 59248,
  [SMALL_STATE(1253)] = 59258,
  [SMALL_STATE(1254)] = 59266,
  [SMALL_STATE(1255)] = 59274,
  [SMALL_STATE(1256)] = 59284,
  [SMALL_STATE(1257)] = 59294,
  [SMALL_STATE(1258)] = 59304,
  [SMALL_STATE(1259)] = 59314,
  [SMALL_STATE(1260)] = 59324,
  [SMALL_STATE(1261)] = 59334,
  [SMALL_STATE(1262)] = 59342,
  [SMALL_STATE(1263)] = 59352,
  [SMALL_STATE(1264)] = 59360,
  [SMALL_STATE(1265)] = 59368,
  [SMALL_STATE(1266)] = 59378,
  [SMALL_STATE(1267)] = 59388,
  [SMALL_STATE(1268)] = 59398,
  [SMALL_STATE(1269)] = 59408,
  [SMALL_STATE(1270)] = 59416,
  [SMALL_STATE(1271)] = 59426,
  [SMALL_STATE(1272)] = 59436,
  [SMALL_STATE(1273)] = 59446,
  [SMALL_STATE(1274)] = 59454,
  [SMALL_STATE(1275)] = 59464,
  [SMALL_STATE(1276)] = 59474,
  [SMALL_STATE(1277)] = 59482,
  [SMALL_STATE(1278)] = 59490,
  [SMALL_STATE(1279)] = 59498,
  [SMALL_STATE(1280)] = 59506,
  [SMALL_STATE(1281)] = 59516,
  [SMALL_STATE(1282)] = 59524,
  [SMALL_STATE(1283)] = 59532,
  [SMALL_STATE(1284)] = 59542,
  [SMALL_STATE(1285)] = 59550,
  [SMALL_STATE(1286)] = 59560,
  [SMALL_STATE(1287)] = 59568,
  [SMALL_STATE(1288)] = 59576,
  [SMALL_STATE(1289)] = 59586,
  [SMALL_STATE(1290)] = 59594,
  [SMALL_STATE(1291)] = 59604,
  [SMALL_STATE(1292)] = 59614,
  [SMALL_STATE(1293)] = 59624,
  [SMALL_STATE(1294)] = 59634,
  [SMALL_STATE(1295)] = 59644,
  [SMALL_STATE(1296)] = 59654,
  [SMALL_STATE(1297)] = 59664,
  [SMALL_STATE(1298)] = 59672,
  [SMALL_STATE(1299)] = 59680,
  [SMALL_STATE(1300)] = 59688,
  [SMALL_STATE(1301)] = 59698,
  [SMALL_STATE(1302)] = 59706,
  [SMALL_STATE(1303)] = 59716,
  [SMALL_STATE(1304)] = 59726,
  [SMALL_STATE(1305)] = 59734,
  [SMALL_STATE(1306)] = 59744,
  [SMALL_STATE(1307)] = 59754,
  [SMALL_STATE(1308)] = 59764,
  [SMALL_STATE(1309)] = 59774,
  [SMALL_STATE(1310)] = 59784,
  [SMALL_STATE(1311)] = 59792,
  [SMALL_STATE(1312)] = 59802,
  [SMALL_STATE(1313)] = 59812,
  [SMALL_STATE(1314)] = 59822,
  [SMALL_STATE(1315)] = 59832,
  [SMALL_STATE(1316)] = 59842,
  [SMALL_STATE(1317)] = 59852,
  [SMALL_STATE(1318)] = 59859,
  [SMALL_STATE(1319)] = 59866,
  [SMALL_STATE(1320)] = 59873,
  [SMALL_STATE(1321)] = 59880,
  [SMALL_STATE(1322)] = 59887,
  [SMALL_STATE(1323)] = 59894,
  [SMALL_STATE(1324)] = 59901,
  [SMALL_STATE(1325)] = 59908,
  [SMALL_STATE(1326)] = 59915,
  [SMALL_STATE(1327)] = 59922,
  [SMALL_STATE(1328)] = 59929,
  [SMALL_STATE(1329)] = 59936,
  [SMALL_STATE(1330)] = 59943,
  [SMALL_STATE(1331)] = 59950,
  [SMALL_STATE(1332)] = 59957,
  [SMALL_STATE(1333)] = 59964,
  [SMALL_STATE(1334)] = 59971,
  [SMALL_STATE(1335)] = 59978,
  [SMALL_STATE(1336)] = 59985,
  [SMALL_STATE(1337)] = 59992,
  [SMALL_STATE(1338)] = 59999,
  [SMALL_STATE(1339)] = 60006,
  [SMALL_STATE(1340)] = 60013,
  [SMALL_STATE(1341)] = 60020,
  [SMALL_STATE(1342)] = 60027,
  [SMALL_STATE(1343)] = 60034,
  [SMALL_STATE(1344)] = 60041,
  [SMALL_STATE(1345)] = 60048,
  [SMALL_STATE(1346)] = 60055,
  [SMALL_STATE(1347)] = 60062,
  [SMALL_STATE(1348)] = 60069,
  [SMALL_STATE(1349)] = 60076,
  [SMALL_STATE(1350)] = 60083,
  [SMALL_STATE(1351)] = 60090,
  [SMALL_STATE(1352)] = 60097,
  [SMALL_STATE(1353)] = 60104,
  [SMALL_STATE(1354)] = 60111,
  [SMALL_STATE(1355)] = 60118,
  [SMALL_STATE(1356)] = 60125,
  [SMALL_STATE(1357)] = 60132,
  [SMALL_STATE(1358)] = 60139,
  [SMALL_STATE(1359)] = 60146,
  [SMALL_STATE(1360)] = 60153,
  [SMALL_STATE(1361)] = 60160,
  [SMALL_STATE(1362)] = 60167,
  [SMALL_STATE(1363)] = 60174,
  [SMALL_STATE(1364)] = 60181,
  [SMALL_STATE(1365)] = 60188,
  [SMALL_STATE(1366)] = 60195,
  [SMALL_STATE(1367)] = 60202,
  [SMALL_STATE(1368)] = 60209,
  [SMALL_STATE(1369)] = 60216,
  [SMALL_STATE(1370)] = 60223,
  [SMALL_STATE(1371)] = 60230,
  [SMALL_STATE(1372)] = 60237,
  [SMALL_STATE(1373)] = 60244,
  [SMALL_STATE(1374)] = 60251,
  [SMALL_STATE(1375)] = 60258,
  [SMALL_STATE(1376)] = 60265,
  [SMALL_STATE(1377)] = 60272,
  [SMALL_STATE(1378)] = 60279,
  [SMALL_STATE(1379)] = 60286,
  [SMALL_STATE(1380)] = 60293,
  [SMALL_STATE(1381)] = 60300,
  [SMALL_STATE(1382)] = 60307,
  [SMALL_STATE(1383)] = 60314,
  [SMALL_STATE(1384)] = 60321,
  [SMALL_STATE(1385)] = 60328,
  [SMALL_STATE(1386)] = 60335,
  [SMALL_STATE(1387)] = 60342,
  [SMALL_STATE(1388)] = 60349,
  [SMALL_STATE(1389)] = 60356,
  [SMALL_STATE(1390)] = 60363,
  [SMALL_STATE(1391)] = 60370,
  [SMALL_STATE(1392)] = 60377,
  [SMALL_STATE(1393)] = 60384,
  [SMALL_STATE(1394)] = 60391,
  [SMALL_STATE(1395)] = 60398,
  [SMALL_STATE(1396)] = 60405,
  [SMALL_STATE(1397)] = 60412,
  [SMALL_STATE(1398)] = 60419,
  [SMALL_STATE(1399)] = 60426,
  [SMALL_STATE(1400)] = 60433,
  [SMALL_STATE(1401)] = 60440,
  [SMALL_STATE(1402)] = 60447,
  [SMALL_STATE(1403)] = 60454,
};

static const TSParseActionEntry ts_parse_actions[] = {
  [0] = {.entry = {.count = 0, .reusable = false}},
  [1] = {.entry = {.count = 1, .reusable = false}}, RECOVER(),
  [3] = {.entry = {.count = 1, .reusable = true}}, SHIFT_EXTRA(),
  [5] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_source_file, 0, 0, 0),
  [7] = {.entry = {.count = 1, .reusable = false}}, SHIFT(238),
  [9] = {.entry = {.count = 1, .reusable = true}}, SHIFT(935),
  [11] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1331),
  [13] = {.entry = {.count = 1, .reusable = false}}, SHIFT(837),
  [15] = {.entry = {.count = 1, .reusable = true}}, SHIFT(135),
  [17] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1219),
  [19] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1105),
  [21] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1229),
  [23] = {.entry = {.count = 1, .reusable = true}}, SHIFT(50),
  [25] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1131),
  [27] = {.entry = {.count = 1, .reusable = true}}, SHIFT(148),
  [29] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1249),
  [31] = {.entry = {.count = 1, .reusable = true}}, SHIFT(740),
  [33] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15),
  [35] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1361),
  [37] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1363),
  [39] = {.entry = {.count = 1, .reusable = false}}, SHIFT(704),
  [41] = {.entry = {.count = 1, .reusable = true}}, SHIFT(147),
  [43] = {.entry = {.count = 1, .reusable = false}}, SHIFT(933),
  [45] = {.entry = {.count = 1, .reusable = false}}, SHIFT(912),
  [47] = {.entry = {.count = 1, .reusable = false}}, SHIFT(897),
  [49] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1330),
  [51] = {.entry = {.count = 1, .reusable = false}}, SHIFT(28),
  [53] = {.entry = {.count = 1, .reusable = false}}, SHIFT(157),
  [55] = {.entry = {.count = 1, .reusable = false}}, SHIFT(165),
  [57] = {.entry = {.count = 1, .reusable = false}}, SHIFT(27),
  [59] = {.entry = {.count = 1, .reusable = false}}, SHIFT(21),
  [61] = {.entry = {.count = 1, .reusable = false}}, SHIFT(22),
  [63] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1376),
  [65] = {.entry = {.count = 1, .reusable = false}}, SHIFT(251),
  [67] = {.entry = {.count = 1, .reusable = true}}, SHIFT(160),
  [69] = {.entry = {.count = 1, .reusable = true}}, SHIFT(266),
  [71] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1051),
  [73] = {.entry = {.count = 1, .reusable = false}}, SHIFT(266),
  [75] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_source_file, 1, 0, 0),
  [77] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0),
  [79] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(238),
  [82] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(935),
  [85] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(1350),
  [88] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(838),
  [91] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(135),
  [94] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(1219),
  [97] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(1105),
  [100] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(1216),
  [103] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(50),
  [106] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(1131),
  [109] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(148),
  [112] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(1249),
  [115] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(740),
  [118] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(15),
  [121] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(1361),
  [124] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(1363),
  [127] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(704),
  [130] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(147),
  [133] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(933),
  [136] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(912),
  [139] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(897),
  [142] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(1330),
  [145] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(28),
  [148] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(157),
  [151] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(165),
  [154] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(27),
  [157] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(21),
  [160] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(22),
  [163] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(1376),
  [166] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(251),
  [169] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(160),
  [172] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(266),
  [175] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(1051),
  [178] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(266),
  [181] = {.entry = {.count = 1, .reusable = false}}, SHIFT(237),
  [183] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1280),
  [185] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_case, 4, 0, 103),
  [187] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_case, 4, 0, 103),
  [189] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_expression_case, 3, 0, 7),
  [191] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_expression_case, 3, 0, 7),
  [193] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_case, 3, 0, 41),
  [195] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_case, 3, 0, 41),
  [197] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_communication_case, 3, 0, 88),
  [199] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_communication_case, 3, 0, 88),
  [201] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_default_case, 2, 0, 0),
  [203] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_default_case, 2, 0, 0),
  [205] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__statement_list, 2, 0, 0),
  [207] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__statement_list, 2, 0, 0),
  [209] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__statement_list, 3, 0, 0),
  [211] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__statement_list, 3, 0, 0),
  [213] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_empty_labeled_statement, 2, 0, 26),
  [215] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_empty_labeled_statement, 2, 0, 26),
  [217] = {.entry = {.count = 1, .reusable = true}}, SHIFT(300),
  [219] = {.entry = {.count = 1, .reusable = true}}, SHIFT(396),
  [221] = {.entry = {.count = 1, .reusable = true}}, SHIFT(506),
  [223] = {.entry = {.count = 1, .reusable = true}}, SHIFT(249),
  [225] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1063),
  [227] = {.entry = {.count = 1, .reusable = true}}, SHIFT(364),
  [229] = {.entry = {.count = 1, .reusable = true}}, SHIFT(537),
  [231] = {.entry = {.count = 1, .reusable = false}}, SHIFT(296),
  [233] = {.entry = {.count = 1, .reusable = true}}, SHIFT(87),
  [235] = {.entry = {.count = 1, .reusable = true}}, SHIFT(220),
  [237] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1294),
  [239] = {.entry = {.count = 1, .reusable = true}}, SHIFT(174),
  [241] = {.entry = {.count = 1, .reusable = true}}, SHIFT(176),
  [243] = {.entry = {.count = 1, .reusable = false}}, SHIFT(149),
  [245] = {.entry = {.count = 1, .reusable = false}}, SHIFT(298),
  [247] = {.entry = {.count = 1, .reusable = true}}, SHIFT(196),
  [249] = {.entry = {.count = 1, .reusable = true}}, SHIFT(306),
  [251] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1095),
  [253] = {.entry = {.count = 1, .reusable = false}}, SHIFT(306),
  [255] = {.entry = {.count = 1, .reusable = true}}, SHIFT(964),
  [257] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_clause, 3, 0, 57),
  [259] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_clause, 2, 0, 0),
  [261] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_clause, 3, 0, 58),
  [263] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_clause, 4, 0, 86),
  [265] = {.entry = {.count = 1, .reusable = false}}, SHIFT(431),
  [267] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_return_statement, 1, 0, 0),
  [269] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_return_statement, 1, 0, 0),
  [271] = {.entry = {.count = 1, .reusable = false}}, SHIFT(215),
  [273] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1290),
  [275] = {.entry = {.count = 1, .reusable = false}}, SHIFT(50),
  [277] = {.entry = {.count = 1, .reusable = false}}, SHIFT(166),
  [279] = {.entry = {.count = 1, .reusable = false}}, SHIFT(740),
  [281] = {.entry = {.count = 1, .reusable = false}}, SHIFT(167),
  [283] = {.entry = {.count = 1, .reusable = false}}, SHIFT(453),
  [285] = {.entry = {.count = 1, .reusable = false}}, SHIFT(188),
  [287] = {.entry = {.count = 1, .reusable = false}}, SHIFT(502),
  [289] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1083),
  [291] = {.entry = {.count = 1, .reusable = false}}, SHIFT_EXTRA(),
  [293] = {.entry = {.count = 1, .reusable = false}}, SHIFT(390),
  [295] = {.entry = {.count = 1, .reusable = true}}, SHIFT(210),
  [297] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1400),
  [299] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1303),
  [301] = {.entry = {.count = 1, .reusable = true}}, SHIFT(156),
  [303] = {.entry = {.count = 1, .reusable = true}}, SHIFT(34),
  [305] = {.entry = {.count = 1, .reusable = true}}, SHIFT(373),
  [307] = {.entry = {.count = 1, .reusable = true}}, SHIFT(158),
  [309] = {.entry = {.count = 1, .reusable = false}}, SHIFT(389),
  [311] = {.entry = {.count = 1, .reusable = true}}, SHIFT(182),
  [313] = {.entry = {.count = 1, .reusable = true}}, SHIFT(394),
  [315] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1067),
  [317] = {.entry = {.count = 1, .reusable = false}}, SHIFT(394),
  [319] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1362),
  [321] = {.entry = {.count = 1, .reusable = true}}, SHIFT(508),
  [323] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1378),
  [325] = {.entry = {.count = 1, .reusable = true}}, SHIFT(312),
  [327] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1325),
  [329] = {.entry = {.count = 1, .reusable = true}}, SHIFT(288),
  [331] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1377),
  [333] = {.entry = {.count = 1, .reusable = true}}, SHIFT(554),
  [335] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1327),
  [337] = {.entry = {.count = 1, .reusable = true}}, SHIFT(404),
  [339] = {.entry = {.count = 1, .reusable = true}}, SHIFT(489),
  [341] = {.entry = {.count = 1, .reusable = true}}, SHIFT(417),
  [343] = {.entry = {.count = 1, .reusable = true}}, SHIFT(476),
  [345] = {.entry = {.count = 1, .reusable = true}}, SHIFT(281),
  [347] = {.entry = {.count = 1, .reusable = true}}, SHIFT(326),
  [349] = {.entry = {.count = 1, .reusable = true}}, SHIFT(425),
  [351] = {.entry = {.count = 1, .reusable = true}}, SHIFT(335),
  [353] = {.entry = {.count = 1, .reusable = true}}, SHIFT(272),
  [355] = {.entry = {.count = 1, .reusable = true}}, SHIFT(360),
  [357] = {.entry = {.count = 1, .reusable = true}}, SHIFT(576),
  [359] = {.entry = {.count = 1, .reusable = true}}, SHIFT(350),
  [361] = {.entry = {.count = 1, .reusable = true}}, SHIFT(528),
  [363] = {.entry = {.count = 1, .reusable = false}}, SHIFT(452),
  [365] = {.entry = {.count = 1, .reusable = true}}, SHIFT(230),
  [367] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1305),
  [369] = {.entry = {.count = 1, .reusable = true}}, SHIFT(209),
  [371] = {.entry = {.count = 1, .reusable = true}}, SHIFT(207),
  [373] = {.entry = {.count = 1, .reusable = false}}, SHIFT(515),
  [375] = {.entry = {.count = 1, .reusable = true}}, SHIFT(232),
  [377] = {.entry = {.count = 1, .reusable = true}}, SHIFT(534),
  [379] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1118),
  [381] = {.entry = {.count = 1, .reusable = false}}, SHIFT(534),
  [383] = {.entry = {.count = 1, .reusable = true}}, SHIFT(754),
  [385] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1337),
  [387] = {.entry = {.count = 1, .reusable = false}}, SHIFT(520),
  [389] = {.entry = {.count = 1, .reusable = true}}, SHIFT(208),
  [391] = {.entry = {.count = 1, .reusable = true}}, SHIFT(116),
  [393] = {.entry = {.count = 1, .reusable = false}}, SHIFT(514),
  [395] = {.entry = {.count = 1, .reusable = true}}, SHIFT(283),
  [397] = {.entry = {.count = 1, .reusable = true}}, SHIFT(189),
  [399] = {.entry = {.count = 1, .reusable = true}}, SHIFT(137),
  [401] = {.entry = {.count = 1, .reusable = true}}, SHIFT(172),
  [403] = {.entry = {.count = 1, .reusable = false}}, SHIFT(535),
  [405] = {.entry = {.count = 1, .reusable = true}}, SHIFT(203),
  [407] = {.entry = {.count = 1, .reusable = true}}, SHIFT(988),
  [409] = {.entry = {.count = 1, .reusable = true}}, SHIFT(191),
  [411] = {.entry = {.count = 1, .reusable = true}}, SHIFT(150),
  [413] = {.entry = {.count = 1, .reusable = true}}, SHIFT(270),
  [415] = {.entry = {.count = 1, .reusable = true}}, SHIFT(406),
  [417] = {.entry = {.count = 1, .reusable = true}}, SHIFT(724),
  [419] = {.entry = {.count = 1, .reusable = true}}, SHIFT(421),
  [421] = {.entry = {.count = 1, .reusable = true}}, SHIFT(427),
  [423] = {.entry = {.count = 1, .reusable = true}}, SHIFT(464),
  [425] = {.entry = {.count = 1, .reusable = true}}, SHIFT(715),
  [427] = {.entry = {.count = 1, .reusable = true}}, SHIFT(483),
  [429] = {.entry = {.count = 1, .reusable = true}}, SHIFT(85),
  [431] = {.entry = {.count = 1, .reusable = true}}, SHIFT(494),
  [433] = {.entry = {.count = 1, .reusable = false}}, SHIFT(146),
  [435] = {.entry = {.count = 1, .reusable = true}}, SHIFT(330),
  [437] = {.entry = {.count = 1, .reusable = true}}, SHIFT(315),
  [439] = {.entry = {.count = 1, .reusable = false}}, SHIFT(236),
  [441] = {.entry = {.count = 1, .reusable = true}}, SHIFT(276),
  [443] = {.entry = {.count = 1, .reusable = true}}, SHIFT(375),
  [445] = {.entry = {.count = 1, .reusable = true}}, SHIFT(376),
  [447] = {.entry = {.count = 1, .reusable = true}}, SHIFT(352),
  [449] = {.entry = {.count = 1, .reusable = true}}, SHIFT(592),
  [451] = {.entry = {.count = 1, .reusable = true}}, SHIFT(580),
  [453] = {.entry = {.count = 1, .reusable = true}}, SHIFT(585),
  [455] = {.entry = {.count = 1, .reusable = true}}, SHIFT(98),
  [457] = {.entry = {.count = 1, .reusable = true}}, SHIFT(128),
  [459] = {.entry = {.count = 1, .reusable = true}}, SHIFT(91),
  [461] = {.entry = {.count = 1, .reusable = true}}, SHIFT(81),
  [463] = {.entry = {.count = 1, .reusable = true}}, SHIFT(336),
  [465] = {.entry = {.count = 1, .reusable = true}}, SHIFT(366),
  [467] = {.entry = {.count = 1, .reusable = true}}, SHIFT(485),
  [469] = {.entry = {.count = 1, .reusable = true}}, SHIFT(486),
  [471] = {.entry = {.count = 1, .reusable = true}}, SHIFT(263),
  [473] = {.entry = {.count = 1, .reusable = true}}, SHIFT(24),
  [475] = {.entry = {.count = 1, .reusable = true}}, SHIFT(736),
  [477] = {.entry = {.count = 1, .reusable = true}}, SHIFT(215),
  [479] = {.entry = {.count = 1, .reusable = true}}, SHIFT(166),
  [481] = {.entry = {.count = 1, .reusable = true}}, SHIFT(167),
  [483] = {.entry = {.count = 1, .reusable = true}}, SHIFT(188),
  [485] = {.entry = {.count = 1, .reusable = true}}, SHIFT(502),
  [487] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1083),
  [489] = {.entry = {.count = 1, .reusable = true}}, SHIFT(323),
  [491] = {.entry = {.count = 1, .reusable = true}}, SHIFT(325),
  [493] = {.entry = {.count = 1, .reusable = true}}, SHIFT(332),
  [495] = {.entry = {.count = 1, .reusable = true}}, SHIFT(334),
  [497] = {.entry = {.count = 1, .reusable = true}}, SHIFT(271),
  [499] = {.entry = {.count = 1, .reusable = true}}, SHIFT(414),
  [501] = {.entry = {.count = 1, .reusable = true}}, SHIFT(745),
  [503] = {.entry = {.count = 1, .reusable = true}}, SHIFT(416),
  [505] = {.entry = {.count = 1, .reusable = true}}, SHIFT(280),
  [507] = {.entry = {.count = 1, .reusable = true}}, SHIFT(278),
  [509] = {.entry = {.count = 1, .reusable = true}}, SHIFT(25),
  [511] = {.entry = {.count = 1, .reusable = true}}, SHIFT(348),
  [513] = {.entry = {.count = 1, .reusable = true}}, SHIFT(349),
  [515] = {.entry = {.count = 1, .reusable = true}}, SHIFT(423),
  [517] = {.entry = {.count = 1, .reusable = true}}, SHIFT(752),
  [519] = {.entry = {.count = 1, .reusable = true}}, SHIFT(424),
  [521] = {.entry = {.count = 1, .reusable = true}}, SHIFT(573),
  [523] = {.entry = {.count = 1, .reusable = true}}, SHIFT(575),
  [525] = {.entry = {.count = 1, .reusable = true}}, SHIFT(582),
  [527] = {.entry = {.count = 1, .reusable = true}}, SHIFT(583),
  [529] = {.entry = {.count = 1, .reusable = true}}, SHIFT(474),
  [531] = {.entry = {.count = 1, .reusable = true}}, SHIFT(457),
  [533] = {.entry = {.count = 1, .reusable = true}}, SHIFT(359),
  [535] = {.entry = {.count = 1, .reusable = true}}, SHIFT(136),
  [537] = {.entry = {.count = 1, .reusable = false}}, SHIFT(737),
  [539] = {.entry = {.count = 1, .reusable = false}}, SHIFT(240),
  [541] = {.entry = {.count = 1, .reusable = false}}, SHIFT(337),
  [543] = {.entry = {.count = 1, .reusable = true}}, SHIFT(225),
  [545] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1300),
  [547] = {.entry = {.count = 1, .reusable = true}}, SHIFT(206),
  [549] = {.entry = {.count = 1, .reusable = true}}, SHIFT(205),
  [551] = {.entry = {.count = 1, .reusable = false}}, SHIFT(345),
  [553] = {.entry = {.count = 1, .reusable = true}}, SHIFT(202),
  [555] = {.entry = {.count = 1, .reusable = true}}, SHIFT(362),
  [557] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1107),
  [559] = {.entry = {.count = 1, .reusable = false}}, SHIFT(362),
  [561] = {.entry = {.count = 1, .reusable = false}}, SHIFT(841),
  [563] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__expression, 1, 0, 0), SHIFT(1403),
  [566] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym__simple_type, 1, -1, 1), REDUCE(sym__expression, 1, 0, 0), SHIFT(714),
  [570] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1392),
  [572] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1316),
  [574] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym__simple_type, 1, -1, 1), REDUCE(sym__expression, 1, 0, 0), SHIFT(60),
  [578] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__expression, 1, 0, 0),
  [580] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__expression, 1, 0, 0), SHIFT(717),
  [583] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__expression, 1, 0, 0),
  [585] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1393),
  [587] = {.entry = {.count = 1, .reusable = false}}, SHIFT(713),
  [589] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1359),
  [591] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__expression, 1, 0, 0), SHIFT(1403),
  [594] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_type, 1, -1, 1), REDUCE(sym__expression, 1, 0, 0),
  [597] = {.entry = {.count = 3, .reusable = false}}, REDUCE(sym__simple_type, 1, -1, 1), REDUCE(sym__expression, 1, 0, 0), SHIFT(642),
  [601] = {.entry = {.count = 1, .reusable = false}}, SHIFT(32),
  [603] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11),
  [605] = {.entry = {.count = 1, .reusable = false}}, SHIFT(19),
  [607] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_expression_statement, 1, 0, 0),
  [609] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_expression_statement, 1, 0, 0),
  [611] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1285),
  [613] = {.entry = {.count = 1, .reusable = false}}, SHIFT(54),
  [615] = {.entry = {.count = 1, .reusable = false}}, SHIFT(169),
  [617] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_expression_list, 1, 0, 0),
  [619] = {.entry = {.count = 1, .reusable = false}}, SHIFT(62),
  [621] = {.entry = {.count = 1, .reusable = false}}, SHIFT(138),
  [623] = {.entry = {.count = 1, .reusable = false}}, SHIFT(139),
  [625] = {.entry = {.count = 1, .reusable = false}}, SHIFT(140),
  [627] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1015),
  [629] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1016),
  [631] = {.entry = {.count = 1, .reusable = false}}, SHIFT(141),
  [633] = {.entry = {.count = 1, .reusable = false}}, SHIFT(144),
  [635] = {.entry = {.count = 1, .reusable = false}}, SHIFT(145),
  [637] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_binary_expression, 3, 0, 32),
  [639] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_binary_expression, 3, 0, 32),
  [641] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_unary_expression, 2, 0, 6),
  [643] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_unary_expression, 2, 0, 6),
  [645] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0),
  [647] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_block, 3, 0, 0),
  [649] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_block, 3, 0, 0),
  [651] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_block, 2, 0, 0),
  [653] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_block, 2, 0, 0),
  [655] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_interpreted_string_literal, 3, 0, 0),
  [657] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_interpreted_string_literal, 3, 0, 0),
  [659] = {.entry = {.count = 1, .reusable = false}}, SHIFT(640),
  [661] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_interpreted_string_literal, 2, 0, 0),
  [663] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_interpreted_string_literal, 2, 0, 0),
  [665] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_composite_literal, 2, 0, 12),
  [667] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_composite_literal, 2, 0, 12),
  [669] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_composite_literal, 2, 0, 13),
  [671] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_composite_literal, 2, 0, 13),
  [673] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1251),
  [675] = {.entry = {.count = 1, .reusable = true}}, SHIFT(80),
  [677] = {.entry = {.count = 1, .reusable = true}}, SHIFT(169),
  [679] = {.entry = {.count = 1, .reusable = true}}, SHIFT(78),
  [681] = {.entry = {.count = 1, .reusable = false}}, SHIFT(197),
  [683] = {.entry = {.count = 1, .reusable = false}}, SHIFT(198),
  [685] = {.entry = {.count = 1, .reusable = true}}, SHIFT(235),
  [687] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_expression_list, 1, 0, 0),
  [689] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1253),
  [691] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1254),
  [693] = {.entry = {.count = 1, .reusable = true}}, SHIFT(199),
  [695] = {.entry = {.count = 1, .reusable = false}}, SHIFT(199),
  [697] = {.entry = {.count = 1, .reusable = true}}, SHIFT(200),
  [699] = {.entry = {.count = 1, .reusable = true}}, SHIFT(201),
  [701] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_special_argument_list, 3, 0, 0),
  [703] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_special_argument_list, 3, 0, 0),
  [705] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_func_literal, 4, 0, 46),
  [707] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_func_literal, 4, 0, 46),
  [709] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_literal_value, 3, 0, 0),
  [711] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_literal_value, 3, 0, 0),
  [713] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_conversion_expression, 4, -1, 61),
  [715] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_conversion_expression, 4, -1, 61),
  [717] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_instantiation_expression, 4, -1, 19),
  [719] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_instantiation_expression, 4, -1, 19),
  [721] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_argument_list, 3, 0, 0),
  [723] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_argument_list, 3, 0, 0),
  [725] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_slice_expression, 4, 0, 62),
  [727] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_slice_expression, 4, 0, 62),
  [729] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_index_expression, 4, 0, 63),
  [731] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_index_expression, 4, 0, 63),
  [733] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_call_expression, 2, 0, 10),
  [735] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_call_expression, 2, 0, 10),
  [737] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_special_argument_list, 2, 0, 0),
  [739] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_special_argument_list, 2, 0, 0),
  [741] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_func_literal, 3, 0, 22),
  [743] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_func_literal, 3, 0, 22),
  [745] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_selector_expression, 3, 0, 34),
  [747] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_selector_expression, 3, 0, 34),
  [749] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_argument_list, 2, 0, 0),
  [751] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_argument_list, 2, 0, 0),
  [753] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_special_argument_list, 4, 0, 0),
  [755] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_special_argument_list, 4, 0, 0),
  [757] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_literal_value, 4, 0, 0),
  [759] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_literal_value, 4, 0, 0),
  [761] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_conversion_expression, 5, -1, 61),
  [763] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_conversion_expression, 5, -1, 61),
  [765] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_instantiation_expression, 5, -1, 19),
  [767] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_instantiation_expression, 5, -1, 19),
  [769] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_assertion_expression, 5, 0, 89),
  [771] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_assertion_expression, 5, 0, 89),
  [773] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_argument_list, 4, 0, 0),
  [775] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_argument_list, 4, 0, 0),
  [777] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_slice_expression, 5, 0, 90),
  [779] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_slice_expression, 5, 0, 90),
  [781] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_slice_expression, 5, 0, 91),
  [783] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_slice_expression, 5, 0, 91),
  [785] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parenthesized_expression, 3, 0, 0),
  [787] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_parenthesized_expression, 3, 0, 0),
  [789] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_special_argument_list, 5, 0, 0),
  [791] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_special_argument_list, 5, 0, 0),
  [793] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_literal_value, 5, 0, 0),
  [795] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_literal_value, 5, 0, 0),
  [797] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_instantiation_expression, 6, -1, 19),
  [799] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_instantiation_expression, 6, -1, 19),
  [801] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_argument_list, 5, 0, 0),
  [803] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_argument_list, 5, 0, 0),
  [805] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_slice_expression, 6, 0, 101),
  [807] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_slice_expression, 6, 0, 101),
  [809] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_slice_expression, 7, 0, 104),
  [811] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_slice_expression, 7, 0, 104),
  [813] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_slice_expression, 8, 0, 107),
  [815] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_slice_expression, 8, 0, 107),
  [817] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_call_expression, 3, 0, 36),
  [819] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_call_expression, 3, 0, 36),
  [821] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_literal_value, 2, 0, 0),
  [823] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_literal_value, 2, 0, 0),
  [825] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1291),
  [827] = {.entry = {.count = 1, .reusable = true}}, SHIFT(986),
  [829] = {.entry = {.count = 1, .reusable = true}}, SHIFT(143),
  [831] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__simple_type, 1, -1, 1), REDUCE(sym__expression, 1, 0, 0),
  [834] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym__simple_type, 1, -1, 1), REDUCE(sym__expression, 1, 0, 0), SHIFT(642),
  [838] = {.entry = {.count = 1, .reusable = true}}, SHIFT(671),
  [840] = {.entry = {.count = 1, .reusable = true}}, SHIFT(29),
  [842] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1309),
  [844] = {.entry = {.count = 1, .reusable = true}}, SHIFT(69),
  [846] = {.entry = {.count = 1, .reusable = true}}, SHIFT(79),
  [848] = {.entry = {.count = 1, .reusable = false}}, SHIFT(204),
  [850] = {.entry = {.count = 1, .reusable = false}}, SHIFT(212),
  [852] = {.entry = {.count = 1, .reusable = true}}, SHIFT(217),
  [854] = {.entry = {.count = 1, .reusable = false}}, SHIFT(217),
  [856] = {.entry = {.count = 1, .reusable = true}}, SHIFT(222),
  [858] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_expression_list_repeat1, 2, 0, 0),
  [860] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_expression_list_repeat1, 2, 0, 0),
  [862] = {.entry = {.count = 1, .reusable = true}}, SHIFT(227),
  [864] = {.entry = {.count = 1, .reusable = true}}, SHIFT(677),
  [866] = {.entry = {.count = 1, .reusable = false}}, SHIFT(792),
  [868] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_type, 2, 0, 5),
  [870] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_type, 2, 0, 5),
  [872] = {.entry = {.count = 1, .reusable = false}}, SHIFT(478),
  [874] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1244),
  [876] = {.entry = {.count = 1, .reusable = false}}, SHIFT(88),
  [878] = {.entry = {.count = 1, .reusable = false}}, SHIFT(738),
  [880] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1243),
  [882] = {.entry = {.count = 1, .reusable = false}}, SHIFT(712),
  [884] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1342),
  [886] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1317),
  [888] = {.entry = {.count = 1, .reusable = false}}, SHIFT(775),
  [890] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1321),
  [892] = {.entry = {.count = 1, .reusable = false}}, SHIFT(793),
  [894] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_field_declaration, 1, 0, 25),
  [896] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_field_declaration, 1, 0, 25),
  [898] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1380),
  [900] = {.entry = {.count = 1, .reusable = false}}, SHIFT(716),
  [902] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1385),
  [904] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1247),
  [906] = {.entry = {.count = 1, .reusable = false}}, SHIFT(56),
  [908] = {.entry = {.count = 1, .reusable = false}}, SHIFT(727),
  [910] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1395),
  [912] = {.entry = {.count = 1, .reusable = false}}, SHIFT(722),
  [914] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1383),
  [916] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1079),
  [918] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1051),
  [920] = {.entry = {.count = 1, .reusable = false}}, SHIFT(125),
  [922] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1248),
  [924] = {.entry = {.count = 1, .reusable = true}}, SHIFT(55),
  [926] = {.entry = {.count = 1, .reusable = true}}, SHIFT(76),
  [928] = {.entry = {.count = 1, .reusable = true}}, SHIFT(650),
  [930] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_const_spec, 1, 0, 4),
  [932] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_const_spec, 1, 0, 4),
  [934] = {.entry = {.count = 1, .reusable = false}}, SHIFT(714),
  [936] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1370),
  [938] = {.entry = {.count = 1, .reusable = false}}, SHIFT(89),
  [940] = {.entry = {.count = 1, .reusable = false}}, SHIFT(82),
  [942] = {.entry = {.count = 1, .reusable = false}}, SHIFT(717),
  [944] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1359),
  [946] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_const_spec, 2, 0, 17),
  [948] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_const_spec, 2, 0, 17),
  [950] = {.entry = {.count = 1, .reusable = false}}, SHIFT(119),
  [952] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1267),
  [954] = {.entry = {.count = 1, .reusable = false}}, SHIFT(59),
  [956] = {.entry = {.count = 1, .reusable = false}}, SHIFT(142),
  [958] = {.entry = {.count = 1, .reusable = false}}, SHIFT(77),
  [960] = {.entry = {.count = 1, .reusable = false}}, SHIFT(190),
  [962] = {.entry = {.count = 1, .reusable = false}}, SHIFT(192),
  [964] = {.entry = {.count = 1, .reusable = false}}, SHIFT(193),
  [966] = {.entry = {.count = 1, .reusable = false}}, SHIFT(194),
  [968] = {.entry = {.count = 1, .reusable = false}}, SHIFT(195),
  [970] = {.entry = {.count = 1, .reusable = false}}, SHIFT(30),
  [972] = {.entry = {.count = 1, .reusable = true}}, SHIFT(488),
  [974] = {.entry = {.count = 1, .reusable = true}}, SHIFT(82),
  [976] = {.entry = {.count = 1, .reusable = true}}, SHIFT(717),
  [978] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1248),
  [980] = {.entry = {.count = 1, .reusable = true}}, SHIFT(183),
  [982] = {.entry = {.count = 1, .reusable = false}}, SHIFT(183),
  [984] = {.entry = {.count = 1, .reusable = false}}, SHIFT(184),
  [986] = {.entry = {.count = 1, .reusable = true}}, SHIFT(184),
  [988] = {.entry = {.count = 1, .reusable = true}}, SHIFT(185),
  [990] = {.entry = {.count = 1, .reusable = false}}, SHIFT(185),
  [992] = {.entry = {.count = 1, .reusable = true}}, SHIFT(186),
  [994] = {.entry = {.count = 1, .reusable = false}}, SHIFT(832),
  [996] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1307),
  [998] = {.entry = {.count = 1, .reusable = true}}, SHIFT(100),
  [1000] = {.entry = {.count = 1, .reusable = true}}, SHIFT(694),
  [1002] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1343),
  [1004] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_go_statement, 2, 0, 0),
  [1006] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_go_statement, 2, 0, 0),
  [1008] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_send_statement, 3, 0, 35),
  [1010] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_send_statement, 3, 0, 35),
  [1012] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13),
  [1014] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1265),
  [1016] = {.entry = {.count = 1, .reusable = true}}, SHIFT(72),
  [1018] = {.entry = {.count = 1, .reusable = true}}, SHIFT(173),
  [1020] = {.entry = {.count = 1, .reusable = true}}, SHIFT(51),
  [1022] = {.entry = {.count = 1, .reusable = true}}, SHIFT(178),
  [1024] = {.entry = {.count = 1, .reusable = false}}, SHIFT(132),
  [1026] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_receive_statement, 1, 0, 60),
  [1028] = {.entry = {.count = 1, .reusable = true}}, SHIFT(132),
  [1030] = {.entry = {.count = 1, .reusable = false}}, SHIFT(178),
  [1032] = {.entry = {.count = 1, .reusable = true}}, SHIFT(133),
  [1034] = {.entry = {.count = 1, .reusable = false}}, SHIFT(133),
  [1036] = {.entry = {.count = 1, .reusable = true}}, SHIFT(134),
  [1038] = {.entry = {.count = 1, .reusable = true}}, SHIFT(131),
  [1040] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1403),
  [1042] = {.entry = {.count = 1, .reusable = true}}, SHIFT(714),
  [1044] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__simple_type, 1, -1, 1),
  [1046] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__simple_type, 1, -1, 1), SHIFT(1392),
  [1049] = {.entry = {.count = 1, .reusable = true}}, SHIFT(60),
  [1051] = {.entry = {.count = 1, .reusable = true}}, SHIFT(756),
  [1053] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_defer_statement, 2, 0, 0),
  [1055] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_defer_statement, 2, 0, 0),
  [1057] = {.entry = {.count = 1, .reusable = true}}, SHIFT(33),
  [1059] = {.entry = {.count = 1, .reusable = false}}, SHIFT(659),
  [1061] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_method_declaration, 4, 0, 45),
  [1063] = {.entry = {.count = 1, .reusable = false}}, SHIFT(891),
  [1065] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_method_declaration, 4, 0, 45),
  [1067] = {.entry = {.count = 1, .reusable = false}}, SHIFT(467),
  [1069] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1302),
  [1071] = {.entry = {.count = 1, .reusable = false}}, SHIFT(101),
  [1073] = {.entry = {.count = 1, .reusable = false}}, SHIFT(747),
  [1075] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1271),
  [1077] = {.entry = {.count = 1, .reusable = false}}, SHIFT(721),
  [1079] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16),
  [1081] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1356),
  [1083] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1399),
  [1085] = {.entry = {.count = 1, .reusable = false}}, SHIFT(742),
  [1087] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1381),
  [1089] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_declaration, 3, 0, 20),
  [1091] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_declaration, 3, 0, 20),
  [1093] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_declaration, 4, 0, 42),
  [1095] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_declaration, 4, 0, 42),
  [1097] = {.entry = {.count = 1, .reusable = false}}, SHIFT(450),
  [1099] = {.entry = {.count = 1, .reusable = true}}, SHIFT(789),
  [1101] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1336),
  [1103] = {.entry = {.count = 1, .reusable = true}}, SHIFT(729),
  [1105] = {.entry = {.count = 1, .reusable = true}}, SHIFT(777),
  [1107] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1333),
  [1109] = {.entry = {.count = 1, .reusable = true}}, SHIFT(187),
  [1111] = {.entry = {.count = 1, .reusable = true}}, SHIFT(785),
  [1113] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1340),
  [1115] = {.entry = {.count = 1, .reusable = false}}, SHIFT(887),
  [1117] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1262),
  [1119] = {.entry = {.count = 1, .reusable = false}}, SHIFT(113),
  [1121] = {.entry = {.count = 1, .reusable = false}}, SHIFT(753),
  [1123] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1401),
  [1125] = {.entry = {.count = 1, .reusable = false}}, SHIFT(751),
  [1127] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1355),
  [1129] = {.entry = {.count = 1, .reusable = false}}, SHIFT(15),
  [1131] = {.entry = {.count = 1, .reusable = true}}, SHIFT(779),
  [1133] = {.entry = {.count = 1, .reusable = true}}, SHIFT(346),
  [1135] = {.entry = {.count = 1, .reusable = true}}, SHIFT(70),
  [1137] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1282),
  [1139] = {.entry = {.count = 1, .reusable = true}}, SHIFT(175),
  [1141] = {.entry = {.count = 1, .reusable = false}}, SHIFT(177),
  [1143] = {.entry = {.count = 1, .reusable = true}}, SHIFT(177),
  [1145] = {.entry = {.count = 1, .reusable = false}}, SHIFT(175),
  [1147] = {.entry = {.count = 1, .reusable = true}}, SHIFT(179),
  [1149] = {.entry = {.count = 1, .reusable = false}}, SHIFT(179),
  [1151] = {.entry = {.count = 1, .reusable = true}}, SHIFT(180),
  [1153] = {.entry = {.count = 1, .reusable = true}}, SHIFT(181),
  [1155] = {.entry = {.count = 1, .reusable = true}}, SHIFT(413),
  [1157] = {.entry = {.count = 1, .reusable = true}}, SHIFT(57),
  [1159] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1296),
  [1161] = {.entry = {.count = 1, .reusable = true}}, SHIFT(151),
  [1163] = {.entry = {.count = 1, .reusable = true}}, SHIFT(929),
  [1165] = {.entry = {.count = 1, .reusable = false}}, SHIFT(152),
  [1167] = {.entry = {.count = 1, .reusable = true}}, SHIFT(152),
  [1169] = {.entry = {.count = 1, .reusable = false}}, SHIFT(151),
  [1171] = {.entry = {.count = 1, .reusable = true}}, SHIFT(153),
  [1173] = {.entry = {.count = 1, .reusable = false}}, SHIFT(153),
  [1175] = {.entry = {.count = 1, .reusable = true}}, SHIFT(154),
  [1177] = {.entry = {.count = 1, .reusable = true}}, SHIFT(155),
  [1179] = {.entry = {.count = 1, .reusable = true}}, SHIFT(684),
  [1181] = {.entry = {.count = 1, .reusable = true}}, SHIFT(572),
  [1183] = {.entry = {.count = 1, .reusable = true}}, SHIFT(73),
  [1185] = {.entry = {.count = 1, .reusable = true}}, SHIFT(778),
  [1187] = {.entry = {.count = 1, .reusable = true}}, SHIFT(784),
  [1189] = {.entry = {.count = 1, .reusable = true}}, SHIFT(786),
  [1191] = {.entry = {.count = 1, .reusable = true}}, SHIFT(322),
  [1193] = {.entry = {.count = 1, .reusable = true}}, SHIFT(65),
  [1195] = {.entry = {.count = 1, .reusable = true}}, SHIFT(787),
  [1197] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_method_elem, 2, 0, 55),
  [1199] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_method_elem, 2, 0, 55),
  [1201] = {.entry = {.count = 1, .reusable = true}}, SHIFT(473),
  [1203] = {.entry = {.count = 1, .reusable = true}}, SHIFT(61),
  [1205] = {.entry = {.count = 1, .reusable = true}}, SHIFT(783),
  [1207] = {.entry = {.count = 1, .reusable = true}}, SHIFT(262),
  [1209] = {.entry = {.count = 1, .reusable = true}}, SHIFT(68),
  [1211] = {.entry = {.count = 1, .reusable = false}}, SHIFT(839),
  [1213] = {.entry = {.count = 1, .reusable = true}}, SHIFT(716),
  [1215] = {.entry = {.count = 1, .reusable = true}}, SHIFT(125),
  [1217] = {.entry = {.count = 1, .reusable = true}}, SHIFT(727),
  [1219] = {.entry = {.count = 1, .reusable = true}}, SHIFT(712),
  [1221] = {.entry = {.count = 1, .reusable = true}}, SHIFT(819),
  [1223] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1383),
  [1225] = {.entry = {.count = 1, .reusable = true}}, SHIFT(944),
  [1227] = {.entry = {.count = 1, .reusable = true}}, SHIFT(93),
  [1229] = {.entry = {.count = 1, .reusable = true}}, SHIFT(126),
  [1231] = {.entry = {.count = 1, .reusable = true}}, SHIFT(823),
  [1233] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_argument_list_repeat1, 2, 0, 0),
  [1235] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1270),
  [1237] = {.entry = {.count = 1, .reusable = true}}, SHIFT(860),
  [1239] = {.entry = {.count = 1, .reusable = true}}, SHIFT(937),
  [1241] = {.entry = {.count = 1, .reusable = true}}, SHIFT(878),
  [1243] = {.entry = {.count = 1, .reusable = true}}, SHIFT(806),
  [1245] = {.entry = {.count = 1, .reusable = true}}, SHIFT(999),
  [1247] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_literal_element, 1, 0, 0),
  [1249] = {.entry = {.count = 1, .reusable = true}}, SHIFT(844),
  [1251] = {.entry = {.count = 1, .reusable = true}}, SHIFT(170),
  [1253] = {.entry = {.count = 1, .reusable = false}}, SHIFT(945),
  [1255] = {.entry = {.count = 1, .reusable = true}}, SHIFT(574),
  [1257] = {.entry = {.count = 1, .reusable = true}}, SHIFT(120),
  [1259] = {.entry = {.count = 1, .reusable = true}}, SHIFT(946),
  [1261] = {.entry = {.count = 1, .reusable = true}}, SHIFT(581),
  [1263] = {.entry = {.count = 1, .reusable = true}}, SHIFT(233),
  [1265] = {.entry = {.count = 1, .reusable = true}}, SHIFT(484),
  [1267] = {.entry = {.count = 1, .reusable = true}}, SHIFT(218),
  [1269] = {.entry = {.count = 1, .reusable = true}}, SHIFT(822),
  [1271] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12),
  [1273] = {.entry = {.count = 1, .reusable = true}}, SHIFT(320),
  [1275] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1324),
  [1277] = {.entry = {.count = 1, .reusable = true}}, SHIFT(586),
  [1279] = {.entry = {.count = 1, .reusable = true}}, SHIFT(234),
  [1281] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17),
  [1283] = {.entry = {.count = 1, .reusable = true}}, SHIFT(381),
  [1285] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1347),
  [1287] = {.entry = {.count = 1, .reusable = true}}, SHIFT(496),
  [1289] = {.entry = {.count = 1, .reusable = true}}, SHIFT(219),
  [1291] = {.entry = {.count = 1, .reusable = true}}, SHIFT(411),
  [1293] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1348),
  [1295] = {.entry = {.count = 1, .reusable = true}}, SHIFT(358),
  [1297] = {.entry = {.count = 1, .reusable = true}}, SHIFT(108),
  [1299] = {.entry = {.count = 1, .reusable = true}}, SHIFT(299),
  [1301] = {.entry = {.count = 1, .reusable = true}}, SHIFT(95),
  [1303] = {.entry = {.count = 1, .reusable = true}}, SHIFT(939),
  [1305] = {.entry = {.count = 1, .reusable = true}}, SHIFT(333),
  [1307] = {.entry = {.count = 1, .reusable = true}}, SHIFT(224),
  [1309] = {.entry = {.count = 1, .reusable = false}}, SHIFT(976),
  [1311] = {.entry = {.count = 1, .reusable = true}}, SHIFT(859),
  [1313] = {.entry = {.count = 1, .reusable = true}}, SHIFT(284),
  [1315] = {.entry = {.count = 1, .reusable = true}}, SHIFT(171),
  [1317] = {.entry = {.count = 1, .reusable = true}}, SHIFT(331),
  [1319] = {.entry = {.count = 1, .reusable = true}}, SHIFT(223),
  [1321] = {.entry = {.count = 1, .reusable = true}}, SHIFT(353),
  [1323] = {.entry = {.count = 1, .reusable = true}}, SHIFT(229),
  [1325] = {.entry = {.count = 1, .reusable = true}}, SHIFT(812),
  [1327] = {.entry = {.count = 1, .reusable = true}}, SHIFT(415),
  [1329] = {.entry = {.count = 1, .reusable = true}}, SHIFT(111),
  [1331] = {.entry = {.count = 1, .reusable = true}}, SHIFT(264),
  [1333] = {.entry = {.count = 1, .reusable = true}}, SHIFT(106),
  [1335] = {.entry = {.count = 1, .reusable = true}}, SHIFT(749),
  [1337] = {.entry = {.count = 1, .reusable = true}}, SHIFT(67),
  [1339] = {.entry = {.count = 1, .reusable = true}}, SHIFT(875),
  [1341] = {.entry = {.count = 1, .reusable = true}}, SHIFT(428),
  [1343] = {.entry = {.count = 1, .reusable = true}}, SHIFT(214),
  [1345] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14),
  [1347] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18),
  [1349] = {.entry = {.count = 1, .reusable = true}}, SHIFT(471),
  [1351] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1387),
  [1353] = {.entry = {.count = 1, .reusable = true}}, SHIFT(422),
  [1355] = {.entry = {.count = 1, .reusable = true}}, SHIFT(213),
  [1357] = {.entry = {.count = 1, .reusable = true}}, SHIFT(475),
  [1359] = {.entry = {.count = 1, .reusable = true}}, SHIFT(83),
  [1361] = {.entry = {.count = 1, .reusable = true}}, SHIFT(570),
  [1363] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1398),
  [1365] = {.entry = {.count = 1, .reusable = true}}, SHIFT(260),
  [1367] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1328),
  [1369] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1385),
  [1371] = {.entry = {.count = 1, .reusable = true}}, SHIFT(277),
  [1373] = {.entry = {.count = 1, .reusable = true}}, SHIFT(168),
  [1375] = {.entry = {.count = 1, .reusable = true}}, SHIFT(347),
  [1377] = {.entry = {.count = 1, .reusable = true}}, SHIFT(228),
  [1379] = {.entry = {.count = 1, .reusable = true}}, SHIFT(702),
  [1381] = {.entry = {.count = 1, .reusable = true}}, SHIFT(267),
  [1383] = {.entry = {.count = 1, .reusable = true}}, SHIFT(26),
  [1385] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1391),
  [1387] = {.entry = {.count = 1, .reusable = true}}, SHIFT(274),
  [1389] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_range_clause, 4, 0, 84),
  [1391] = {.entry = {.count = 1, .reusable = true}}, SHIFT(279),
  [1393] = {.entry = {.count = 1, .reusable = true}}, SHIFT(400),
  [1395] = {.entry = {.count = 1, .reusable = true}}, SHIFT(282),
  [1397] = {.entry = {.count = 1, .reusable = true}}, SHIFT(755),
  [1399] = {.entry = {.count = 1, .reusable = true}}, SHIFT(403),
  [1401] = {.entry = {.count = 1, .reusable = true}}, SHIFT(419),
  [1403] = {.entry = {.count = 1, .reusable = true}}, SHIFT(426),
  [1405] = {.entry = {.count = 1, .reusable = true}}, SHIFT(429),
  [1407] = {.entry = {.count = 1, .reusable = true}}, SHIFT(430),
  [1409] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1390),
  [1411] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1368),
  [1413] = {.entry = {.count = 1, .reusable = true}}, SHIFT(501),
  [1415] = {.entry = {.count = 1, .reusable = true}}, SHIFT(731),
  [1417] = {.entry = {.count = 1, .reusable = true}}, SHIFT(503),
  [1419] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_receive_statement, 3, 0, 33),
  [1421] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_range_clause, 2, 0, 29),
  [1423] = {.entry = {.count = 1, .reusable = true}}, SHIFT(480),
  [1425] = {.entry = {.count = 1, .reusable = true}}, SHIFT(490),
  [1427] = {.entry = {.count = 1, .reusable = true}}, SHIFT(497),
  [1429] = {.entry = {.count = 1, .reusable = true}}, SHIFT(498),
  [1431] = {.entry = {.count = 1, .reusable = true}}, SHIFT(286),
  [1433] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1397),
  [1435] = {.entry = {.count = 1, .reusable = true}}, SHIFT(308),
  [1437] = {.entry = {.count = 1, .reusable = true}}, SHIFT(739),
  [1439] = {.entry = {.count = 1, .reusable = true}}, SHIFT(311),
  [1441] = {.entry = {.count = 1, .reusable = true}}, SHIFT(328),
  [1443] = {.entry = {.count = 1, .reusable = true}}, SHIFT(314),
  [1445] = {.entry = {.count = 1, .reusable = true}}, SHIFT(301),
  [1447] = {.entry = {.count = 1, .reusable = true}}, SHIFT(302),
  [1449] = {.entry = {.count = 1, .reusable = true}}, SHIFT(368),
  [1451] = {.entry = {.count = 1, .reusable = true}}, SHIFT(372),
  [1453] = {.entry = {.count = 1, .reusable = true}}, SHIFT(363),
  [1455] = {.entry = {.count = 1, .reusable = true}}, SHIFT(351),
  [1457] = {.entry = {.count = 1, .reusable = true}}, SHIFT(354),
  [1459] = {.entry = {.count = 1, .reusable = true}}, SHIFT(355),
  [1461] = {.entry = {.count = 1, .reusable = true}}, SHIFT(545),
  [1463] = {.entry = {.count = 1, .reusable = true}}, SHIFT(709),
  [1465] = {.entry = {.count = 1, .reusable = true}}, SHIFT(553),
  [1467] = {.entry = {.count = 1, .reusable = true}}, SHIFT(578),
  [1469] = {.entry = {.count = 1, .reusable = true}}, SHIFT(584),
  [1471] = {.entry = {.count = 1, .reusable = true}}, SHIFT(587),
  [1473] = {.entry = {.count = 1, .reusable = true}}, SHIFT(588),
  [1475] = {.entry = {.count = 1, .reusable = true}}, SHIFT(743),
  [1477] = {.entry = {.count = 1, .reusable = true}}, SHIFT(23),
  [1479] = {.entry = {.count = 1, .reusable = true}}, SHIFT(285),
  [1481] = {.entry = {.count = 1, .reusable = true}}, SHIFT(88),
  [1483] = {.entry = {.count = 1, .reusable = true}}, SHIFT(738),
  [1485] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1321),
  [1487] = {.entry = {.count = 1, .reusable = true}}, SHIFT(726),
  [1489] = {.entry = {.count = 1, .reusable = true}}, SHIFT(101),
  [1491] = {.entry = {.count = 1, .reusable = true}}, SHIFT(747),
  [1493] = {.entry = {.count = 1, .reusable = true}}, SHIFT(721),
  [1495] = {.entry = {.count = 1, .reusable = false}}, SHIFT(700),
  [1497] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1381),
  [1499] = {.entry = {.count = 1, .reusable = true}}, SHIFT(699),
  [1501] = {.entry = {.count = 1, .reusable = true}}, SHIFT(735),
  [1503] = {.entry = {.count = 1, .reusable = true}}, SHIFT(113),
  [1505] = {.entry = {.count = 1, .reusable = true}}, SHIFT(753),
  [1507] = {.entry = {.count = 1, .reusable = false}}, SHIFT(708),
  [1509] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1355),
  [1511] = {.entry = {.count = 1, .reusable = true}}, SHIFT(707),
  [1513] = {.entry = {.count = 1, .reusable = true}}, SHIFT(746),
  [1515] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1250),
  [1517] = {.entry = {.count = 1, .reusable = true}}, SHIFT(725),
  [1519] = {.entry = {.count = 1, .reusable = false}}, SHIFT(728),
  [1521] = {.entry = {.count = 1, .reusable = false}}, SHIFT(748),
  [1523] = {.entry = {.count = 1, .reusable = false}}, SHIFT(764),
  [1525] = {.entry = {.count = 1, .reusable = true}}, SHIFT(760),
  [1527] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_parameter_list, 3, 0, 0),
  [1529] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameter_list, 3, 0, 0),
  [1531] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_parameter_list, 2, 0, 0),
  [1533] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameter_list, 2, 0, 0),
  [1535] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_parameter_list, 5, 0, 0),
  [1537] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameter_list, 5, 0, 0),
  [1539] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_parameter_list, 4, 0, 0),
  [1541] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameter_list, 4, 0, 0),
  [1543] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_const_spec_repeat1, 2, 0, 0),
  [1545] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_const_spec_repeat1, 2, 0, 0),
  [1547] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_const_spec_repeat1, 2, 0, 0), SHIFT_REPEAT(1370),
  [1550] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_expression_list, 2, 0, 0),
  [1552] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_expression_list_repeat1, 2, 0, 0), SHIFT_REPEAT(169),
  [1555] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__simple_type, 1, -1, 1),
  [1557] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_type, 1, -1, 1), SHIFT(690),
  [1560] = {.entry = {.count = 1, .reusable = false}}, SHIFT(690),
  [1562] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_var_spec_repeat1, 2, 0, 40),
  [1564] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_var_spec_repeat1, 2, 0, 40),
  [1566] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_var_spec_repeat1, 2, 0, 40), SHIFT_REPEAT(1392),
  [1569] = {.entry = {.count = 1, .reusable = true}}, SHIFT(86),
  [1571] = {.entry = {.count = 1, .reusable = true}}, SHIFT(90),
  [1573] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__simple_type, 1, 0, 0),
  [1575] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__simple_type, 1, 0, 0),
  [1577] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_type, 1, 0, 0), SHIFT(690),
  [1580] = {.entry = {.count = 1, .reusable = true}}, SHIFT(75),
  [1582] = {.entry = {.count = 1, .reusable = true}}, SHIFT(64),
  [1584] = {.entry = {.count = 1, .reusable = true}}, SHIFT(123),
  [1586] = {.entry = {.count = 1, .reusable = true}}, SHIFT(94),
  [1588] = {.entry = {.count = 1, .reusable = true}}, SHIFT(127),
  [1590] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_field_declaration_repeat1, 2, 0, 40),
  [1592] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_field_declaration_repeat1, 2, 0, 40),
  [1594] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_field_declaration_repeat1, 2, 0, 40), SHIFT_REPEAT(1385),
  [1597] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_var_spec_repeat1, 2, 0, 38),
  [1599] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_var_spec_repeat1, 2, 0, 38),
  [1601] = {.entry = {.count = 1, .reusable = true}}, SHIFT(118),
  [1603] = {.entry = {.count = 1, .reusable = true}}, SHIFT(122),
  [1605] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_arguments, 3, 2, 0),
  [1607] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_arguments, 3, 2, 0),
  [1609] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_field_declaration_repeat1, 2, 0, 76),
  [1611] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_field_declaration_repeat1, 2, 0, 76),
  [1613] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_interface_type, 5, 0, 0),
  [1615] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_interface_type, 5, 0, 0),
  [1617] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_struct_type, 2, 0, 0),
  [1619] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_struct_type, 2, 0, 0),
  [1621] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_negated_type, 2, 0, 0),
  [1623] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_negated_type, 2, 0, 0),
  [1625] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_map_type, 5, 0, 80),
  [1627] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_map_type, 5, 0, 80),
  [1629] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_channel_type, 2, 0, 7),
  [1631] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_channel_type, 2, 0, 7),
  [1633] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_arguments, 4, 2, 0),
  [1635] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_arguments, 4, 2, 0),
  [1637] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_generic_type, 2, 1, 11),
  [1639] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_generic_type, 2, 1, 11),
  [1641] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_generic_type, 2, 1, 14),
  [1643] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_generic_type, 2, 1, 14),
  [1645] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_field_declaration_list, 5, 0, 0),
  [1647] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_field_declaration_list, 5, 0, 0),
  [1649] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parenthesized_type, 3, 0, 0),
  [1651] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_parenthesized_type, 3, 0, 0),
  [1653] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_slice_type, 3, 0, 23),
  [1655] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_slice_type, 3, 0, 23),
  [1657] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_field_declaration_list, 4, 0, 0),
  [1659] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_field_declaration_list, 4, 0, 0),
  [1661] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_interface_type, 6, 0, 0),
  [1663] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_interface_type, 6, 0, 0),
  [1665] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_field_declaration_list, 2, 0, 0),
  [1667] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_field_declaration_list, 2, 0, 0),
  [1669] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_pointer_type, 2, 0, 0),
  [1671] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_pointer_type, 2, 0, 0),
  [1673] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_arguments, 5, 2, 0),
  [1675] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_arguments, 5, 2, 0),
  [1677] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_interface_type, 3, 0, 0),
  [1679] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_interface_type, 3, 0, 0),
  [1681] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_channel_type, 3, 0, 27),
  [1683] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_channel_type, 3, 0, 27),
  [1685] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_qualified_type, 3, 0, 31),
  [1687] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_qualified_type, 3, 0, 31),
  [1689] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_interface_type, 4, 0, 0),
  [1691] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_interface_type, 4, 0, 0),
  [1693] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_array_type, 4, 0, 48),
  [1695] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_array_type, 4, 0, 48),
  [1697] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_field_declaration_list, 3, 0, 0),
  [1699] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_field_declaration_list, 3, 0, 0),
  [1701] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_type, 3, 0, 21),
  [1703] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_type, 3, 0, 21),
  [1705] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1403),
  [1707] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__simple_type, 1, -1, 1), SHIFT(642),
  [1710] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_parameter_list, 5, 0, 0),
  [1712] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_parameter_list, 5, 0, 0),
  [1714] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_parameter_list, 4, 0, 0),
  [1716] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_parameter_list, 4, 0, 0),
  [1718] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_parameter_list, 3, 0, 0),
  [1720] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_parameter_list, 3, 0, 0),
  [1722] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__simple_type, 1, 0, 0), SHIFT(642),
  [1725] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1231),
  [1727] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1287),
  [1729] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1227),
  [1731] = {.entry = {.count = 1, .reusable = true}}, SHIFT(864),
  [1733] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1129),
  [1735] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1078),
  [1737] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1151),
  [1739] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1149),
  [1741] = {.entry = {.count = 1, .reusable = true}}, SHIFT(872),
  [1743] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1091),
  [1745] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_field_declaration, 2, 0, 51),
  [1747] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_field_declaration, 2, 0, 51),
  [1749] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1077),
  [1751] = {.entry = {.count = 1, .reusable = true}}, SHIFT(642),
  [1753] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1124),
  [1755] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1203),
  [1757] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1137),
  [1759] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1126),
  [1761] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1064),
  [1763] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_field_declaration, 1, 0, 19),
  [1765] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_field_declaration, 1, 0, 19),
  [1767] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1082),
  [1769] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_field_declaration, 2, 0, 41),
  [1771] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_field_declaration, 2, 0, 41),
  [1773] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1115),
  [1775] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1191),
  [1777] = {.entry = {.count = 1, .reusable = true}}, SHIFT(385),
  [1779] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1046),
  [1781] = {.entry = {.count = 1, .reusable = true}}, SHIFT(818),
  [1783] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_expression_list, 2, 0, 0),
  [1785] = {.entry = {.count = 1, .reusable = true}}, SHIFT(851),
  [1787] = {.entry = {.count = 1, .reusable = true}}, SHIFT(936),
  [1789] = {.entry = {.count = 1, .reusable = true}}, SHIFT(877),
  [1791] = {.entry = {.count = 1, .reusable = true}}, SHIFT(942),
  [1793] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1365),
  [1795] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_type, 1, -1, 1), SHIFT(691),
  [1798] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_expression_list_repeat1, 2, 0, 0), SHIFT_REPEAT(142),
  [1801] = {.entry = {.count = 1, .reusable = true}}, SHIFT(989),
  [1803] = {.entry = {.count = 1, .reusable = true}}, SHIFT(820),
  [1805] = {.entry = {.count = 1, .reusable = false}}, SHIFT(691),
  [1807] = {.entry = {.count = 1, .reusable = true}}, SHIFT(815),
  [1809] = {.entry = {.count = 1, .reusable = true}}, SHIFT(857),
  [1811] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_type, 1, 0, 0), SHIFT(691),
  [1814] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_var_spec, 3, 0, 39),
  [1816] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_var_spec, 3, 0, 39),
  [1818] = {.entry = {.count = 1, .reusable = false}}, SHIFT(114),
  [1820] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1006),
  [1822] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_continue_statement, 1, 0, 0),
  [1824] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_continue_statement, 1, 0, 0),
  [1826] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9),
  [1828] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9),
  [1830] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__statement_list, 1, 0, 0),
  [1832] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__statement_list_repeat1, 2, 0, 0), SHIFT_REPEAT(20),
  [1835] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__statement_list_repeat1, 2, 0, 0), SHIFT_REPEAT(20),
  [1838] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__statement_list_repeat1, 2, 0, 0),
  [1840] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_var_spec, 2, 0, 18),
  [1842] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_var_spec, 2, 0, 18),
  [1844] = {.entry = {.count = 1, .reusable = false}}, SHIFT(124),
  [1846] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_if_statement, 3, 0, 28),
  [1848] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_if_statement, 3, 0, 28),
  [1850] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1133),
  [1852] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_field_declaration, 3, 0, 78),
  [1854] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_field_declaration, 3, 0, 78),
  [1856] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1057),
  [1858] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_if_statement, 5, 0, 81),
  [1860] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_if_statement, 5, 0, 81),
  [1862] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1062),
  [1864] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1055),
  [1866] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_field_declaration, 2, 0, 53),
  [1868] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_field_declaration, 2, 0, 53),
  [1870] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1059),
  [1872] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10),
  [1874] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10),
  [1876] = {.entry = {.count = 1, .reusable = false}}, SHIFT(112),
  [1878] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1005),
  [1880] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_break_statement, 1, 0, 0),
  [1882] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_break_statement, 1, 0, 0),
  [1884] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_statement, 3, 0, 30),
  [1886] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_for_statement, 3, 0, 30),
  [1888] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_declaration, 5, 0, 69),
  [1890] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_declaration, 5, 0, 69),
  [1892] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_method_declaration, 5, 0, 72),
  [1894] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_method_declaration, 5, 0, 72),
  [1896] = {.entry = {.count = 1, .reusable = true}}, SHIFT(997),
  [1898] = {.entry = {.count = 1, .reusable = true}}, SHIFT(49),
  [1900] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1367),
  [1902] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_expression_switch_statement, 3, 0, 0),
  [1904] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_expression_switch_statement, 3, 0, 0),
  [1906] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_type_elem_repeat1, 2, 0, 0),
  [1908] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_type_elem_repeat1, 2, 0, 0),
  [1910] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_type_elem_repeat1, 2, 0, 0), SHIFT_REPEAT(697),
  [1913] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_const_declaration, 4, 0, 0),
  [1915] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_const_declaration, 4, 0, 0),
  [1917] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_if_statement, 5, 0, 82),
  [1919] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_if_statement, 5, 0, 82),
  [1921] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_expression_switch_statement, 5, 0, 87),
  [1923] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_expression_switch_statement, 5, 0, 87),
  [1925] = {.entry = {.count = 1, .reusable = true}}, SHIFT(955),
  [1927] = {.entry = {.count = 1, .reusable = true}}, SHIFT(105),
  [1929] = {.entry = {.count = 1, .reusable = true}}, SHIFT(957),
  [1931] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_switch_statement, 5, 0, 59),
  [1933] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_switch_statement, 5, 0, 59),
  [1935] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_type_switch_statement_repeat1, 2, 0, 0),
  [1937] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_type_switch_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(701),
  [1940] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_type_switch_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1367),
  [1943] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_expression_switch_statement, 5, 0, 7),
  [1945] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_expression_switch_statement, 5, 0, 7),
  [1947] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_fallthrough_statement, 1, 0, 0),
  [1949] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_fallthrough_statement, 1, 0, 0),
  [1951] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_const_spec, 3, 0, 37),
  [1953] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_const_spec, 3, 0, 37),
  [1955] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_empty_statement, 1, 0, 0),
  [1957] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_empty_statement, 1, 0, 0),
  [1959] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_var_spec_list, 3, 0, 0),
  [1961] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_var_spec_list, 3, 0, 0),
  [1963] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_var_spec, 3, 0, 37),
  [1965] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_var_spec, 3, 0, 37),
  [1967] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_const_declaration, 3, 0, 0),
  [1969] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_const_declaration, 3, 0, 0),
  [1971] = {.entry = {.count = 1, .reusable = true}}, SHIFT(478),
  [1973] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_var_spec_list, 2, 0, 0),
  [1975] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_var_spec_list, 2, 0, 0),
  [1977] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_const_spec, 5, 0, 92),
  [1979] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_const_spec, 5, 0, 92),
  [1981] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_var_spec, 5, 0, 93),
  [1983] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_var_spec, 5, 0, 93),
  [1985] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_expression_switch_statement, 6, 0, 87),
  [1987] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_expression_switch_statement, 6, 0, 87),
  [1989] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_statement, 2, 0, 9),
  [1991] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_for_statement, 2, 0, 9),
  [1993] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_expression_switch_statement, 6, 0, 99),
  [1995] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_expression_switch_statement, 6, 0, 99),
  [1997] = {.entry = {.count = 1, .reusable = true}}, SHIFT(971),
  [1999] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_declaration, 4, 0, 43),
  [2001] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_declaration, 4, 0, 43),
  [2003] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_declaration, 4, 0, 0),
  [2005] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_declaration, 4, 0, 0),
  [2007] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_const_declaration, 2, 0, 0),
  [2009] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_const_declaration, 2, 0, 0),
  [2011] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_alias, 3, 0, 49),
  [2013] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_alias, 3, 0, 49),
  [2015] = {.entry = {.count = 1, .reusable = true}}, SHIFT(922),
  [2017] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_spec, 3, 0, 50),
  [2019] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_spec, 3, 0, 50),
  [2021] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_labeled_statement, 3, 0, 26),
  [2023] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_labeled_statement, 3, 0, 26),
  [2025] = {.entry = {.count = 1, .reusable = true}}, SHIFT(984),
  [2027] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_if_statement, 7, 0, 102),
  [2029] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_if_statement, 7, 0, 102),
  [2031] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_assignment_statement, 3, 0, 32),
  [2033] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_assignment_statement, 3, 0, 32),
  [2035] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_expression_switch_statement, 7, 0, 99),
  [2037] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_expression_switch_statement, 7, 0, 99),
  [2039] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_expression_list_repeat1, 2, 0, 0), SHIFT_REPEAT(173),
  [2042] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__statement_list_repeat1, 2, 0, 0),
  [2044] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_var_declaration, 2, 0, 0),
  [2046] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_var_declaration, 2, 0, 0),
  [2048] = {.entry = {.count = 1, .reusable = true}}, SHIFT(467),
  [2050] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_elem, 2, 0, 0),
  [2052] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_elem, 2, 0, 0),
  [2054] = {.entry = {.count = 1, .reusable = false}}, SHIFT(697),
  [2056] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__statement, 1, 0, 0),
  [2058] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__statement, 1, 0, 0),
  [2060] = {.entry = {.count = 1, .reusable = true}}, SHIFT(994),
  [2062] = {.entry = {.count = 1, .reusable = true}}, SHIFT(991),
  [2064] = {.entry = {.count = 1, .reusable = true}}, SHIFT(701),
  [2066] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_expression_switch_statement, 4, 0, 0),
  [2068] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_expression_switch_statement, 4, 0, 0),
  [2070] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_expression_switch_statement_repeat1, 2, 0, 0),
  [2072] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_expression_switch_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(105),
  [2075] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_expression_switch_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1367),
  [2078] = {.entry = {.count = 1, .reusable = true}}, SHIFT(995),
  [2080] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_declaration, 3, 0, 0),
  [2082] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_declaration, 3, 0, 0),
  [2084] = {.entry = {.count = 1, .reusable = true}}, SHIFT(927),
  [2086] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_spec, 2, 0, 24),
  [2088] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_spec, 2, 0, 24),
  [2090] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_switch_statement, 4, 0, 59),
  [2092] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_switch_statement, 4, 0, 59),
  [2094] = {.entry = {.count = 1, .reusable = true}}, SHIFT(930),
  [2096] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_select_statement, 3, 0, 0),
  [2098] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_select_statement, 3, 0, 0),
  [2100] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_expression_switch_statement, 4, 0, 7),
  [2102] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_expression_switch_statement, 4, 0, 7),
  [2104] = {.entry = {.count = 1, .reusable = true}}, SHIFT(932),
  [2106] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_select_statement, 4, 0, 0),
  [2108] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_select_statement, 4, 0, 0),
  [2110] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_select_statement_repeat1, 2, 0, 0),
  [2112] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_select_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(49),
  [2115] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_select_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1367),
  [2118] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__simple_statement, 1, 0, 0),
  [2120] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__simple_statement, 1, 0, 0),
  [2122] = {.entry = {.count = 1, .reusable = true}}, SHIFT(211),
  [2124] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_elem, 1, 0, 0),
  [2126] = {.entry = {.count = 1, .reusable = true}}, SHIFT(761),
  [2128] = {.entry = {.count = 1, .reusable = true}}, SHIFT(718),
  [2130] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_break_statement, 2, 0, 8),
  [2132] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_break_statement, 2, 0, 8),
  [2134] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_continue_statement, 2, 0, 8),
  [2136] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_continue_statement, 2, 0, 8),
  [2138] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_elem, 1, 0, 0),
  [2140] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_const_spec, 4, 0, 64),
  [2142] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_const_spec, 4, 0, 64),
  [2144] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_const_spec, 4, 0, 65),
  [2146] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_const_spec, 4, 0, 65),
  [2148] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_var_spec, 4, 0, 64),
  [2150] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_var_spec, 4, 0, 64),
  [2152] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_var_spec, 4, 0, 66),
  [2154] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_var_spec, 4, 0, 66),
  [2156] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_goto_statement, 2, 0, 8),
  [2158] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_goto_statement, 2, 0, 8),
  [2160] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_return_statement, 2, 0, 0),
  [2162] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_return_statement, 2, 0, 0),
  [2164] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_declaration, 2, 0, 0),
  [2166] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_declaration, 2, 0, 0),
  [2168] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_inc_statement, 2, 0, 0),
  [2170] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_inc_statement, 2, 0, 0),
  [2172] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_dec_statement, 2, 0, 0),
  [2174] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_dec_statement, 2, 0, 0),
  [2176] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_short_var_declaration, 3, 0, 33),
  [2178] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_short_var_declaration, 3, 0, 33),
  [2180] = {.entry = {.count = 1, .reusable = true}}, SHIFT(31),
  [2182] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_type_declaration_repeat1, 2, 0, 0), SHIFT_REPEAT(624),
  [2185] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_type_declaration_repeat1, 2, 0, 0),
  [2187] = {.entry = {.count = 1, .reusable = true}}, SHIFT(530),
  [2189] = {.entry = {.count = 1, .reusable = false}}, SHIFT(530),
  [2191] = {.entry = {.count = 1, .reusable = false}}, SHIFT(806),
  [2193] = {.entry = {.count = 1, .reusable = true}}, SHIFT(883),
  [2195] = {.entry = {.count = 1, .reusable = false}}, SHIFT(883),
  [2197] = {.entry = {.count = 1, .reusable = false}}, SHIFT(874),
  [2199] = {.entry = {.count = 1, .reusable = true}}, SHIFT(884),
  [2201] = {.entry = {.count = 1, .reusable = false}}, SHIFT(884),
  [2203] = {.entry = {.count = 1, .reusable = false}}, SHIFT(918),
  [2205] = {.entry = {.count = 1, .reusable = true}}, SHIFT(556),
  [2207] = {.entry = {.count = 1, .reusable = false}}, SHIFT(556),
  [2209] = {.entry = {.count = 1, .reusable = false}}, SHIFT(921),
  [2211] = {.entry = {.count = 1, .reusable = true}}, SHIFT(879),
  [2213] = {.entry = {.count = 1, .reusable = false}}, SHIFT(879),
  [2215] = {.entry = {.count = 1, .reusable = false}}, SHIFT(829),
  [2217] = {.entry = {.count = 1, .reusable = true}}, SHIFT(563),
  [2219] = {.entry = {.count = 1, .reusable = false}}, SHIFT(563),
  [2221] = {.entry = {.count = 1, .reusable = false}}, SHIFT(827),
  [2223] = {.entry = {.count = 1, .reusable = true}}, SHIFT(562),
  [2225] = {.entry = {.count = 1, .reusable = false}}, SHIFT(562),
  [2227] = {.entry = {.count = 1, .reusable = false}}, SHIFT(844),
  [2229] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_interface_type_repeat1, 2, 0, 0), SHIFT_REPEAT(620),
  [2232] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_interface_type_repeat1, 2, 0, 0), SHIFT_REPEAT(620),
  [2235] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_interface_type_repeat1, 2, 0, 0),
  [2237] = {.entry = {.count = 1, .reusable = true}}, SHIFT(863),
  [2239] = {.entry = {.count = 1, .reusable = false}}, SHIFT(863),
  [2241] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1124),
  [2243] = {.entry = {.count = 1, .reusable = true}}, SHIFT(886),
  [2245] = {.entry = {.count = 1, .reusable = false}}, SHIFT(886),
  [2247] = {.entry = {.count = 1, .reusable = false}}, SHIFT(936),
  [2249] = {.entry = {.count = 1, .reusable = true}}, SHIFT(32),
  [2251] = {.entry = {.count = 1, .reusable = true}}, SHIFT(849),
  [2253] = {.entry = {.count = 1, .reusable = false}}, SHIFT(849),
  [2255] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1137),
  [2257] = {.entry = {.count = 1, .reusable = true}}, SHIFT(624),
  [2259] = {.entry = {.count = 1, .reusable = true}}, SHIFT(987),
  [2261] = {.entry = {.count = 1, .reusable = true}}, SHIFT(531),
  [2263] = {.entry = {.count = 1, .reusable = false}}, SHIFT(531),
  [2265] = {.entry = {.count = 1, .reusable = false}}, SHIFT(937),
  [2267] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_field_declaration_list_repeat1, 2, 0, 0), SHIFT_REPEAT(902),
  [2270] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_field_declaration_list_repeat1, 2, 0, 0), SHIFT_REPEAT(902),
  [2273] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_field_declaration_list_repeat1, 2, 0, 0),
  [2275] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_import_spec_list_repeat1, 2, 0, 0), SHIFT_REPEAT(882),
  [2278] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_import_spec_list_repeat1, 2, 0, 0), SHIFT_REPEAT(882),
  [2281] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_import_spec_list_repeat1, 2, 0, 0),
  [2283] = {.entry = {.count = 1, .reusable = true}}, SHIFT(589),
  [2285] = {.entry = {.count = 1, .reusable = false}}, SHIFT(589),
  [2287] = {.entry = {.count = 1, .reusable = false}}, SHIFT(842),
  [2289] = {.entry = {.count = 1, .reusable = true}}, SHIFT(845),
  [2291] = {.entry = {.count = 1, .reusable = false}}, SHIFT(845),
  [2293] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1122),
  [2295] = {.entry = {.count = 1, .reusable = true}}, SHIFT(892),
  [2297] = {.entry = {.count = 1, .reusable = false}}, SHIFT(892),
  [2299] = {.entry = {.count = 1, .reusable = false}}, SHIFT(818),
  [2301] = {.entry = {.count = 1, .reusable = true}}, SHIFT(30),
  [2303] = {.entry = {.count = 1, .reusable = true}}, SHIFT(960),
  [2305] = {.entry = {.count = 1, .reusable = true}}, SHIFT(861),
  [2307] = {.entry = {.count = 1, .reusable = false}}, SHIFT(861),
  [2309] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1232),
  [2311] = {.entry = {.count = 1, .reusable = true}}, SHIFT(840),
  [2313] = {.entry = {.count = 1, .reusable = true}}, SHIFT(893),
  [2315] = {.entry = {.count = 1, .reusable = false}}, SHIFT(893),
  [2317] = {.entry = {.count = 1, .reusable = false}}, SHIFT(851),
  [2319] = {.entry = {.count = 1, .reusable = true}}, SHIFT(479),
  [2321] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1080),
  [2323] = {.entry = {.count = 1, .reusable = true}}, SHIFT(252),
  [2325] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1116),
  [2327] = {.entry = {.count = 1, .reusable = true}}, SHIFT(42),
  [2329] = {.entry = {.count = 1, .reusable = true}}, SHIFT(258),
  [2331] = {.entry = {.count = 1, .reusable = true}}, SHIFT(48),
  [2333] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_declaration, 6, 0, 95),
  [2335] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_declaration, 6, 0, 95),
  [2337] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_method_declaration, 6, 0, 96),
  [2339] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_method_declaration, 6, 0, 96),
  [2341] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_field_declaration, 4, 0, 97),
  [2343] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_field_declaration, 4, 0, 97),
  [2345] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_field_declaration, 3, 0, 77),
  [2347] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_field_declaration, 3, 0, 77),
  [2349] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_import_spec, 2, 0, 15),
  [2351] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_import_spec, 2, 0, 15),
  [2353] = {.entry = {.count = 1, .reusable = true}}, SHIFT(532),
  [2355] = {.entry = {.count = 1, .reusable = true}}, SHIFT(940),
  [2357] = {.entry = {.count = 1, .reusable = true}}, SHIFT(27),
  [2359] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_import_spec_list, 2, 0, 0),
  [2361] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_import_spec_list, 2, 0, 0),
  [2363] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_method_declaration, 5, 0, 73),
  [2365] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_method_declaration, 5, 0, 73),
  [2367] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_declaration, 4, 0, 44),
  [2369] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_declaration, 4, 0, 44),
  [2371] = {.entry = {.count = 1, .reusable = true}}, SHIFT(432),
  [2373] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1071),
  [2375] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_import_spec, 2, 0, 16),
  [2377] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_import_spec, 2, 0, 16),
  [2379] = {.entry = {.count = 1, .reusable = true}}, SHIFT(245),
  [2381] = {.entry = {.count = 1, .reusable = false}}, SHIFT(245),
  [2383] = {.entry = {.count = 1, .reusable = true}}, SHIFT(409),
  [2385] = {.entry = {.count = 1, .reusable = true}}, SHIFT(37),
  [2387] = {.entry = {.count = 1, .reusable = true}}, SHIFT(470),
  [2389] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_interface_type_repeat1, 2, 0, 0),
  [2391] = {.entry = {.count = 1, .reusable = true}}, SHIFT(947),
  [2393] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_import_declaration, 2, 0, 0),
  [2395] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_import_declaration, 2, 0, 0),
  [2397] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_field_declaration, 3, 0, 74),
  [2399] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_field_declaration, 3, 0, 74),
  [2401] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1102),
  [2403] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1098),
  [2405] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_field_declaration, 2, 0, 52),
  [2407] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_field_declaration, 2, 0, 52),
  [2409] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_interpreted_string_literal_repeat1, 2, 0, 0),
  [2411] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_interpreted_string_literal_repeat1, 2, 0, 0), SHIFT_REPEAT(1080),
  [2414] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_declaration, 5, 0, 70),
  [2416] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_declaration, 5, 0, 70),
  [2418] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_field_declaration, 2, 0, 54),
  [2420] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_field_declaration, 2, 0, 54),
  [2422] = {.entry = {.count = 1, .reusable = true}}, SHIFT(466),
  [2424] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1050),
  [2426] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_field_declaration_list_repeat1, 2, 0, 0),
  [2428] = {.entry = {.count = 1, .reusable = true}}, SHIFT(39),
  [2430] = {.entry = {.count = 1, .reusable = true}}, SHIFT(319),
  [2432] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1274),
  [2434] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_var_spec_list_repeat1, 2, 0, 0), SHIFT_REPEAT(532),
  [2437] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_var_spec_list_repeat1, 2, 0, 0),
  [2439] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_import_spec, 1, 0, 3),
  [2441] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_import_spec, 1, 0, 3),
  [2443] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_type_case_repeat1, 2, 0, 0), SHIFT_REPEAT(723),
  [2446] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_type_case_repeat1, 2, 0, 0),
  [2448] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_const_declaration_repeat1, 2, 0, 0), SHIFT_REPEAT(391),
  [2451] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_const_declaration_repeat1, 2, 0, 0),
  [2453] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_source_file, 2, 0, 0),
  [2455] = {.entry = {.count = 1, .reusable = true}}, SHIFT(307),
  [2457] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1097),
  [2459] = {.entry = {.count = 1, .reusable = true}}, SHIFT(324),
  [2461] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1121),
  [2463] = {.entry = {.count = 1, .reusable = true}}, SHIFT(43),
  [2465] = {.entry = {.count = 1, .reusable = true}}, SHIFT(380),
  [2467] = {.entry = {.count = 1, .reusable = true}}, SHIFT(391),
  [2469] = {.entry = {.count = 1, .reusable = true}}, SHIFT(925),
  [2471] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1075),
  [2473] = {.entry = {.count = 1, .reusable = true}}, SHIFT(943),
  [2475] = {.entry = {.count = 1, .reusable = true}}, SHIFT(356),
  [2477] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1111),
  [2479] = {.entry = {.count = 1, .reusable = true}}, SHIFT(357),
  [2481] = {.entry = {.count = 1, .reusable = true}}, SHIFT(44),
  [2483] = {.entry = {.count = 1, .reusable = true}}, SHIFT(569),
  [2485] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_field_declaration, 3, 0, 75),
  [2487] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_field_declaration, 3, 0, 75),
  [2489] = {.entry = {.count = 1, .reusable = true}}, SHIFT(250),
  [2491] = {.entry = {.count = 1, .reusable = true}}, SHIFT(591),
  [2493] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1119),
  [2495] = {.entry = {.count = 1, .reusable = true}}, SHIFT(529),
  [2497] = {.entry = {.count = 1, .reusable = true}}, SHIFT(36),
  [2499] = {.entry = {.count = 1, .reusable = true}}, SHIFT(410),
  [2501] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_import_spec_list, 3, 0, 0),
  [2503] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_import_spec_list, 3, 0, 0),
  [2505] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_package_clause, 2, 0, 2),
  [2507] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_package_clause, 2, 0, 2),
  [2509] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_import_spec_list, 4, 0, 0),
  [2511] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_import_spec_list, 4, 0, 0),
  [2513] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_import_spec_list_repeat1, 2, 0, 0),
  [2515] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_import_spec_list, 5, 0, 0),
  [2517] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_import_spec_list, 5, 0, 0),
  [2519] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_type_elem_repeat1, 2, 0, 0), SHIFT_REPEAT(718),
  [2522] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_declaration, 5, 0, 71),
  [2524] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_declaration, 5, 0, 71),
  [2526] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_method_elem, 3, 0, 79),
  [2528] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_method_elem, 3, 0, 79),
  [2530] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1034),
  [2532] = {.entry = {.count = 1, .reusable = true}}, SHIFT(723),
  [2534] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6),
  [2536] = {.entry = {.count = 1, .reusable = true}}, SHIFT(517),
  [2538] = {.entry = {.count = 1, .reusable = true}}, SHIFT(518),
  [2540] = {.entry = {.count = 1, .reusable = true}}, SHIFT(115),
  [2542] = {.entry = {.count = 1, .reusable = true}}, SHIFT(84),
  [2544] = {.entry = {.count = 1, .reusable = true}}, SHIFT(596),
  [2546] = {.entry = {.count = 1, .reusable = true}}, SHIFT(782),
  [2548] = {.entry = {.count = 1, .reusable = true}}, SHIFT(526),
  [2550] = {.entry = {.count = 1, .reusable = true}}, SHIFT(35),
  [2552] = {.entry = {.count = 1, .reusable = true}}, SHIFT(58),
  [2554] = {.entry = {.count = 1, .reusable = true}}, SHIFT(63),
  [2556] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_case, 4, 0, 41),
  [2558] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_expression_case, 4, 0, 7),
  [2560] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1110),
  [2562] = {.entry = {.count = 1, .reusable = true}}, SHIFT(615),
  [2564] = {.entry = {.count = 1, .reusable = true}}, SHIFT(847),
  [2566] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1112),
  [2568] = {.entry = {.count = 1, .reusable = true}}, SHIFT(644),
  [2570] = {.entry = {.count = 1, .reusable = true}}, SHIFT(261),
  [2572] = {.entry = {.count = 1, .reusable = true}}, SHIFT(547),
  [2574] = {.entry = {.count = 1, .reusable = true}}, SHIFT(833),
  [2576] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1297),
  [2578] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1297),
  [2580] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1153),
  [2582] = {.entry = {.count = 1, .reusable = true}}, SHIFT(834),
  [2584] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_case, 5, 0, 103),
  [2586] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1158),
  [2588] = {.entry = {.count = 1, .reusable = true}}, SHIFT(835),
  [2590] = {.entry = {.count = 1, .reusable = true}}, SHIFT(318),
  [2592] = {.entry = {.count = 1, .reusable = true}}, SHIFT(92),
  [2594] = {.entry = {.count = 1, .reusable = true}}, SHIFT(672),
  [2596] = {.entry = {.count = 1, .reusable = true}}, SHIFT(321),
  [2598] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_type_parameter_list_repeat1, 2, 0, 0), SHIFT_REPEAT(1288),
  [2601] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_type_parameter_list_repeat1, 2, 0, 0),
  [2603] = {.entry = {.count = 1, .reusable = true}}, SHIFT(96),
  [2605] = {.entry = {.count = 1, .reusable = true}}, SHIFT(41),
  [2607] = {.entry = {.count = 1, .reusable = true}}, SHIFT(673),
  [2609] = {.entry = {.count = 1, .reusable = true}}, SHIFT(66),
  [2611] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_type_arguments_repeat1, 2, 0, 0), SHIFT_REPEAT(661),
  [2614] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_type_arguments_repeat1, 2, 0, 0),
  [2616] = {.entry = {.count = 1, .reusable = true}}, SHIFT(600),
  [2618] = {.entry = {.count = 1, .reusable = true}}, SHIFT(40),
  [2620] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1277),
  [2622] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1277),
  [2624] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1246),
  [2626] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1246),
  [2628] = {.entry = {.count = 1, .reusable = true}}, SHIFT(379),
  [2630] = {.entry = {.count = 1, .reusable = true}}, SHIFT(130),
  [2632] = {.entry = {.count = 1, .reusable = true}}, SHIFT(678),
  [2634] = {.entry = {.count = 1, .reusable = true}}, SHIFT(382),
  [2636] = {.entry = {.count = 1, .reusable = true}}, SHIFT(109),
  [2638] = {.entry = {.count = 1, .reusable = true}}, SHIFT(45),
  [2640] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4),
  [2642] = {.entry = {.count = 1, .reusable = true}}, SHIFT(679),
  [2644] = {.entry = {.count = 1, .reusable = true}}, SHIFT(71),
  [2646] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_argument_list_repeat1, 2, 0, 0), SHIFT_REPEAT(99),
  [2649] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_literal_value_repeat1, 2, 0, 0),
  [2651] = {.entry = {.count = 1, .reusable = true}}, SHIFT(788),
  [2653] = {.entry = {.count = 1, .reusable = true}}, SHIFT(523),
  [2655] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_default_case, 3, 0, 0),
  [2657] = {.entry = {.count = 1, .reusable = true}}, SHIFT(568),
  [2659] = {.entry = {.count = 1, .reusable = true}}, SHIFT(117),
  [2661] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_communication_case, 4, 0, 88),
  [2663] = {.entry = {.count = 1, .reusable = true}}, SHIFT(685),
  [2665] = {.entry = {.count = 1, .reusable = true}}, SHIFT(571),
  [2667] = {.entry = {.count = 1, .reusable = true}}, SHIFT(843),
  [2669] = {.entry = {.count = 1, .reusable = true}}, SHIFT(121),
  [2671] = {.entry = {.count = 1, .reusable = true}}, SHIFT(104),
  [2673] = {.entry = {.count = 1, .reusable = true}}, SHIFT(46),
  [2675] = {.entry = {.count = 1, .reusable = true}}, SHIFT(686),
  [2677] = {.entry = {.count = 1, .reusable = true}}, SHIFT(74),
  [2679] = {.entry = {.count = 1, .reusable = true}}, SHIFT(625),
  [2681] = {.entry = {.count = 1, .reusable = true}}, SHIFT(393),
  [2683] = {.entry = {.count = 1, .reusable = true}}, SHIFT(102),
  [2685] = {.entry = {.count = 1, .reusable = true}}, SHIFT(619),
  [2687] = {.entry = {.count = 1, .reusable = true}}, SHIFT(804),
  [2689] = {.entry = {.count = 1, .reusable = true}}, SHIFT(38),
  [2691] = {.entry = {.count = 1, .reusable = true}}, SHIFT(776),
  [2693] = {.entry = {.count = 1, .reusable = true}}, SHIFT(510),
  [2695] = {.entry = {.count = 1, .reusable = true}}, SHIFT(648),
  [2697] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_literal_value_repeat1, 2, 0, 0), SHIFT_REPEAT(47),
  [2700] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1088),
  [2702] = {.entry = {.count = 1, .reusable = true}}, SHIFT(52),
  [2704] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1106),
  [2706] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_expression_list_repeat1, 2, 0, 0), SHIFT_REPEAT(170),
  [2709] = {.entry = {.count = 1, .reusable = true}}, SHIFT(469),
  [2711] = {.entry = {.count = 1, .reusable = true}}, SHIFT(129),
  [2713] = {.entry = {.count = 1, .reusable = true}}, SHIFT(610),
  [2715] = {.entry = {.count = 1, .reusable = true}}, SHIFT(924),
  [2717] = {.entry = {.count = 1, .reusable = true}}, SHIFT(651),
  [2719] = {.entry = {.count = 1, .reusable = true}}, SHIFT(412),
  [2721] = {.entry = {.count = 1, .reusable = true}}, SHIFT(256),
  [2723] = {.entry = {.count = 1, .reusable = true}}, SHIFT(97),
  [2725] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_expression_list_repeat1, 2, 0, 0), SHIFT_REPEAT(161),
  [2728] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1060),
  [2730] = {.entry = {.count = 1, .reusable = true}}, SHIFT(652),
  [2732] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1103),
  [2734] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__statement_list, 4, 0, 0),
  [2736] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1069),
  [2738] = {.entry = {.count = 1, .reusable = true}}, SHIFT(519),
  [2740] = {.entry = {.count = 1, .reusable = true}}, SHIFT(663),
  [2742] = {.entry = {.count = 1, .reusable = true}}, SHIFT(472),
  [2744] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_parameter_list_repeat1, 2, 0, 0),
  [2746] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_parameter_list_repeat1, 2, 0, 0), SHIFT_REPEAT(557),
  [2749] = {.entry = {.count = 1, .reusable = true}}, SHIFT(664),
  [2751] = {.entry = {.count = 1, .reusable = true}}, SHIFT(890),
  [2753] = {.entry = {.count = 1, .reusable = true}}, SHIFT(405),
  [2755] = {.entry = {.count = 1, .reusable = true}}, SHIFT(762),
  [2757] = {.entry = {.count = 1, .reusable = true}}, SHIFT(885),
  [2759] = {.entry = {.count = 1, .reusable = true}}, SHIFT(668),
  [2761] = {.entry = {.count = 1, .reusable = true}}, SHIFT(313),
  [2763] = {.entry = {.count = 1, .reusable = true}}, SHIFT(769),
  [2765] = {.entry = {.count = 1, .reusable = true}}, SHIFT(54),
  [2767] = {.entry = {.count = 1, .reusable = true}}, SHIFT(690),
  [2769] = {.entry = {.count = 1, .reusable = true}}, SHIFT(163),
  [2771] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_keyed_element, 3, 0, 0),
  [2773] = {.entry = {.count = 1, .reusable = true}}, SHIFT(555),
  [2775] = {.entry = {.count = 1, .reusable = true}}, SHIFT(695),
  [2777] = {.entry = {.count = 1, .reusable = true}}, SHIFT(458),
  [2779] = {.entry = {.count = 1, .reusable = true}}, SHIFT(766),
  [2781] = {.entry = {.count = 1, .reusable = true}}, SHIFT(655),
  [2783] = {.entry = {.count = 1, .reusable = true}}, SHIFT(889),
  [2785] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameter_declaration, 1, 0, 19),
  [2787] = {.entry = {.count = 1, .reusable = true}}, SHIFT(59),
  [2789] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_variadic_parameter_declaration, 2, 0, 41),
  [2791] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_variadic_argument, 2, 0, 0),
  [2793] = {.entry = {.count = 1, .reusable = true}}, SHIFT(231),
  [2795] = {.entry = {.count = 1, .reusable = true}}, SHIFT(774),
  [2797] = {.entry = {.count = 1, .reusable = true}}, SHIFT(269),
  [2799] = {.entry = {.count = 1, .reusable = true}}, SHIFT(730),
  [2801] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameter_declaration, 2, 0, 18),
  [2803] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_dot, 1, 0, 0),
  [2805] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_parameter_declaration, 3, 0, 94),
  [2807] = {.entry = {.count = 1, .reusable = true}}, SHIFT(643),
  [2809] = {.entry = {.count = 1, .reusable = true}}, SHIFT(656),
  [2811] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_variadic_parameter_declaration, 3, 0, 67),
  [2813] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameter_declaration, 3, 0, 39),
  [2815] = {.entry = {.count = 1, .reusable = true}}, SHIFT(164),
  [2817] = {.entry = {.count = 1, .reusable = true}}, SHIFT(705),
  [2819] = {.entry = {.count = 1, .reusable = true}}, SHIFT(374),
  [2821] = {.entry = {.count = 1, .reusable = true}}, SHIFT(772),
  [2823] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_parameter_declaration, 2, 0, 68),
  [2825] = {.entry = {.count = 1, .reusable = true}}, SHIFT(216),
  [2827] = {.entry = {.count = 1, .reusable = true}}, SHIFT(765),
  [2829] = {.entry = {.count = 1, .reusable = true}}, SHIFT(221),
  [2831] = {.entry = {.count = 1, .reusable = true}}, SHIFT(768),
  [2833] = {.entry = {.count = 1, .reusable = true}}, SHIFT(226),
  [2835] = {.entry = {.count = 1, .reusable = true}}, SHIFT(771),
  [2837] = {.entry = {.count = 1, .reusable = true}}, SHIFT(767),
  [2839] = {.entry = {.count = 1, .reusable = true}}, SHIFT(579),
  [2841] = {.entry = {.count = 1, .reusable = true}}, SHIFT(248),
  [2843] = {.entry = {.count = 1, .reusable = true}}, SHIFT(110),
  [2845] = {.entry = {.count = 1, .reusable = true}}, SHIFT(734),
  [2847] = {.entry = {.count = 1, .reusable = true}}, SHIFT(816),
  [2849] = {.entry = {.count = 1, .reusable = true}}, SHIFT(103),
  [2851] = {.entry = {.count = 1, .reusable = true}}, SHIFT(327),
  [2853] = {.entry = {.count = 1, .reusable = true}}, SHIFT(420),
  [2855] = {.entry = {.count = 1, .reusable = true}}, SHIFT(273),
  [2857] = {.entry = {.count = 1, .reusable = true}}, SHIFT(329),
  [2859] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1012),
  [2861] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1123),
  [2863] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__type_switch_header, 7, 0, 105),
  [2865] = {.entry = {.count = 1, .reusable = true}}, SHIFT(552),
  [2867] = {.entry = {.count = 1, .reusable = true}}, SHIFT(509),
  [2869] = {.entry = {.count = 1, .reusable = true}}, SHIFT(741),
  [2871] = {.entry = {.count = 1, .reusable = true}}, SHIFT(275),
  [2873] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1109),
  [2875] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_clause, 4, 0, 83),
  [2877] = {.entry = {.count = 1, .reusable = true}}, SHIFT(540),
  [2879] = {.entry = {.count = 1, .reusable = true}}, SHIFT(758),
  [2881] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__type_switch_header, 5, 0, 100),
  [2883] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_implicit_length_array_type, 4, 0, 47),
  [2885] = {.entry = {.count = 1, .reusable = true}}, SHIFT(459),
  [2887] = {.entry = {.count = 1, .reusable = true}}, SHIFT(361),
  [2889] = {.entry = {.count = 1, .reusable = true}}, SHIFT(418),
  [2891] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7),
  [2893] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1169),
  [2895] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_clause, 5, 0, 98),
  [2897] = {.entry = {.count = 1, .reusable = true}}, SHIFT(744),
  [2899] = {.entry = {.count = 1, .reusable = true}}, SHIFT(369),
  [2901] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__type_switch_header, 9, 0, 108),
  [2903] = {.entry = {.count = 1, .reusable = true}}, SHIFT(710),
  [2905] = {.entry = {.count = 1, .reusable = true}}, SHIFT(564),
  [2907] = {.entry = {.count = 1, .reusable = true}}, SHIFT(371),
  [2909] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_clause, 3, 0, 56),
  [2911] = {.entry = {.count = 1, .reusable = true}}, SHIFT(757),
  [2913] = {.entry = {.count = 1, .reusable = true}}, SHIFT(159),
  [2915] = {.entry = {.count = 1, .reusable = true}}, SHIFT(544),
  [2917] = {.entry = {.count = 1, .reusable = true}}, SHIFT(733),
  [2919] = {.entry = {.count = 1, .reusable = true}}, SHIFT(698),
  [2921] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1002),
  [2923] = {.entry = {.count = 1, .reusable = true}}, SHIFT(980),
  [2925] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8),
  [2927] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1374),
  [2929] = {.entry = {.count = 1, .reusable = true}}, SHIFT(402),
  [2931] = {.entry = {.count = 1, .reusable = true}}, SHIFT(781),
  [2933] = {.entry = {.count = 1, .reusable = true}}, SHIFT(696),
  [2935] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5),
  [2937] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_clause, 4, 0, 85),
  [2939] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__type_switch_header, 7, 0, 106),
  [2941] = {.entry = {.count = 1, .reusable = true}}, SHIFT(711),
  [2943] = {.entry = {.count = 1, .reusable = true}}, SHIFT(981),
  [2945] = {.entry = {.count = 1, .reusable = true}}, SHIFT(706),
  [2947] = {.entry = {.count = 1, .reusable = true}}, SHIFT(826),
  [2949] = {.entry = {.count = 1, .reusable = true}}, SHIFT(703),
  [2951] = {.entry = {.count = 1, .reusable = true}}, SHIFT(310),
  [2953] = {.entry = {.count = 1, .reusable = true}}, SHIFT(732),
  [2955] = {.entry = {.count = 1, .reusable = true}},  ACCEPT_INPUT(),
  [2957] = {.entry = {.count = 1, .reusable = true}}, SHIFT(805),
  [2959] = {.entry = {.count = 1, .reusable = true}}, SHIFT(53),
  [2961] = {.entry = {.count = 1, .reusable = true}}, SHIFT(477),
  [2963] = {.entry = {.count = 1, .reusable = true}}, SHIFT(719),
  [2965] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1332),
  [2967] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1344),
  [2969] = {.entry = {.count = 1, .reusable = true}}, SHIFT(802),
  [2971] = {.entry = {.count = 1, .reusable = true}}, SHIFT(759),
  [2973] = {.entry = {.count = 1, .reusable = true}}, SHIFT(107),
  [2975] = {.entry = {.count = 1, .reusable = true}}, SHIFT(763),
  [2977] = {.entry = {.count = 1, .reusable = true}}, SHIFT(162),
  [2979] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1354),
  [2981] = {.entry = {.count = 1, .reusable = true}}, SHIFT(577),
  [2983] = {.entry = {.count = 1, .reusable = true}}, SHIFT(770),
  [2985] = {.entry = {.count = 1, .reusable = true}}, SHIFT(773),
  [2987] = {.entry = {.count = 1, .reusable = true}}, SHIFT(982),
  [2989] = {.entry = {.count = 1, .reusable = true}}, SHIFT(856),
};

#ifdef __cplusplus
extern "C" {
#endif
#ifdef TREE_SITTER_HIDE_SYMBOLS
#define TS_PUBLIC
#elif defined(_WIN32)
#define TS_PUBLIC __declspec(dllexport)
#else
#define TS_PUBLIC __attribute__((visibility("default")))
#endif

TS_PUBLIC const TSLanguage *tree_sitter_go(void) {
  static const TSLanguage language = {
    .version = LANGUAGE_VERSION,
    .symbol_count = SYMBOL_COUNT,
    .alias_count = ALIAS_COUNT,
    .token_count = TOKEN_COUNT,
    .external_token_count = EXTERNAL_TOKEN_COUNT,
    .state_count = STATE_COUNT,
    .large_state_count = LARGE_STATE_COUNT,
    .production_id_count = PRODUCTION_ID_COUNT,
    .field_count = FIELD_COUNT,
    .max_alias_sequence_length = MAX_ALIAS_SEQUENCE_LENGTH,
    .parse_table = &ts_parse_table[0][0],
    .small_parse_table = ts_small_parse_table,
    .small_parse_table_map = ts_small_parse_table_map,
    .parse_actions = ts_parse_actions,
    .symbol_names = ts_symbol_names,
    .field_names = ts_field_names,
    .field_map_slices = ts_field_map_slices,
    .field_map_entries = ts_field_map_entries,
    .symbol_metadata = ts_symbol_metadata,
    .public_symbol_map = ts_symbol_map,
    .alias_map = ts_non_terminal_alias_map,
    .alias_sequences = &ts_alias_sequences[0][0],
    .lex_modes = ts_lex_modes,
    .lex_fn = ts_lex,
    .keyword_lex_fn = ts_lex_keywords,
    .keyword_capture_token = sym_identifier,
    .primary_state_ids = ts_primary_state_ids,
  };
  return &language;
}
#ifdef __cplusplus
}
#endif
